@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -31,6 +31,6 @@ namespace seqan3::align_cfg::detail
  * \note This configuration is only useful for debugging purposes as it can have a significant impact on the
  *       performance.
  */
-using debug = seqan3::detail::debug_mode<std::integral_constant<seqan3::detail::align_config_id,
-                                                                seqan3::detail::align_config_id::debug>>;
-}  // namespace seqan3::align_cfg::detail
+using debug = seqan3::detail::debug_mode<
+    std::integral_constant<seqan3::detail::align_config_id, seqan3::detail::align_config_id::debug>>;
+} // namespace seqan3::align_cfg::detail
