@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -44,19 +44,18 @@ public:
     /*!\name Constructors, destructor and assignment
      * \{
      */
-    constexpr min_score() noexcept = default; //!< Defaulted
-    constexpr min_score(min_score const &) noexcept = default; //!< Defaulted
-    constexpr min_score(min_score &&) noexcept = default; //!< Defaulted
+    constexpr min_score() noexcept = default;                              //!< Defaulted
+    constexpr min_score(min_score const &) noexcept = default;             //!< Defaulted
+    constexpr min_score(min_score &&) noexcept = default;                  //!< Defaulted
     constexpr min_score & operator=(min_score const &) noexcept = default; //!< Defaulted
-    constexpr min_score & operator=(min_score &&) noexcept = default; //!< Defaulted
-    ~min_score() noexcept = default; //!< Defaulted
+    constexpr min_score & operator=(min_score &&) noexcept = default;      //!< Defaulted
+    ~min_score() noexcept = default;                                       //!< Defaulted
 
     /*!\brief Initialises the minimal score.
      *
      * \param score \copybrief score
      */
-    constexpr min_score(const int32_t score) :
-        score{score}
+    constexpr min_score(const int32_t score) : score{score}
     {}
     //!\}
 
