@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -14,10 +14,9 @@
 
 #include <type_traits>
 
-
 #include <seqan3/alignment/configuration/detail.hpp>
 #include <seqan3/core/configuration/pipeable_config_element.hpp>
-#include <seqan3/core/semiregular_box.hpp>
+#include <seqan3/core/detail/copyable_wrapper.hpp>
 
 namespace seqan3::align_cfg
 {
@@ -26,7 +25,7 @@ namespace seqan3::align_cfg
  * \ingroup alignment_configuration
  *
  * \tparam callback_t The type of the callback; must model std::invocable with the generated seqan3::alignment_result
- *                    and std::move_constructible.
+ *                    and std::copy_constructible.
  *
  * \details
  *
@@ -39,7 +38,7 @@ namespace seqan3::align_cfg
  * function, you need to make sure that the referenced function object outlives the call to the alignment algorithm.
  *
  * \if DEV
- * The given callback is wrapped inside a seqan3::semiregular_box wrapper type. This allows to also
+ * The given callback is wrapped inside a seqan3::detail::copyable_wrapper wrapper type. This allows to also
  * use lambdas with a capture block, which otherwise are not std::copy_assignable and therefore invalidate the
  * requirements for the configuration element (must model std::semiregular).
  * \endif
@@ -50,27 +49,27 @@ namespace seqan3::align_cfg
  *
  * \include test/snippet/alignment/configuration/align_cfg_on_result.cpp
  */
-template <std::move_constructible callback_t>
+template <std::copy_constructible callback_t>
 class on_result : private seqan3::pipeable_config_element
 {
 public:
     //!\brief The stored callable which will be invoked with the alignment result.
-    seqan3::semiregular_box_t<callback_t> callback{}; // Allow lambdas with capture block which are not copy_assignable.
+    seqan3::detail::copyable_wrapper_t<callback_t> callback{}; // Allows lambdas with capture blocks.
 
     /*!\name Constructors, destructor and assignment
      * \{
      */
-    constexpr on_result() = default; //!< Defaulted.
-    constexpr on_result(on_result const &) = default; //!< Defaulted.
-    constexpr on_result(on_result &&) = default; //!< Defaulted.
+    constexpr on_result() = default;                              //!< Defaulted.
+    constexpr on_result(on_result const &) = default;             //!< Defaulted.
+    constexpr on_result(on_result &&) = default;                  //!< Defaulted.
     constexpr on_result & operator=(on_result const &) = default; //!< Defaulted.
-    constexpr on_result & operator=(on_result &&) = default; //!< Defaulted.
-    ~on_result() = default; //!< Defaulted.
+    constexpr on_result & operator=(on_result &&) = default;      //!< Defaulted.
+    ~on_result() = default;                                       //!< Defaulted.
 
     /*!\brief Constructs the configuration element with the given user callback.
      * \param[in] callback The callback to invoke for a computed seqan3::alignment_result.
      */
-    constexpr explicit on_result(callback_t callback) : callback{std::forward<callback_t>(callback)}
+    constexpr explicit on_result(callback_t && callback) : callback{std::forward<callback_t>(callback)}
     {}
     //!\}
 
@@ -83,7 +82,7 @@ public:
  * \{
  */
 //!\brief Deduces the callback type from a forwarding constructor argument.
-template <std::move_constructible callback_t>
+template <std::copy_constructible callback_t>
 on_result(callback_t &&) -> on_result<std::decay_t<callback_t>>;
 //!\}
-}  // namespace seqan3::align_cfg
+} // namespace seqan3::align_cfg
