@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -12,7 +12,7 @@
 
 #pragma once
 
-#include <seqan3/std/type_traits>
+#include <type_traits>
 
 #include <seqan3/alignment/configuration/detail.hpp>
 #include <seqan3/alignment/pairwise/alignment_result.hpp>
@@ -40,9 +40,7 @@ namespace seqan3::align_cfg::detail
  *       public use.
  */
 template <typename alignment_result_t>
-//!\cond
     requires seqan3::detail::is_type_specialisation_of_v<alignment_result_t, seqan3::alignment_result>
-//!\endcond
 class result_type : private pipeable_config_element
 {
 public:
@@ -52,12 +50,12 @@ public:
     /*!\name Constructor, destructor and assignment
      * \{
      */
-    constexpr result_type() = default; //!< Defaulted.
-    constexpr result_type(result_type const &) = default; //!< Defaulted.
-    constexpr result_type(result_type &&) = default; //!< Defaulted.
+    constexpr result_type() = default;                                //!< Defaulted.
+    constexpr result_type(result_type const &) = default;             //!< Defaulted.
+    constexpr result_type(result_type &&) = default;                  //!< Defaulted.
     constexpr result_type & operator=(result_type const &) = default; //!< Defaulted.
-    constexpr result_type & operator=(result_type &&) = default; //!< Defaulted.
-    ~result_type() = default; //!< Defaulted.
+    constexpr result_type & operator=(result_type &&) = default;      //!< Defaulted.
+    ~result_type() = default;                                         //!< Defaulted.
 
     //!\}
 
