@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -12,9 +12,10 @@
 
 #pragma once
 
-#include <seqan3/std/iterator>
-#include <seqan3/std/ranges>
-#include <seqan3/std/span>
+#include <cassert>
+#include <iterator>
+#include <ranges>
+#include <span>
 
 #include <seqan3/core/range/type_traits.hpp>
 #include <seqan3/utility/type_traits/basic.hpp>
@@ -98,7 +99,6 @@ private:
         class iterator_type
         {
         public:
-
             /*!\name Associated types
              * \{
              */
@@ -117,12 +117,12 @@ private:
             /*!\name Constructors, destructor and assignment
              * \{
              */
-            constexpr iterator_type() = default; //!< Defaulted.
-            constexpr iterator_type(iterator_type const &) = default; //!< Defaulted.
-            constexpr iterator_type(iterator_type &&) = default; //!< Defaulted.
+            constexpr iterator_type() = default;                                  //!< Defaulted.
+            constexpr iterator_type(iterator_type const &) = default;             //!< Defaulted.
+            constexpr iterator_type(iterator_type &&) = default;                  //!< Defaulted.
             constexpr iterator_type & operator=(iterator_type const &) = default; //!< Defaulted.
-            constexpr iterator_type & operator=(iterator_type &&) = default; //!< Defaulted.
-            ~iterator_type() = default; //!< Defaulted.
+            constexpr iterator_type & operator=(iterator_type &&) = default;      //!< Defaulted.
+            ~iterator_type() = default;                                           //!< Defaulted.
 
             /*!\brief Construction from the underlying alignment-column.
              * \param host The alignment-column for this iterator.
@@ -223,12 +223,12 @@ private:
         /*!\name Constructors, destructor and assignment
          * \{
          */
-        constexpr alignment_column_type() = default; //!< Defaulted.
-        constexpr alignment_column_type(alignment_column_type const &) = default; //!< Defaulted.
-        constexpr alignment_column_type(alignment_column_type &&) = default; //!< Defaulted.
+        constexpr alignment_column_type() = default;                                          //!< Defaulted.
+        constexpr alignment_column_type(alignment_column_type const &) = default;             //!< Defaulted.
+        constexpr alignment_column_type(alignment_column_type &&) = default;                  //!< Defaulted.
         constexpr alignment_column_type & operator=(alignment_column_type const &) = default; //!< Defaulted.
-        constexpr alignment_column_type & operator=(alignment_column_type &&) = default; //!< Defaulted.
-        ~alignment_column_type() = default; //!< Defaulted.
+        constexpr alignment_column_type & operator=(alignment_column_type &&) = default;      //!< Defaulted.
+        ~alignment_column_type() = default;                                                   //!< Defaulted.
 
         /*!\brief Constructs from the derived type.
          * \param[in] me  An instance of the derived type.
@@ -238,9 +238,7 @@ private:
          *
          * This constructor is called by the derived type when invoking the function `initialise_column`.
          */
-        constexpr alignment_column_type(derived_t & me, view_type ref) :
-            ref{std::move(ref)},
-            me_ptr{&me}
+        constexpr alignment_column_type(derived_t & me, view_type ref) : ref{std::move(ref)}, me_ptr{&me}
         {}
         //!\}
 
@@ -314,19 +312,17 @@ private:
         /*!\name Constructors, destructor and assignment
          * \{
          */
-        constexpr iterator_type() = default; //!< Defaulted.
-        constexpr iterator_type(iterator_type const &) = default; //!< Defaulted.
-        constexpr iterator_type(iterator_type &&) = default; //!< Defaulted.
+        constexpr iterator_type() = default;                                  //!< Defaulted.
+        constexpr iterator_type(iterator_type const &) = default;             //!< Defaulted.
+        constexpr iterator_type(iterator_type &&) = default;                  //!< Defaulted.
         constexpr iterator_type & operator=(iterator_type const &) = default; //!< Defaulted.
-        constexpr iterator_type & operator=(iterator_type &&) = default; //!< Defaulted.
-        ~iterator_type() = default; //!< Defaulted.
+        constexpr iterator_type & operator=(iterator_type &&) = default;      //!< Defaulted.
+        ~iterator_type() = default;                                           //!< Defaulted.
 
         /*!\brief Construction from an instance of the derived type.
          * \param me     An instance of the derived type.
          */
-        explicit constexpr iterator_type(derived_t & me) :
-            me_ptr{&me},
-            column_index{0}
+        explicit constexpr iterator_type(derived_t & me) : me_ptr{&me}, column_index{0}
         {}
         //!\}
 
@@ -451,7 +447,7 @@ private:
      * stores a column view as defined by the derived class using the
      * seqan3::detail::alignment_matrix_column_major_range_base::column_data_view_type type definition.
      */
-    SEQAN3_DOXYGEN_ONLY(alignment_column_type initialise_column(size_t column_index) {})
+    SEQAN3_DOXYGEN_ONLY(alignment_column_type initialise_column(size_t column_index){})
 
     /*!\brief Allows additional initialisations when calling begin on an alignment-column.
      * \tparam iter_t The iterator type of the host iterator.
