@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -45,12 +45,12 @@ public:
     /*!\name Constructors, destructor and assignment
      * \{
      */
-    constexpr trace_iterator_banded() = default; //!< Defaulted.
-    constexpr trace_iterator_banded(trace_iterator_banded const &) = default; //!< Defaulted.
-    constexpr trace_iterator_banded(trace_iterator_banded &&) = default; //!< Defaulted.
+    constexpr trace_iterator_banded() = default;                                          //!< Defaulted.
+    constexpr trace_iterator_banded(trace_iterator_banded const &) = default;             //!< Defaulted.
+    constexpr trace_iterator_banded(trace_iterator_banded &&) = default;                  //!< Defaulted.
     constexpr trace_iterator_banded & operator=(trace_iterator_banded const &) = default; //!< Defaulted.
-    constexpr trace_iterator_banded & operator=(trace_iterator_banded &&) = default; //!< Defaulted.
-    ~trace_iterator_banded() = default; //!< Defaulted.
+    constexpr trace_iterator_banded & operator=(trace_iterator_banded &&) = default;      //!< Defaulted.
+    ~trace_iterator_banded() = default;                                                   //!< Defaulted.
 
     /*!\brief Constructs from the underlying trace matrix iterator indicating the start of the trace path.
      * \param[in] matrix_iter The underlying matrix iterator.
@@ -58,8 +58,8 @@ public:
      *                         banded matrix.
      */
     template <typename index_t>
-    constexpr trace_iterator_banded(matrix_iter_t const matrix_iter, column_index_type<index_t> const & pivot_column)
-        noexcept :
+    constexpr trace_iterator_banded(matrix_iter_t const matrix_iter,
+                                    column_index_type<index_t> const & pivot_column) noexcept :
         base_t{matrix_iter},
         pivot_column{static_cast<size_t>(pivot_column.get())}
     {}
@@ -74,9 +74,7 @@ public:
      * Allows the conversion of non-const to const iterator.
      */
     template <two_dimensional_matrix_iterator other_matrix_iter_t>
-    //!\cond
         requires std::constructible_from<matrix_iter_t, other_matrix_iter_t>
-    //!\endcond
     constexpr trace_iterator_banded(trace_iterator_banded<other_matrix_iter_t> const other) noexcept : base_t{other}
     {}
     //!\}
