@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -12,9 +12,9 @@
 
 #pragma once
 
-#include <seqan3/std/algorithm>
+#include <algorithm>
 #include <memory>
-#include <seqan3/std/ranges>
+#include <ranges>
 #include <vector>
 
 #include <seqan3/alignment/matrix/detail/matrix_coordinate.hpp>
@@ -64,7 +64,6 @@ template <typename value_t,
 class two_dimensional_matrix
 {
 private:
-
     /*!\name Auxiliary types
      * \{
      */
@@ -76,37 +75,37 @@ private:
     class basic_iterator;
 
 public:
-
     /*!\name Associated types
      * \{
      */
-    using value_type = typename storage_type::value_type;  //!< The value type.
-    using reference = typename storage_type::reference;  //!< The reference type.
+    using value_type = typename storage_type::value_type;           //!< The value type.
+    using reference = typename storage_type::reference;             //!< The reference type.
     using const_reference = typename storage_type::const_reference; //!< The const reference type.
-    using pointer = typename storage_type::pointer;  //!< The pointer type.
-    using const_pointer = typename storage_type::const_pointer;  //!< The pointer type.
+    using pointer = typename storage_type::pointer;                 //!< The pointer type.
+    using const_pointer = typename storage_type::const_pointer;     //!< The pointer type.
     using difference_type = typename storage_type::difference_type; //!< The difference type.
-    using size_type = typename storage_type::size_type;  //!< The difference type.
-    using iterator = basic_iterator<false>; //!< The iterator type.
-    using const_iterator = basic_iterator<true>; //!< The const iterator type.
+    using size_type = typename storage_type::size_type;             //!< The difference type.
+    using iterator = basic_iterator<false>;                         //!< The iterator type.
+    using const_iterator = basic_iterator<true>;                    //!< The const iterator type.
     //!\}
 
     /*!\name Constructors, destructor and assignment
      * \{
      */
-    two_dimensional_matrix() = default; //!< Defaulted
-    two_dimensional_matrix(two_dimensional_matrix const &) = default; //!< Defaulted
-    two_dimensional_matrix(two_dimensional_matrix &&) = default; //!< Defaulted
+    two_dimensional_matrix() = default;                                           //!< Defaulted
+    two_dimensional_matrix(two_dimensional_matrix const &) = default;             //!< Defaulted
+    two_dimensional_matrix(two_dimensional_matrix &&) = default;                  //!< Defaulted
     two_dimensional_matrix & operator=(two_dimensional_matrix const &) = default; //!< Defaulted
-    two_dimensional_matrix & operator=(two_dimensional_matrix &&) = default; //!< Defaulted
-    ~two_dimensional_matrix() = default; //!< Defaulted
+    two_dimensional_matrix & operator=(two_dimensional_matrix &&) = default;      //!< Defaulted
+    ~two_dimensional_matrix() = default;                                          //!< Defaulted
 
     /*!\brief Constructs the matrix by the given dimensions.
      * \param row_dim The row dimension (number of rows).
      * \param col_dim The column dimension (number of columns).
      */
     two_dimensional_matrix(number_rows const row_dim, number_cols const col_dim) :
-        row_dim{row_dim.get()}, col_dim{col_dim.get()}
+        row_dim{row_dim.get()},
+        col_dim{col_dim.get()}
     {
         storage.resize(row_dim.get() * col_dim.get());
     }
@@ -118,14 +117,13 @@ public:
      * \param[in] entries A range used to fill the underlying matrix.
      */
     template <std::ranges::forward_range entries_t>
-    //!\cond
         requires (std::convertible_to<std::ranges::range_value_t<entries_t>, value_type>)
-    //!\endcond
     two_dimensional_matrix(number_rows const row_dim, number_cols const col_dim, entries_t entries) :
         row_dim{row_dim.get()},
         col_dim{col_dim.get()}
     {
-        static_assert(std::move_constructible<std::ranges::range_value_t<entries_t>>, "The value type must be moveable.");
+        static_assert(std::move_constructible<std::ranges::range_value_t<entries_t>>,
+                      "The value type must be moveable.");
 
         assert(static_cast<size_t>(std::ranges::distance(entries)) == (row_dim.get() * col_dim.get()));
         storage.resize(row_dim.get() * col_dim.get());
@@ -167,12 +165,9 @@ public:
      * It only changes the matrix major order, i.e. data stored row wise is now stored column wise and vice versa.
      */
     template <typename other_value_t, typename other_allocator_t, matrix_major_order other_order>
-    //!\cond
         requires std::assignable_from<other_value_t &, value_t &>
-    //!\endcond
-    explicit constexpr two_dimensional_matrix(two_dimensional_matrix<other_value_t,
-                                                                     other_allocator_t,
-                                                                     other_order> const & matrix) :
+    explicit constexpr two_dimensional_matrix(
+        two_dimensional_matrix<other_value_t, other_allocator_t, other_order> const & matrix) :
         two_dimensional_matrix{number_rows{matrix.rows()}, number_cols{matrix.cols()}}
     {
         for (size_t i = 0; i < cols(); ++i)
@@ -194,8 +189,9 @@ public:
         assert(coordinate.col < cols());
         assert(coordinate.row < rows());
 
-        return *(begin() + matrix_offset{row_index_type{static_cast<std::ptrdiff_t>(coordinate.row)},
-                                         column_index_type{static_cast<std::ptrdiff_t>(coordinate.col)}});
+        return *(begin()
+                 + matrix_offset{row_index_type{static_cast<std::ptrdiff_t>(coordinate.row)},
+                                 column_index_type{static_cast<std::ptrdiff_t>(coordinate.col)}});
     }
 
     //!\copydoc operator[]
@@ -204,8 +200,9 @@ public:
         assert(coordinate.col < cols());
         assert(coordinate.row < rows());
 
-        return *(begin() + matrix_offset{row_index_type{static_cast<std::ptrdiff_t>(coordinate.row)},
-                                         column_index_type{static_cast<std::ptrdiff_t>(coordinate.col)}});
+        return *(begin()
+                 + matrix_offset{row_index_type{static_cast<std::ptrdiff_t>(coordinate.row)},
+                                 column_index_type{static_cast<std::ptrdiff_t>(coordinate.col)}});
     }
 
     //!\copydoc seqan3::detail::matrix::at
@@ -307,10 +304,9 @@ public:
     //!\}
 
 private:
-
     storage_type storage; //!< The matrix as a one-dimensional (flattened) vector of entries.
-    size_type    row_dim; //!< \copydoc seqan3::detail::matrix::rows
-    size_type    col_dim; //!< \copydoc seqan3::detail::matrix::cols
+    size_type row_dim;    //!< \copydoc seqan3::detail::matrix::rows
+    size_type col_dim;    //!< \copydoc seqan3::detail::matrix::cols
 };
 
 /*!\brief A two-dimensional matrix iterator.
@@ -335,9 +331,7 @@ private:
 
     //!\brief Befriend the base crtp class.
     template <typename derived_t, matrix_major_order other_order>
-    //!\cond
-        requires is_type_specialisation_of_v<derived_t, basic_iterator> && (other_order == order)
-    //!\endcond
+        requires is_value_specialisation_of_v<derived_t, basic_iterator> && (other_order == order)
     friend class two_dimensional_matrix_iterator_base;
 
     //!\brief Befriend the corresponding const iterator.
@@ -348,7 +342,6 @@ private:
     using storage_iterator = detail::maybe_const_iterator_t<const_range, storage_type>;
 
 public:
-
     /*!\name Associated types
     * \{
     */
@@ -367,29 +360,24 @@ public:
     /*!\name Constructors, destructor and assignment
     * \{
     */
-    constexpr basic_iterator() = default; //!< Defaulted.
-    constexpr basic_iterator(basic_iterator const &) = default; //!< Defaulted.
-    constexpr basic_iterator(basic_iterator &&) = default; //!< Defaulted.
+    constexpr basic_iterator() = default;                                   //!< Defaulted.
+    constexpr basic_iterator(basic_iterator const &) = default;             //!< Defaulted.
+    constexpr basic_iterator(basic_iterator &&) = default;                  //!< Defaulted.
     constexpr basic_iterator & operator=(basic_iterator const &) = default; //!< Defaulted.
-    constexpr basic_iterator & operator=(basic_iterator &&) = default; //!< Defaulted.
-    ~basic_iterator() = default; //!< Defaulted.
+    constexpr basic_iterator & operator=(basic_iterator &&) = default;      //!< Defaulted.
+    ~basic_iterator() = default;                                            //!< Defaulted.
 
     /*!\brief Construction from the underlying matrix and the iterator over actual storage.
     * \param[in] matrix The underlying matrix to access the corresponding dimensions.
     * \param[in] iter   The underlying iterator over the actual storage; must model std::random_access_iterator.
     */
-    constexpr basic_iterator(parent_t & matrix, storage_iterator iter) :
-        matrix_ptr{&matrix},
-        host_iter{iter}
+    constexpr basic_iterator(parent_t & matrix, storage_iterator iter) : matrix_ptr{&matrix}, host_iter{iter}
     {}
 
     //!\brief Construction of cons-iterator from non-const-iterator.
     constexpr basic_iterator(basic_iterator<!const_range> const & other) noexcept
-    //!\cond
         requires const_range
-    //!\endcond
-        : matrix_ptr{other.matrix_ptr},
-          host_iter{other.host_iter}
+    : matrix_ptr{other.matrix_ptr}, host_iter{other.host_iter}
     {}
     //!\}
 
@@ -427,9 +415,8 @@ public:
     }
 
 private:
-
     parent_t * matrix_ptr{nullptr}; //!< Points to the associated matrix.
-    storage_iterator host_iter{}; //!< The underlying storage iterator.
+    storage_iterator host_iter{};   //!< The underlying storage iterator.
 };
 
 } // namespace seqan3::detail
