@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -24,11 +24,7 @@ namespace seqan3::detail
 
 // forward declaration for friend declaration in alignment_result.
 template <typename configuration_t>
-#if !SEQAN3_WORKAROUND_GCC_93467
-//!\cond
     requires is_type_specialisation_of_v<configuration_t, configuration>
-//!\endcond
-#endif // !SEQAN3_WORKAROUND_GCC_93467
 class policy_alignment_result_builder;
 
 /*!\brief A struct that contains the actual alignment result data.
@@ -76,9 +72,8 @@ struct alignment_result_value_type
  * \brief Type deduction for the different combinations of result types.
  * \{
  */
- //! \brief Type deduction for an empty object. It will always fail the compilation, if any field is accessed.
-alignment_result_value_type()
-    -> alignment_result_value_type<std::nullopt_t *, std::nullopt_t *, std::nullopt_t *>;
+//! \brief Type deduction for an empty object. It will always fail the compilation, if any field is accessed.
+alignment_result_value_type()->alignment_result_value_type<std::nullopt_t *, std::nullopt_t *, std::nullopt_t *>;
 
 //! \brief Type deduction for id and score only.
 template <typename sequence1_id_t, typename sequence2_id_t, typename score_t>
@@ -148,9 +143,7 @@ namespace seqan3
  * \endif
  */
 template <typename alignment_result_value_t>
-//!\cond
     requires detail::is_type_specialisation_of_v<alignment_result_value_t, detail::alignment_result_value_type>
-//!\endcond
 class alignment_result
 {
 private:
@@ -177,11 +170,7 @@ private:
 
     //!\brief Befriend alignment result builder.
     template <typename configuration_t>
-    #if !SEQAN3_WORKAROUND_GCC_93467
-    //!\cond
         requires detail::is_type_specialisation_of_v<configuration_t, configuration>
-    //!\endcond
-    #endif // !SEQAN3_WORKAROUND_GCC_93467
     friend class detail::policy_alignment_result_builder;
 
 public:
@@ -335,8 +324,9 @@ public:
      */
     constexpr auto const & score_matrix() const noexcept
     {
-        static_assert(!std::is_same_v<decltype(data.score_debug_matrix), std::nullopt_t *>,
-                      "Trying to access the score matrix, although it was not requested in the alignment configuration.");
+        static_assert(
+            !std::is_same_v<decltype(data.score_debug_matrix), std::nullopt_t *>,
+            "Trying to access the score matrix, although it was not requested in the alignment configuration.");
         return data.score_debug_matrix;
     }
 
@@ -353,8 +343,9 @@ public:
      */
     constexpr auto const & trace_matrix() const noexcept
     {
-        static_assert(!std::is_same_v<decltype(data.trace_debug_matrix), std::nullopt_t *>,
-                      "Trying to access the trace matrix, although it was not requested in the alignment configuration.");
+        static_assert(
+            !std::is_same_v<decltype(data.trace_debug_matrix), std::nullopt_t *>,
+            "Trying to access the trace matrix, although it was not requested in the alignment configuration.");
         return data.trace_debug_matrix;
     }
     //!\endcond
@@ -394,9 +385,7 @@ namespace seqan3
  * \relates seqan3::debug_stream_type
  */
 template <typename char_t, typename alignment_result_t>
-//!\cond
     requires detail::is_type_specialisation_of_v<std::remove_cvref_t<alignment_result_t>, alignment_result>
-//!\endcond
 inline debug_stream_type<char_t> & operator<<(debug_stream_type<char_t> & stream, alignment_result_t && result)
 {
     using disabled_t = std::nullopt_t *;
@@ -406,14 +395,14 @@ inline debug_stream_type<char_t> & operator<<(debug_stream_type<char_t> & stream
     constexpr bool has_sequence1_id = !std::is_same_v<decltype(std::declval<result_data_t>().sequence1_id), disabled_t>;
     constexpr bool has_sequence2_id = !std::is_same_v<decltype(std::declval<result_data_t>().sequence2_id), disabled_t>;
     constexpr bool has_score = !std::is_same_v<decltype(std::declval<result_data_t>().score), disabled_t>;
-    constexpr bool has_end_positions = !std::is_same_v<decltype(std::declval<result_data_t>().end_positions),
-                                                       disabled_t>;
-    constexpr bool has_begin_positions = !std::is_same_v<decltype(std::declval<result_data_t>().begin_positions),
-                                                         disabled_t>;
+    constexpr bool has_end_positions =
+        !std::is_same_v<decltype(std::declval<result_data_t>().end_positions), disabled_t>;
+    constexpr bool has_begin_positions =
+        !std::is_same_v<decltype(std::declval<result_data_t>().begin_positions), disabled_t>;
     constexpr bool has_alignment = !std::is_same_v<decltype(std::declval<result_data_t>().alignment), disabled_t>;
 
     bool prepend_comma = false;
-    auto append_to_stream = [&] (auto && ...args)
+    auto append_to_stream = [&](auto &&... args)
     {
         ((stream << (prepend_comma ? std::string{", "} : std::string{})) << ... << std::forward<decltype(args)>(args));
         prepend_comma = true;
