@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -12,7 +12,7 @@
 
 #pragma once
 
-#include <seqan3/std/ranges>
+#include <ranges>
 #include <tuple>
 
 #include <seqan3/alphabet/concept.hpp>
@@ -35,15 +35,14 @@ namespace seqan3::detail
  */
 //!\cond
 template <typename t>
-SEQAN3_CONCEPT sequence_pair = requires ()
-{
-    requires tuple_like<t>;
-    requires std::tuple_size_v<t> == 2;
-    requires std::ranges::forward_range<std::tuple_element_t<0, t>>;
-    requires std::ranges::forward_range<std::tuple_element_t<1, t>>;
-    requires semialphabet<std::ranges::range_value_t<std::tuple_element_t<0, t>>>;
-    requires semialphabet<std::ranges::range_value_t<std::tuple_element_t<1, t>>>;
-};
+concept sequence_pair = requires () {
+                            requires tuple_like<t>;
+                            requires std::tuple_size_v<t> == 2;
+                            requires std::ranges::forward_range<std::tuple_element_t<0, t>>;
+                            requires std::ranges::forward_range<std::tuple_element_t<1, t>>;
+                            requires semialphabet<std::ranges::range_value_t<std::tuple_element_t<0, t>>>;
+                            requires semialphabet<std::ranges::range_value_t<std::tuple_element_t<1, t>>>;
+                        };
 //!\endcond
 
 /*!\interface seqan3::detail::sequence_pair_range <>
@@ -59,7 +58,7 @@ SEQAN3_CONCEPT sequence_pair = requires ()
  */
 //!\cond
 template <typename t>
-SEQAN3_CONCEPT sequence_pair_range = std::ranges::forward_range<t> && sequence_pair<std::ranges::range_value_t<t>>;
+concept sequence_pair_range = std::ranges::forward_range<t> && sequence_pair<std::ranges::range_value_t<t>>;
 //!\endcond
 
 /*!\interface seqan3::detail::indexed_sequence_pair_range <>
@@ -81,14 +80,13 @@ SEQAN3_CONCEPT sequence_pair_range = std::ranges::forward_range<t> && sequence_p
  */
 //!\cond
 template <typename t>
-SEQAN3_CONCEPT indexed_sequence_pair_range = std::ranges::forward_range<t> &&
-                                             requires (std::ranges::range_value_t<t> value)
-{
-    requires tuple_like<decltype(value)>;
-    requires std::tuple_size_v<decltype(value)> == 2;
-    requires sequence_pair<std::tuple_element_t<0, decltype(value)>>;
-    requires std::copy_constructible<std::tuple_element_t<1, decltype(value)>>;
-};
+concept indexed_sequence_pair_range =
+    std::ranges::forward_range<t> && requires (std::ranges::range_value_t<t> value) {
+                                         requires tuple_like<decltype(value)>;
+                                         requires std::tuple_size_v<decltype(value)> == 2;
+                                         requires sequence_pair<std::tuple_element_t<0, decltype(value)>>;
+                                         requires std::copy_constructible<std::tuple_element_t<1, decltype(value)>>;
+                                     };
 //!\endcond
 
 /*!\interface seqan3::detail::align_pairwise_single_input <>
@@ -106,11 +104,10 @@ SEQAN3_CONCEPT indexed_sequence_pair_range = std::ranges::forward_range<t> &&
  */
 //!\cond
 template <typename t>
-SEQAN3_CONCEPT align_pairwise_single_input =
-    sequence_pair<std::remove_reference_t<t>> &&
-    std::is_lvalue_reference_v<t> ||
-    (std::ranges::viewable_range<std::tuple_element_t<0, std::remove_reference_t<t>>> &&
-     std::ranges::viewable_range<std::tuple_element_t<1, std::remove_reference_t<t>>>);
+concept align_pairwise_single_input =
+    sequence_pair<std::remove_reference_t<t>> && std::is_lvalue_reference_v<t>
+    || (std::ranges::viewable_range<std::tuple_element_t<0, std::remove_reference_t<t>>>
+        && std::ranges::viewable_range<std::tuple_element_t<1, std::remove_reference_t<t>>>);
 //!\endcond
 
 /*!\interface seqan3::detail::align_pairwise_range_input <>
@@ -132,10 +129,9 @@ SEQAN3_CONCEPT align_pairwise_single_input =
  */
 //!\cond
 template <typename t>
-SEQAN3_CONCEPT align_pairwise_range_input =
-    std::ranges::forward_range<t> &&
-    sequence_pair<std::ranges::range_value_t<t>> &&
-    ((std::ranges::viewable_range<t> && std::is_lvalue_reference_v<std::ranges::range_reference_t<t>>) ||
-     align_pairwise_single_input<std::remove_reference_t<std::ranges::range_reference_t<t>>>);
+concept align_pairwise_range_input =
+    std::ranges::forward_range<t> && sequence_pair<std::ranges::range_value_t<t>>
+    && ((std::ranges::viewable_range<t> && std::is_lvalue_reference_v<std::ranges::range_reference_t<t>>)
+        || align_pairwise_single_input<std::remove_reference_t<std::ranges::range_reference_t<t>>>);
 //!\endcond
-}  // namespace seqan3::detail
+} // namespace seqan3::detail
