@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -68,12 +68,12 @@ protected:
     /*!\name Constructors, destructor and assignment
      * \{
      */
-    policy_affine_gap_recursion() = default; //!< Defaulted.
-    policy_affine_gap_recursion(policy_affine_gap_recursion const &) = default; //!< Defaulted.
-    policy_affine_gap_recursion(policy_affine_gap_recursion &&) = default; //!< Defaulted.
+    policy_affine_gap_recursion() = default;                                                //!< Defaulted.
+    policy_affine_gap_recursion(policy_affine_gap_recursion const &) = default;             //!< Defaulted.
+    policy_affine_gap_recursion(policy_affine_gap_recursion &&) = default;                  //!< Defaulted.
     policy_affine_gap_recursion & operator=(policy_affine_gap_recursion const &) = default; //!< Defaulted.
-    policy_affine_gap_recursion & operator=(policy_affine_gap_recursion &&) = default; //!< Defaulted.
-    ~policy_affine_gap_recursion() = default; //!< Defaulted.
+    policy_affine_gap_recursion & operator=(policy_affine_gap_recursion &&) = default;      //!< Defaulted.
+    ~policy_affine_gap_recursion() = default;                                               //!< Defaulted.
 
     /*!\brief Construction and initialisation using the alignment configuration.
      * \param[in] config The alignment configuration.
@@ -87,8 +87,8 @@ protected:
     explicit policy_affine_gap_recursion(alignment_configuration_t const & config)
     {
         // Get the gap scheme from the config or choose -1 and -10 as default.
-        auto const & selected_gap_scheme = config.get_or(align_cfg::gap_cost_affine{align_cfg::open_score{-10},
-                                                                                    align_cfg::extension_score{-1}});
+        auto const & selected_gap_scheme =
+            config.get_or(align_cfg::gap_cost_affine{align_cfg::open_score{-10}, align_cfg::extension_score{-1}});
 
         gap_extension_score = maybe_convert_to_simd(selected_gap_scheme.extension_score);
         gap_open_score = maybe_convert_to_simd(selected_gap_scheme.open_score) + gap_extension_score;
@@ -219,8 +219,8 @@ protected:
         else
             assert(gap_open_score <= 0 && gap_extension_score <= 0);
 
-        return maybe_convert_to_simd(std::numeric_limits<original_score_type>::lowest()) -
-               (gap_open_score + gap_extension_score);
+        return maybe_convert_to_simd(std::numeric_limits<original_score_type>::lowest())
+             - (gap_open_score + gap_extension_score);
     }
 
     /*!\brief Converts the given score type to a simd vector if the alignment is executed in vectorised mode.
@@ -231,9 +231,7 @@ protected:
      * \returns The score converted to the target simd vector or the unmodified value if in scalar mode.
      */
     template <typename score_t>
-    //!\cond
         requires arithmetic<std::remove_cvref_t<score_t>>
-    //!\endcond
     constexpr auto maybe_convert_to_simd(score_t && score) const noexcept
     {
         if constexpr (simd_concept<score_type>)
