@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -30,9 +30,9 @@ protected:
     //!\brief The type of the base policy.
     using base_t = policy_affine_gap_with_trace_recursion<alignment_configuration_t>;
     // Import base types.
-    using typename base_t::traits_type;
-    using typename base_t::score_type;
     using typename base_t::affine_cell_type;
+    using typename base_t::score_type;
+    using typename base_t::traits_type;
 
     // Import base member.
     using base_t::gap_extension_score;
@@ -46,11 +46,11 @@ protected:
     policy_affine_gap_with_trace_recursion_banded(policy_affine_gap_with_trace_recursion_banded const &) = default;
     //!\brief Defaulted.
     policy_affine_gap_with_trace_recursion_banded(policy_affine_gap_with_trace_recursion_banded &&) = default;
-    policy_affine_gap_with_trace_recursion_banded & operator=(policy_affine_gap_with_trace_recursion_banded const &)
-        = default; //!< Defaulted.
-    policy_affine_gap_with_trace_recursion_banded & operator=(policy_affine_gap_with_trace_recursion_banded &&)
-        = default; //!< Defaulted.
-    ~policy_affine_gap_with_trace_recursion_banded() = default; //!< Defaulted.
+    policy_affine_gap_with_trace_recursion_banded &
+    operator=(policy_affine_gap_with_trace_recursion_banded const &) = default; //!< Defaulted.
+    policy_affine_gap_with_trace_recursion_banded &
+    operator=(policy_affine_gap_with_trace_recursion_banded &&) = default; //!< Defaulted.
+    ~policy_affine_gap_with_trace_recursion_banded() = default;            //!< Defaulted.
 
     //!\copydoc seqan3::detail::policy_affine_gap_recursion::policy_affine_gap_recursion
     explicit policy_affine_gap_with_trace_recursion_banded(alignment_configuration_t const & config) : base_t{config}
@@ -69,16 +69,16 @@ protected:
 
         best_trace = previous_cell.horizontal_trace();
         diagonal_score = (diagonal_score < horizontal_score)
-                       ? horizontal_score
-                       : (best_trace |= trace_directions::diagonal, diagonal_score);
+                           ? horizontal_score
+                           : (best_trace |= trace_directions::diagonal, diagonal_score);
 
         score_type from_optimal_score = diagonal_score + gap_open_score;
         trace_directions next_horizontal_trace = trace_directions::left;
 
         horizontal_score += gap_extension_score;
         horizontal_score = (horizontal_score < from_optimal_score)
-                         ? (next_horizontal_trace = trace_directions::left_open, from_optimal_score)
-                         : horizontal_score;
+                             ? (next_horizontal_trace = trace_directions::left_open, from_optimal_score)
+                             : horizontal_score;
 
         return {{diagonal_score, horizontal_score, from_optimal_score},
                 {best_trace, next_horizontal_trace, trace_directions::up_open}};
