@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -53,10 +53,8 @@ struct max_score_updater
      * one is the new optimum. Otherwise, keeps the old optimum.
      */
     template <typename score_t, typename coordinate_t>
-    //!\cond
-        requires (std::totally_ordered<score_t> && std::assignable_from<score_t &, score_t const &> &&
-                  std::assignable_from<coordinate_t &, coordinate_t const &>)
-    //!\endcond
+        requires (std::totally_ordered<score_t> && std::assignable_from<score_t &, score_t const &>
+                  && std::assignable_from<coordinate_t &, coordinate_t const &>)
     void operator()(score_t & optimal_score,
                     coordinate_t & optimal_coordinate,
                     score_t current_score,
@@ -135,18 +133,16 @@ public:
      * accordingly.
      */
     template <typename score_t, typename coordinate_t>
-    //!\cond
-        requires (std::totally_ordered<score_t> && std::assignable_from<score_t &, score_t const &> &&
-                  std::assignable_from<coordinate_t &, coordinate_t const &>)
-    //!\endcond
+        requires (std::totally_ordered<score_t> && std::assignable_from<score_t &, score_t const &>
+                  && std::assignable_from<coordinate_t &, coordinate_t const &>)
     void operator()(score_t & optimal_score,
                     coordinate_t & optimal_coordinate,
                     score_t current_score,
                     coordinate_t current_coordinate) const noexcept
     {
-        bool const is_better_score = (target_row_index == current_coordinate.row ||
-                                      target_col_index == current_coordinate.col) &&
-                                      (current_score >= optimal_score);
+        bool const is_better_score =
+            (target_row_index == current_coordinate.row || target_col_index == current_coordinate.col)
+            && (current_score >= optimal_score);
         optimal_score = (is_better_score) ? std::move(current_score) : optimal_score;
         optimal_coordinate = (is_better_score) ? std::move(current_coordinate) : optimal_coordinate;
     }
@@ -182,14 +178,13 @@ public:
  * tracked.
  */
 template <typename alignment_configuration_t, std::semiregular optimum_updater_t>
-//!\cond
-    requires is_type_specialisation_of_v<alignment_configuration_t, configuration> &&
-             std::invocable<optimum_updater_t,
-                            typename alignment_configuration_traits<alignment_configuration_t>::score_type &,
-                            typename alignment_configuration_traits<alignment_configuration_t>::matrix_coordinate_type &,
-                            typename alignment_configuration_traits<alignment_configuration_t>::score_type,
-                            typename alignment_configuration_traits<alignment_configuration_t>::matrix_coordinate_type>
-//!\endcond
+    requires is_type_specialisation_of_v<alignment_configuration_t, configuration>
+          && std::invocable<
+                 optimum_updater_t,
+                 typename alignment_configuration_traits<alignment_configuration_t>::score_type &,
+                 typename alignment_configuration_traits<alignment_configuration_t>::matrix_coordinate_type &,
+                 typename alignment_configuration_traits<alignment_configuration_t>::score_type,
+                 typename alignment_configuration_traits<alignment_configuration_t>::matrix_coordinate_type>
 class policy_optimum_tracker
 {
 protected:
@@ -217,12 +212,12 @@ protected:
     /*!\name Constructors, destructor and assignment
      * \{
      */
-    policy_optimum_tracker() = default; //!< Defaulted.
-    policy_optimum_tracker(policy_optimum_tracker const &) = default; //!< Defaulted.
-    policy_optimum_tracker(policy_optimum_tracker &&) = default; //!< Defaulted.
+    policy_optimum_tracker() = default;                                           //!< Defaulted.
+    policy_optimum_tracker(policy_optimum_tracker const &) = default;             //!< Defaulted.
+    policy_optimum_tracker(policy_optimum_tracker &&) = default;                  //!< Defaulted.
     policy_optimum_tracker & operator=(policy_optimum_tracker const &) = default; //!< Defaulted.
-    policy_optimum_tracker & operator=(policy_optimum_tracker &&) = default; //!< Defaulted.
-    ~policy_optimum_tracker() = default; //!< Defaulted.
+    policy_optimum_tracker & operator=(policy_optimum_tracker &&) = default;      //!< Defaulted.
+    ~policy_optimum_tracker() = default;                                          //!< Defaulted.
 
     /*!\brief Construction and initialisation using the alignment configuration.
      * \param[in] config The alignment configuration (not used in this context).
