@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -13,7 +13,7 @@
 #pragma once
 
 #include <limits>
-#include <seqan3/std/ranges>
+#include <ranges>
 
 #include <seqan3/alignment/pairwise/detail/policy_optimum_tracker.hpp>
 #include <seqan3/utility/simd/algorithm.hpp>
@@ -61,21 +61,19 @@ struct max_score_updater_simd_global
      * will be set for the optimal score.
      */
     template <typename score_t, typename coordinate_t>
-    //!\cond
         requires (std::assignable_from<score_t &, score_t const &> &&
                   requires (coordinate_t coordinate)
                   {
                       requires simd_concept<decltype(coordinate.col)>;
                       requires simd_concept<decltype(coordinate.row)>;
                   })
-    //!\endcond
     void operator()(score_t & optimal_score,
                     coordinate_t const & optimal_coordinate,
                     score_t current_score,
                     coordinate_t const & current_coordinate) const noexcept
     {
-        auto mask = (optimal_coordinate.col == current_coordinate.col) &&
-                    (optimal_coordinate.row == current_coordinate.row);
+        auto mask =
+            (optimal_coordinate.col == current_coordinate.col) && (optimal_coordinate.row == current_coordinate.row);
         optimal_score = (mask) ? std::move(current_score) : optimal_score;
     }
 };
@@ -85,24 +83,22 @@ struct max_score_updater_simd_global
  * \copydetails seqan3::detail::policy_optimum_tracker
  */
 template <typename alignment_configuration_t, std::semiregular optimum_updater_t>
-//!\cond
-    requires is_type_specialisation_of_v<alignment_configuration_t, configuration> &&
-             std::invocable<optimum_updater_t,
-                            typename alignment_configuration_traits<alignment_configuration_t>::score_type &,
-                            typename alignment_configuration_traits<alignment_configuration_t>::matrix_coordinate_type &,
-                            typename alignment_configuration_traits<alignment_configuration_t>::score_type,
-                            typename alignment_configuration_traits<alignment_configuration_t>::matrix_coordinate_type>
-//!\endcond
-class policy_optimum_tracker_simd :
-    protected policy_optimum_tracker<alignment_configuration_t, optimum_updater_t>
+    requires is_type_specialisation_of_v<alignment_configuration_t, configuration>
+          && std::invocable<
+                 optimum_updater_t,
+                 typename alignment_configuration_traits<alignment_configuration_t>::score_type &,
+                 typename alignment_configuration_traits<alignment_configuration_t>::matrix_coordinate_type &,
+                 typename alignment_configuration_traits<alignment_configuration_t>::score_type,
+                 typename alignment_configuration_traits<alignment_configuration_t>::matrix_coordinate_type>
+class policy_optimum_tracker_simd : protected policy_optimum_tracker<alignment_configuration_t, optimum_updater_t>
 {
 protected:
     //!\brief The type of the base class.
     using base_policy_t = policy_optimum_tracker<alignment_configuration_t, optimum_updater_t>;
 
     // Import the configured score type.
-    using typename base_policy_t::traits_type;
     using typename base_policy_t::score_type;
+    using typename base_policy_t::traits_type;
 
     //!\brief The scalar type of the simd vector.
     using scalar_type = typename simd::simd_traits<score_type>::scalar_type;
@@ -113,20 +109,20 @@ protected:
 
     // Import base variables into class scope.
     using base_policy_t::compare_and_set_optimum;
-    using base_policy_t::optimal_score;
     using base_policy_t::optimal_coordinate;
+    using base_policy_t::optimal_score;
     //!\brief The individual offsets used for padding the sequences.
     std::array<original_score_type, simd_traits<score_type>::length> padding_offsets{};
 
     /*!\name Constructors, destructor and assignment
      * \{
      */
-    policy_optimum_tracker_simd() = default; //!< Defaulted.
-    policy_optimum_tracker_simd(policy_optimum_tracker_simd const &) = default; //!< Defaulted.
-    policy_optimum_tracker_simd(policy_optimum_tracker_simd &&) = default; //!< Defaulted.
+    policy_optimum_tracker_simd() = default;                                                //!< Defaulted.
+    policy_optimum_tracker_simd(policy_optimum_tracker_simd const &) = default;             //!< Defaulted.
+    policy_optimum_tracker_simd(policy_optimum_tracker_simd &&) = default;                  //!< Defaulted.
     policy_optimum_tracker_simd & operator=(policy_optimum_tracker_simd const &) = default; //!< Defaulted.
-    policy_optimum_tracker_simd & operator=(policy_optimum_tracker_simd &&) = default; //!< Defaulted.
-    ~policy_optimum_tracker_simd() = default; //!< Defaulted.
+    policy_optimum_tracker_simd & operator=(policy_optimum_tracker_simd &&) = default;      //!< Defaulted.
+    ~policy_optimum_tracker_simd() = default;                                               //!< Defaulted.
 
     /*!\brief Construction and initialisation using the alignment configuration.
      * \param[in] config The alignment configuration (not used in this context).
