@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -12,16 +12,16 @@
 
 #pragma once
 
-#include <seqan3/std/ranges>
+#include <ranges>
 #include <type_traits>
 
-#include <seqan3/alignment/configuration/align_config_result_type.hpp>
 #include <seqan3/alignment/configuration/align_config_band.hpp>
 #include <seqan3/alignment/configuration/align_config_debug.hpp>
 #include <seqan3/alignment/configuration/align_config_method.hpp>
 #include <seqan3/alignment/configuration/align_config_on_result.hpp>
 #include <seqan3/alignment/configuration/align_config_output.hpp>
 #include <seqan3/alignment/configuration/align_config_parallel.hpp>
+#include <seqan3/alignment/configuration/align_config_result_type.hpp>
 #include <seqan3/alignment/configuration/align_config_score_type.hpp>
 #include <seqan3/alignment/configuration/align_config_scoring_scheme.hpp>
 #include <seqan3/alignment/configuration/align_config_vectorised.hpp>
@@ -32,8 +32,8 @@
 #include <seqan3/core/detail/empty_type.hpp>
 #include <seqan3/core/detail/template_inspection.hpp>
 #include <seqan3/utility/detail/bits_of.hpp>
-#include <seqan3/utility/simd/simd_traits.hpp>
 #include <seqan3/utility/simd/simd.hpp>
+#include <seqan3/utility/simd/simd_traits.hpp>
 #include <seqan3/utility/type_traits/function_traits.hpp>
 #include <seqan3/utility/type_traits/lazy_conditional.hpp>
 #include <seqan3/utility/views/chunk.hpp>
@@ -59,9 +59,7 @@ namespace seqan3::detail
  * The returned type models seqan3::detail::indexed_sequence_pair_range.
  */
 template <typename sequence_pairs_t>
-//!\cond
     requires sequence_pair_range<std::remove_reference_t<sequence_pairs_t>>
-//!\endcond
 struct chunked_indexed_sequence_pairs
 {
     //!\brief The transformed type that models seqan3::detail::indexed_sequence_pair_range.
@@ -80,9 +78,7 @@ struct chunked_indexed_sequence_pairs
  *         seqan3::configuration.
  */
 template <typename configuration_t>
-//!\cond
     requires is_type_specialisation_of_v<std::remove_cv_t<configuration_t>, configuration>
-//!\endcond
 struct alignment_configuration_traits
 {
 private:
@@ -104,11 +100,9 @@ private:
     {
         if constexpr (configuration_t::template exists<align_cfg::detail::result_type>())
         {
-            using result_type_cfg_t =
-                std::remove_cvref_t<
-                    decltype(seqan3::get<align_cfg::detail::result_type>(std::declval<configuration_t>()))
-                >;
-            return typename result_type_cfg_t::type{};  // Access the stored result_type.
+            using result_type_cfg_t = std::remove_cvref_t<decltype(seqan3::get<align_cfg::detail::result_type>(
+                std::declval<configuration_t>()))>;
+            return typename result_type_cfg_t::type{}; // Access the stored result_type.
         }
         else
         {
@@ -122,8 +116,7 @@ public:
     //!\brief Flag indicating whether parallel alignment mode is enabled.
     static constexpr bool is_parallel = configuration_t::template exists<align_cfg::parallel>();
     //!\brief Flag indicating whether global alignment method is enabled.
-    static constexpr bool is_global =
-        configuration_t::template exists<seqan3::align_cfg::method_global>();
+    static constexpr bool is_global = configuration_t::template exists<seqan3::align_cfg::method_global>();
     //!\brief Flag indicating whether local alignment mode is enabled.
     static constexpr bool is_local = configuration_t::template exists<seqan3::align_cfg::method_local>();
     //!\brief Flag indicating whether banded alignment mode is enabled.
@@ -137,8 +130,8 @@ public:
     //!\brief The alphabet of the selected scoring scheme.
     using scoring_scheme_alphabet_type = typename scoring_scheme_type::alphabet_type;
     //!\brief The original score type selected by the user.
-    using original_score_type = typename std::remove_reference_t<decltype(
-        std::declval<configuration_t>().get_or(align_cfg::score_type<int32_t>{}))>::type;
+    using original_score_type = typename std::remove_reference_t<decltype(std::declval<configuration_t>().get_or(
+        align_cfg::score_type<int32_t>{}))>::type;
     //!\brief The score type for the alignment algorithm.
     using score_type = std::conditional_t<is_vectorised, simd_type_t<original_score_type>, original_score_type>;
     //!\brief The trace directions type for the alignment algorithm.
@@ -146,46 +139,38 @@ public:
     //!\brief The alignment result type if present. Otherwise seqan3::detail::empty_type.
     using alignment_result_type = decltype(determine_alignment_result_type());
     //!\brief The type of the matrix index.
-    using matrix_index_type = std::conditional_t<is_vectorised,
-                                                 simd_type_t<select_scalar_index_t<original_score_type>>,
-                                                 size_t>;
+    using matrix_index_type =
+        std::conditional_t<is_vectorised, simd_type_t<select_scalar_index_t<original_score_type>>, size_t>;
     //!\brief The type of the matrix coordinate.
-    using matrix_coordinate_type = lazy_conditional_t<is_vectorised,
-                                                      lazy<simd_matrix_coordinate, matrix_index_type>,
-                                                      matrix_coordinate>;
+    using matrix_coordinate_type =
+        lazy_conditional_t<is_vectorised, lazy<simd_matrix_coordinate, matrix_index_type>, matrix_coordinate>;
 
     //!\brief The number of alignments that can be computed in one simd vector.
-    static constexpr size_t alignments_per_vector = [] () constexpr
-                                                    {
-                                                        if constexpr (is_vectorised)
-                                                            return simd_traits<score_type>::length;
-                                                        else
-                                                            return 1;
-                                                    }();
+    static constexpr size_t alignments_per_vector = []() constexpr
+    {
+        if constexpr (is_vectorised)
+            return simd_traits<score_type>::length;
+        else
+            return 1;
+    }
+    ();
     //!\brief Flag indicating whether the score shall be computed.
     static constexpr bool compute_score = configuration_t::template exists<align_cfg::output_score>();
     //!\brief Flag indicating whether the end positions shall be computed.
-    static constexpr bool compute_end_positions =
-        configuration_t::template exists<align_cfg::output_end_position>();
+    static constexpr bool compute_end_positions = configuration_t::template exists<align_cfg::output_end_position>();
     //!\brief Flag indicating whether the begin positions shall be computed.
     static constexpr bool compute_begin_positions =
         configuration_t::template exists<align_cfg::output_begin_position>();
     //!\brief Flag indicating whether the sequence alignment shall be computed.
-    static constexpr bool compute_sequence_alignment =
-        configuration_t::template exists<align_cfg::output_alignment>();
+    static constexpr bool compute_sequence_alignment = configuration_t::template exists<align_cfg::output_alignment>();
     //!\brief Flag indicating whether the id of the first sequence shall be returned.
-    static constexpr bool output_sequence1_id =
-        configuration_t::template exists<align_cfg::output_sequence1_id>();
+    static constexpr bool output_sequence1_id = configuration_t::template exists<align_cfg::output_sequence1_id>();
     //!\brief Flag indicating whether the id of the second sequence shall be returned.
-    static constexpr bool output_sequence2_id =
-        configuration_t::template exists<align_cfg::output_sequence2_id>();
+    static constexpr bool output_sequence2_id = configuration_t::template exists<align_cfg::output_sequence2_id>();
     //!\brief Flag indicating if any output option was set.
-    static constexpr bool has_output_configuration = compute_score ||
-                                                     compute_end_positions ||
-                                                     compute_begin_positions ||
-                                                     compute_sequence_alignment ||
-                                                     output_sequence1_id ||
-                                                     output_sequence2_id;
+    static constexpr bool has_output_configuration = compute_score || compute_end_positions || compute_begin_positions
+                                                  || compute_sequence_alignment || output_sequence1_id
+                                                  || output_sequence2_id;
     //!\brief Flag indicating whether the trace matrix needs to be computed.
     static constexpr bool requires_trace_information = compute_begin_positions || compute_sequence_alignment;
 };
@@ -210,4 +195,4 @@ struct alignment_function_traits
     using alignment_result_type = typename function_traits<callback_type>::template argument_type_at<0>;
 };
 
-}  // namespace seqan3::detail
+} // namespace seqan3::detail
