@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -13,8 +13,8 @@
 #pragma once
 
 #include <seqan3/alphabet/alphabet_base.hpp>
-#include <seqan3/alphabet/detail/convert.hpp>
 #include <seqan3/alphabet/aminoacid/concept.hpp>
+#include <seqan3/alphabet/detail/convert.hpp>
 #include <seqan3/utility/char_operations/transform.hpp>
 
 namespace seqan3
@@ -40,12 +40,12 @@ private:
     /*!\name Constructors, destructor and assignment
      * \{
      */
-    constexpr aminoacid_base()                                   noexcept = default; //!< Defaulted.
-    constexpr aminoacid_base(aminoacid_base const &)             noexcept = default; //!< Defaulted.
-    constexpr aminoacid_base(aminoacid_base &&)                  noexcept = default; //!< Defaulted.
+    constexpr aminoacid_base() noexcept = default;                                   //!< Defaulted.
+    constexpr aminoacid_base(aminoacid_base const &) noexcept = default;             //!< Defaulted.
+    constexpr aminoacid_base(aminoacid_base &&) noexcept = default;                  //!< Defaulted.
     constexpr aminoacid_base & operator=(aminoacid_base const &) noexcept = default; //!< Defaulted.
-    constexpr aminoacid_base & operator=(aminoacid_base &&)      noexcept = default; //!< Defaulted.
-    ~aminoacid_base()                                            noexcept = default; //!< Defaulted.
+    constexpr aminoacid_base & operator=(aminoacid_base &&) noexcept = default;      //!< Defaulted.
+    ~aminoacid_base() noexcept = default;                                            //!< Defaulted.
 
     //!\}
 
@@ -70,23 +70,15 @@ public:
      * \experimentalapi{Experimental since version 3.1.}
      */
     template <typename other_aa_type>
-    //!\cond
-        requires (!std::same_as<aminoacid_base, other_aa_type>) &&
-                 (!std::same_as<derived_type, other_aa_type>) &&
-                 aminoacid_alphabet<other_aa_type>
-    //!\endcond
+        requires (!std::same_as<aminoacid_base, other_aa_type>)
+              && (!std::same_as<derived_type, other_aa_type>) && aminoacid_alphabet<other_aa_type>
     explicit constexpr aminoacid_base(other_aa_type const other) noexcept
     {
-        if constexpr (is_constexpr_default_constructible_v<other_aa_type> &&
-#if SEQAN3_WORKAROUND_GCC7_AND_8_CONCEPT_ISSUES
-                      writable_alphabet<other_aa_type>
-#else
-                      detail::writable_constexpr_alphabet<other_aa_type>
-#endif // SEQAN3_WORKAROUND_GCC7_AND_8_CONCEPT_ISSUES
-                     )
+        if constexpr (is_constexpr_default_constructible_v<other_aa_type>
+                      && detail::writable_constexpr_alphabet<other_aa_type>)
         {
             static_cast<derived_type &>(*this) =
-                detail::convert_through_char_representation<derived_type, other_aa_type>[seqan3::to_rank(other)];
+                detail::convert_through_char_representation<other_aa_type, derived_type>[seqan3::to_rank(other)];
         }
         else
         {
@@ -121,24 +113,21 @@ public:
 
 private:
     //!\brief Implementation of #char_is_valid().
-    static constexpr std::array<bool, 256> valid_char_table
+    static constexpr std::array<bool, 256> valid_char_table{[]() constexpr {// init with false
+                                                                            std::array<bool, 256> ret{};
+
+    // the original valid chars and their lower cases
+    for (size_t rank = 0u; rank < derived_type::alphabet_size; ++rank)
     {
-        [] () constexpr
-        {
-            // init with false
-            std::array<bool, 256> ret{};
+        uint8_t c = derived_type::rank_to_char(rank);
+        ret[c] = true;
+        ret[to_lower(c)] = true;
+    }
 
-            // the original valid chars and their lower cases
-            for (size_t rank = 0u; rank < derived_type::alphabet_size; ++rank)
-            {
-                uint8_t c = derived_type::rank_to_char(rank);
-                ret[c] = true;
-                ret[to_lower(c)] = true;
-            }
-
-            return ret;
-        }()
-    };
-};
+    return ret;
+}()
+}; // namespace seqan3
+}
+;
 
 } // namespace seqan3
