@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -63,27 +63,24 @@ public:
     /*!\name Constructors, destructor and assignment
      * \{
      */
-    constexpr rna15()                           noexcept = default; //!< Defaulted.
-    constexpr rna15(rna15 const &)              noexcept = default; //!< Defaulted.
-    constexpr rna15(rna15 &&)                   noexcept = default; //!< Defaulted.
-    constexpr rna15 & operator=(rna15 const &)  noexcept = default; //!< Defaulted.
-    constexpr rna15 & operator=(rna15 &&)       noexcept = default; //!< Defaulted.
-    ~rna15()                                    noexcept = default; //!< Defaulted.
+    constexpr rna15() noexcept = default;                          //!< Defaulted.
+    constexpr rna15(rna15 const &) noexcept = default;             //!< Defaulted.
+    constexpr rna15(rna15 &&) noexcept = default;                  //!< Defaulted.
+    constexpr rna15 & operator=(rna15 const &) noexcept = default; //!< Defaulted.
+    constexpr rna15 & operator=(rna15 &&) noexcept = default;      //!< Defaulted.
+    ~rna15() noexcept = default;                                   //!< Defaulted.
 
     using base_t::base_t;
 
     /*!\brief Allow implicit construction from seqan3::dna15 of the same size.
      * \details
      *
-     * \copydetails seqan3::doxygen::rna15_implicit_conversion_from_dna15
+     * \include{doc} doc/fragments/rna15_implicit_conversion_from_dna15.md
      *
      * \stableapi{Since version 3.1.}
      */
     template <std::same_as<dna15> t>
     constexpr rna15(t const & r) noexcept
-#if SEQAN3_WORKAROUND_GCC_90897
-        requires true
-#endif
     {
         assign_rank(r.to_rank());
     }
@@ -91,24 +88,8 @@ public:
 
 private:
     //!\copydoc seqan3::dna4::rank_to_char_table
-    static constexpr char_type rank_to_char_table[alphabet_size]
-    {
-        'A',
-        'B',
-        'C',
-        'D',
-        'G',
-        'H',
-        'K',
-        'M',
-        'N',
-        'R',
-        'S',
-        'U',
-        'V',
-        'W',
-        'Y'
-    };
+    static constexpr char_type
+        rank_to_char_table[alphabet_size]{'A', 'B', 'C', 'D', 'G', 'H', 'K', 'M', 'N', 'R', 'S', 'U', 'V', 'W', 'Y'};
 
     //!\copydoc seqan3::dna4::rank_complement
     static constexpr rank_type rank_complement(rank_type const rank)
@@ -186,6 +167,6 @@ inline rna15_vector operator""_rna15(char const * s, std::size_t n)
 }
 //!\}
 
-} // inline namespace literals
+} // namespace literals
 
 } // namespace seqan3
