@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -23,8 +23,8 @@ namespace seqan3::detail::adl_only
 {
 
 //!\brief Poison-pill overload to prevent non-ADL forms of unqualified lookup.
-template <typename ...args_t>
-void to_phred(args_t ...) = delete;
+template <typename... args_t>
+void to_phred(args_t...) = delete;
 
 //!\brief seqan3::detail::customisation_point_object (CPO) definition for seqan3::to_phred.
 //!\ingroup alphabet_quality
@@ -40,8 +40,7 @@ struct to_phred_cpo : public detail::customisation_point_object<to_phred_cpo, 2>
      * \param alphabet The alphabet the Phred is returned from.
      */
     template <typename alphabet_t>
-    static constexpr auto SEQAN3_CPO_OVERLOAD(priority_tag<2>, alphabet_t && alphabet)
-    (
+    static constexpr auto SEQAN3_CPO_OVERLOAD(priority_tag<2>, alphabet_t && alphabet)(
         /*return*/ seqan3::custom::alphabet<alphabet_t>::to_phred(std::forward<alphabet_t>(alphabet)) /*;*/
     );
 
@@ -50,8 +49,7 @@ struct to_phred_cpo : public detail::customisation_point_object<to_phred_cpo, 2>
      * \param alphabet The alphabet the Phred is returned from.
      */
     template <typename alphabet_t>
-    static constexpr auto SEQAN3_CPO_OVERLOAD(priority_tag<1>, alphabet_t && alphabet)
-    (
+    static constexpr auto SEQAN3_CPO_OVERLOAD(priority_tag<1>, alphabet_t && alphabet)(
         /*return*/ to_phred(std::forward<alphabet_t>(alphabet)) /*;*/
     );
 
@@ -60,8 +58,7 @@ struct to_phred_cpo : public detail::customisation_point_object<to_phred_cpo, 2>
      * \param alphabet The alphabet the Phred is returned from.
      */
     template <typename alphabet_t>
-    static constexpr auto SEQAN3_CPO_OVERLOAD(priority_tag<0>, alphabet_t && alphabet)
-    (
+    static constexpr auto SEQAN3_CPO_OVERLOAD(priority_tag<0>, alphabet_t && alphabet)(
         /*return*/ std::forward<alphabet_t>(alphabet).to_phred() /*;*/
     );
 };
@@ -115,9 +112,11 @@ inline constexpr auto to_phred = detail::adl_only::to_phred_cpo{};
  * \stableapi{Since version 3.1.}
  */
 template <typename alphabet_type>
-//!\cond
-    requires requires { { seqan3::to_phred(std::declval<alphabet_type>()) }; }
-//!\endcond
+    requires requires {
+                 {
+                     seqan3::to_phred(std::declval<alphabet_type>())
+                 };
+             }
 using alphabet_phred_t = decltype(seqan3::to_phred(std::declval<alphabet_type>()));
 
 } // namespace seqan3
@@ -130,8 +129,8 @@ namespace seqan3::detail::adl_only
 {
 
 //!\brief Poison-pill overload to prevent non-ADL forms of unqualified lookup.
-template <typename ...args_t>
-void assign_phred_to(args_t ...) = delete;
+template <typename... args_t>
+void assign_phred_to(args_t...) = delete;
 
 //!\brief seqan3::detail::customisation_point_object (CPO) definition for seqan3::assign_phred_to.
 //!\ingroup alphabet_quality
@@ -156,10 +155,8 @@ struct assign_phred_to_cpo : public detail::customisation_point_object<assign_ph
      * return an explicit copy of it if the forwarding reference of the alphabet is a rvalue-reference.
      */
     template <typename alphabet_t>
-    static constexpr auto SEQAN3_CPO_OVERLOAD(priority_tag<2>,
-                                              seqan3::alphabet_phred_t<alphabet_t> const phred,
-                                              alphabet_t && alphabet)
-    (
+    static constexpr auto
+    SEQAN3_CPO_OVERLOAD(priority_tag<2>, seqan3::alphabet_phred_t<alphabet_t> const phred, alphabet_t && alphabet)(
         /*return*/ static_cast<alphabet_t>(seqan3::custom::alphabet<alphabet_t>::assign_phred_to(phred, alphabet)) /*;*/
     );
 
@@ -178,10 +175,8 @@ struct assign_phred_to_cpo : public detail::customisation_point_object<assign_ph
      * return an explicit copy of it if the forwarding reference of the alphabet is a rvalue-reference.
      */
     template <typename alphabet_t>
-    static constexpr auto SEQAN3_CPO_OVERLOAD(priority_tag<1>,
-                                              seqan3::alphabet_phred_t<alphabet_t> const phred,
-                                              alphabet_t && alphabet)
-    (
+    static constexpr auto
+    SEQAN3_CPO_OVERLOAD(priority_tag<1>, seqan3::alphabet_phred_t<alphabet_t> const phred, alphabet_t && alphabet)(
         /*return*/ static_cast<alphabet_t>(assign_phred_to(phred, alphabet)) /*;*/
     );
 
@@ -196,10 +191,8 @@ struct assign_phred_to_cpo : public detail::customisation_point_object<assign_ph
      * return an explicit copy of it if the forwarding reference of the alphabet is a rvalue-reference.
      */
     template <typename alphabet_t>
-    static constexpr auto SEQAN3_CPO_OVERLOAD(priority_tag<0>,
-                                              seqan3::alphabet_phred_t<alphabet_t> const phred,
-                                              alphabet_t && alphabet)
-    (
+    static constexpr auto
+    SEQAN3_CPO_OVERLOAD(priority_tag<0>, seqan3::alphabet_phred_t<alphabet_t> const phred, alphabet_t && alphabet)(
         /*return*/ static_cast<alphabet_t>(alphabet.assign_phred(phred)) /*;*/
     );
 };
@@ -289,10 +282,11 @@ namespace seqan3
  */
 //!\cond
 template <typename t>
-SEQAN3_CONCEPT quality_alphabet = alphabet<t> && requires(t qual)
-{
-    { seqan3::to_phred(qual) };
-};
+concept quality_alphabet = alphabet<t> && requires (t qual) {
+                                              {
+                                                  seqan3::to_phred(qual)
+                                              };
+                                          };
 //!\endcond
 
 // ============================================================================
@@ -329,12 +323,12 @@ SEQAN3_CONCEPT quality_alphabet = alphabet<t> && requires(t qual)
  */
 //!\cond
 template <typename t>
-SEQAN3_CONCEPT writable_quality_alphabet = writable_alphabet<t> &&
-                                           quality_alphabet<t> &&
-                                           requires(t v, alphabet_phred_t<t> c)
-{
-    { seqan3::assign_phred_to(c, v) };
-};
+concept writable_quality_alphabet =
+    writable_alphabet<t> && quality_alphabet<t> && requires (t v, alphabet_phred_t<t> c) {
+                                                       {
+                                                           seqan3::assign_phred_to(c, v)
+                                                       };
+                                                   };
 //!\endcond
 
 } // namespace seqan3
