@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -56,12 +56,12 @@ public:
     /*!\name Constructors, destructor and assignment
      * \{
      */
-    constexpr phred94()                             noexcept = default; //!< Defaulted.
-    constexpr phred94(phred94 const &)              noexcept = default; //!< Defaulted.
-    constexpr phred94(phred94 &&)                   noexcept = default; //!< Defaulted.
-    constexpr phred94 & operator=(phred94 const &)  noexcept = default; //!< Defaulted.
-    constexpr phred94 & operator=(phred94 &&)       noexcept = default; //!< Defaulted.
-    ~phred94()                                      noexcept = default; //!< Defaulted.
+    constexpr phred94() noexcept = default;                            //!< Defaulted.
+    constexpr phred94(phred94 const &) noexcept = default;             //!< Defaulted.
+    constexpr phred94(phred94 &&) noexcept = default;                  //!< Defaulted.
+    constexpr phred94 & operator=(phred94 const &) noexcept = default; //!< Defaulted.
+    constexpr phred94 & operator=(phred94 &&) noexcept = default;      //!< Defaulted.
+    ~phred94() noexcept = default;                                     //!< Defaulted.
 
     // Inherit converting constructor
     using base_t::base_t;
@@ -128,6 +128,6 @@ inline std::vector<phred94> operator""_phred94(char const * s, std::size_t n)
 }
 //!\}
 
-} // inline namespace literals
+} // namespace literals
 
 } // namespace seqan3
