@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -12,7 +12,7 @@
 
 #pragma once
 
-#include <seqan3/std/ranges>
+#include <ranges>
 
 #include <seqan3/alphabet/concept.hpp>
 #include <seqan3/utility/views/deep.hpp>
@@ -60,10 +60,12 @@ namespace seqan3::views
  *
  * \stableapi{Since version 3.1.}
  */
-inline auto const to_char = deep{std::views::transform([] (auto const in) noexcept
-{
-    static_assert(alphabet<std::remove_cvref_t<decltype(in)>>, "The value type of seqan3::views::to_char must model the seqan3::alphabet.");
-    return seqan3::to_char(in);
-})};
+inline auto const to_char = deep{std::views::transform(
+    [](auto const in) noexcept
+    {
+        static_assert(alphabet<std::remove_cvref_t<decltype(in)>>,
+                      "The value type of seqan3::views::to_char must model the seqan3::alphabet.");
+        return seqan3::to_char(in);
+    })};
 
 } // namespace seqan3::views
