@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -13,7 +13,7 @@
 #pragma once
 
 #include <cstring>
-#include <seqan3/std/ranges>
+#include <ranges>
 
 #include <seqan3/alphabet/concept.hpp>
 #include <seqan3/utility/views/deep.hpp>
@@ -63,11 +63,12 @@ namespace seqan3::views
  *
  * \stableapi{Since version 3.1.}
  */
-inline auto const to_rank = deep{std::views::transform([] (auto const in) noexcept
-{
-    static_assert(semialphabet<decltype(in)>,
-                  "The value type of seqan3::views::to_rank must model the seqan3::alphabet.");
-    return seqan3::to_rank(in);
-})};
+inline auto const to_rank = deep{std::views::transform(
+    [](auto const in) noexcept
+    {
+        static_assert(semialphabet<decltype(in)>,
+                      "The value type of seqan3::views::to_rank must model the seqan3::alphabet.");
+        return seqan3::to_rank(in);
+    })};
 
 } // namespace seqan3::views
