@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -12,8 +12,8 @@
 
 #pragma once
 
-#include <seqan3/std/concepts>
-#include <seqan3/std/ranges>
+#include <concepts>
+#include <ranges>
 #include <stdexcept>
 #include <vector>
 
@@ -52,27 +52,26 @@ private:
      * \{
      */
     //!\brief The reference_type.
-    using reference         = view_translate_single<std::views::all_t<std::ranges::range_reference_t<urng_t>>>;
+    using reference = view_translate_single<std::views::all_t<std::ranges::range_reference_t<urng_t>>>;
     //!\brief The const_reference type.
-    using const_reference   = reference;
+    using const_reference = reference;
     //!\brief The value_type (which equals the reference_type with any references removed).
-    using value_type        = reference;
+    using value_type = reference;
     //!\brief The size_type.
-    using size_type         = std::ranges::range_size_t<std::ranges::range_reference_t<urng_t>>;
+    using size_type = std::ranges::range_size_t<std::ranges::range_reference_t<urng_t>>;
     //!\brief A signed integer type, usually std::ptrdiff_t.
-    using difference_type   = std::ranges::range_difference_t<std::ranges::range_reference_t<urng_t>>;
+    using difference_type = std::ranges::range_difference_t<std::ranges::range_reference_t<urng_t>>;
     //!\brief The iterator type of this view (a random access iterator).
-    using iterator          = detail::random_access_iterator<view_translate_join>;
+    using iterator = detail::random_access_iterator<view_translate_join>;
     //!\brief The const iterator type of this view (same as iterator, because it's a view).
-    using const_iterator    = detail::random_access_iterator<view_translate_join const>;
+    using const_iterator = detail::random_access_iterator<view_translate_join const>;
     //!\}
 
     //!\brief Befriend the following class s.t. iterator and const_iterator can be defined for this type.
-    template <typename, typename>
+    template <typename, template <typename...> typename>
     friend class detail::random_access_iterator_base;
 
 public:
-
     static_assert(range_dimension_v<urng_t> == 2,
                   "This adaptor only handles range-of-range (two dimensions) as input.");
     static_assert(std::ranges::viewable_range<urng_t>,
@@ -97,19 +96,20 @@ public:
     /*!\name Constructors, destructor and assignment
      * \{
      */
-    view_translate_join()                                                      noexcept = default; //!< Defaulted.
-    constexpr view_translate_join(view_translate_join const & rhs)             noexcept = default; //!< Defaulted.
-    constexpr view_translate_join(view_translate_join && rhs)                  noexcept = default; //!< Defaulted.
+    view_translate_join() noexcept = default;                                                      //!< Defaulted.
+    constexpr view_translate_join(view_translate_join const & rhs) noexcept = default;             //!< Defaulted.
+    constexpr view_translate_join(view_translate_join && rhs) noexcept = default;                  //!< Defaulted.
     constexpr view_translate_join & operator=(view_translate_join const & rhs) noexcept = default; //!< Defaulted.
-    constexpr view_translate_join & operator=(view_translate_join && rhs)      noexcept = default; //!< Defaulted.
-    ~view_translate_join()                                                     noexcept = default; //!< Defaulted.
+    constexpr view_translate_join & operator=(view_translate_join && rhs) noexcept = default;      //!< Defaulted.
+    ~view_translate_join() noexcept = default;                                                     //!< Defaulted.
 
     /*!\brief Construct from another view.
      * \param[in] _urange The underlying range (of ranges).
      * \param[in] _tf The frames that should be used for translation.
      */
-    view_translate_join(urng_t _urange, translation_frames const _tf = translation_frames::six_frames)
-        : urange{std::move(_urange)}, tf{_tf}
+    view_translate_join(urng_t _urange, translation_frames const _tf = translation_frames::six_frames) :
+        urange{std::move(_urange)},
+        tf{_tf}
     {
         if ((_tf & translation_frames::forward_frame0) == translation_frames::forward_frame0)
             selected_frames.push_back(translation_frames::forward_frame0);
@@ -130,13 +130,10 @@ public:
      * \param[in] _tf The frames that should be used for translation.
      */
     template <typename rng_t>
-    //!\cond
-        requires (!std::same_as<std::remove_cvref_t<rng_t>, view_translate_join>) &&
-                 std::ranges::viewable_range<rng_t> &&
-                 std::constructible_from<urng_t, std::ranges::ref_view<std::remove_reference_t<rng_t>>>
-    //!\endcond
-    view_translate_join(rng_t && _urange, translation_frames const _tf = translation_frames::six_frames)
-     : view_translate_join{std::views::all(std::forward<rng_t>(_urange)), _tf}
+        requires (!std::same_as<std::remove_cvref_t<rng_t>, view_translate_join>) && std::ranges::viewable_range<rng_t>
+              && std::constructible_from<urng_t, std::ranges::ref_view<std::remove_reference_t<rng_t>>>
+    view_translate_join(rng_t && _urange, translation_frames const _tf = translation_frames::six_frames) :
+        view_translate_join{std::views::all(std::forward<rng_t>(_urange)), _tf}
     {}
     //!\}
 
@@ -207,14 +204,14 @@ public:
      */
     size_type size() noexcept
     {
-        return (size_type) std::ranges::size(urange) * selected_frames.size();
+        return (size_type)std::ranges::size(urange) * selected_frames.size();
     }
 
     //!\overload
     size_type size() const noexcept
         requires const_iterable_range<urng_t>
     {
-        return (size_type) std::ranges::size(urange) * selected_frames.size();
+        return (size_type)std::ranges::size(urange) * selected_frames.size();
     }
 
     /*!\name Element access
@@ -257,7 +254,8 @@ public:
 
 //!\brief Class template argument deduction for view_translate_join.
 template <typename urng_t>
-view_translate_join(urng_t &&, translation_frames const = translation_frames{}) -> view_translate_join<std::views::all_t<urng_t>>;
+view_translate_join(urng_t &&, translation_frames const = translation_frames{})
+    -> view_translate_join<std::views::all_t<urng_t>>;
 
 // ============================================================================
 //  translate_fn (adaptor definition for both views)
