@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -12,16 +12,15 @@
 
 #pragma once
 
-#include <seqan3/std/concepts>
+#include <concepts>
 #include <sstream>
-#include <seqan3/std/type_traits>
+#include <type_traits>
 #include <unordered_map>
 #include <vector>
 
 #include <seqan3/core/debug_stream/debug_stream_type.hpp>
 #include <seqan3/core/detail/customisation_point.hpp>
 #include <seqan3/io/stream/concept.hpp>
-#include <seqan3/utility/type_traits/basic.hpp>
 
 namespace seqan3::custom
 {
@@ -66,7 +65,7 @@ struct argument_parsing<t const &> : argument_parsing<t>
 {};
 //!\endcond
 
-} // seqan3::custom
+} // namespace seqan3::custom
 
 namespace seqan3::detail::adl_only
 {
@@ -86,22 +85,20 @@ struct enumeration_names_cpo : public detail::customisation_point_object<enumera
     //!\brief Only this class is allowed to import the constructors from #base_t. (CRTP safety idiom)
     using base_t::base_t;
 
-    /*!\brief If `alphabet_type` isn't std::is_nothrow_default_constructible, enumeration_names will be called with
+    /*!\brief If `option_t` isn't std::is_nothrow_default_constructible, enumeration_names will be called with
      *        std::type_identity instead of a default constructed alphabet.
      */
     template <typename option_type>
-    using option_or_type_identity
-        = std::conditional_t<std::is_nothrow_default_constructible_v<std::remove_cvref_t<option_type>> &&
-                             seqan3::is_constexpr_default_constructible_v<std::remove_cvref_t<option_type>>,
-                             std::remove_cvref_t<option_type>,
-                             std::type_identity<option_type>>;
+    using option_or_type_identity =
+        std::conditional_t<std::is_nothrow_default_constructible_v<std::remove_cvref_t<option_type>>,
+                           std::remove_cvref_t<option_type>,
+                           std::type_identity<option_type>>;
 
     /*!\brief CPO overload (check 1 out of 2): explicit customisation via `seqan3::custom::argument_parsing`
      * \tparam option_type The type of the option. (Needed to defer instantiation for incomplete types.)
      */
     template <typename option_type = option_t>
-    static constexpr auto SEQAN3_CPO_OVERLOAD(priority_tag<1>)
-    (
+    static constexpr auto SEQAN3_CPO_OVERLOAD(priority_tag<1>)(
         /*return*/ seqan3::custom::argument_parsing<option_type>::enumeration_names /*;*/
     );
 
@@ -112,11 +109,10 @@ struct enumeration_names_cpo : public detail::customisation_point_object<enumera
      * \details
      *
      * If the option_type isn't std::is_nothrow_default_constructible,
-     * `enumeration_names(std::type_identity<alphabet_type>{})` will be called.
+     * `enumeration_names(std::type_identity<option_t>{})` will be called.
      */
     template <typename option_type = option_t>
-    static constexpr auto SEQAN3_CPO_OVERLOAD(priority_tag<0>)
-    (
+    static constexpr auto SEQAN3_CPO_OVERLOAD(priority_tag<0>)(
         /*return*/ enumeration_names(option_or_type_identity<option_type>{}) /*;*/
     );
 };
@@ -165,9 +161,11 @@ namespace seqan3
  * simply provide one of the two functions specified above.
  */
 template <typename option_type>
-//!\cond
-    requires requires { { detail::adl_only::enumeration_names_cpo<option_type>{}() }; }
-//!\endcond
+    requires requires {
+                 {
+                     detail::adl_only::enumeration_names_cpo<option_type>{}()
+                 };
+             }
 inline auto const enumeration_names = detail::adl_only::enumeration_names_cpo<option_type>{}();
 //!\}
 
@@ -185,10 +183,11 @@ inline auto const enumeration_names = detail::adl_only::enumeration_names_cpo<op
  */
 //!\cond
 template <typename option_type>
-SEQAN3_CONCEPT named_enumeration = requires
-{
-    { seqan3::enumeration_names<option_type> };
-};
+concept named_enumeration = requires {
+                                {
+                                    seqan3::enumeration_names<option_type>
+                                };
+                            };
 //!\endcond
 
 /*!\interface seqan3::argument_parser_compatible_option <>
@@ -205,8 +204,8 @@ SEQAN3_CONCEPT named_enumeration = requires
  */
 //!\cond
 template <typename option_type>
-SEQAN3_CONCEPT argument_parser_compatible_option = input_stream_over<std::istringstream, option_type> ||
-                                                   named_enumeration<option_type>;
+concept argument_parser_compatible_option =
+    input_stream_over<std::istringstream, option_type> || named_enumeration<option_type>;
 //!\endcond
 
 /*!\name Formatted output overloads
@@ -224,9 +223,7 @@ SEQAN3_CONCEPT argument_parser_compatible_option = input_stream_over<std::istrin
  * respective string if found or '\<UNKNOWN_VALUE\>' if the value cannot be found in the map.
  */
 template <typename char_t, typename option_type>
-//!\cond
     requires named_enumeration<std::remove_cvref_t<option_type>>
-//!\endcond
 inline debug_stream_type<char_t> & operator<<(debug_stream_type<char_t> & s, option_type && op)
 {
     for (auto & [key, value] : enumeration_names<option_type>)
