@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -13,18 +13,17 @@
 
 #pragma once
 
-#include <seqan3/std/filesystem>
+#include <filesystem>
 #include <iostream>
 #include <limits>
 #include <sstream>
 #include <string>
 
 #include <seqan3/argument_parser/auxiliary.hpp>
+#include <seqan3/argument_parser/detail/concept.hpp>
 #include <seqan3/argument_parser/exceptions.hpp>
 #include <seqan3/argument_parser/validators.hpp>
-#include <seqan3/utility/container/concept.hpp>
 #include <seqan3/utility/detail/type_name_as_string.hpp>
-#include <seqan3/utility/type_list/traits.hpp>
 #include <seqan3/version.hpp>
 
 namespace seqan3::detail
@@ -84,10 +83,7 @@ protected:
      * \tparam container_type The container type for which to query it's value_type.
      * \returns The type of the container value_type as a string.
      */
-    template <sequence_container container_type>
-    //!\cond
-        requires (!std::is_same_v<container_type, std::string>)
-    //!\endcond
+    template <detail::is_container_option container_type>
     static std::string get_type_name_as_string(container_type const & /**/)
     {
         typename container_type::value_type tmp{};
@@ -106,15 +102,12 @@ protected:
     }
 
     /*!\brief Formats the container and its value_type for the help page printing.
-     * \tparam container_type A type that must satisfy the seqan3::sequence_container.
+     * \tparam container_type A type that must satisfy the seqan3::detail::is_container_option.
      * \param[in] container The container to deduct the type from.
      *
      * \returns The type of the container value type as a string, encapsulated in "List of".
      */
-    template <typename container_type>
-    //!\cond
-        requires sequence_container<container_type> && (!std::is_same_v<container_type, std::string>)
-    //!\endcond
+    template <detail::is_container_option container_type>
     static std::string option_type_and_list_info(container_type const & container)
     {
         return ("(\\fIList\\fP of \\fI" + get_type_name_as_string(container) + "\\fP)");
@@ -188,10 +181,10 @@ protected:
             ++it;
 
         for (; it != flag_cluster.end() - 1; ++it)
-            tmp.append("-" + std::string(1, *it) + ", ");
+            tmp.append({'-', *it, ',', ' '});
 
         tmp.erase(tmp.find_last_of(',')); // remove last ', '
-        tmp.append(" and -" + std::string(1, flag_cluster[flag_cluster.size() - 1]));
+        tmp.append({'a', 'n', 'd', ' ', '-', flag_cluster[flag_cluster.size() - 1]});
 
         return tmp;
     }
@@ -221,7 +214,8 @@ private:
      * \param[in] advanced Set to `true` to show advanced options.
      */
     format_help_base(std::vector<std::string> const & names, bool const advanced) :
-        command_names{names}, show_advanced_options{advanced}
+        command_names{names},
+        show_advanced_options{advanced}
     {}
     //!\}
 
@@ -241,7 +235,12 @@ public:
         std::string info{desc};
         info += ((spec & option_spec::required) ? std::string{" "} : detail::to_string(" Default: ", value, ". "));
         info += option_validator.get_help_page_message();
-        store_help_page_element([this, id, info] () { derived_t().print_list_item(id, info); }, spec);
+        store_help_page_element(
+            [this, id, info]()
+            {
+                derived_t().print_list_item(id, info);
+            },
+            spec);
     }
 
     /*!\brief Adds a seqan3::print_list_item call to be evaluated later on.
@@ -254,31 +253,37 @@ public:
                   option_spec const spec)
     {
         std::string id = prep_id_for_help(short_id, long_id);
-        store_help_page_element([this, id, desc] () { derived_t().print_list_item(id, desc); }, spec);
+        store_help_page_element(
+            [this, id, desc]()
+            {
+                derived_t().print_list_item(id, desc);
+            },
+            spec);
     }
 
     /*!\brief Adds a seqan3::print_list_item call to be evaluated later on.
      * \copydetails seqan3::argument_parser::add_positional_option
      */
     template <typename option_type, typename validator_type>
-    void add_positional_option(option_type & value,
-                               std::string const & desc,
-                               validator_type & option_validator)
+    void add_positional_option(option_type & value, std::string const & desc, validator_type & option_validator)
     {
         std::string msg = option_validator.get_help_page_message();
 
-        positional_option_calls.push_back([this, &value, desc, msg] ()
-        {
-            ++positional_option_count;
-            derived_t().print_list_item(detail::to_string("\\fBARGUMENT-", positional_option_count, "\\fP ",
-                                                          option_type_and_list_info(value)),
-                                        desc +
-                                        // a list at the end may be empty and thus have a default value
-                                        ((sequence_container<option_type> && !std::same_as<option_type, std::string>)
-                                            ? detail::to_string(" Default: ", value, ". ")
-                                            : std::string{" "}) +
-                                        msg);
-        });
+        positional_option_calls.push_back(
+            [this, &value, desc, msg]()
+            {
+                ++positional_option_count;
+                derived_t().print_list_item(detail::to_string("\\fBARGUMENT-",
+                                                              positional_option_count,
+                                                              "\\fP ",
+                                                              option_type_and_list_info(value)),
+                                            desc +
+                                                // a list at the end may be empty and thus have a default value
+                                                ((detail::is_container_option<option_type>)
+                                                     ? detail::to_string(" Default: ", value, ". ")
+                                                     : std::string{" "})
+                                                + msg);
+            });
     }
 
     /*!\brief Initiates the printing of the help page to std::cout.
@@ -309,11 +314,13 @@ public:
             derived_t().print_line("This program must be invoked with one of the following subcommands:", false);
             for (std::string const & name : command_names)
                 derived_t().print_line("- \\fB" + name + "\\fP", false);
-            derived_t().print_line("See the respective help page for further details (e.g. by calling " +
-                                   meta.app_name + " " + command_names[0] + " -h).", true);
+            derived_t().print_line("See the respective help page for further details (e.g. by calling " + meta.app_name
+                                       + " " + command_names[0] + " -h).",
+                                   true);
             derived_t().print_line("The following options below belong to the top-level parser and need to be "
                                    "specified \\fBbefore\\fP the subcommand key word. Every argument after the "
-                                   "subcommand key word is passed on to the corresponding sub-parser.", true);
+                                   "subcommand key word is passed on to the corresponding sub-parser.",
+                                   true);
         }
 
         // add positional options if specified
@@ -353,7 +360,12 @@ public:
      */
     void add_section(std::string const & title, option_spec const spec)
     {
-        store_help_page_element([this, title] () { derived_t().print_section(title); }, spec);
+        store_help_page_element(
+            [this, title]()
+            {
+                derived_t().print_section(title);
+            },
+            spec);
     }
 
     /*!\brief Adds a print_subsection call to parser_set_up_calls.
@@ -361,7 +373,12 @@ public:
      */
     void add_subsection(std::string const & title, option_spec const spec)
     {
-        store_help_page_element([this, title] () { derived_t().print_subsection(title); }, spec);
+        store_help_page_element(
+            [this, title]()
+            {
+                derived_t().print_subsection(title);
+            },
+            spec);
     }
 
     /*!\brief Adds a print_line call to parser_set_up_calls.
@@ -369,7 +386,12 @@ public:
      */
     void add_line(std::string const & text, bool is_paragraph, option_spec const spec)
     {
-        store_help_page_element([this, text, is_paragraph] () { derived_t().print_line(text, is_paragraph); }, spec);
+        store_help_page_element(
+            [this, text, is_paragraph]()
+            {
+                derived_t().print_line(text, is_paragraph);
+            },
+            spec);
     }
 
     /*!\brief Adds a seqan3::print_list_item call to parser_set_up_calls.
@@ -377,7 +399,12 @@ public:
      */
     void add_list_item(std::string const & key, std::string const & desc, option_spec const spec)
     {
-        store_help_page_element([this, key, desc] () { derived_t().print_list_item(key, desc); }, spec);
+        store_help_page_element(
+            [this, key, desc]()
+            {
+                derived_t().print_list_item(key, desc);
+            },
+            spec);
     }
 
     /*!\brief Stores all meta information about the application
@@ -449,11 +476,8 @@ protected:
     void print_legal()
     {
         // Print legal stuff
-        if ((!empty(meta.short_copyright)) ||
-            (!empty(meta.long_copyright)) ||
-            (!empty(meta.citation)) ||
-            (!empty(meta.author)) ||
-            (!empty(meta.email)))
+        if ((!empty(meta.short_copyright)) || (!empty(meta.long_copyright)) || (!empty(meta.citation))
+            || (!empty(meta.author)) || (!empty(meta.email)))
         {
             derived_t().print_section("Legal");
 
@@ -473,8 +497,9 @@ protected:
                 derived_t().print_line(derived_t().in_bold("Contact: ") + meta.email, false);
             }
 
-            derived_t().print_line(derived_t().in_bold("SeqAn Copyright: ") +
-                                   "2006-2021 Knut Reinert, FU-Berlin; released under the 3-clause BSDL.", false);
+            derived_t().print_line(derived_t().in_bold("SeqAn Copyright: ")
+                                       + "2006-2022 Knut Reinert, FU-Berlin; released under the 3-clause BSDL.",
+                                   false);
 
             if (!empty(meta.citation))
             {
@@ -484,8 +509,8 @@ protected:
 
             if (!empty(meta.long_copyright))
             {
-                derived_t().print_line("For full copyright and/or warranty information see " +
-                                       derived_t().in_bold("--copyright") + ".",
+                derived_t().print_line("For full copyright and/or warranty information see "
+                                           + derived_t().in_bold("--copyright") + ".",
                                        false);
             }
         }
