@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -12,15 +12,14 @@
 
 #pragma once
 
+#include <concepts>
 #include <seqan3/std/charconv>
-#include <seqan3/std/concepts>
 #include <sstream>
 #include <string>
 #include <vector>
 
 #include <seqan3/argument_parser/detail/format_base.hpp>
 #include <seqan3/utility/char_operations/predicate.hpp>
-#include <seqan3/utility/detail/type_name_as_string.hpp>
 
 namespace seqan3::detail
 {
@@ -49,7 +48,7 @@ namespace seqan3::detail
  * the vector format_parse::argv. That way, options that are specified multiple times,
  * but are no container type, can be identified and an error is reported.
  *
- * \remark For a complete overview, take a look at \ref argument_parser 
+ * \remark For a complete overview, take a look at \ref argument_parser
  */
 class format_parse : public format_base
 {
@@ -68,8 +67,7 @@ public:
      * \param[in] argc_ The number of command line arguments.
      * \param[in] argv_ The command line arguments to parse.
      */
-    format_parse(int const argc_, std::vector<std::string> argv_) :
-        argc{argc_ - 1}, argv{std::move(argv_)}
+    format_parse(int const argc_, std::vector<std::string> argv_) : argc{argc_ - 1}, argv{std::move(argv_)}
     {}
     //!\}
 
@@ -84,10 +82,11 @@ public:
                     option_spec const spec,
                     validator_type && option_validator)
     {
-        option_calls.push_back([this, &value, short_id, long_id, spec, option_validator]()
-        {
-            get_option(value, short_id, long_id, spec, option_validator);
-        });
+        option_calls.push_back(
+            [this, &value, short_id, long_id, spec, option_validator]()
+            {
+                get_option(value, short_id, long_id, spec, option_validator);
+            });
     }
 
     /*!\brief Adds a get_flag call to be evaluated later on.
@@ -99,10 +98,11 @@ public:
                   std::string const & SEQAN3_DOXYGEN_ONLY(desc),
                   option_spec const & SEQAN3_DOXYGEN_ONLY(spec))
     {
-        flag_calls.push_back([this, &value, short_id, long_id]()
-        {
-            get_flag(value, short_id, long_id);
-        });
+        flag_calls.push_back(
+            [this, &value, short_id, long_id]()
+            {
+                get_flag(value, short_id, long_id);
+            });
     }
 
     /*!\brief Adds a get_positional_option call to be evaluated later on.
@@ -113,10 +113,11 @@ public:
                                std::string const & SEQAN3_DOXYGEN_ONLY(desc),
                                validator_type && option_validator)
     {
-        positional_option_calls.push_back([this, &value, option_validator]()
-        {
-            get_positional_option(value, option_validator);
-        });
+        positional_option_calls.push_back(
+            [this, &value, option_validator]()
+            {
+                get_positional_option(value, option_validator);
+            });
     }
 
     //!\brief Initiates the actual command line parsing.
@@ -145,10 +146,14 @@ public:
 
     // functions are not needed for command line parsing but are part of the format interface.
     //!\cond
-    void add_section(std::string const &, option_spec const) {}
-    void add_subsection(std::string const &, option_spec const) {}
-    void add_line(std::string const &, bool, option_spec const) {}
-    void add_list_item(std::string const &, std::string const &, option_spec const) {}
+    void add_section(std::string const &, option_spec const)
+    {}
+    void add_subsection(std::string const &, option_spec const)
+    {}
+    void add_line(std::string const &, bool, option_spec const)
+    {}
+    void add_list_item(std::string const &, std::string const &, option_spec const)
+    {}
     //!\endcond
 
     //!\brief Checks whether `id` is empty.
@@ -188,32 +193,34 @@ public:
         if (is_empty_id(id))
             return end_it;
 
-        return (std::find_if(begin_it, end_it,
-            [&] (std::string const & current_arg)
-            {
-                std::string full_id = prepend_dash(id);
+        return (std::find_if(begin_it,
+                             end_it,
+                             [&](std::string const & current_arg)
+                             {
+                                 std::string full_id = prepend_dash(id);
 
-                if constexpr (std::same_as<id_type, char>) // short id
-                {
-                    // check if current_arg starts with "-o", i.e. it correctly identifies all short notations:
-                    // "-ovalue", "-o=value", and "-o value".
-                    return current_arg.substr(0, full_id.size()) == full_id;
-                }
-                else
-                {
-                    // only "--opt Value" or "--opt=Value" are valid
-                    return current_arg.substr(0, full_id.size()) == full_id && // prefix is the same
-                           (current_arg.size() == full_id.size() || current_arg[full_id.size()] == '='); // space or `=`
-                }
-            }));
+                                 if constexpr (std::same_as<id_type, char>) // short id
+                                 {
+                                     // check if current_arg starts with "-o", i.e. it correctly identifies all short notations:
+                                     // "-ovalue", "-o=value", and "-o value".
+                                     return current_arg.substr(0, full_id.size()) == full_id;
+                                 }
+                                 else
+                                 {
+                                     // only "--opt Value" or "--opt=Value" are valid
+                                     return current_arg.substr(0, full_id.size()) == full_id && // prefix is the same
+                                            (current_arg.size() == full_id.size()
+                                             || current_arg[full_id.size()] == '='); // space or `=`
+                                 }
+                             }));
     }
 
 private:
     //!\brief Describes the result of parsing the user input string given the respective option value type.
     enum class option_parse_result
     {
-        success, //!< Parsing of user input was successful.
-        error, //!< There was some error while trying to parse the user input.
+        success,       //!< Parsing of user input was successful.
+        error,         //!< There was some error while trying to parse the user input.
         overflow_error //!< Parsing was successful but the arithmetic value would cause an overflow.
     };
 
@@ -232,7 +239,7 @@ private:
     */
     static std::string prepend_dash(char const short_id)
     {
-        return {"-" + std::string{short_id}};
+        return {'-', short_id};
     }
 
     /*!\brief Returns "-[short_id]/--[long_id]" if both are non-empty or just one of them if the other is empty.
@@ -260,7 +267,7 @@ private:
         if (it != end_of_options_it)
             *it = ""; // remove seen flag
 
-        return(it != end_of_options_it);
+        return (it != end_of_options_it);
     }
 
     /*!\brief Returns true and removes the short identifier if it is in format_parse::argv.
@@ -297,9 +304,7 @@ private:
      *          operator and otherwise seqan3::option_parse_result::success.
      */
     template <typename option_t>
-    //!\cond
         requires input_stream_over<std::istringstream, option_t>
-    //!\endcond
     option_parse_result parse_option_value(option_t & value, std::string const & in)
     {
         std::istringstream stream{in};
@@ -326,18 +331,21 @@ private:
         if (auto it = map.find(in); it == map.end())
         {
             std::vector<std::pair<std::string_view, option_t>> key_value_pairs(map.begin(), map.end());
-            std::ranges::sort(key_value_pairs, [] (auto pair1, auto pair2)
-                {
-                    if constexpr (std::totally_ordered<option_t>)
-                    {
-                        if (pair1.second != pair2.second)
-                            return pair1.second < pair2.second;
-                    }
-                    return pair1.first < pair2.first;
-                });
+            std::ranges::sort(key_value_pairs,
+                              [](auto pair1, auto pair2)
+                              {
+                                  if constexpr (std::totally_ordered<option_t>)
+                                  {
+                                      if (pair1.second != pair2.second)
+                                          return pair1.second < pair2.second;
+                                  }
+                                  return pair1.first < pair2.first;
+                              });
 
-            throw user_input_error{detail::to_string("You have chosen an invalid input value: ", in,
-                                                     ". Please use one of: ", key_value_pairs | std::views::keys)};
+            throw user_input_error{detail::to_string("You have chosen an invalid input value: ",
+                                                     in,
+                                                     ". Please use one of: ",
+                                                     key_value_pairs | std::views::keys)};
         }
         else
         {
@@ -356,20 +364,24 @@ private:
     //!\endcond
 
     /*!\brief Parses the given option value and appends it to the target container.
-     * \tparam container_option_t Must model the seqan3::sequence_container and
+     * \tparam container_option_t Must model seqan3::detail::is_container_option and
      *                            its value_type must be parseable via parse_option_value
+     * \tparam format_parse_t Needed to make the function "dependent" (i.e. do instantiation in the second phase of
+     *                        two-phase lookup) as the requires clause needs to be able to access the other
+     *                        parse_option_value overloads.
      *
      * \param[out] value The container that stores the parsed value.
      * \param[in] in The input argument to be parsed.
      * \returns A seqan3::option_parse_result whether parsing was successful or not.
      */
-    template <sequence_container container_option_t>
-    //!\cond
-        requires requires (format_parse fp, typename container_option_t::value_type & container_value, std::string const & in)
-        {
-            SEQAN3_RETURN_TYPE_CONSTRAINT(fp.parse_option_value(container_value, in), std::same_as, option_parse_result);
-        }
-    //!\endcond
+    template <detail::is_container_option container_option_t, typename format_parse_t = format_parse>
+        requires requires (format_parse_t fp,
+                           typename container_option_t::value_type & container_value,
+                           std::string const & in) {
+                     {
+                         fp.parse_option_value(container_value, in)
+                         } -> std::same_as<option_parse_result>;
+                 }
     option_parse_result parse_option_value(container_option_t & value, std::string const & in)
     {
         typename container_option_t::value_type tmp{};
@@ -395,9 +407,7 @@ private:
      * This function delegates to std::from_chars.
      */
     template <arithmetic option_t>
-    //!\cond
         requires input_stream_over<std::istringstream, option_t>
-    //!\endcond
     option_parse_result parse_option_value(option_t & value, std::string const & in)
     {
         auto res = std::from_chars(&in[0], &in[in.size()], value);
@@ -452,17 +462,17 @@ private:
 
         if (res == option_parse_result::error)
         {
-            throw user_input_error{msg + "Argument " + input_value + " could not be parsed as type " +
-                                   get_type_name_as_string(option_type{}) + "."};
+            throw user_input_error{msg + "Argument " + input_value + " could not be parsed as type "
+                                   + get_type_name_as_string(option_type{}) + "."};
         }
 
         if constexpr (arithmetic<option_type>)
         {
             if (res == option_parse_result::overflow_error)
             {
-                throw user_input_error{msg + "Numeric argument " + input_value + " is not in the valid range [" +
-                                       std::to_string(std::numeric_limits<option_type>::min()) + "," +
-                                       std::to_string(std::numeric_limits<option_type>::max()) + "]."};
+                throw user_input_error{msg + "Numeric argument " + input_value + " is not in the valid range ["
+                                       + std::to_string(std::numeric_limits<option_type>::min()) + ","
+                                       + std::to_string(std::numeric_limits<option_type>::max()) + "]."};
             }
         }
 
@@ -555,10 +565,10 @@ private:
             identify_and_retrieve_option_value(value, it, id);
 
         if (find_option_id(it, end_of_options_it, id) != end_of_options_it) // should not be found again
-           throw option_declared_multiple_times("Option " + prepend_dash(id) +
-                                                " is no list/container but declared multiple times.");
+            throw option_declared_multiple_times("Option " + prepend_dash(id)
+                                                 + " is no list/container but declared multiple times.");
 
-       return (it != end_of_options_it); // first search was successful or not
+        return (it != end_of_options_it); // first search was successful or not
     }
 
     /*!\brief Handles value retrieval (container type) options.
@@ -572,10 +582,7 @@ private:
      * multiple times.
      *
      */
-    template <sequence_container option_type, typename id_type>
-    //!\cond
-        requires (!std::is_same_v<option_type, std::string>)
-    //!\endcond
+    template <detail::is_container_option option_type, typename id_type>
     bool get_option_by_id(option_type & value, id_type const & id)
     {
         auto it = find_option_id(argv.begin(), end_of_options_it, id);
@@ -619,17 +626,17 @@ private:
                 }
                 else if (arg[1] != '-' && arg.size() > 2) // one dash, but more than one character (-> multiple flags)
                 {
-                    throw unknown_option("Unknown flags " + expand_multiple_flags(arg) +
-                                         ". In case this is meant to be a non-option/argument/parameter, " +
-                                         "please specify the start of arguments with '--'. " +
-                                         "See -h/--help for program information.");
+                    throw unknown_option("Unknown flags " + expand_multiple_flags(arg)
+                                         + ". In case this is meant to be a non-option/argument/parameter, "
+                                         + "please specify the start of arguments with '--'. "
+                                         + "See -h/--help for program information.");
                 }
                 else // unknown short or long option
                 {
-                    throw unknown_option("Unknown option " + arg +
-                                         ". In case this is meant to be a non-option/argument/parameter, " +
-                                         "please specify the start of non-options with '--'. " +
-                                         "See -h/--help for program information.");
+                    throw unknown_option("Unknown option " + arg
+                                         + ". In case this is meant to be a non-option/argument/parameter, "
+                                         + "please specify the start of non-options with '--'. "
+                                         + "See -h/--help for program information.");
                 }
             }
         }
@@ -648,7 +655,13 @@ private:
      */
     void check_for_left_over_args()
     {
-        if (std::find_if(argv.begin(), argv.end(), [](std::string const & s){return (s != "");}) != argv.end())
+        if (std::find_if(argv.begin(),
+                         argv.end(),
+                         [](std::string const & s)
+                         {
+                             return (s != "");
+                         })
+            != argv.end())
             throw too_many_arguments("Too many arguments provided. Please see -h/--help for more information.");
     }
 
@@ -674,19 +687,18 @@ private:
      */
     template <typename option_type, typename validator_type>
     void get_option(option_type & value,
-                     char const short_id,
-                     std::string const & long_id,
-                     option_spec const spec,
-                     validator_type && validator)
+                    char const short_id,
+                    std::string const & long_id,
+                    option_spec const spec,
+                    validator_type && validator)
     {
         bool short_id_is_set{get_option_by_id(value, short_id)};
         bool long_id_is_set{get_option_by_id(value, long_id)};
 
         // if value is no container we need to check for multiple declarations
-        if (short_id_is_set && long_id_is_set &&
-            !(sequence_container<option_type> && !std::is_same_v<option_type, std::string>))
-            throw option_declared_multiple_times("Option " + combine_option_names(short_id, long_id) +
-                                                 " is no list/container but specified multiple times");
+        if (short_id_is_set && long_id_is_set && !detail::is_container_option<option_type>)
+            throw option_declared_multiple_times("Option " + combine_option_names(short_id, long_id)
+                                                 + " is no list/container but specified multiple times");
 
         if (short_id_is_set || long_id_is_set)
         {
@@ -696,16 +708,16 @@ private:
             }
             catch (std::exception & ex)
             {
-                throw validation_error(std::string("Validation failed for option ") +
-                                        combine_option_names(short_id, long_id) + ": " + ex.what());
+                throw validation_error(std::string("Validation failed for option ")
+                                       + combine_option_names(short_id, long_id) + ": " + ex.what());
             }
         }
         else // option is not set
         {
             // check if option is required
             if (spec & option_spec::required)
-                throw required_option_missing("Option " + combine_option_names(short_id, long_id) +
-                                              " is required but not set.");
+                throw required_option_missing("Option " + combine_option_names(short_id, long_id)
+                                              + " is required but not set.");
         }
     }
 
@@ -716,9 +728,7 @@ private:
      * \param[in]  long_id  The long identifier for the flag (e.g. "integer").
      *
      */
-    void get_flag(bool & value,
-                  char const short_id,
-                  std::string const & long_id)
+    void get_flag(bool & value, char const short_id, std::string const & long_id)
     {
         value = flag_is_set(short_id) || flag_is_set(long_id);
     }
@@ -746,18 +756,23 @@ private:
      * - retrieves the next (no container type) or all (container type) remaining non empty value/s in argv
      */
     template <typename option_type, typename validator_type>
-    void get_positional_option(option_type & value,
-                               validator_type && validator)
+    void get_positional_option(option_type & value, validator_type && validator)
     {
         ++positional_option_count;
-        auto it = std::find_if(argv.begin(), argv.end(), [](std::string const & s){return (s != "");});
+        auto it = std::find_if(argv.begin(),
+                               argv.end(),
+                               [](std::string const & s)
+                               {
+                                   return (s != "");
+                               });
 
         if (it == argv.end())
-            throw too_few_arguments("Not enough positional arguments provided (Need at least " +
-                                    std::to_string(positional_option_calls.size()) +
-                                    "). See -h/--help for more information.");
+            throw too_few_arguments("Not enough positional arguments provided (Need at least "
+                                    + std::to_string(positional_option_calls.size())
+                                    + "). See -h/--help for more information.");
 
-        if constexpr (sequence_container<option_type> && !std::is_same_v<option_type, std::string>) // vector/list will be filled with all remaining arguments
+        if constexpr (detail::is_container_option<
+                          option_type>) // vector/list will be filled with all remaining arguments
         {
             assert(positional_option_count == positional_option_calls.size()); // checked on set up.
 
@@ -770,7 +785,12 @@ private:
                 throw_on_input_error<option_type>(res, id, *it);
 
                 *it = ""; // remove arg from argv
-                it = std::find_if(it, argv.end(), [](std::string const & s){return (s != "");});
+                it = std::find_if(it,
+                                  argv.end(),
+                                  [](std::string const & s)
+                                  {
+                                      return (s != "");
+                                  });
                 ++positional_option_count;
             }
         }
@@ -789,8 +809,8 @@ private:
         }
         catch (std::exception & ex)
         {
-            throw validation_error("Validation failed for positional option " +
-                                    std::to_string(positional_option_count) + ": " + ex.what());
+            throw validation_error("Validation failed for positional option " + std::to_string(positional_option_count)
+                                   + ": " + ex.what());
         }
     }
 
@@ -810,4 +830,4 @@ private:
     std::vector<std::string>::iterator end_of_options_it;
 };
 
-} // namespace seqan3
+} // namespace seqan3::detail
