@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -12,16 +12,17 @@
 
 #pragma once
 
-#include <seqan3/std/algorithm>
+#include <algorithm>
 #include <atomic>
-#include <seqan3/std/bit>
+#include <bit>
+#include <cassert>
 #include <cmath>
-#include <seqan3/std/concepts>
+#include <concepts>
 #include <mutex>
 #include <seqan3/std/new>
-#include <seqan3/std/ranges>
+#include <ranges>
 #include <shared_mutex>
-#include <seqan3/std/span>
+#include <span>
 #include <type_traits>
 #include <vector>
 
@@ -377,7 +378,7 @@ using dynamic_buffer_queue = buffer_queue<value_t, buffer_t, buffer_queue_policy
 // Functions
 // ============================================================================
 
-template <typename value_t, typename buffer_t, buffer_queue_policy buffer_policy>
+template <std::semiregular value_t, sequence_container buffer_t, buffer_queue_policy buffer_policy>
 template <typename value2_t>
     requires (std::convertible_to<value2_t, value_t>) &&
              (buffer_policy == buffer_queue_policy::dynamic)
@@ -455,7 +456,7 @@ inline bool buffer_queue<value_t, buffer_t, buffer_policy>::overflow(value2_t &&
  *                            Default is @link ParallelismTags#Parallel @endlink.
  * @return        bool        Returns <tt>true</tt> if a value could be dequeued and <tt>false</tt> otherwise.
  */
-template <typename value_t, typename buffer_t, buffer_queue_policy buffer_policy>
+template <std::semiregular value_t, sequence_container buffer_t, buffer_queue_policy buffer_policy>
 inline queue_op_status buffer_queue<value_t, buffer_t, buffer_policy>::try_pop(value_t & result)
 {
     // try to extract a value
@@ -530,7 +531,7 @@ inline queue_op_status buffer_queue<value_t, buffer_t, buffer_policy>::try_pop(v
  *                            @endlink tag can only be used if one thread calls <tt>appendValue</tt> at a time.
  *                            Default is @link ParallelismTags#Parallel @endlink.
  */
-template <typename value_t, typename buffer_t, buffer_queue_policy buffer_policy>
+template <std::semiregular value_t, sequence_container buffer_t, buffer_queue_policy buffer_policy>
 template <typename value2_t>
     requires std::convertible_to<value2_t, value_t>
 inline queue_op_status buffer_queue<value_t, buffer_t, buffer_policy>::try_push(value2_t && value)
