@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -17,8 +17,8 @@
 #include <seqan3/core/platform.hpp>
 
 #if SEQAN3_WITH_CEREAL
-#include <cereal/details/traits.hpp>
-#include <cereal/archives/binary.hpp>
+#    include <cereal/archives/binary.hpp>
+#    include <cereal/details/traits.hpp>
 #endif
 
 namespace seqan3
@@ -40,10 +40,10 @@ namespace seqan3
 //!\cond
 #if SEQAN3_WITH_CEREAL
 template <typename t>
-SEQAN3_CONCEPT cereal_output_archive = std::is_base_of_v<cereal::detail::OutputArchiveBase, t>;
+concept cereal_output_archive = std::is_base_of_v<cereal::detail::OutputArchiveBase, t>;
 #else
 template <typename t>
-SEQAN3_CONCEPT cereal_output_archive = false;
+concept cereal_output_archive = false;
 #endif
 //!\endcond
 
@@ -63,10 +63,10 @@ SEQAN3_CONCEPT cereal_output_archive = false;
 //!\cond
 #if SEQAN3_WITH_CEREAL
 template <typename t>
-SEQAN3_CONCEPT cereal_input_archive = std::is_base_of_v<cereal::detail::InputArchiveBase, t>;
+concept cereal_input_archive = std::is_base_of_v<cereal::detail::InputArchiveBase, t>;
 #else
 template <typename t>
-SEQAN3_CONCEPT cereal_input_archive = false;
+concept cereal_input_archive = false;
 #endif
 //!\endcond
 
@@ -82,10 +82,10 @@ SEQAN3_CONCEPT cereal_input_archive = false;
 //!\cond
 #if SEQAN3_WITH_CEREAL
 template <typename t>
-SEQAN3_CONCEPT cereal_archive = cereal_output_archive<t> || cereal_input_archive<t>;
+concept cereal_archive = cereal_output_archive<t> || cereal_input_archive<t>;
 #else
 template <typename t>
-SEQAN3_CONCEPT cereal_archive = false;
+concept cereal_archive = false;
 #endif
 //!\endcond
 
@@ -105,10 +105,10 @@ SEQAN3_CONCEPT cereal_archive = false;
 //!\cond
 #if SEQAN3_WITH_CEREAL
 template <typename t>
-SEQAN3_CONCEPT cereal_text_archive = std::is_base_of_v<cereal::traits::TextArchive, t>;
+concept cereal_text_archive = std::is_base_of_v<cereal::traits::TextArchive, t>;
 #else
 template <typename t>
-SEQAN3_CONCEPT cereal_text_archive = false;
+concept cereal_text_archive = false;
 #endif
 //!\endcond
 
@@ -149,14 +149,11 @@ SEQAN3_CONCEPT cereal_text_archive = false;
 template <typename value_t,
           typename input_archive_t = cereal::BinaryInputArchive,
           typename output_archive_t = cereal::BinaryOutputArchive>
-SEQAN3_CONCEPT cerealisable =
-    cereal::traits::is_input_serializable<value_t, input_archive_t>::value &&
-    cereal::traits::is_output_serializable<value_t, output_archive_t>::value;
+concept cerealisable = cereal::traits::is_input_serializable<value_t, input_archive_t>::value
+                    && cereal::traits::is_output_serializable<value_t, output_archive_t>::value;
 #else
-template <typename value_t,
-          typename input_archive_t = void,
-          typename output_archive_t = void>
-SEQAN3_CONCEPT cerealisable = false;
+template <typename value_t, typename input_archive_t = void, typename output_archive_t = void>
+concept cerealisable = false;
 #endif
 //!\endcond
 
