@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -13,7 +13,7 @@
 
 #pragma once
 
-#include <seqan3/std/concepts>
+#include <concepts>
 
 #include <seqan3/utility/type_traits/detail/transformation_trait_or.hpp>
 
@@ -25,7 +25,7 @@ namespace seqan3::detail
 // ----------------------------------------------------------------------------
 
 //!\cond
-template <typename source_type, template <typename ...> typename target_template>
+template <typename source_type, template <typename...> typename target_template>
 struct transfer_template_args_onto
 {};
 //!\endcond
@@ -54,15 +54,11 @@ struct transfer_template_args_onto
  *
  * \include test/snippet/core/detail/template_inspection_usage.cpp
  */
-template <template <typename ...> typename source_template,
-          template <typename ...> typename target_template,
-          typename ...source_arg_types>
-//!\cond
-    requires requires ()
-    {
-        typename target_template<source_arg_types...>;
-    }
-//!\endcond
+template <template <typename...> typename source_template,
+          template <typename...>
+          typename target_template,
+          typename... source_arg_types>
+    requires requires () { typename target_template<source_arg_types...>; }
 struct transfer_template_args_onto<source_template<source_arg_types...>, target_template>
 {
     //!\brief The return type: the target type specialised by the unpacked types in the list.
@@ -73,7 +69,7 @@ struct transfer_template_args_onto<source_template<source_arg_types...>, target_
  * \ingroup core
  * \see seqan3::detail::transfer_template_args_onto
  */
-template <typename source_type, template <typename ...> typename target_template>
+template <typename source_type, template <typename...> typename target_template>
 using transfer_template_args_onto_t = typename transfer_template_args_onto<source_type, target_template>::type;
 
 // ----------------------------------------------------------------------------
@@ -81,7 +77,7 @@ using transfer_template_args_onto_t = typename transfer_template_args_onto<sourc
 // ----------------------------------------------------------------------------
 
 //!\cond
-template <typename source_type, template <auto ...> typename target_template>
+template <typename source_type, template <auto...> typename target_template>
 struct transfer_template_vargs_onto
 {};
 //!\endcond
@@ -103,15 +99,11 @@ struct transfer_template_vargs_onto
  * no transformation trait that can handle a combination of type and non-type arguments.
  * If the `source_type` is a not a template class, e.g. an `int`, the member type `type` is not defined.
  */
-template <template <auto ...> typename source_template,
-          template <auto ...> typename target_template,
-          auto ... source_varg_types>
-//!\cond
-    requires requires ()
-    {
-        typename target_template<source_varg_types...>;
-    }
-//!\endcond
+template <template <auto...> typename source_template,
+          template <auto...>
+          typename target_template,
+          auto... source_varg_types>
+    requires requires () { typename target_template<source_varg_types...>; }
 struct transfer_template_vargs_onto<source_template<source_varg_types...>, target_template>
 {
     //!\brief The return type: the target type specialised by the unpacked types in the list.
@@ -122,7 +114,7 @@ struct transfer_template_vargs_onto<source_template<source_varg_types...>, targe
  * \ingroup core
  * \see seqan3::detail::transfer_template_vargs_onto
  */
-template <typename source_type, template <auto ...> typename target_template>
+template <typename source_type, template <auto...> typename target_template>
 using transfer_template_vargs_onto_t = typename transfer_template_vargs_onto<source_type, target_template>::type;
 
 // ----------------------------------------------------------------------------
@@ -141,18 +133,16 @@ using transfer_template_vargs_onto_t = typename transfer_template_vargs_onto<sou
  *
  * \include test/snippet/core/detail/template_inspection_usage_2.cpp
  */
-template <typename source_t, template <typename ...> typename target_template>
+template <typename source_t, template <typename...> typename target_template>
 struct is_type_specialisation_of : public std::false_type
 {};
 
 //!\overload
-template <typename source_t, template <typename ...> typename target_template>
-//!\cond
-    requires (!std::same_as<transformation_trait_or_t<transfer_template_args_onto<source_t, target_template>, void>,
-                            void>)
-//!\endcond
+template <typename source_t, template <typename...> typename target_template>
+    requires (
+        !std::same_as<transformation_trait_or_t<transfer_template_args_onto<source_t, target_template>, void>, void>)
 struct is_type_specialisation_of<source_t, target_template> :
-        std::is_same<source_t, transfer_template_args_onto_t<source_t, target_template>>
+    std::is_same<source_t, transfer_template_args_onto_t<source_t, target_template>>
 {};
 
 /*!\brief Helper variable template for seqan3::detail::is_type_specialisation_of (unary_type_trait shortcut).
@@ -160,7 +150,7 @@ struct is_type_specialisation_of<source_t, target_template> :
  * \tparam source_type      The source type.
  * \tparam target_template  The type template you wish to compare against (must take only types as template arguments).
  */
-template <typename source_t, template <typename ...> typename target_template>
+template <typename source_t, template <typename...> typename target_template>
 inline constexpr bool is_type_specialisation_of_v = is_type_specialisation_of<source_t, target_template>::value;
 
 // ----------------------------------------------------------------------------
@@ -168,7 +158,7 @@ inline constexpr bool is_type_specialisation_of_v = is_type_specialisation_of<so
 // ----------------------------------------------------------------------------
 
 //!\cond
-template <typename source_t, template <auto ...> typename target_template>
+template <typename source_t, template <auto...> typename target_template>
 struct is_value_specialisation_of : std::false_type
 {};
 //!\endcond
@@ -182,11 +172,9 @@ struct is_value_specialisation_of : std::false_type
  * \see seqan3::detail::is_type_specialisation_of
  * \see seqan3::detail::is_value_specialisation_of_v
  */
-template <typename source_t, template <auto ...> typename target_template>
-//!\cond
-    requires (!std::same_as<transformation_trait_or_t<transfer_template_vargs_onto<source_t, target_template>, void>,
-                            void>)
-//!\endcond
+template <typename source_t, template <auto...> typename target_template>
+    requires (
+        !std::same_as<transformation_trait_or_t<transfer_template_vargs_onto<source_t, target_template>, void>, void>)
 struct is_value_specialisation_of<source_t, target_template> :
     std::is_same<source_t, transfer_template_vargs_onto_t<source_t, target_template>>
 {};
@@ -196,7 +184,7 @@ struct is_value_specialisation_of<source_t, target_template> :
  * \tparam source_type      The source type.
  * \tparam target_template  The type template you wish to compare against (must take only types as template arguments).
  */
-template <typename source_t, template <auto ...> typename target_template>
+template <typename source_t, template <auto...> typename target_template>
 inline constexpr bool is_value_specialisation_of_v = is_value_specialisation_of<source_t, target_template>::value;
 
 /*!\brief Exposes `templ_t<spec_t...>` if that is valid, otherwise `fallback_t`.
@@ -207,7 +195,7 @@ inline constexpr bool is_value_specialisation_of_v = is_value_specialisation_of<
  * \tparam templ_t    The type template that should be specialised.
  * \tparam spec_t     The specialisation for the type template.
  */
-template <typename fallback_t, template <typename ...> typename templ_t, typename ...spec_t>
+template <typename fallback_t, template <typename...> typename templ_t, typename... spec_t>
 struct valid_template_spec_or
 {
     //!\brief The resulting type.
@@ -215,10 +203,8 @@ struct valid_template_spec_or
 };
 
 //!\overload
-template <typename fallback_t, template <typename ...> typename templ_t, typename ...spec_t>
-//!\cond
+template <typename fallback_t, template <typename...> typename templ_t, typename... spec_t>
     requires requires { typename templ_t<spec_t...>; }
-//!\endcond
 struct valid_template_spec_or<fallback_t, templ_t, spec_t...>
 {
     //!\brief The resulting type.
@@ -232,7 +218,7 @@ struct valid_template_spec_or<fallback_t, templ_t, spec_t...>
  * \tparam templ_t    The type template that should be specialised.
  * \tparam spec_t     The specialisation for the type template.
  */
-template <typename fallback_t, template <typename ...> typename templ_t, typename ...spec_t>
+template <typename fallback_t, template <typename...> typename templ_t, typename... spec_t>
 using valid_template_spec_or_t = typename valid_template_spec_or<fallback_t, templ_t, spec_t...>::type;
 
 // ----------------------------------------------------------------------------
@@ -254,8 +240,8 @@ using valid_template_spec_or_t = typename valid_template_spec_or<fallback_t, tem
  * \include test/snippet/core/detail/template_inspection_usage_3.cpp
  */
 //!\cond
-template <typename mytype, template <typename ...> typename type_template>
-SEQAN3_CONCEPT template_specialisation_of = is_type_specialisation_of_v<mytype, type_template>;
+template <typename mytype, template <typename...> typename type_template>
+concept template_specialisation_of = is_type_specialisation_of_v<mytype, type_template>;
 
 //!\endcond
 
@@ -268,7 +254,6 @@ SEQAN3_CONCEPT template_specialisation_of = is_type_specialisation_of_v<mytype,
  * \tparam t The type to operate on.
  */
 template <typename t>
-using strip_type_identity_t = std::conditional_t<is_type_specialisation_of_v<t, std::type_identity>,
-                                                 transformation_trait_or_t<t, void>,
-                                                 t>;
+using strip_type_identity_t =
+    std::conditional_t<is_type_specialisation_of_v<t, std::type_identity>, transformation_trait_or_t<t, void>, t>;
 } // namespace seqan3::detail
