@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -12,10 +12,11 @@
 
 #pragma once
 
-#include <seqan3/std/algorithm>
-#include <seqan3/std/filesystem>
-#include <seqan3/std/iterator>
+#include <algorithm>
+#include <filesystem>
+#include <iterator>
 #include <variant>
+#include <vector>
 
 #include <seqan3/core/detail/template_inspection.hpp>
 #include <seqan3/io/exception.hpp>
@@ -26,12 +27,12 @@ namespace seqan3::detail
 
 //!\brief Base class to deduce the std::variant type from format tags.
 //!\ingroup io
-template <typename list_t, template <typename ...> typename output_t>
+template <typename list_t, template <typename...> typename output_t>
 struct variant_from_tags;
 
 //!\brief Transfers a list of format tags (`...ts`) onto a std::variant by specialising output_t with each.
 //!\ingroup io
-template <template <typename...> typename output_t, typename ...ts>
+template <template <typename...> typename output_t, typename... ts>
 struct variant_from_tags<type_list<ts...>, output_t>
 {
     //!\brief The type of std::variant.
@@ -64,8 +65,7 @@ constexpr void write_eol(it_t & it, bool const add_cr)
  *         \p format_variant_type template argument list.
  */
 template <typename format_variant_type>
-void set_format(format_variant_type & format,
-                std::filesystem::path const & file_name)
+void set_format(format_variant_type & format, std::filesystem::path const & file_name)
 {
     using valid_formats = detail::transfer_template_args_onto_t<format_variant_type, type_list>;
 
@@ -74,20 +74,21 @@ void set_format(format_variant_type & format,
     if (extension.size() > 1)
     {
         extension = extension.substr(1); // drop leading "."
-        detail::for_each<valid_formats>([&] (auto fmt)
-        {
-            using fm_type = typename decltype(fmt)::type; // remove type_identity wrapper
-
-            for (auto const & ext : fm_type::file_extensions)
+        detail::for_each<valid_formats>(
+            [&](auto fmt)
             {
-                if (std::ranges::equal(ext, extension))
+                using fm_type = typename decltype(fmt)::type; // remove type_identity wrapper
+
+                for (auto const & ext : fm_type::file_extensions)
                 {
-                    format.template emplace<fm_type>();
-                    format_found = true;
-                    return;
+                    if (std::ranges::equal(ext, extension))
+                    {
+                        format.template emplace<fm_type>();
+                        format_found = true;
+                        return;
+                    }
                 }
-            }
-        });
+            });
     }
 
     if (!format_found)
@@ -103,8 +104,11 @@ template <typename list_t>
 inline constexpr bool has_member_file_extensions = false;
 
 //!\cond
-template <template <typename ...> typename list_t, typename ...ts>
-    requires (requires { ts::file_extensions; }, ..., true)
+template <template <typename...> typename list_t, typename... ts>
+    requires (
+                 requires { ts::file_extensions; },
+                 ...,
+                 true)
 inline constexpr bool has_member_file_extensions<list_t<ts...>> = true;
 //!\endcond
 
@@ -149,11 +153,12 @@ inline std::vector<std::string> valid_file_extensions()
                   "Expects that all formats have a static member file_extensions storing the extensions in a range");
 
     std::vector<std::string> extensions;
-    detail::for_each<formats_t>([&extensions] (auto t_identity)
-    {
-        using format_t = typename decltype(t_identity)::type;
-        std::ranges::copy(format_t::file_extensions, std::cpp20::back_inserter(extensions));
-    });
+    detail::for_each<formats_t>(
+        [&extensions](auto t_identity)
+        {
+            using format_t = typename decltype(t_identity)::type;
+            std::ranges::copy(format_t::file_extensions, std::back_inserter(extensions));
+        });
 
     return extensions;
 }
