@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -38,16 +38,17 @@ class sam_record : public record<field_types, field_ids>
     using field_constant = typename base_t::template field_constant<f>;
 
     using base_t::get_impl;
+
 public:
     /*!\name Constructors, destructor and assignment
      * \{
      */
-    sam_record() = default; //!< Defaulted.
-    sam_record(sam_record const &) = default; //!< Defaulted.
+    sam_record() = default;                               //!< Defaulted.
+    sam_record(sam_record const &) = default;             //!< Defaulted.
     sam_record & operator=(sam_record const &) = default; //!< Defaulted.
-    sam_record(sam_record &&) = default; //!< Defaulted.
-    sam_record & operator=(sam_record &&) = default; //!< Defaulted.
-    ~sam_record() = default; //!< Defaulted.
+    sam_record(sam_record &&) = default;                  //!< Defaulted.
+    sam_record & operator=(sam_record &&) = default;      //!< Defaulted.
+    ~sam_record() = default;                              //!< Defaulted.
 
     //!\brief Inherit std::tuple's and seqan3::record constructors.
     using base_t::base_t;
@@ -428,8 +429,8 @@ namespace std
  * \see std::tuple_size_v
  */
 template <typename field_types, typename field_ids>
-struct tuple_size<seqan3::sam_record<field_types, field_ids>>
-    : tuple_size<typename seqan3::sam_record<field_types, field_ids>::base_type>
+struct tuple_size<seqan3::sam_record<field_types, field_ids>> :
+    tuple_size<typename seqan3::sam_record<field_types, field_ids>::base_type>
 {};
 
 /*!\brief Obtains the type of the specified element.
@@ -438,8 +439,8 @@ struct tuple_size<seqan3::sam_record<field_types, field_ids>>
  * \see [std::tuple_element](https://en.cppreference.com/w/cpp/utility/tuple/tuple_element)
  */
 template <size_t elem_no, typename field_types, typename field_ids>
-struct tuple_element<elem_no, seqan3::sam_record<field_types, field_ids>>
-    : tuple_element<elem_no, typename seqan3::sam_record<field_types, field_ids>::base_type>
+struct tuple_element<elem_no, seqan3::sam_record<field_types, field_ids>> :
+    tuple_element<elem_no, typename seqan3::sam_record<field_types, field_ids>::base_type>
 {};
 
 } // namespace std
