@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -12,9 +12,9 @@
 
 #pragma once
 
-#include <seqan3/std/algorithm>
+#include <algorithm>
 #include <iterator>
-#include <seqan3/std/ranges>
+#include <ranges>
 #include <string>
 #include <string_view>
 #include <vector>
@@ -43,7 +43,7 @@
 namespace seqan3
 {
 
-/*!\brief The FastA format.
+/*!\brief The FASTA format.
  * \implements sequence_file_input_format
  * \implements sequence_file_output_format
  * \ingroup io_sequence_file
@@ -52,12 +52,12 @@ namespace seqan3
  *
  * ### Introduction
  *
- * FastA is the de-facto-standard for sequence storage in bionformatics. See the
+ * FASTA is the de-facto-standard for sequence storage in bioinformatics. See the
  * [article on wikipedia](https://en.wikipedia.org/wiki/FASTA_format) for a an in-depth description of the format.
  *
  * ### fields_specialisation
  *
- * The FastA format provides the fields seqan3::field::seq and seqan3::field::id. Both fields are required when writing.
+ * The FASTA format provides the fields seqan3::field::seq and seqan3::field::id. Both fields are required when writing.
  *
  * ### Implementation notes
  *
@@ -82,42 +82,46 @@ public:
     /*!\name Constructors, destructor and assignment
      * \{
      */
-    format_fasta() noexcept = default; //!< Defaulted.
-    format_fasta(format_fasta const &) noexcept = default; //!< Defaulted.
+    format_fasta() noexcept = default;                                 //!< Defaulted.
+    format_fasta(format_fasta const &) noexcept = default;             //!< Defaulted.
     format_fasta & operator=(format_fasta const &) noexcept = default; //!< Defaulted.
-    format_fasta(format_fasta &&) noexcept = default; //!< Defaulted.
-    format_fasta & operator=(format_fasta &&) noexcept = default; //!< Defaulted.
-    ~format_fasta() noexcept = default; //!< Defaulted.
+    format_fasta(format_fasta &&) noexcept = default;                  //!< Defaulted.
+    format_fasta & operator=(format_fasta &&) noexcept = default;      //!< Defaulted.
+    ~format_fasta() noexcept = default;                                //!< Defaulted.
 
     //!\}
 
     //!\brief The valid file extensions for this format; note that you can modify this value.
-    static inline std::vector<std::string> file_extensions
-    {
-        { "fasta" },
-        { "fa"    },
-        { "fna"   },
-        { "ffn"   },
-        { "faa"   },
-        { "frn"   },
-        { "fas"   },
+    static inline std::vector<std::string> file_extensions{
+        {"fasta"},
+        {"fa"},
+        {"fna"},
+        {"ffn"},
+        {"faa"},
+        {"frn"},
+        {"fas"},
     };
 
 protected:
     //!\copydoc sequence_file_input_format::read_sequence_record
-    template <typename stream_type,     // constraints checked by file
+    template <typename stream_type, // constraints checked by file
               typename legal_alph_type,
-              typename seq_type,        // other constraints checked inside function
+              typename stream_pos_type,
+              typename seq_type, // other constraints checked inside function
               typename id_type,
               typename qual_type>
     void read_sequence_record(stream_type & stream,
                               sequence_file_input_options<legal_alph_type> const & options,
+                              stream_pos_type & position_buffer,
                               seq_type & sequence,
                               id_type & id,
                               qual_type & SEQAN3_DOXYGEN_ONLY(qualities))
     {
         auto stream_view = detail::istreambuf(stream);
 
+        // Store current position in buffer
+        position_buffer = stream.tellg();
+
         // ID
         read_id(stream_view, options, id);
 
@@ -126,8 +130,8 @@ protected:
     }
 
     //!\copydoc sequence_file_output_format::write_sequence_record
-    template <typename stream_type,     // constraints checked by file
-              typename seq_type,        // other constraints checked inside function
+    template <typename stream_type, // constraints checked by file
+              typename seq_type,    // other constraints checked inside function
               typename id_type,
               typename qual_type>
     void write_sequence_record(stream_type & stream,
@@ -154,7 +158,8 @@ protected:
         // Sequence
         if constexpr (detail::decays_to_ignore_v<seq_type>) // sequence
         {
-            throw std::logic_error{"The SEQ and SEQ_QUAL fields may not both be set to ignore when writing FASTA files."};
+            throw std::logic_error{
+                "The SEQ and SEQ_QUAL fields may not both be set to ignore when writing FASTA files."};
         }
         else
         {
@@ -168,29 +173,34 @@ protected:
 private:
     //!\privatesection
     //!\brief Implementation of reading the ID.
-    template <typename stream_view_t,
-              typename seq_legal_alph_type,
-              typename id_type>
-    void read_id(stream_view_t & stream_view,
-                  sequence_file_input_options<seq_legal_alph_type> const & options,
-                  id_type & id)
+    template <typename stream_view_t, typename seq_legal_alph_type, typename id_type>
+    void
+    read_id(stream_view_t & stream_view, sequence_file_input_options<seq_legal_alph_type> const & options, id_type & id)
     {
         auto const is_id = is_char<'>'> || is_char<';'>;
 
         if (!is_id(*begin(stream_view)))
-            throw parse_error{std::string{"Expected to be on beginning of ID, but "} + is_id.msg +
-                              " evaluated to false on " + detail::make_printable(*begin(stream_view))};
+            throw parse_error{std::string{"Expected to be on beginning of ID, but "} + is_id.msg
+                              + " evaluated to false on " + detail::make_printable(*begin(stream_view))};
 
-        // read id
-        if constexpr (!detail::decays_to_ignore_v<id_type>)
+        if constexpr (detail::decays_to_ignore_v<id_type>) // Skip the ID, it is not requested by the user.
+        {
+            detail::consume(stream_view | detail::take_line_or_throw);
+        }
+        else // read ID
         {
             if (options.truncate_ids)
             {
-            #if SEQAN3_WORKAROUND_VIEW_PERFORMANCE
+#if SEQAN3_WORKAROUND_VIEW_PERFORMANCE
                 auto it = stream_view.begin();
                 auto e = stream_view.end();
-                for (; (it != e) && (is_id || is_blank)(*it); ++it)
-                {}
+                ++it; // already checked `is_id`
+
+                if (options.fasta_ignore_blanks_before_id)
+                {
+                    for (; (it != e) && (is_blank)(*it); ++it) // skip leading ' '
+                    {}
+                }
 
                 bool at_delimiter = false;
                 for (; it != e; ++it)
@@ -204,30 +214,46 @@ private:
                 }
 
                 if (!at_delimiter)
-                    throw unexpected_end_of_input{"FastA ID line did not end in newline."};
+                    throw unexpected_end_of_input{"FASTA ID line did not end in newline."};
 
                 for (; (it != e) && ((!is_char<'\n'>)(*it)); ++it)
                 {}
 
-            #else // ↑↑↑ WORKAROUND | ORIGINAL ↓↓↓
-
-                std::ranges::copy(stream_view | std::views::drop_while(is_id || is_blank)        // skip leading >
-                                              | detail::take_until_or_throw(is_cntrl || is_blank) // read ID until delimiter…
-                                              | views::char_to<std::ranges::range_value_t<id_type>>,
-                                  std::cpp20::back_inserter(id));                               // … ^A is old delimiter
+#else  // ↑↑↑ WORKAROUND | ORIGINAL ↓↓↓
+                if (options.fasta_ignore_blanks_before_id)
+                {
+                    std::ranges::copy(
+                        stream_view | std::views::drop(1)                       // skip leading '>' or ';'
+                            | std::views::drop_while(is_blank)                  // skip leading ' '
+                            | detail::take_until_or_throw(is_cntrl || is_blank) // read ID until delimiter…
+                            | views::char_to<std::ranges::range_value_t<id_type>>,
+                        std::back_inserter(id)); // … ^A is old delimiter
+                }
+                else
+                {
+                    std::ranges::copy(
+                        stream_view | std::views::drop(1)                       // skip leading '>' or ';'
+                            | detail::take_until_or_throw(is_cntrl || is_blank) // read ID until delimiter…
+                            | views::char_to<std::ranges::range_value_t<id_type>>,
+                        std::back_inserter(id)); // … ^A is old delimiter
+                }
 
                 // consume rest of line
                 detail::consume(stream_view | detail::take_line_or_throw);
-            #endif // SEQAN3_WORKAROUND_VIEW_PERFORMANCE
-
+#endif // SEQAN3_WORKAROUND_VIEW_PERFORMANCE
             }
-            else
+            else // options.truncate_ids
             {
-            #if SEQAN3_WORKAROUND_VIEW_PERFORMANCE
+#if SEQAN3_WORKAROUND_VIEW_PERFORMANCE
                 auto it = stream_view.begin();
                 auto e = stream_view.end();
-                for (; (it != e) && (is_id || is_blank)(*it); ++it)
-                {}
+                ++it; // skip leading '>' or ';'
+
+                if (options.fasta_ignore_blanks_before_id)
+                {
+                    for (; (it != e) && (is_blank)(*it); ++it) // skip leading ' '
+                    {}
+                }
 
                 bool at_delimiter = false;
                 for (; it != e; ++it)
@@ -241,38 +267,40 @@ private:
                 }
 
                 if (!at_delimiter)
-                    throw unexpected_end_of_input{"FastA ID line did not end in newline."};
+                    throw unexpected_end_of_input{"FASTA ID line did not end in newline."};
 
-            #else // ↑↑↑ WORKAROUND | ORIGINAL ↓↓↓
-
-                std::ranges::copy(stream_view | detail::take_line_or_throw                   // read line
-                                              | std::views::drop_while(is_id || is_blank)    // skip leading >
-                                              | views::char_to<std::ranges::range_value_t<id_type>>,
-                                  std::cpp20::back_inserter(id));
-            #endif // SEQAN3_WORKAROUND_VIEW_PERFORMANCE
+#else  // ↑↑↑ WORKAROUND | ORIGINAL ↓↓↓
+                if (options.fasta_ignore_blanks_before_id)
+                {
+                    std::ranges::copy(stream_view | detail::take_line_or_throw // read line
+                                          | std::views::drop(1)                // skip leading '>' or ';'
+                                          | std::views::drop_while(is_blank)   // skip leading ' '
+                                          | views::char_to<std::ranges::range_value_t<id_type>>,
+                                      std::back_inserter(id));
+                }
+                else
+                {
+                    std::ranges::copy(stream_view | detail::take_line_or_throw // read line
+                                          | std::views::drop(1)                // skip leading '>' or ';'
+                                          | views::char_to<std::ranges::range_value_t<id_type>>,
+                                      std::back_inserter(id));
+                }
+#endif // SEQAN3_WORKAROUND_VIEW_PERFORMANCE
             }
         }
-        else
-        {
-            detail::consume(stream_view | detail::take_line_or_throw);
-        }
     }
 
     //!\brief Implementation of reading the sequence.
-    template <typename stream_view_t,
-              typename seq_legal_alph_type,
-              typename seq_type>
-    void read_seq(stream_view_t & stream_view,
-                   sequence_file_input_options<seq_legal_alph_type> const &,
-                   seq_type & seq)
+    template <typename stream_view_t, typename seq_legal_alph_type, typename seq_type>
+    void read_seq(stream_view_t & stream_view, sequence_file_input_options<seq_legal_alph_type> const &, seq_type & seq)
     {
-        auto constexpr is_id = is_char<'>'> || is_char<';'>;
+        constexpr auto is_id = is_char<'>'> || is_char<';'>;
 
         if constexpr (!detail::decays_to_ignore_v<seq_type>)
         {
-            auto constexpr is_legal_alph = char_is_valid_for<seq_legal_alph_type>;
+            constexpr auto is_legal_alph = char_is_valid_for<seq_legal_alph_type>;
 
-        #if SEQAN3_WORKAROUND_VIEW_PERFORMANCE
+#if SEQAN3_WORKAROUND_VIEW_PERFORMANCE
             auto it = stream_view.begin();
             auto e = stream_view.end();
 
@@ -285,38 +313,37 @@ private:
                     continue;
                 else if (!is_legal_alph(*it))
                 {
-                    throw parse_error{std::string{"Encountered an unexpected letter: "} +
-                                      "char_is_valid_for<" +
-                                      detail::type_name_as_string<seq_legal_alph_type> +
-                                      "> evaluated to false on " +
-                                      detail::make_printable(*it)};
+                    throw parse_error{std::string{"Encountered an unexpected letter: "} + "char_is_valid_for<"
+                                      + detail::type_name_as_string<seq_legal_alph_type>
+                                      + "> evaluated to false on " + detail::make_printable(*it)};
                 }
 
                 seq.push_back(assign_char_to(*it, std::ranges::range_value_t<seq_type>{}));
             }
 
-        #else // ↑↑↑ WORKAROUND | ORIGINAL ↓↓↓
+#else  // ↑↑↑ WORKAROUND | ORIGINAL ↓↓↓
 
             if (std::ranges::begin(stream_view) == std::ranges::end(stream_view))
                 throw unexpected_end_of_input{"No sequence information given!"};
 
-            std::ranges::copy(stream_view | detail::take_until(is_id)                  // until next header (or end)
-                                          | std::views::filter(!(is_space || is_digit))// ignore whitespace and numbers
-                                          | std::views::transform([is_legal_alph] (char const c)
-                                            {
-                                                if (!is_legal_alph(c))
-                                                {
-                                                    throw parse_error{std::string{"Encountered an unexpected letter: "} +
-                                                                      "char_is_valid_for<" +
-                                                                      detail::type_name_as_string<seq_legal_alph_type> +
-                                                                      "> evaluated to false on " +
-                                                                      detail::make_printable(c)};
-                                                }
-                                                return c;
-                                            })                                      // enforce legal alphabet
-                                          | views::char_to<std::ranges::range_value_t<seq_type>>, // convert to actual target alphabet
-                              std::cpp20::back_inserter(seq));
-        #endif // SEQAN3_WORKAROUND_VIEW_PERFORMANCE
+            std::ranges::copy(
+                stream_view | detail::take_until(is_id)           // until next header (or end)
+                    | std::views::filter(!(is_space || is_digit)) // ignore whitespace and numbers
+                    | std::views::transform(
+                        [is_legal_alph](char const c)
+                        {
+                            if (!is_legal_alph(c))
+                            {
+                                throw parse_error{std::string{"Encountered an unexpected letter: "}
+                                                  + "char_is_valid_for<"
+                                                  + detail::type_name_as_string<seq_legal_alph_type>
+                                                  + "> evaluated to false on " + detail::make_printable(c)};
+                            }
+                            return c;
+                        })                                                  // enforce legal alphabet
+                    | views::char_to<std::ranges::range_value_t<seq_type>>, // convert to actual target alphabet
+                std::back_inserter(seq));
+#endif // SEQAN3_WORKAROUND_VIEW_PERFORMANCE
         }
         else
         {
@@ -370,4 +397,4 @@ private:
     }
 };
 
-} // namespace seqan
+} // namespace seqan3
