@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -40,12 +40,11 @@ template <typename format_type>
 struct sequence_file_input_format_exposer : public format_type
 {
 public:
-
     // Can't use `using format_type::read_sequence_record` as it produces a hard failure in the format concept check
     // for types that do not model the format concept, i.e. don't offer the proper read_sequence_record interface.
     //!\brief Forwards to the seqan3::sequence_file_input_format::read_sequence_record interface.
-    template <typename ...ts>
-    void read_sequence_record(ts && ...args)
+    template <typename... ts>
+    void read_sequence_record(ts &&... args)
     {
         format_type::read_sequence_record(std::forward<ts>(args)...);
     }
@@ -70,21 +69,27 @@ namespace seqan3
  */
 //!\cond
 template <typename t>
-SEQAN3_CONCEPT sequence_file_input_format = requires (detail::sequence_file_input_format_exposer<t> & v,
-                                                      std::ifstream                                 & f,
-                                                      sequence_file_input_options<dna5>             & options,
-                                                      std::vector<dna5>                             & seq,
-                                                      std::string                                   & id,
-                                                      std::vector<phred42>                          & qual,
-                                                      std::vector<qualified<dna5, phred42>>         & seq_qual)
-{
-    t::file_extensions;
+concept sequence_file_input_format =
+    requires (detail::sequence_file_input_format_exposer<t> & v,
+              std::ifstream & f,
+              sequence_file_input_options<dna5> & options,
+              std::streampos & position_buffer,
+              std::vector<dna5> & seq,
+              std::string & id,
+              std::vector<phred42> & qual,
+              std::vector<qualified<dna5, phred42>> & seq_qual) {
+        t::file_extensions;
 
-    SEQAN3_RETURN_TYPE_CONSTRAINT(v.read_sequence_record(f, options, seq, id, qual), std::same_as, void);
-    SEQAN3_RETURN_TYPE_CONSTRAINT(v.read_sequence_record(f, options, seq_qual, id, seq_qual), std::same_as, void);
-    SEQAN3_RETURN_TYPE_CONSTRAINT(v.read_sequence_record(f, options, std::ignore, std::ignore, std::ignore),
-                                  std::same_as, void);
-};
+        {
+            v.read_sequence_record(f, options, position_buffer, seq, id, qual)
+            } -> std::same_as<void>;
+        {
+            v.read_sequence_record(f, options, position_buffer, seq_qual, id, seq_qual)
+            } -> std::same_as<void>;
+        {
+            v.read_sequence_record(f, options, position_buffer, std::ignore, std::ignore, std::ignore)
+            } -> std::same_as<void>;
+    };
 //!\endcond
 
 /*!\name Requirements for seqan3::sequence_file_input_format
@@ -93,10 +98,15 @@ SEQAN3_CONCEPT sequence_file_input_format = requires (detail::sequence_file_inpu
  * \{
  */
 
-/*!\fn void read_sequence_record(stream_type & stream, seqan3::sequence_file_input_options const & options, seq_type & sequence,
- *               id_type & id, qual_type & qualities)
+/*!\fn void read_sequence_record(stream_type & stream,
+                                 seqan3::sequence_file_input_options const & options,
+                                 stream_pos_type & position_buffer,
+                                 seq_type & sequence,
+                                 id_type & id,
+                                 qual_type & qualities)
  * \brief Read from the specified stream and back-insert into the given field buffers.
  * \tparam stream_type      Input stream, must satisfy seqan3::input_stream_over with `char`.
+ * \tparam stream_pos_type  Buffer for storing the current record's file position.
  * \tparam seq_type         Type of the seqan3::field::seq input; must satisfy std::ranges::output_range
  * over a seqan3::alphabet.
  * \tparam id_type          Type of the seqan3::field::id input; must satisfy std::ranges::output_range
@@ -104,9 +114,10 @@ SEQAN3_CONCEPT sequence_file_input_format = requires (detail::sequence_file_inpu
  * \tparam qual_type        Type of the seqan3::field::qual input; must satisfy std::ranges::output_range
  * over a seqan3::writable_quality_alphabet.
  * \param[in,out] stream    The input stream to read from.
+ * \param[in,out] position_buffer The buffer to store the current record's file position.
  * \param[in]     options   File specific options passed to the format.
  * \param[out]    sequence  The buffer for seqan3::field::seq input, i.e. the "sequence".
- * \param[out]    id        The buffer for seqan3::field::id input, e.g. the header line in FastA.
+ * \param[out]    id        The buffer for seqan3::field::id input, e.g. the header line in FASTA .
  * \param[out]    qualities The buffer for seqan3::field::qual input.
  *
  * \details
@@ -117,7 +128,7 @@ SEQAN3_CONCEPT sequence_file_input_format = requires (detail::sequence_file_inpu
  *     [This is enforced by the concept checker!]
  *   * In this case the data read for that field shall be discarded by the format.
  */
- /*!\var static inline std::vector<std::string> seqan3::sequence_file_input_format::file_extensions
+/*!\var static inline std::vector<std::string> seqan3::sequence_file_input_format::file_extensions
  * \brief The format type is required to provide a vector of all supported file extensions.
  */
 //!\}
@@ -140,7 +151,7 @@ constexpr bool is_type_list_of_sequence_file_input_formats_v = false;
  * \ingroup core
   * \see seqan3::type_list_specialisationOfsequence_file_input_formats
  */
-template <typename ...ts>
+template <typename... ts>
 constexpr bool is_type_list_of_sequence_file_input_formats_v<type_list<ts...>> =
     (sequence_file_input_format<ts> && ...);
 
@@ -150,5 +161,5 @@ constexpr bool is_type_list_of_sequence_file_input_formats_v<type_list<ts...>> =
  * \see seqan3::is_type_list_of_sequence_file_formats_v
  */
 template <typename t>
-SEQAN3_CONCEPT type_list_of_sequence_file_input_formats = is_type_list_of_sequence_file_input_formats_v<t>;
+concept type_list_of_sequence_file_input_formats = is_type_list_of_sequence_file_input_formats_v<t>;
 } // namespace seqan3::detail
