@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -29,6 +29,8 @@ struct sequence_file_input_options
     bool truncate_ids = false;
     //!\brief Read the complete_header into the seqan3::field::id for embl or genbank format.
     bool embl_genbank_complete_header = false;
+    //!\brief Remove spaces after ">" (or ";") before the actual ID.
+    bool fasta_ignore_blanks_before_id = true;
 };
 
 } // namespace seqan3
