@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -41,12 +41,11 @@ template <typename format_type>
 struct sequence_file_output_format_exposer : public format_type
 {
 public:
-
     // Can't use `using format_type::write_sequence_record` as it produces a hard failure in the format concept check
     // for types that do not model the format concept, i.e. don't offer the proper write_sequence_record interface.
     //!\brief Forwards to the seqan3::sequence_file_output_format::write_sequence_record interface.
-    template <typename ...ts>
-    void write_sequence_record(ts && ...args)
+    template <typename... ts>
+    void write_sequence_record(ts &&... args)
     {
         format_type::write_sequence_record(std::forward<ts>(args)...);
     }
@@ -69,23 +68,26 @@ namespace seqan3
  */
 //!\cond
 template <typename t>
-SEQAN3_CONCEPT sequence_file_output_format = requires (detail::sequence_file_output_format_exposer<t> & v,
-                                                       std::ofstream                                  & f,
-                                                       sequence_file_output_options                   & options,
-                                                       dna5_vector                                    & seq,
-                                                       std::string                                    & id,
-                                                       std::vector<phred42>                           & qual,
-                                                       std::vector<dna5q>                             & seq_qual)
-{
-    t::file_extensions;
+concept sequence_file_output_format = requires (detail::sequence_file_output_format_exposer<t> & v,
+                                                std::ofstream & f,
+                                                sequence_file_output_options & options,
+                                                dna5_vector & seq,
+                                                std::string & id,
+                                                std::vector<phred42> & qual,
+                                                std::vector<dna5q> & seq_qual) {
+                                          t::file_extensions;
 
-    SEQAN3_RETURN_TYPE_CONSTRAINT(v.write_sequence_record(f, options, seq, id, qual), std::same_as, void);
-    SEQAN3_RETURN_TYPE_CONSTRAINT(v.write_sequence_record(f, options, std::ignore, id, std::ignore),
-                                  std::same_as, void);
-    SEQAN3_RETURN_TYPE_CONSTRAINT(v.write_sequence_record(f, options, std::ignore, std::ignore, std::ignore),
-                                  std::same_as, void);
-    // the last is required to be compile time valid, but should always throw at run-time.
-};
+                                          {
+                                              v.write_sequence_record(f, options, seq, id, qual)
+                                              } -> std::same_as<void>;
+                                          {
+                                              v.write_sequence_record(f, options, std::ignore, id, std::ignore)
+                                              } -> std::same_as<void>;
+                                          {
+                                              v.write_sequence_record(f, options, std::ignore, std::ignore, std::ignore)
+                                              } -> std::same_as<void>;
+                                          // the last is required to be compile time valid, but should always throw at run-time.
+                                      };
 //!\endcond
 
 /*!\name Requirements for seqan3::sequence_file_output_format
@@ -107,7 +109,7 @@ SEQAN3_CONCEPT sequence_file_output_format = requires (detail::sequence_file_out
  * \param[in,out] stream    The output stream to write into.
  * \param[in]     options   File specific options passed to the format.
  * \param[in]     sequence  The data for seqan3::field::seq, i.e. the "sequence".
- * \param[in]     id        The data for seqan3::field::id, e.g. the header line in FastA.
+ * \param[in]     id        The data for seqan3::field::id, e.g. the header line in FASTA.
  * \param[in]     qualities The data for seqan3::field::qual.
  *
  * \details
@@ -141,7 +143,7 @@ constexpr bool is_type_list_of_sequence_file_output_formats_v = false;
  * \ingroup io_sequence_file
  * \see seqan3::type_list_specialisationOfsequence_file_output_formats
  */
-template <typename ...ts>
+template <typename... ts>
 constexpr bool is_type_list_of_sequence_file_output_formats_v<type_list<ts...>> =
     (sequence_file_output_format<ts> && ...);
 
@@ -151,5 +153,5 @@ constexpr bool is_type_list_of_sequence_file_output_formats_v<type_list<ts...>>
  * \see seqan3::is_type_list_of_sequence_file_formats_v
  */
 template <typename t>
-SEQAN3_CONCEPT type_list_of_sequence_file_output_formats = is_type_list_of_sequence_file_output_formats_v<t>;
+concept type_list_of_sequence_file_output_formats = is_type_list_of_sequence_file_output_formats_v<t>;
 } // namespace seqan3::detail
