@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -25,25 +25,24 @@ namespace seqan3
 struct sequence_file_output_options
 {
     //!\brief Begin the ID line with ";" instead of ">" (not recommended).
-    bool        fasta_legacy_id_marker  = false;
+    bool fasta_legacy_id_marker = false;
     //!\brief Insert a single space after ">" (or ";") before the actual ID.
-    bool        fasta_blank_before_id   = true;
+    bool fasta_blank_before_id = false;
     //!\brief Inserts linebreaks after every n-th letter in the sequence; 0 means no linebreaks.
-    uint32_t    fasta_letters_per_line  = 80;
+    uint32_t fasta_letters_per_line = 80;
     //TODO:
-//     bool        fasta_charcounts        = false;
-
+    //     bool        fasta_charcounts        = false;
 
     //!\brief Whether to write the ID only '@' or also after '+' line.
-    bool        fastq_double_id         = false;
+    bool fastq_double_id = false;
 
     /*!\brief The default plain text line-ending is "\n", but on Windows an additional carriage return is
      *        recommended ("\r\n" for line-ending).
      */
-    bool        add_carriage_return     = false;
+    bool add_carriage_return = false;
 
     //!\brief Complete header given for embl or genbank
-    bool        embl_genbank_complete_header  = false;
+    bool embl_genbank_complete_header = false;
 };
 
 } // namespace seqan3
