@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -13,11 +13,11 @@
 #pragma once
 
 #include <map>
+#include <ranges>
 #include <stack>
 
 #include <seqan3/alphabet/structure/concept.hpp>
 #include <seqan3/io/exception.hpp>
-#include <seqan3/std/ranges>
 
 namespace seqan3::detail
 {
@@ -34,8 +34,7 @@ namespace seqan3::detail
  *                             As the source allows only one interaction partner, the weight defaults to 1.0.
  */
 template <typename structure_alph_type, typename bpp_type, std::ranges::range structure_type>
-inline
-void bpp_from_rna_structure(bpp_type & bpp, structure_type const & structure, double weight = 1.)
+inline void bpp_from_rna_structure(bpp_type & bpp, structure_type const & structure, double weight = 1.)
 {
     if constexpr (!rna_structure_alphabet<structure_alph_type>)
         throw parse_error{"Cannot create base pair probabilities from a structure that is not RNA structure."};
