@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -12,8 +12,10 @@
 
 #pragma once
 
+#include <algorithm>
 #include <cstdio>
 #include <iterator>
+#include <ranges>
 #include <stack>
 #include <string>
 #include <string_view>
@@ -21,33 +23,31 @@
 #include <vector>
 
 #include <seqan3/alphabet/adaptation/char.hpp>
+#include <seqan3/alphabet/concept.hpp>
 #include <seqan3/alphabet/structure/wuss.hpp>
-#include <seqan3/core/char_operations/predicate.hpp>
-#include <seqan3/core/type_traits/range.hpp>
+#include <seqan3/alphabet/views/char_to.hpp>
+#include <seqan3/alphabet/views/to_char.hpp>
+#include <seqan3/core/range/detail/misc.hpp>
+#include <seqan3/core/range/type_traits.hpp>
 #include <seqan3/io/detail/misc.hpp>
-#include <seqan3/io/stream/iterator.hpp>
 #include <seqan3/io/structure_file/detail.hpp>
 #include <seqan3/io/structure_file/input_format_concept.hpp>
 #include <seqan3/io/structure_file/input_options.hpp>
 #include <seqan3/io/structure_file/output_format_concept.hpp>
 #include <seqan3/io/structure_file/output_options.hpp>
-#include <seqan3/range/detail/misc.hpp>
-#include <seqan3/range/views/char_to.hpp>
-#include <seqan3/range/views/istreambuf.hpp>
-#include <seqan3/range/views/take.hpp>
-#include <seqan3/range/views/take_line.hpp>
-#include <seqan3/range/views/take_until.hpp>
-#include <seqan3/range/views/to_char.hpp>
-#include <seqan3/range/views/to.hpp>
-#include <seqan3/std/algorithm>
-#include <seqan3/std/ranges>
+#include <seqan3/io/views/detail/istreambuf_view.hpp>
+#include <seqan3/io/views/detail/take_line_view.hpp>
+#include <seqan3/io/views/detail/take_until_view.hpp>
+#include <seqan3/utility/char_operations/predicate.hpp>
+#include <seqan3/utility/detail/type_name_as_string.hpp>
+#include <seqan3/utility/range/to.hpp>
 
 namespace seqan3
 {
 /*!\brief       The Vienna format (dot bracket notation) for RNA sequences with secondary structure.
  * \implements  seqan3::structure_file_input_format
  * \implements  seqan3::structure_file_output_format
- * \ingroup     structure_file
+ * \ingroup     io_structure_file
  *
  * \details
  *
@@ -56,7 +56,7 @@ namespace seqan3
  * Dot Bracket or Vienna Notation is widely used for secondary structure annotation. Is is a very simple format,
  * containing one or more sequences. Each sequence must appear as a single line in the file.
  * A sequence may be preceded by a special line starting with the '>' character followed by a sequence name
- * (like FastA). After each sequence line there is usually a line containing
+ * (like FASTA). After each sequence line there is usually a line containing
  * secondary structure, using brackets to denote interacting nucleotides or amino acids, and dots for unpaired sites.
  * The length of the struture must equal the length of the sequence.
  * Optionally, the structure may be followed by a space character and the minimum free energy value enclosed
@@ -79,6 +79,8 @@ namespace seqan3
  * When reading the ID-line the identifier (`>`) and any blank characters before the actual ID are
  * stripped. Each field is read/written as a single line (except ENERGY, which goes right after the structure).
  * Numbers and spaces within the sequence are simply ignored, but not within the structure.
+ *
+ * \remark For a complete overview, take a look at \ref io_structure_file
  */
 class format_vienna
 {
@@ -86,28 +88,24 @@ public:
     /*!\name Constructors, destructor and assignment
      * \{
      */
-    format_vienna() noexcept = default; //!< Defaulted.
-    format_vienna(format_vienna const &) noexcept = default; //!< Defaulted.
+    format_vienna() noexcept = default;                                  //!< Defaulted.
+    format_vienna(format_vienna const &) noexcept = default;             //!< Defaulted.
     format_vienna & operator=(format_vienna const &) noexcept = default; //!< Defaulted.
-    format_vienna(format_vienna &&) noexcept = default; //!< Defaulted.
-    format_vienna & operator=(format_vienna &&) noexcept = default; //!< Defaulted.
-    ~format_vienna() noexcept = default; //!< Defaulted.
+    format_vienna(format_vienna &&) noexcept = default;                  //!< Defaulted.
+    format_vienna & operator=(format_vienna &&) noexcept = default;      //!< Defaulted.
+    ~format_vienna() noexcept = default;                                 //!< Defaulted.
+
     //!\}
 
     //!\brief The valid file extensions for this format; note that you can modify this value.
-    static inline std::vector<std::string> file_extensions
-    {
-        { "dbn" },
-        { "fasta" },
-        { "fa" }
-    };
+    static inline std::vector<std::string> file_extensions{{"dbn"}, {"fasta"}, {"fa"}};
 
 protected:
     //!\copydoc seqan3::structure_file_input_format::read_structure_record
-    template <typename stream_type,     // constraints checked by file
+    template <typename stream_type, // constraints checked by file
               typename seq_legal_alph_type,
-              bool     structured_seq_combined,
-              typename seq_type,        // other constraints checked inside function
+              bool structured_seq_combined,
+              typename seq_type, // other constraints checked inside function
               typename id_type,
               typename bpp_type,
               typename structure_type,
@@ -115,22 +113,23 @@ protected:
               typename react_type,
               typename comment_type,
               typename offset_type>
-    void read_structure_record(stream_type & stream,
-                               structure_file_input_options<seq_legal_alph_type, structured_seq_combined> const & options,
-                               seq_type & seq,
-                               id_type & id,
-                               bpp_type & bpp,
-                               structure_type & structure,
-                               energy_type & energy,
-                               react_type & SEQAN3_DOXYGEN_ONLY(react),
-                               react_type & SEQAN3_DOXYGEN_ONLY(react_err),
-                               comment_type & SEQAN3_DOXYGEN_ONLY(comment),
-                               offset_type & SEQAN3_DOXYGEN_ONLY(offset))
+    void
+    read_structure_record(stream_type & stream,
+                          structure_file_input_options<seq_legal_alph_type, structured_seq_combined> const & options,
+                          seq_type & seq,
+                          id_type & id,
+                          bpp_type & bpp,
+                          structure_type & structure,
+                          energy_type & energy,
+                          react_type & SEQAN3_DOXYGEN_ONLY(react),
+                          react_type & SEQAN3_DOXYGEN_ONLY(react_err),
+                          comment_type & SEQAN3_DOXYGEN_ONLY(comment),
+                          offset_type & SEQAN3_DOXYGEN_ONLY(offset))
     {
-        auto stream_view = views::istreambuf(stream);
+        auto stream_view = detail::istreambuf(stream);
 
         // READ ID (if present)
-        auto constexpr is_id = is_char<'>'>;
+        constexpr auto is_id = is_char<'>'>;
         if (is_id(*begin(stream_view)))
         {
             if constexpr (!detail::decays_to_ignore_v<id_type>)
@@ -138,58 +137,60 @@ protected:
                 if (options.truncate_ids)
                 {
                     std::ranges::copy(stream_view | std::views::drop_while(is_id || is_blank) // skip leading >
-                                                  | views::take_until_or_throw(is_cntrl || is_blank)
-                                                  | views::char_to<std::ranges::range_value_t<id_type>>,
-                                      std::cpp20::back_inserter(id));
-                    detail::consume(stream_view | views::take_line_or_throw);
+                                          | detail::take_until_or_throw(is_cntrl || is_blank)
+                                          | views::char_to<std::ranges::range_value_t<id_type>>,
+                                      std::back_inserter(id));
+                    detail::consume(stream_view | detail::take_line_or_throw);
                 }
                 else
                 {
                     std::ranges::copy(stream_view | std::views::drop_while(is_id || is_blank) // skip leading >
-                                                  | views::take_line_or_throw
-                                                  | views::char_to<std::ranges::range_value_t<id_type>>,
-                                      std::cpp20::back_inserter(id));
+                                          | detail::take_line_or_throw
+                                          | views::char_to<std::ranges::range_value_t<id_type>>,
+                                      std::back_inserter(id));
                 }
             }
             else
             {
-                detail::consume(stream_view | views::take_line_or_throw);
+                detail::consume(stream_view | detail::take_line_or_throw);
             }
         }
         else if constexpr (!detail::decays_to_ignore_v<id_type>)
         {
-            auto constexpr is_legal_seq = is_in_alphabet<seq_legal_alph_type>;
+            constexpr auto is_legal_seq = char_is_valid_for<seq_legal_alph_type>;
             if (!is_legal_seq(*begin(stream_view))) // if neither id nor seq found: throw
             {
-                throw parse_error{std::string{"Expected to be on beginning of ID or sequence, but "} +
-                                  is_id.msg + " and " + is_legal_seq.msg +
-                                  " evaluated to false on " + detail::make_printable(*begin(stream_view))};
+                throw parse_error{std::string{"Expected to be on beginning of ID or sequence, but "} + is_id.msg
+                                  + " and char_is_valid_for<" + detail::type_name_as_string<seq_legal_alph_type>
+                                  + ">" + " evaluated to false on " + detail::make_printable(*begin(stream_view))};
             }
         }
 
         // READ SEQUENCE
         if constexpr (!detail::decays_to_ignore_v<seq_type>)
         {
-            auto constexpr is_legal_seq = is_in_alphabet<seq_legal_alph_type>;
-            std::ranges::copy(stream_view | views::take_line_or_throw                      // until end of line
-                                          | std::views::filter(!(is_space || is_digit)) // ignore whitespace and numbers
-                                          | std::views::transform([is_legal_seq](char const c)
-                                            {
-                                                if (!is_legal_seq(c))                    // enforce legal alphabet
-                                                {
-                                                    throw parse_error{std::string{"Encountered an unexpected letter: "} +
-                                                                      is_legal_seq.msg +
-                                                                      " evaluated to false on " +
-                                                                      detail::make_printable(c)};
-                                                }
-                                              return c;
-                                            })
-                                          | views::char_to<std::ranges::range_value_t<seq_type>>, // convert to actual target alphabet
-                              std::cpp20::back_inserter(seq));
+            constexpr auto is_legal_seq = char_is_valid_for<seq_legal_alph_type>;
+            std::ranges::copy(
+                stream_view | detail::take_line_or_throw          // until end of line
+                    | std::views::filter(!(is_space || is_digit)) // ignore whitespace and numbers
+                    | std::views::transform(
+                        [is_legal_seq](char const c)
+                        {
+                            if (!is_legal_seq(c)) // enforce legal alphabet
+                            {
+                                throw parse_error{std::string{"Encountered an unexpected letter: "}
+                                                  + "char_is_valid_for<"
+                                                  + detail::type_name_as_string<seq_legal_alph_type>
+                                                  + "> evaluated to false on " + detail::make_printable(c)};
+                            }
+                            return c;
+                        })
+                    | views::char_to<std::ranges::range_value_t<seq_type>>, // convert to actual target alphabet
+                std::back_inserter(seq));
         }
         else
         {
-            detail::consume(stream_view | views::take_line_or_throw);
+            detail::consume(stream_view | detail::take_line_or_throw);
         }
 
         // READ STRUCTURE (if present)
@@ -211,7 +212,7 @@ protected:
             else
             {
                 using alph_type = std::ranges::range_value_t<structure_type>;
-                std::ranges::copy(read_structure<alph_type>(stream_view), std::cpp20::back_inserter(structure));
+                std::ranges::copy(read_structure<alph_type>(stream_view), std::back_inserter(structure));
                 structure_length = std::ranges::distance(structure);
 
                 if constexpr (!detail::decays_to_ignore_v<bpp_type>)
@@ -225,11 +226,11 @@ protected:
         }
         else
         {
-            detail::consume(stream_view | views::take_until(is_space)); // until whitespace
+            detail::consume(stream_view | detail::take_until(is_space)); // until whitespace
         }
 
-        if constexpr (!detail::decays_to_ignore_v<seq_type> &&
-                      !(detail::decays_to_ignore_v<structure_type> && detail::decays_to_ignore_v<bpp_type>))
+        if constexpr (!detail::decays_to_ignore_v<seq_type>
+                      && !(detail::decays_to_ignore_v<structure_type> && detail::decays_to_ignore_v<bpp_type>))
         {
             if (std::ranges::distance(seq) != structure_length)
                 throw parse_error{"Found sequence and associated structure of different length."};
@@ -238,9 +239,9 @@ protected:
         // READ ENERGY (if present)
         if constexpr (!detail::decays_to_ignore_v<energy_type>)
         {
-            std::string e_str = stream_view | views::take_line
-                                            | std::views::filter(!(is_space || is_char<'('> || is_char<')'>))
-                                            | views::to<std::string>;
+            std::string e_str = stream_view | detail::take_line
+                              | std::views::filter(!(is_space || is_char<'('> || is_char<')'>))
+                              | ranges::to<std::string>();
             if (!e_str.empty())
             {
                 size_t num_processed;
@@ -253,14 +254,14 @@ protected:
         }
         else
         {
-            detail::consume(stream_view | views::take_line);
+            detail::consume(stream_view | detail::take_line);
         }
-        detail::consume(stream_view | views::take_until(!is_space));
+        detail::consume(stream_view | detail::take_until(!is_space));
     }
 
     //!\copydoc seqan3::structure_file_output_format::write_structure_record
-    template <typename stream_type,     // constraints checked by file
-              typename seq_type,        // other constraints checked inside function
+    template <typename stream_type, // constraints checked by file
+              typename seq_type,    // other constraints checked inside function
               typename id_type,
               typename bpp_type,
               typename structure_type,
@@ -280,7 +281,7 @@ protected:
                                 comment_type && SEQAN3_DOXYGEN_ONLY(comment),
                                 offset_type && SEQAN3_DOXYGEN_ONLY(offset))
     {
-        std::cpp20::ostreambuf_iterator stream_it{stream};
+        std::ostreambuf_iterator stream_it{stream};
 
         // WRITE ID (optional)
         if constexpr (!detail::decays_to_ignore_v<id_type>)
@@ -320,16 +321,16 @@ protected:
             {
                 if (energy)
                 {
-// TODO(joergi-w) enable the following when std::to_chars is implemented for float types
-//                    auto [endptr, ec] = std::to_chars(str.data(),
-//                                                      str.data() + str.size(),
-//                                                      energy,
-//                                                      std::chars_format::fixed,
-//                                                      options.precision);
-//                    if (ec == std::errc())
-//                        std::ranges::copy(str.data(), endptr, stream_it);
-//                    else
-//                        throw std::runtime_error{"The energy could not be transformed into a string."};
+                    // TODO(joergi-w) enable the following when std::to_chars is implemented for float types
+                    //                    auto [endptr, ec] = std::to_chars(str.data(),
+                    //                                                      str.data() + str.size(),
+                    //                                                      energy,
+                    //                                                      std::chars_format::fixed,
+                    //                                                      options.precision);
+                    //                    if (ec == std::errc())
+                    //                        std::ranges::copy(str.data(), endptr, stream_it);
+                    //                    else
+                    //                        throw std::runtime_error{"The energy could not be transformed into a string."};
 
                     stream_it = ' ';
                     stream_it = '(';
@@ -361,21 +362,21 @@ private:
     template <typename alph_type, typename stream_view_type>
     auto read_structure(stream_view_type & stream_view)
     {
-        auto constexpr is_legal_structure = is_in_alphabet<alph_type>;
-        return stream_view | views::take_until(is_space) // until whitespace
-                           | std::views::transform([is_legal_structure](char const c)
-                             {
-                                 if (!is_legal_structure(c))
-                                 {
-                                     throw parse_error{
-                                         std::string{"Encountered an unexpected letter: "} +
-                                         is_legal_structure.msg +
-                                         " evaluated to false on " + detail::make_printable(c)};
-                                 }
-                                 return c;
-                             })                                  // enforce legal alphabet
-                           | views::char_to<alph_type>;           // convert to actual target alphabet
+        constexpr auto is_legal_structure = char_is_valid_for<alph_type>;
+        return stream_view | detail::take_until(is_space) // until whitespace
+             | std::views::transform(
+                   [is_legal_structure](char const c)
+                   {
+                       if (!is_legal_structure(c))
+                       {
+                           throw parse_error{std::string{"Encountered an unexpected letter: char_is_valid_for<"}
+                                             + detail::type_name_as_string<alph_type>
+                                             + "> evaluated to false on " + detail::make_printable(c)};
+                       }
+                       return c;
+                   })                     // enforce legal alphabet
+             | views::char_to<alph_type>; // convert to actual target alphabet
     }
 };
 
-} // namespace seqan3::detail
+} // namespace seqan3
