@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -42,23 +42,23 @@ public:
     /*!\name Constructors, destructor and assignment
      * \{
      */
-    max_error_total() = default; //!< Defaulted.
-    max_error_total(max_error_total const &) = default; //!< Defaulted.
-    max_error_total(max_error_total &&) = default; //!< Defaulted.
+    max_error_total() = default;                                    //!< Defaulted.
+    max_error_total(max_error_total const &) = default;             //!< Defaulted.
+    max_error_total(max_error_total &&) = default;                  //!< Defaulted.
     max_error_total & operator=(max_error_total const &) = default; //!< Defaulted.
-    max_error_total & operator=(max_error_total &&) = default; //!< Defaulted.
-    ~max_error_total() = default; //!< Defaulted.
+    max_error_total & operator=(max_error_total &&) = default;      //!< Defaulted.
+    ~max_error_total() = default;                                   //!< Defaulted.
 
     /*!\brief Initialises the total error with the given seqan3::search_cfg::error_count.
      * \param[in] error The maximal number of total errors allowed in the search.
      */
-    explicit max_error_total(error_count error) : error{std::move(error)}
+    constexpr explicit max_error_total(error_count error) : error{std::move(error)}
     {}
 
     /*!\brief Initialises the total error with the given seqan3::search_cfg::error_rate.
      * \param[in] error The maximal total error rate allowed in the search.
      */
-    explicit max_error_total(error_rate error) : error{std::move(error)}
+    constexpr explicit max_error_total(error_rate error) : error{std::move(error)}
     {}
     //!\}
 
@@ -87,23 +87,23 @@ public:
     /*!\name Constructors, destructor and assignment
      * \{
      */
-    max_error_substitution() = default; //!< Defaulted.
-    max_error_substitution(max_error_substitution const &) = default; //!< Defaulted.
-    max_error_substitution(max_error_substitution &&) = default; //!< Defaulted.
+    max_error_substitution() = default;                                           //!< Defaulted.
+    max_error_substitution(max_error_substitution const &) = default;             //!< Defaulted.
+    max_error_substitution(max_error_substitution &&) = default;                  //!< Defaulted.
     max_error_substitution & operator=(max_error_substitution const &) = default; //!< Defaulted.
-    max_error_substitution & operator=(max_error_substitution &&) = default; //!< Defaulted.
-    ~max_error_substitution() = default; //!< Defaulted.
+    max_error_substitution & operator=(max_error_substitution &&) = default;      //!< Defaulted.
+    ~max_error_substitution() = default;                                          //!< Defaulted.
 
     /*!\brief Initialises the substitution error with the given seqan3::search_cfg::error_count.
      * \param[in] error The maximal number of substitution errors allowed in the search.
      */
-    explicit max_error_substitution(error_count error) : error{std::move(error)}
+    constexpr explicit max_error_substitution(error_count error) : error{std::move(error)}
     {}
 
     /*!\brief Initialises the substitution error with the given seqan3::search_cfg::error_rate.
      * \param[in] error The maximal error rate for substitutions allowed in the search.
      */
-    explicit max_error_substitution(error_rate error) : error{std::move(error)}
+    constexpr explicit max_error_substitution(error_rate error) : error{std::move(error)}
     {}
     //!\}
 
@@ -132,23 +132,23 @@ public:
     /*!\name Constructors, destructor and assignment
      * \{
      */
-    max_error_insertion() = default; //!< Defaulted.
-    max_error_insertion(max_error_insertion const &) = default; //!< Defaulted.
-    max_error_insertion(max_error_insertion &&) = default; //!< Defaulted.
+    max_error_insertion() = default;                                        //!< Defaulted.
+    max_error_insertion(max_error_insertion const &) = default;             //!< Defaulted.
+    max_error_insertion(max_error_insertion &&) = default;                  //!< Defaulted.
     max_error_insertion & operator=(max_error_insertion const &) = default; //!< Defaulted.
-    max_error_insertion & operator=(max_error_insertion &&) = default; //!< Defaulted.
-    ~max_error_insertion() = default; //!< Defaulted.
+    max_error_insertion & operator=(max_error_insertion &&) = default;      //!< Defaulted.
+    ~max_error_insertion() = default;                                       //!< Defaulted.
 
     /*!\brief Initialises the insertion error with the given seqan3::search_cfg::error_count.
      * \param[in] error The maximal number of insertion errors allowed in the search.
      */
-    explicit max_error_insertion(error_count error) : error{std::move(error)}
+    constexpr explicit max_error_insertion(error_count error) : error{std::move(error)}
     {}
 
     /*!\brief Initialises the insertion error with the given seqan3::search_cfg::error_rate.
      * \param[in] error The maximal error rate for insertions allowed in the search.
      */
-    explicit max_error_insertion(error_rate error) : error{std::move(error)}
+    constexpr explicit max_error_insertion(error_rate error) : error{std::move(error)}
     {}
     //!\}
 
@@ -178,23 +178,23 @@ public:
     /*!\name Constructors, destructor and assignment
      * \{
      */
-    max_error_deletion() = default; //!< Defaulted.
-    max_error_deletion(max_error_deletion const &) = default; //!< Defaulted.
-    max_error_deletion(max_error_deletion &&) = default; //!< Defaulted.
+    max_error_deletion() = default;                                       //!< Defaulted.
+    max_error_deletion(max_error_deletion const &) = default;             //!< Defaulted.
+    max_error_deletion(max_error_deletion &&) = default;                  //!< Defaulted.
     max_error_deletion & operator=(max_error_deletion const &) = default; //!< Defaulted.
-    max_error_deletion & operator=(max_error_deletion &&) = default; //!< Defaulted.
-    ~max_error_deletion() = default; //!< Defaulted.
+    max_error_deletion & operator=(max_error_deletion &&) = default;      //!< Defaulted.
+    ~max_error_deletion() = default;                                      //!< Defaulted.
 
     /*!\brief Initialises the deletion error with the given seqan3::search_cfg::error_count.
      * \param[in] error The maximal number of deletion errors allowed in the search.
      */
-    explicit max_error_deletion(error_count error) : error{std::move(error)}
+    constexpr explicit max_error_deletion(error_count error) : error{std::move(error)}
     {}
 
     /*!\brief Initialises the deletion error with the given seqan3::search_cfg::error_rate.
      * \param[in] error The maximal error rate for deletions allowed in the search.
      */
-    explicit max_error_deletion(error_rate error) : error{std::move(error)}
+    constexpr explicit max_error_deletion(error_rate error) : error{std::move(error)}
     {}
     //!\}
 
