@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -12,8 +12,8 @@
 
 #pragma once
 
-#include <seqan3/std/algorithm>
-#include <seqan3/std/bit>
+#include <algorithm>
+#include <bit>
 
 #include <sdsl/bit_vectors.hpp>
 
@@ -106,7 +106,7 @@ struct bin_index : public detail::strong_type<size_t, bin_index, detail::strong_
  *
  * ### Querying
  * To query the Interleaved Bloom Filter for a value, call seqan3::interleaved_bloom_filter::membership_agent() and use
- * the returned seqan3::interleaved_bloom_filter::membership_agent.
+ * the returned seqan3::interleaved_bloom_filter::membership_agent_type.
  *
  * To count the occurrences of a range of values in the Interleaved Bloom Filter, call
  * seqan3::interleaved_bloom_filter::counting_agent() and use
@@ -139,9 +139,8 @@ private:
     //!\endcond
 
     //!\brief The underlying datatype to use.
-    using data_type = std::conditional_t<data_layout_mode_ == data_layout::uncompressed,
-                                         sdsl::bit_vector,
-                                         sdsl::sd_vector<>>;
+    using data_type =
+        std::conditional_t<data_layout_mode_ == data_layout::uncompressed, sdsl::bit_vector, sdsl::sd_vector<>>;
 
     //!\brief The number of bins specified by the user.
     size_t bins{};
@@ -175,9 +174,9 @@ private:
     {
         h *= seed;
         assert(hash_shift < 64);
-        h ^= h >> hash_shift; // XOR and shift higher bits into lower bits
+        h ^= h >> hash_shift;         // XOR and shift higher bits into lower bits
         h *= 11400714819323198485ULL; // = 2^64 / golden_ration, to expand h to 64 bit range
-        // Use fastrange (integer modulo without division) if possible.
+                                      // Use fastrange (integer modulo without division) if possible.
 #ifdef __SIZEOF_INT128__
         h = static_cast<uint64_t>((static_cast<__uint128_t>(h) * static_cast<__uint128_t>(bin_size_)) >> 64);
 #else
@@ -191,19 +190,20 @@ public:
     //!\brief Indicates whether the Interleaved Bloom Filter is compressed.
     static constexpr data_layout data_layout_mode = data_layout_mode_;
 
-    class membership_agent; // documented upon definition below
+    class membership_agent_type; // documented upon definition below
+
     template <std::integral value_t>
     class counting_agent_type; // documented upon definition below
 
     /*!\name Constructors, destructor and assignment
      * \{
      */
-    interleaved_bloom_filter() = default; //!< Defaulted.
-    interleaved_bloom_filter(interleaved_bloom_filter const &) = default; //!< Defaulted.
+    interleaved_bloom_filter() = default;                                             //!< Defaulted.
+    interleaved_bloom_filter(interleaved_bloom_filter const &) = default;             //!< Defaulted.
     interleaved_bloom_filter & operator=(interleaved_bloom_filter const &) = default; //!< Defaulted.
-    interleaved_bloom_filter(interleaved_bloom_filter &&) = default; //!< Defaulted.
-    interleaved_bloom_filter & operator=(interleaved_bloom_filter &&) = default; //!< Defaulted.
-    ~interleaved_bloom_filter() = default; //!< Defaulted.
+    interleaved_bloom_filter(interleaved_bloom_filter &&) = default;                  //!< Defaulted.
+    interleaved_bloom_filter & operator=(interleaved_bloom_filter &&) = default;      //!< Defaulted.
+    ~interleaved_bloom_filter() = default;                                            //!< Defaulted.
 
     /*!\brief Construct an uncompressed Interleaved Bloom Filter.
      * \param bins_ The number of bins.
@@ -221,9 +221,7 @@ public:
     interleaved_bloom_filter(seqan3::bin_count bins_,
                              seqan3::bin_size size,
                              seqan3::hash_function_count funs = seqan3::hash_function_count{2u})
-    //!\cond
         requires (data_layout_mode == data_layout::uncompressed)
-    //!\endcond
     {
         bins = bins_.get();
         bin_size_ = size.get();
@@ -237,8 +235,8 @@ public:
             throw std::logic_error{"The size of a bin must be > 0."};
 
         hash_shift = std::countl_zero(bin_size_);
-        bin_words = (bins + 63) >> 6; // = ceil(bins/64)
-        technical_bins  = bin_words << 6; // = bin_words * 64
+        bin_words = (bins + 63) >> 6;    // = ceil(bins/64)
+        technical_bins = bin_words << 6; // = bin_words * 64
         data = sdsl::bit_vector(technical_bins * bin_size_);
     }
 
@@ -254,9 +252,7 @@ public:
      * \include test/snippet/search/dream_index/interleaved_bloom_filter_constructor_compressed.cpp
      */
     interleaved_bloom_filter(interleaved_bloom_filter<data_layout::uncompressed> const & ibf)
-    //!\cond
         requires (data_layout_mode == data_layout::compressed)
-    //!\endcond
     {
         std::tie(bins, technical_bins, bin_size_, hash_shift, bin_words, hash_funs) =
             std::tie(ibf.bins, ibf.technical_bins, ibf.bin_size_, ibf.hash_shift, ibf.bin_words, ibf.hash_funs);
@@ -281,9 +277,7 @@ public:
      * \include test/snippet/search/dream_index/interleaved_bloom_filter_emplace.cpp
      */
     void emplace(size_t const value, bin_index const bin) noexcept
-    //!\cond
         requires (data_layout_mode == data_layout::uncompressed)
-    //!\endcond
     {
         assert(bin.get() < bins);
         for (size_t i = 0; i < hash_funs; ++i)
@@ -307,9 +301,7 @@ public:
      * \include test/snippet/search/dream_index/interleaved_bloom_filter_clear.cpp
      */
     void clear(bin_index const bin) noexcept
-    //!\cond
         requires (data_layout_mode == data_layout::uncompressed)
-    //!\endcond
     {
         assert(bin.get() < bins);
         for (size_t idx = bin.get(), i = 0; i < bin_size_; idx += technical_bins, ++i)
@@ -330,9 +322,7 @@ public:
      * \include test/snippet/search/dream_index/interleaved_bloom_filter_clear.cpp
      */
     template <typename rng_t>
-    //!\cond
         requires (data_layout_mode == data_layout::uncompressed)
-    //!\endcond
     void clear(rng_t && bin_range) noexcept
     {
         static_assert(std::ranges::forward_range<rng_t>, "The range of bins to clear must model a forward_range.");
@@ -354,8 +344,8 @@ public:
      *
      * \attention This function is only available for **uncompressed** Interleaved Bloom Filters.
      * \attention The new number of bins must be greater or equal to the current number of bins.
-     * \attention This function invalidates all seqan3::interleaved_bloom_filter::membership_agent constructed for this
-     * Interleaved Bloom Filter.
+     * \attention This function invalidates all seqan3::interleaved_bloom_filter::membership_agent_type constructed for
+     * this Interleaved Bloom Filter.
      *
      * \details
      *
@@ -372,9 +362,7 @@ public:
      * \include test/snippet/search/dream_index/interleaved_bloom_filter_increase_bin_number_to.cpp
      */
     void increase_bin_number_to(bin_count const new_bins_)
-    //!\cond
         requires (data_layout_mode == data_layout::uncompressed)
-    //!\endcond
     {
         size_t new_bins = new_bins_.get();
 
@@ -417,20 +405,20 @@ public:
     /*!\name Lookup
      * \{
      */
-    /*!\brief Returns a seqan3::interleaved_bloom_filter::membership_agent to be used for lookup.
+    /*!\brief Returns a seqan3::interleaved_bloom_filter::membership_agent_type to be used for lookup.
      * \attention Calling seqan3::interleaved_bloom_filter::increase_bin_number_to invalidates all
-     * `seqan3::interleaved_bloom_filter::membership_agent`s constructed for this Interleaved Bloom Filter.
+     * `seqan3::interleaved_bloom_filter::membership_agent_type`s constructed for this Interleaved Bloom Filter.
      *
      * \details
      *
      * ### Example
      *
      * \include test/snippet/search/dream_index/membership_agent_construction.cpp
-     * \sa seqan3::interleaved_bloom_filter::membership_agent::bulk_contains
+     * \sa seqan3::interleaved_bloom_filter::membership_agent_type::bulk_contains
      */
-    membership_agent membership_agent() const
+    membership_agent_type membership_agent() const
     {
-        return typename interleaved_bloom_filter<data_layout_mode>::membership_agent{*this};
+        return membership_agent_type{*this};
     }
 
     /*!\brief Returns a seqan3::interleaved_bloom_filter::counting_agent_type to be used for counting.
@@ -497,9 +485,19 @@ public:
      */
     friend bool operator==(interleaved_bloom_filter const & lhs, interleaved_bloom_filter const & rhs) noexcept
     {
-        return std::tie(lhs.bins, lhs.technical_bins, lhs.bin_size_, lhs.hash_shift, lhs.bin_words, lhs.hash_funs,
-                        lhs.data) ==
-               std::tie(rhs.bins, rhs.technical_bins, rhs.bin_size_, rhs.hash_shift, rhs.bin_words, rhs.hash_funs,
+        return std::tie(lhs.bins,
+                        lhs.technical_bins,
+                        lhs.bin_size_,
+                        lhs.hash_shift,
+                        lhs.bin_words,
+                        lhs.hash_funs,
+                        lhs.data)
+            == std::tie(rhs.bins,
+                        rhs.technical_bins,
+                        rhs.bin_size_,
+                        rhs.hash_shift,
+                        rhs.bin_words,
+                        rhs.hash_funs,
                         rhs.data);
     }
 
@@ -568,7 +566,7 @@ public:
  * \include test/snippet/search/dream_index/membership_agent_construction.cpp
  */
 template <data_layout data_layout_mode>
-class interleaved_bloom_filter<data_layout_mode>::membership_agent
+class interleaved_bloom_filter<data_layout_mode>::membership_agent_type
 {
 private:
     //!\brief The type of the augmented seqan3::interleaved_bloom_filter.
@@ -583,19 +581,18 @@ public:
     /*!\name Constructors, destructor and assignment
      * \{
      */
-    membership_agent() = default; //!< Defaulted.
-    membership_agent(membership_agent const &) = default; //!< Defaulted.
-    membership_agent & operator=(membership_agent const &) = default; //!< Defaulted.
-    membership_agent(membership_agent &&) = default; //!< Defaulted.
-    membership_agent & operator=(membership_agent &&) = default; //!< Defaulted.
-    ~membership_agent() = default; //!< Defaulted.
+    membership_agent_type() = default;                                          //!< Defaulted.
+    membership_agent_type(membership_agent_type const &) = default;             //!< Defaulted.
+    membership_agent_type & operator=(membership_agent_type const &) = default; //!< Defaulted.
+    membership_agent_type(membership_agent_type &&) = default;                  //!< Defaulted.
+    membership_agent_type & operator=(membership_agent_type &&) = default;      //!< Defaulted.
+    ~membership_agent_type() = default;                                         //!< Defaulted.
 
-    /*!\brief Construct a membership_agent from a seqan3::interleaved_bloom_filter.
+    /*!\brief Construct a membership_agent_type from a seqan3::interleaved_bloom_filter.
      * \private
      * \param ibf The seqan3::interleaved_bloom_filter.
      */
-    explicit membership_agent(ibf_t const & ibf) :
-        ibf_ptr(std::addressof(ibf)), result_buffer(ibf.bin_count())
+    explicit membership_agent_type(ibf_t const & ibf) : ibf_ptr(std::addressof(ibf)), result_buffer(ibf.bin_count())
     {}
     //!\}
 
@@ -620,7 +617,7 @@ public:
      * ### Thread safety
      *
      * Concurrent invocations of this function are not thread safe, please create a
-     * seqan3::interleaved_bloom_filter::membership_agent for each thread.
+     * seqan3::interleaved_bloom_filter::membership_agent_type for each thread.
      */
     [[nodiscard]] binning_bitvector const & bulk_contains(size_t const value) & noexcept
     {
@@ -635,15 +632,15 @@ public:
 
         for (size_t batch = 0; batch < ibf_ptr->bin_words; ++batch)
         {
-           size_t tmp{-1ULL};
-           for (size_t i = 0; i < ibf_ptr->hash_funs; ++i)
-           {
-               assert(bloom_filter_indices[i] < ibf_ptr->data.size());
-               tmp &= ibf_ptr->data.get_int(bloom_filter_indices[i]);
-               bloom_filter_indices[i] += 64;
-           }
+            size_t tmp{-1ULL};
+            for (size_t i = 0; i < ibf_ptr->hash_funs; ++i)
+            {
+                assert(bloom_filter_indices[i] < ibf_ptr->data.size());
+                tmp &= ibf_ptr->data.get_int(bloom_filter_indices[i]);
+                bloom_filter_indices[i] += 64;
+            }
 
-           result_buffer.data.set_int(batch << 6, tmp);
+            result_buffer.data.set_int(batch << 6, tmp);
         }
 
         return result_buffer;
@@ -653,12 +650,11 @@ public:
     // is immediately destroyed.
     [[nodiscard]] binning_bitvector const & bulk_contains(size_t const value) && noexcept = delete;
     //!\}
-
 };
 
 //!\brief A bitvector representing the result of a call to `bulk_contains` of the seqan3::interleaved_bloom_filter.
 template <data_layout data_layout_mode>
-class interleaved_bloom_filter<data_layout_mode>::membership_agent::binning_bitvector
+class interleaved_bloom_filter<data_layout_mode>::membership_agent_type::binning_bitvector
 {
 private:
     //!\brief The underlying datatype to use.
@@ -666,25 +662,21 @@ private:
     //!\brief The bitvector.
     data_type data{};
 
-    friend class membership_agent;
-
-    template <std::integral value_t>
-    friend class counting_vector;
+    friend class membership_agent_type;
 
 public:
     /*!\name Constructors, destructor and assignment
      * \{
      */
-    binning_bitvector() = default; //!< Defaulted.
-    binning_bitvector(binning_bitvector const &) = default; //!< Defaulted.
+    binning_bitvector() = default;                                      //!< Defaulted.
+    binning_bitvector(binning_bitvector const &) = default;             //!< Defaulted.
     binning_bitvector & operator=(binning_bitvector const &) = default; //!< Defaulted.
-    binning_bitvector(binning_bitvector &&) = default; //!< Defaulted.
-    binning_bitvector & operator=(binning_bitvector &&) = default; //!< Defaulted.
-    ~binning_bitvector() = default; //!< Defaulted.
+    binning_bitvector(binning_bitvector &&) = default;                  //!< Defaulted.
+    binning_bitvector & operator=(binning_bitvector &&) = default;      //!< Defaulted.
+    ~binning_bitvector() = default;                                     //!< Defaulted.
 
     //!\brief Construct with given size.
-    explicit binning_bitvector(size_t const size) :
-        data(size)
+    explicit binning_bitvector(size_t const size) : data(size)
     {}
     //!\}
 
@@ -741,7 +733,7 @@ public:
     /*!\name Access
      * \{
      */
-     //!\brief Return the i-th element.
+    //!\brief Return the i-th element.
     auto operator[](size_t const i) noexcept
     {
         assert(i < size());
@@ -776,19 +768,19 @@ public:
 };
 
 /*!\brief A data structure that behaves like a std::vector and can be used to consolidate the results of multiple calls
- *        to seqan3::interleaved_bloom_filter::membership_agent::bulk_contains.
+ *        to seqan3::interleaved_bloom_filter::membership_agent_type::bulk_contains.
  * \ingroup search_dream_index
  * \tparam value_t The type of the count. Must model std::integral.
  *
  * \details
  *
- * When using the seqan3::interleaved_bloom_filter::membership_agent::bulk_contains operation, a common use case is to
+ * When using the seqan3::interleaved_bloom_filter::membership_agent_type::bulk_contains operation, a common use case is to
  * add up, for example, the results for all k-mers in a query. This yields, for each bin, the number of k-mers of a
  * query that are in the respective bin. Such information can be used to apply further filtering or abundance estimation
  * based on the k-mer counts.
  *
  * The seqan3::counting_vector offers an easy way to add up the individual
- * seqan3::interleaved_bloom_filter::membership_agent::binning_bitvector by offering an `+=` operator.
+ * seqan3::interleaved_bloom_filter::membership_agent_type::binning_bitvector by offering an `+=` operator.
  *
  * The `value_t` template parameter should be chosen in a way that no overflow occurs if all calls to `bulk_contains`
  * return a hit for a specific bin. For example, `uint8_t` will suffice when processing short Illumina reads, whereas
@@ -804,25 +796,34 @@ class counting_vector : public std::vector<value_t>
 private:
     //!\brief The base type.
     using base_t = std::vector<value_t>;
+
+    //!\brief Is binning_bitvector_t a seqan3::interleaved_bloom_filter::membership_agent_type::binning_bitvector?
+    template <typename binning_bitvector_t>
+    static constexpr bool is_binning_bitvector =
+        std::same_as<binning_bitvector_t,
+                     interleaved_bloom_filter<data_layout::uncompressed>::membership_agent_type::binning_bitvector>
+        || std::same_as<binning_bitvector_t,
+                        interleaved_bloom_filter<data_layout::compressed>::membership_agent_type::binning_bitvector>;
+
 public:
     /*!\name Constructors, destructor and assignment
      * \{
      */
-    counting_vector() = default; //!< Defaulted.
-    counting_vector(counting_vector const &) = default; //!< Defaulted.
+    counting_vector() = default;                                    //!< Defaulted.
+    counting_vector(counting_vector const &) = default;             //!< Defaulted.
     counting_vector & operator=(counting_vector const &) = default; //!< Defaulted.
-    counting_vector(counting_vector &&) = default; //!< Defaulted.
-    counting_vector & operator=(counting_vector &&) = default; //!< Defaulted.
-    ~counting_vector() = default; //!< Defaulted.
+    counting_vector(counting_vector &&) = default;                  //!< Defaulted.
+    counting_vector & operator=(counting_vector &&) = default;      //!< Defaulted.
+    ~counting_vector() = default;                                   //!< Defaulted.
 
     using base_t::base_t;
     //!\}
 
-    /*!\brief Bin-wise adds the bits of a seqan3::interleaved_bloom_filter::membership_agent::binning_bitvector.
-     * \tparam rhs_t The type of the right-hand side.
-     *         Must be seqan3::interleaved_bloom_filter::membership_agent::binning_bitvector.
-     * \param rhs The seqan3::interleaved_bloom_filter::membership_agent::binning_bitvector.
-     * \attention The counting_vector must be at least as big as `rhs`.
+    /*!\brief Bin-wise adds the bits of a seqan3::interleaved_bloom_filter::membership_agent_type::binning_bitvector.
+     * \tparam binning_bitvector_t The type of the right-hand side.
+     *         Must be seqan3::interleaved_bloom_filter::membership_agent_type::binning_bitvector.
+     * \param binning_bitvector The seqan3::interleaved_bloom_filter::membership_agent_type::binning_bitvector.
+     * \attention The counting_vector must be at least as big as `binning_bitvector`.
      *
      * \details
      *
@@ -830,38 +831,35 @@ public:
      *
      * \include test/snippet/search/dream_index/counting_vector.cpp
      */
-    template <typename rhs_t>
-    //!\cond
-        requires std::same_as<rhs_t,
-                              interleaved_bloom_filter<data_layout::uncompressed>::membership_agent::binning_bitvector>
-                 ||
-                 std::same_as<rhs_t,
-                              interleaved_bloom_filter<data_layout::compressed>::membership_agent::binning_bitvector>
-    //!\endcond
-    counting_vector & operator+=(rhs_t const & rhs)
+    template <typename binning_bitvector_t>
+        requires is_binning_bitvector<binning_bitvector_t>
+    counting_vector & operator+=(binning_bitvector_t const & binning_bitvector)
     {
-        assert(this->size() >= rhs.size()); // The counting vector may be bigger than what we need.
+        for_each_set_bin(binning_bitvector,
+                         [this](size_t const bin)
+                         {
+                             ++(*this)[bin];
+                         });
+        return *this;
+    }
 
-        // Each iteration can handle 64 bits, so we need to iterate `((rhs.size() + 63) >> 6` many times
-        for (size_t batch = 0, bin = 0; batch < ((rhs.size() + 63) >> 6); bin = 64 * ++batch)
-        {
-            size_t tmp = rhs.data.get_int(batch * 64); // get 64 bits starting at position `batch * 64`
-            if (tmp ^ (1ULL<<63)) // This is a special case, because we would shift by 64 (UB) in the while loop.
-            {
-                while (tmp > 0)
-                {
-                    // Jump to the next 1 and increment the corresponding vector entry.
-                    uint8_t step = std::countr_zero(tmp);
-                    bin += step++;
-                    tmp >>= step;
-                    ++(*this)[bin++];
-                }
-            }
-            else
-            {
-                ++(*this)[bin + 63];
-            }
-        }
+    /*!\brief Bin-wise subtracts the bits of a
+     *        seqan3::interleaved_bloom_filter::membership_agent_type::binning_bitvector.
+     * \tparam binning_bitvector_t The type of the right-hand side.
+     *         Must be seqan3::interleaved_bloom_filter::membership_agent_type::binning_bitvector.
+     * \param binning_bitvector The seqan3::interleaved_bloom_filter::membership_agent_type::binning_bitvector.
+     * \attention The counting_vector must be at least as big as `binning_bitvector`.
+     */
+    template <typename binning_bitvector_t>
+        requires is_binning_bitvector<binning_bitvector_t>
+    counting_vector & operator-=(binning_bitvector_t const & binning_bitvector)
+    {
+        for_each_set_bin(binning_bitvector,
+                         [this](size_t const bin)
+                         {
+                             assert((*this)[bin] > 0);
+                             --(*this)[bin];
+                         });
         return *this;
     }
 
@@ -883,6 +881,59 @@ public:
 
         return *this;
     }
+
+    /*!\brief Bin-wise substraction of two `seqan3::counting_vector`s.
+     * \param rhs The other seqan3::counting_vector.
+     * \attention The seqan3::counting_vector must be at least as big as `rhs`.
+     */
+    counting_vector & operator-=(counting_vector const & rhs)
+    {
+        assert(this->size() >= rhs.size()); // The counting vector may be bigger than what we need.
+
+        std::transform(this->begin(),
+                       this->end(),
+                       rhs.begin(),
+                       this->begin(),
+                       [](auto a, auto b)
+                       {
+                           assert(a >= b);
+                           return a - b;
+                       });
+
+        return *this;
+    }
+
+private:
+    //!\brief Enumerates all bins of a seqan3::interleaved_bloom_filter::membership_agent_type::binning_bitvector.
+    template <typename binning_bitvector_t, typename on_bin_fn_t>
+    void for_each_set_bin(binning_bitvector_t && binning_bitvector, on_bin_fn_t && on_bin_fn)
+    {
+        assert(this->size() >= binning_bitvector.size()); // The counting vector may be bigger than what we need.
+
+        // Jump to the next 1 and return the number of places jumped in the bit_sequence
+        auto jump_to_next_1bit = [](size_t & x)
+        {
+            auto const zeros = std::countr_zero(x);
+            x >>= zeros; // skip number of zeros
+            return zeros;
+        };
+
+        // Each iteration can handle 64 bits
+        for (size_t bit_pos = 0; bit_pos < binning_bitvector.size(); bit_pos += 64)
+        {
+            // get 64 bits starting at position `bit_pos`
+            size_t bit_sequence = binning_bitvector.raw_data().get_int(bit_pos);
+
+            // process each relative bin inside the bit_sequence
+            for (size_t bin = bit_pos; bit_sequence != 0u; ++bin, bit_sequence >>= 1)
+            {
+                // Jump to the next 1 and
+                bin += jump_to_next_1bit(bit_sequence);
+
+                on_bin_fn(bin);
+            }
+        }
+    }
 };
 
 /*!\brief Manages counting ranges of values for the seqan3::interleaved_bloom_filter.
@@ -906,25 +957,27 @@ private:
     ibf_t const * ibf_ptr{nullptr};
 
     //!\brief Store a seqan3::interleaved_bloom_filter::membership_agent to call `bulk_contains`.
-    typename ibf_t::membership_agent membership_agent;
+    membership_agent_type membership_agent;
 
 public:
     /*!\name Constructors, destructor and assignment
      * \{
      */
-    counting_agent_type() = default; //!< Defaulted.
-    counting_agent_type(counting_agent_type const &) = default; //!< Defaulted.
+    counting_agent_type() = default;                                        //!< Defaulted.
+    counting_agent_type(counting_agent_type const &) = default;             //!< Defaulted.
     counting_agent_type & operator=(counting_agent_type const &) = default; //!< Defaulted.
-    counting_agent_type(counting_agent_type &&) = default; //!< Defaulted.
-    counting_agent_type & operator=(counting_agent_type &&) = default; //!< Defaulted.
-    ~counting_agent_type() = default; //!< Defaulted.
+    counting_agent_type(counting_agent_type &&) = default;                  //!< Defaulted.
+    counting_agent_type & operator=(counting_agent_type &&) = default;      //!< Defaulted.
+    ~counting_agent_type() = default;                                       //!< Defaulted.
 
     /*!\brief Construct a counting_agent_type for an existing seqan3::interleaved_bloom_filter.
      * \private
      * \param ibf The seqan3::interleaved_bloom_filter.
      */
     explicit counting_agent_type(ibf_t const & ibf) :
-        ibf_ptr(std::addressof(ibf)), membership_agent(ibf), result_buffer(ibf.bin_count())
+        ibf_ptr(std::addressof(ibf)),
+        membership_agent(ibf),
+        result_buffer(ibf.bin_count())
     {}
     //!\}
 
@@ -976,7 +1029,6 @@ public:
     template <std::ranges::range value_range_t>
     [[nodiscard]] counting_vector<value_t> const & bulk_count(value_range_t && values) && noexcept = delete;
     //!\}
-
 };
 
 } // namespace seqan3
