@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -13,27 +13,25 @@
 #pragma once
 
 #include <array>
+#include <ranges>
 
 #include <sdsl/suffix_trees.hpp>
 
 #include <seqan3/alphabet/adaptation/char.hpp>
 #include <seqan3/alphabet/adaptation/uint.hpp>
 #include <seqan3/alphabet/concept.hpp>
-#include <seqan3/core/type_traits/range.hpp>
-#include <seqan3/range/views/slice.hpp>
-#include <seqan3/search/fm_index/bi_fm_index.hpp>
-#include <seqan3/std/ranges>
+#include <seqan3/core/range/type_traits.hpp>
+#include <seqan3/search/fm_index/fm_index.hpp>
+#include <seqan3/search/fm_index/fm_index_cursor.hpp>
+#include <seqan3/utility/views/slice.hpp>
 
 namespace seqan3
 {
 
-/*!\addtogroup submodule_fm_index
- * \{
- */
-
 /*!\brief The SeqAn Bidirectional FM Index Cursor.
- * \implements seqan3::bi_fm_index_cursor_specialisation
- * \tparam index_t The type of the underlying index; must model seqan3::bi_fm_index_specialisation.
+ * \ingroup search_fm_index
+ * \tparam index_t The type of the underlying index; This is normally seqan3::bi_fm_index.
+ * \implements seqan3::cerealisable
  * \details
  *
  * The cursor's interface provides searching a string both from left to right as well as from right to left in the
@@ -90,23 +88,23 @@ private:
     using locate_result_type = std::vector<locate_result_value_type>;
 
     //!\brief Type of the underlying FM index.
-    index_type const * index;
+    index_type const * index{nullptr};
 
     /*!\name Suffix array intervals of forward and reverse cursors.
      * \{
      */
-     //!\brief Left suffix array interval of the forward cursor (for extend_right).
-    size_type fwd_lb;
+    //!\brief Left suffix array interval of the forward cursor (for extend_right).
+    size_type fwd_lb{};
     //!\brief Right suffix array interval of the forward cursor (for extend_right).
-    size_type fwd_rb;
+    size_type fwd_rb{};
     //!\brief Left suffix array interval of the reverse cursor (for extend_left).
-    size_type rev_lb;
+    size_type rev_lb{};
     //!\brief Right suffix array interval of the reverse cursor (for extend_left).
-    size_type rev_rb;
+    size_type rev_rb{};
     //\}
 
     //!\brief Alphabet size of the index without delimiters
-    sdsl_sigma_type sigma;
+    sdsl_sigma_type sigma{};
 
     /*!\name Information for on cycle_back() and cycle_front()
      * \brief Only stored for the cursor that has been used last to go down an edge because once one cursor is
@@ -123,11 +121,11 @@ private:
     //!\brief Left suffix array interval of the parent node.
     size_type parent_rb{};
     //!\brief Label of the last edge moved down. Needed for cycle_back() or cycle_front().
-    sdsl_char_type _last_char;
+    sdsl_char_type _last_char{};
     //\}
 
     //!\brief Depth of the node in the suffix tree, i.e. length of the searched query.
-    size_type depth; // equal for both cursors. only stored once
+    size_type depth{}; // equal for both cursors. only stored once
 
     // supports assertions to check whether cycle_back() resp. cycle_front() is called on the same direction as the last
     // extend_right([...]) resp. extend_left([...])
@@ -146,13 +144,14 @@ private:
 
     //!\brief Optimized bidirectional search without alphabet mapping
     template <typename csa_t>
-    //!\cond
-        requires (std::same_as<csa_t, typename index_type::sdsl_index_type> ||
-                  std::same_as<csa_t, typename index_type::rev_sdsl_index_type>)
-    //!\endcond
-    bool bidirectional_search(csa_t const & csa, sdsl_char_type const c,
-                              size_type & l_fwd, size_type & r_fwd,
-                              size_type & l_bwd, size_type & r_bwd) const noexcept
+        requires (std::same_as<csa_t, typename index_type::sdsl_index_type>
+                  || std::same_as<csa_t, typename index_type::rev_sdsl_index_type>) bool
+    bidirectional_search(csa_t const & csa,
+                         sdsl_char_type const c,
+                         size_type & l_fwd,
+                         size_type & r_fwd,
+                         size_type & l_bwd,
+                         size_type & r_bwd) const noexcept
     {
         assert((l_fwd <= r_fwd) && (r_fwd < csa.size()));
         assert(r_fwd + 1 >= l_fwd);
@@ -161,7 +160,7 @@ private:
         size_type _l_fwd, _r_fwd, _l_bwd, _r_bwd;
 
         size_type cc = c;
-        if constexpr(!std::same_as<index_alphabet_type, sdsl::plain_byte_alphabet>)
+        if constexpr (!std::same_as<index_alphabet_type, sdsl::plain_byte_alphabet>)
         {
             cc = csa.char2comp[c];
             if (cc == 0 && c > 0) // [[unlikely]]
@@ -179,9 +178,9 @@ private:
         }
         else
         {
-            auto      const r_s_b  = csa.wavelet_tree.lex_count(l_fwd, r_fwd + 1, c);
+            auto const r_s_b = csa.wavelet_tree.lex_count(l_fwd, r_fwd + 1, c);
             size_type const rank_l = std::get<0>(r_s_b);
-            size_type const s      = std::get<1>(r_s_b), b = std::get<2>(r_s_b);
+            size_type const s = std::get<1>(r_s_b), b = std::get<2>(r_s_b);
             size_type const rank_r = r_fwd - l_fwd - s - b + rank_l;
             _l_fwd = c_begin + rank_l;
             _r_fwd = c_begin + rank_r;
@@ -204,27 +203,27 @@ private:
 
     //!\brief Optimized bidirectional search for cycle_back() and cycle_front() without alphabet mapping
     template <typename csa_t>
-    //!\cond
-        requires (std::same_as<csa_t, typename index_type::sdsl_index_type> ||
-                  std::same_as<csa_t, typename index_type::rev_sdsl_index_type>)
-    //!\endcond
-    bool bidirectional_search_cycle(csa_t const & csa, sdsl_char_type const c,
-                                    size_type const l_parent, size_type const r_parent,
-                                    size_type & l_fwd, size_type & r_fwd,
-                                    size_type & l_bwd, size_type & r_bwd) const noexcept
+        requires (std::same_as<csa_t, typename index_type::sdsl_index_type>
+                  || std::same_as<csa_t, typename index_type::rev_sdsl_index_type>) bool
+    bidirectional_search_cycle(csa_t const & csa,
+                               sdsl_char_type const c,
+                               size_type const l_parent,
+                               size_type const r_parent,
+                               size_type & l_fwd,
+                               size_type & r_fwd,
+                               size_type & l_bwd,
+                               size_type & r_bwd) const noexcept
     {
         assert((l_parent <= r_parent) && (r_parent < csa.size()));
 
         size_type c_begin;
-        if constexpr(std::same_as<index_alphabet_type, sdsl::plain_byte_alphabet>)
+        if constexpr (std::same_as<index_alphabet_type, sdsl::plain_byte_alphabet>)
             c_begin = csa.C[c]; // TODO: check whether this can be removed
         else
             c_begin = csa.C[csa.char2comp[c]];
 
         auto const r_s_b = csa.wavelet_tree.lex_count(l_parent, r_parent + 1, c);
-        size_type const s      = std::get<1>(r_s_b),
-                        b      = std::get<2>(r_s_b),
-                        rank_l = std::get<0>(r_s_b),
+        size_type const s = std::get<1>(r_s_b), b = std::get<2>(r_s_b), rank_l = std::get<0>(r_s_b),
                         rank_r = r_parent - l_parent - s - b + rank_l;
 
         size_type const _l_fwd = c_begin + rank_l;
@@ -246,7 +245,6 @@ private:
     }
 
 public:
-
     /*!\name Constructors, destructor and assignment
      * \{
      */
@@ -261,11 +259,14 @@ public:
     ~bi_fm_index_cursor() = default;                                               //!< Defaulted.
 
     //! \brief Construct from given index.
-    bi_fm_index_cursor(index_t const & _index) noexcept : index(&_index),
-                                                          fwd_lb(0), fwd_rb(_index.size() - 1),
-                                                          rev_lb(0), rev_rb(_index.size() - 1),
-                                                          sigma(_index.fwd_fm.index.sigma - index_t::text_layout_mode),
-                                                          depth(0)
+    bi_fm_index_cursor(index_t const & _index) noexcept :
+        index(&_index),
+        fwd_lb(0),
+        fwd_rb(_index.size() - 1),
+        rev_lb(0),
+        rev_rb(_index.size() - 1),
+        sigma(_index.fwd_fm.index.sigma - index_t::text_layout_mode),
+        depth(0)
     {}
     //\}
 
@@ -285,9 +286,8 @@ public:
     {
         assert(index != nullptr);
         // equal SA interval implies equal parent node information (or both are root nodes)
-        assert(!(fwd_lb == rhs.fwd_lb && fwd_rb == rhs.fwd_rb && depth == rhs.depth) ||
-               (depth == 0) ||
-               (parent_lb == rhs.parent_lb && parent_rb == rhs.parent_rb && _last_char == rhs._last_char));
+        assert(!(fwd_lb == rhs.fwd_lb && fwd_rb == rhs.fwd_rb && depth == rhs.depth) || (depth == 0)
+               || (parent_lb == rhs.parent_lb && parent_rb == rhs.parent_rb && _last_char == rhs._last_char));
 
         return std::tie(fwd_lb, fwd_rb, depth) == std::tie(rhs.fwd_lb, rhs.fwd_rb, rhs.depth);
     }
@@ -330,18 +330,22 @@ public:
      */
     bool extend_right() noexcept
     {
-    #ifndef NDEBUG
+#ifndef NDEBUG
         fwd_cursor_last_used = true;
-    #endif
+#endif
 
         assert(index != nullptr);
 
         size_type new_parent_lb = fwd_lb, new_parent_rb = fwd_rb;
 
         sdsl_char_type c = 1; // NOTE: start with 0 or 1 depending on implicit_sentintel
-        while (c < sigma &&
-               !bidirectional_search(index->fwd_fm.index, index->fwd_fm.index.comp2char[c],
-                                     fwd_lb, fwd_rb, rev_lb, rev_rb))
+        while (c < sigma
+               && !bidirectional_search(index->fwd_fm.index,
+                                        index->fwd_fm.index.comp2char[c],
+                                        fwd_lb,
+                                        fwd_rb,
+                                        rev_lb,
+                                        rev_rb))
         {
             ++c;
         }
@@ -378,18 +382,22 @@ public:
      */
     bool extend_left() noexcept
     {
-    #ifndef NDEBUG
+#ifndef NDEBUG
         fwd_cursor_last_used = false;
-    #endif
+#endif
 
         assert(index != nullptr);
 
         size_type new_parent_lb = rev_lb, new_parent_rb = rev_rb;
 
         sdsl_char_type c = 1; // NOTE: start with 0 or 1 depending on implicit_sentintel
-        while (c < sigma &&
-               !bidirectional_search(index->rev_fm.index, index->rev_fm.index.comp2char[c],
-                                     rev_lb, rev_rb, fwd_lb, fwd_rb))
+        while (c < sigma
+               && !bidirectional_search(index->rev_fm.index,
+                                        index->rev_fm.index.comp2char[c],
+                                        rev_lb,
+                                        rev_rb,
+                                        fwd_lb,
+                                        fwd_rb))
         {
             ++c;
         }
@@ -421,20 +429,18 @@ public:
      * No-throw guarantee.
      */
     template <typename char_t>
-    //!\cond
-        requires std::convertible_to<char_t, index_alphabet_type>
-    //!\endcond
-    bool extend_right(char_t const c) noexcept
+        requires std::convertible_to<char_t, index_alphabet_type> bool
+    extend_right(char_t const c) noexcept
     {
-    #ifndef NDEBUG
+#ifndef NDEBUG
         fwd_cursor_last_used = true;
-    #endif
+#endif
 
         assert(index != nullptr);
         // The rank cannot exceed 255 for single text and 254 for text collections as they are reserved as sentinels
         // for the indexed text.
-        assert(seqan3::to_rank(static_cast<index_alphabet_type>(c)) <
-               ((index_type::text_layout_mode == text_layout::single) ? 255 : 254));
+        assert(seqan3::to_rank(static_cast<index_alphabet_type>(c))
+               < ((index_type::text_layout_mode == text_layout::single) ? 255 : 254));
 
         size_type new_parent_lb = fwd_lb, new_parent_rb = fwd_rb;
 
@@ -454,10 +460,8 @@ public:
 
     //!\overload
     template <typename char_type>
-    //!\cond
-        requires seqan3::detail::is_char_adaptation_v<char_type>
-    //!\endcond
-    bool extend_right(char_type const * cstring) noexcept
+        requires seqan3::detail::is_char_adaptation_v<char_type> bool
+    extend_right(char_type const * cstring) noexcept
     {
         return extend_right(std::basic_string_view<char_type>{cstring});
     }
@@ -476,20 +480,18 @@ public:
      * No-throw guarantee.
      */
     template <typename char_t>
-    //!\cond
-        requires std::convertible_to<char_t, index_alphabet_type>
-    //!\endcond
-    bool extend_left(char_t const c) noexcept
+        requires std::convertible_to<char_t, index_alphabet_type> bool
+    extend_left(char_t const c) noexcept
     {
-    #ifndef NDEBUG
+#ifndef NDEBUG
         fwd_cursor_last_used = false;
-    #endif
+#endif
 
         assert(index != nullptr);
         // The rank cannot exceed 255 for single text and 254 for text collections as they are reserved as sentinels
         // for the indexed text.
-        assert(seqan3::to_rank(static_cast<index_alphabet_type>(c)) <
-               ((index_type::text_layout_mode == text_layout::single) ? 255 : 254));
+        assert(seqan3::to_rank(static_cast<index_alphabet_type>(c))
+               < ((index_type::text_layout_mode == text_layout::single) ? 255 : 254));
 
         size_type new_parent_lb = rev_lb, new_parent_rb = rev_rb;
 
@@ -509,10 +511,8 @@ public:
 
     //!\overload
     template <typename char_type>
-    //!\cond
-        requires seqan3::detail::is_char_adaptation_v<char_type>
-    //!\endcond
-    bool extend_left(char_type const * cstring) noexcept
+        requires seqan3::detail::is_char_adaptation_v<char_type> bool
+    extend_left(char_type const * cstring) noexcept
     {
         return extend_left(std::basic_string_view<char_type>{cstring});
     }
@@ -545,9 +545,9 @@ public:
         auto first = std::ranges::begin(seq);
         auto last = std::ranges::end(seq);
 
-    #ifndef NDEBUG
+#ifndef NDEBUG
         fwd_cursor_last_used = (first != last); // only if seq was not empty
-    #endif
+#endif
 
         size_type _fwd_lb = fwd_lb, _fwd_rb = fwd_rb, _rev_lb = rev_lb, _rev_rb = rev_rb;
         size_type new_parent_lb = parent_lb, new_parent_rb = parent_rb;
@@ -558,8 +558,8 @@ public:
         {
             // The rank cannot exceed 255 for single text and 254 for text collections as they are reserved as sentinels
             // for the indexed text.
-            assert(seqan3::to_rank(static_cast<index_alphabet_type>(*it)) <
-                   ((index_type::text_layout_mode == text_layout::single) ? 255 : 254));
+            assert(seqan3::to_rank(static_cast<index_alphabet_type>(*it))
+                   < ((index_type::text_layout_mode == text_layout::single) ? 255 : 254));
 
             c = seqan3::to_rank(static_cast<index_alphabet_type>(*it)) + 1;
 
@@ -615,13 +615,12 @@ public:
         auto first = std::ranges::begin(rev_seq);
         auto last = std::ranges::end(rev_seq);
 
-    #ifndef NDEBUG
+#ifndef NDEBUG
         if (first != last) // only if seq was not empty
             fwd_cursor_last_used = false;
-    #endif
+#endif
 
-        size_type _fwd_lb = fwd_lb, _fwd_rb = fwd_rb,
-                  _rev_lb = rev_lb, _rev_rb = rev_rb;
+        size_type _fwd_lb = fwd_lb, _fwd_rb = fwd_rb, _rev_lb = rev_lb, _rev_rb = rev_rb;
         size_type new_parent_lb = parent_lb, new_parent_rb = parent_rb;
         sdsl_char_type c = _last_char;
         size_t len{0};
@@ -630,8 +629,8 @@ public:
         {
             // The rank cannot exceed 255 for single text and 254 for text collections as they are reserved as sentinels
             // for the indexed text.
-            assert(seqan3::to_rank(static_cast<index_alphabet_type>(*it)) <
-                   ((index_type::text_layout_mode == text_layout::single) ? 255 : 254));
+            assert(seqan3::to_rank(static_cast<index_alphabet_type>(*it))
+                   < ((index_type::text_layout_mode == text_layout::single) ? 255 : 254));
 
             c = seqan3::to_rank(static_cast<index_alphabet_type>(*it)) + 1;
 
@@ -682,18 +681,24 @@ public:
      */
     bool cycle_back() noexcept
     {
-    #ifndef NDEBUG
+#ifndef NDEBUG
         // cycle_back() can only be used if the last extension was to the right.
         assert(fwd_cursor_last_used);
-    #endif
+#endif
 
         assert(index != nullptr && query_length() > 0);
 
         sdsl_char_type c = _last_char + 1;
 
-        while (c < sigma &&
-               !bidirectional_search_cycle(index->fwd_fm.index, index->fwd_fm.index.comp2char[c],
-                                           parent_lb, parent_rb, fwd_lb, fwd_rb, rev_lb, rev_rb))
+        while (c < sigma
+               && !bidirectional_search_cycle(index->fwd_fm.index,
+                                              index->fwd_fm.index.comp2char[c],
+                                              parent_lb,
+                                              parent_rb,
+                                              fwd_lb,
+                                              fwd_rb,
+                                              rev_lb,
+                                              rev_rb))
         {
             ++c;
         }
@@ -735,17 +740,23 @@ public:
      */
     bool cycle_front() noexcept
     {
-    #ifndef NDEBUG
+#ifndef NDEBUG
         // cycle_front() can only be used if the last extension was to the left.
         assert(!fwd_cursor_last_used);
-    #endif
+#endif
 
         assert(index != nullptr && query_length() > 0);
 
         sdsl_char_type c = _last_char + 1;
-        while (c < sigma &&
-               !bidirectional_search_cycle(index->rev_fm.index, index->rev_fm.index.comp2char[c],
-                                           parent_lb, parent_rb, rev_lb, rev_rb, fwd_lb, fwd_rb))
+        while (c < sigma
+               && !bidirectional_search_cycle(index->rev_fm.index,
+                                              index->rev_fm.index.comp2char[c],
+                                              parent_lb,
+                                              parent_rb,
+                                              rev_lb,
+                                              rev_rb,
+                                              fwd_lb,
+                                              fwd_rb))
         {
             ++c;
         }
@@ -759,7 +770,6 @@ public:
         return false;
     }
 
-
     /*!\brief Outputs the rightmost respectively leftmost rank depending on whether extend_right() or extend_left()
      *        has been called last.
      * \returns Rightmost or leftmost rank.
@@ -799,11 +809,7 @@ public:
     {
         assert(index != nullptr);
         // depth == 0 -> root node
-        assert(depth != 0 ||
-               (fwd_lb == rev_lb &&
-                fwd_rb == rev_rb &&
-                fwd_lb == 0 &&
-                fwd_rb == index->size() - 1));
+        assert(depth != 0 || (fwd_lb == rev_lb && fwd_rb == rev_rb && fwd_lb == 0 && fwd_rb == index->size() - 1));
 
         return depth;
     }
@@ -836,14 +842,14 @@ public:
         cur.parent_rb = parent_rb;
         cur.node = {fwd_lb, fwd_rb, depth, _last_char};
 
-    #ifndef NDEBUG
+#ifndef NDEBUG
         if (!fwd_cursor_last_used)
         {
             // invalidate parent interval
             cur.parent_lb = 1;
             cur.parent_rb = 0;
         }
-    #endif
+#endif
 
         return cur;
     }
@@ -866,9 +872,7 @@ public:
      */
     template <std::ranges::range text_t>
     auto path_label(text_t && text) const noexcept
-    //!\cond
         requires (index_t::text_layout_mode == text_layout::single)
-    //!\endcond
     {
         static_assert(std::ranges::input_range<text_t>, "The text must model input_range.");
         static_assert(range_dimension_v<text_t> == 1, "The input cannot be a text collection.");
@@ -883,9 +887,7 @@ public:
     //!\overload
     template <std::ranges::range text_t>
     auto path_label(text_t && text) const noexcept
-    //!\cond
         requires (index_t::text_layout_mode == text_layout::collection)
-    //!\endcond
     {
         static_assert(std::ranges::input_range<text_t>, "The text collection must model input_range.");
         static_assert(range_dimension_v<text_t> == 2, "The input must be a text collection.");
@@ -941,9 +943,7 @@ public:
      * Strong exception guarantee (no data is modified in case an exception is thrown).
      */
     locate_result_type locate() const
-    //!\cond
         requires (index_t::text_layout_mode == text_layout::single)
-    //!\endcond
     {
         assert(index != nullptr);
 
@@ -958,9 +958,7 @@ public:
 
     //!\overload
     std::vector<std::pair<size_type, size_type>> locate() const
-    //!\cond
         requires (index_t::text_layout_mode == text_layout::collection)
-    //!\endcond
     {
         assert(index != nullptr);
 
@@ -989,41 +987,56 @@ public:
      * Strong exception guarantee (no data is modified in case an exception is thrown).
      */
     auto lazy_locate() const
-    //!\cond
         requires (index_t::text_layout_mode == text_layout::single)
-    //!\endcond
     {
         assert(index != nullptr);
 
         return std::views::iota(fwd_lb, fwd_lb + count())
-             | std::views::transform([*this, _offset = offset()] (auto sa_pos)
-               {
-                   return locate_result_value_type{0u, _offset - index->fwd_fm.index[sa_pos]};
-               });
+             | std::views::transform(
+                   [*this, _offset = offset()](auto sa_pos)
+                   {
+                       return locate_result_value_type{0u, _offset - index->fwd_fm.index[sa_pos]};
+                   });
     }
 
     //!\overload
     auto lazy_locate() const
-    //!\cond
         requires (index_t::text_layout_mode == text_layout::collection)
-    //!\endcond
     {
         assert(index != nullptr);
 
         return std::views::iota(fwd_lb, fwd_lb + count())
-             | std::views::transform([*this, _offset = offset()] (auto sa_pos)
-               {
-                   return _offset - index->fwd_fm.index[sa_pos];
-               })
-             | std::views::transform([*this] (auto loc)
-               {
-                   size_type sequence_rank = index->fwd_fm.text_begin_rs.rank(loc + 1);
-                   size_type sequence_position = loc - index->fwd_fm.text_begin_ss.select(sequence_rank);
-                   return locate_result_value_type{sequence_rank-1, sequence_position};
-               });
+             | std::views::transform(
+                   [*this, _offset = offset()](auto sa_pos)
+                   {
+                       auto loc = _offset - index->fwd_fm.index[sa_pos];
+                       size_type sequence_rank = index->fwd_fm.text_begin_rs.rank(loc + 1);
+                       size_type sequence_position = loc - index->fwd_fm.text_begin_ss.select(sequence_rank);
+                       return locate_result_value_type{sequence_rank - 1, sequence_position};
+                   });
     }
+
+    /*!\cond DEV
+     * \brief Serialisation support function.
+     * \tparam archive_t Type of `archive`; must satisfy seqan3::cereal_archive.
+     * \param archive The archive being serialised from/to.
+     *
+     * \attention These functions are never called directly, see \ref serialisation for more details.
+     */
+    template <cereal_archive archive_t>
+    void CEREAL_SERIALIZE_FUNCTION_NAME(archive_t & archive)
+    {
+        archive(fwd_lb);
+        archive(fwd_rb);
+        archive(rev_lb);
+        archive(rev_rb);
+        archive(sigma);
+        archive(parent_lb);
+        archive(parent_rb);
+        archive(_last_char);
+        archive(depth);
+    }
+    //!\endcond
 };
 
-//!\}
-
 } // namespace seqan3
