@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -12,9 +12,9 @@
 
 #pragma once
 
-#include <seqan3/std/algorithm>
-#include <seqan3/std/filesystem>
-#include <seqan3/std/ranges>
+#include <algorithm>
+#include <filesystem>
+#include <ranges>
 
 #include <sdsl/suffix_trees.hpp>
 
@@ -23,7 +23,6 @@
 #include <seqan3/search/fm_index/concept.hpp>
 #include <seqan3/search/fm_index/detail/fm_index_cursor.hpp>
 #include <seqan3/search/fm_index/fm_index_cursor.hpp>
-#include <seqan3/utility/views/join_with.hpp>
 
 namespace seqan3::detail
 {
@@ -53,7 +52,7 @@ struct fm_index_validator
         {
             static_assert(std::ranges::bidirectional_range<text_t>, "The text must model bidirectional_range.");
             static_assert(std::convertible_to<range_innermost_value_t<text_t>, alphabet_t>,
-                        "The alphabet of the text collection must be convertible to the alphabet of the index.");
+                          "The alphabet of the text collection must be convertible to the alphabet of the index.");
             static_assert(range_dimension_v<text_t> == 1, "The input cannot be a text collection.");
 
             if (std::ranges::empty(text))
@@ -90,9 +89,7 @@ class bi_fm_index_cursor;
 
 namespace detail
 {
-template <semialphabet alphabet_t,
-          text_layout text_layout_mode_,
-          detail::sdsl_index sdsl_index_type_>
+template <semialphabet alphabet_t, text_layout text_layout_mode_, detail::sdsl_index sdsl_index_type_>
 class reverse_fm_index;
 }
 //!\endcond
@@ -134,11 +131,11 @@ using sdsl_wt_index_type =
                                sdsl::rank_support_v<>,
                                sdsl::select_support_scan<>,
                                sdsl::select_support_scan<0>>,
-                 16, // Sampling rate of the suffix array
-                 10'000'000, // Sampling rate of the inverse suffix array
+                 16,                           // Sampling rate of the suffix array
+                 10'000'000,                   // Sampling rate of the inverse suffix array
                  sdsl::sa_order_sa_sampling<>, // How to sample positions in the suffix array (text VS SA sampling)
-                 sdsl::isa_sampling<>, // How to sample positons in the inverse suffix array
-                 sdsl::plain_byte_alphabet>; // How to represent the alphabet
+                 sdsl::isa_sampling<>,         // How to sample positons in the inverse suffix array
+                 sdsl::plain_byte_alphabet>;   // How to represent the alphabet
 
 /*!\brief The default FM Index Configuration.
  * \ingroup search_fm_index
@@ -216,6 +213,33 @@ private:
     //!\brief Rank support for text_begin.
     sdsl::rank_support_sd<1> text_begin_rs;
 
+    //!\brief Eagerly convert sequence into ranks, shift by one and copy them into output_it.
+    template <typename output_it_t, typename sequence_t>
+    static output_it_t copy_sequence_ranks_shifted_by_one(output_it_t output_it, sequence_t && sequence)
+    {
+        constexpr size_t sigma = alphabet_size<alphabet_t>;
+        constexpr size_t max_sigma = text_layout_mode_ == text_layout::single ? 256u : 255u;
+
+        constexpr auto warn_if_rank_out_of_range = [](uint8_t const rank)
+        {
+            if (rank >= max_sigma - 1) // same as rank + 1 >= max_sigma but without overflow
+                throw std::out_of_range("The input text cannot be indexed, because for full"
+                                        "character alphabets the last one/two values are reserved"
+                                        "(single sequence/collection).");
+        };
+
+        return std::ranges::transform(sequence,
+                                      output_it,
+                                      [&warn_if_rank_out_of_range](auto const & chr)
+                                      {
+                                          uint8_t const rank = seqan3::to_rank(chr);
+                                          if constexpr (sigma >= max_sigma)
+                                              warn_if_rank_out_of_range(rank);
+                                          return rank + 1;
+                                      })
+            .out;
+    }
+
     /*!\brief Constructs the index given a range.
               The range cannot be an rvalue (i.e. a temporary object) and has to be non-empty.
      * \tparam text_t The type of range to construct from; must model std::ranges::bidirectional_range.
@@ -236,15 +260,11 @@ private:
      * No guarantee. \if DEV \todo Ensure strong exception guarantee. \endif
      */
     template <std::ranges::range text_t>
-    //!\cond
         requires (text_layout_mode_ == text_layout::single)
-    //!\endcond
     void construct(text_t && text)
     {
         detail::fm_index_validator::validate<alphabet_t, text_layout_mode_>(text);
 
-        constexpr auto sigma = alphabet_size<alphabet_t>;
-
         // TODO:
         // * check what happens in sdsl when constructed twice!
         // * choose between in-memory/external and construction algorithms
@@ -252,21 +272,8 @@ private:
         // uint8_t largest_char = 0;
         sdsl::int_vector<8> tmp_text(std::ranges::distance(text));
 
-        std::ranges::move(text
-                          | views::to_rank
-                          | std::views::transform([] (uint8_t const r)
-                          {
-                              if constexpr (sigma == 256)
-                              {
-                                  if (r == 255)
-                                      throw std::out_of_range("The input text cannot be indexed, because for full"
-                                                              "character alphabets the last one/two values are reserved"
-                                                              "(single sequence/collection).");
-                              }
-                              return r + 1;
-                          })
-                          | std::views::reverse,
-                          std::ranges::begin(tmp_text)); // reverse and increase rank by one
+        // copy ranks into tmp_text
+        copy_sequence_ranks_shifted_by_one(std::ranges::begin(tmp_text), text | std::views::reverse);
 
         sdsl::construct_im(index, tmp_text, 0);
 
@@ -278,9 +285,7 @@ private:
 
     //!\overload
     template <std::ranges::range text_t>
-    //!\cond
         requires (text_layout_mode_ == text_layout::collection)
-    //!\endcond
     void construct(text_t && text, bool reverse = false)
     {
         detail::fm_index_validator::validate<alphabet_t, text_layout_mode_>(text);
@@ -312,7 +317,7 @@ private:
             prefix_sum += size + 1;
         }
 
-        text_begin    = sdsl::sd_vector<>(builder);
+        text_begin = sdsl::sd_vector<>(builder);
         text_begin_ss = sdsl::select_support_sd<1>(&text_begin);
         text_begin_rs = sdsl::rank_support_sd<1>(&text_begin);
 
@@ -321,25 +326,27 @@ private:
 
         constexpr uint8_t delimiter = sigma >= 255 ? 255 : sigma + 1;
 
-        std::ranges::move(text
-                          | views::deep{views::to_rank}
-                          | views::deep
-                          {
-                              std::views::transform([] (uint8_t const r)
-                              {
-                                  if constexpr (sigma >= 255)
-                                  {
-                                      if (r >= 254)
-                                          throw std::out_of_range("The input text cannot be indexed, because"
-                                                                  " for full character alphabets the last one/"
-                                                                  "two values are reserved (single sequence/"
-                                                                  "collection).");
-                                  }
-                                  return r + 1;
-                              })
-                          }
-                          | views::join_with(delimiter),
-                          std::ranges::begin(tmp_text));
+        auto copy_join_with = [](auto output_it, auto && collection)
+        {
+            // this is basically std::views::join() with a delimiter
+            auto collection_it = std::ranges::begin(collection);
+            auto const collection_sentinel = std::ranges::end(collection);
+            if (collection_it == collection_sentinel)
+                return;
+
+            output_it = copy_sequence_ranks_shifted_by_one(output_it, *collection_it);
+            ++collection_it;
+
+            for (; collection_it != collection_sentinel; ++collection_it)
+            {
+                *output_it = delimiter;
+                ++output_it;
+                output_it = copy_sequence_ranks_shifted_by_one(output_it, *collection_it);
+            }
+        };
+
+        // copy ranks into tmp_text
+        copy_join_with(std::ranges::begin(tmp_text), text);
 
         if (!reverse)
         {
@@ -395,11 +402,14 @@ public:
     /*!\name Constructors, destructor and assignment
      * \{
      */
-    fm_index() = default;              //!< Defaulted.
+    fm_index() = default; //!< Defaulted.
 
     //!\brief When copy constructing, also update internal data structures.
     fm_index(fm_index const & rhs) :
-        index{rhs.index}, text_begin{rhs.text_begin}, text_begin_ss{rhs.text_begin_ss}, text_begin_rs{rhs.text_begin_rs}
+        index{rhs.index},
+        text_begin{rhs.text_begin},
+        text_begin_ss{rhs.text_begin_ss},
+        text_begin_rs{rhs.text_begin_rs}
     {
         text_begin_ss.set_vector(&text_begin);
         text_begin_rs.set_vector(&text_begin);
@@ -407,7 +417,9 @@ public:
 
     //!\brief When move constructing, also update internal data structures.
     fm_index(fm_index && rhs) :
-        index{std::move(rhs.index)}, text_begin{std::move(rhs.text_begin)},text_begin_ss{std::move(rhs.text_begin_ss)},
+        index{std::move(rhs.index)},
+        text_begin{std::move(rhs.text_begin)},
+        text_begin_ss{std::move(rhs.text_begin_ss)},
         text_begin_rs{std::move(rhs.text_begin_rs)}
     {
         text_begin_ss.set_vector(&text_begin);
@@ -428,7 +440,7 @@ public:
         return *this;
     }
 
-    ~fm_index() = default;             //!< Defaulted.
+    ~fm_index() = default; //!< Defaulted.
 
     /*!\brief Constructor that immediately constructs the index given a range. The range cannot be empty.
      * \tparam text_t The type of range to construct from; must model std::ranges::bidirectional_range.
@@ -550,23 +562,22 @@ public:
         archive(sigma);
         if (sigma != alphabet_size<alphabet_t>)
         {
-            throw std::logic_error{"The fm_index was built over an alphabet of size " + std::to_string(sigma) +
-                                   " but it is being read into an fm_index with an alphabet of size " +
-                                   std::to_string(alphabet_size<alphabet_t>) + "."};
+            throw std::logic_error{"The fm_index was built over an alphabet of size " + std::to_string(sigma)
+                                   + " but it is being read into an fm_index with an alphabet of size "
+                                   + std::to_string(alphabet_size<alphabet_t>) + "."};
         }
 
         bool tmp = text_layout_mode;
         archive(tmp);
         if (tmp != text_layout_mode)
         {
-            throw std::logic_error{std::string{"The fm_index was built over a "} +
-                                   (tmp ? "text collection" : "single text") +
-                                   " but it is being read into an fm_index expecting a " +
-                                   (text_layout_mode ? "text collection." : "single text.")};
+            throw std::logic_error{std::string{"The fm_index was built over a "}
+                                   + (tmp ? "text collection" : "single text")
+                                   + " but it is being read into an fm_index expecting a "
+                                   + (text_layout_mode ? "text collection." : "single text.")};
         }
     }
     //!\endcond
-
 };
 
 /*!\name Template argument type deduction guides
@@ -625,7 +636,6 @@ public:
     {
         construct_(std::forward<text_t>(text));
     }
-
 };
 
 } // namespace seqan3::detail
