@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -15,8 +15,4 @@
 
 #include <seqan3/core/platform.hpp>
 
-/*!\defgroup utility_concept Concept
- * \brief Provides various general purpose concepts.
- * \ingroup utility
- * \see utility
- */
+SEQAN3_DEPRECATED_HEADER("This header is deprecated and will be removed in SeqAn-3.3.0.")
