@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -13,7 +13,7 @@
 #pragma once
 
 #if defined(__GNUC__) || defined(__clang__)
-#include <cxxabi.h>
+#    include <cxxabi.h>
 #endif // defined(__GNUC__) || defined(__clang__)
 
 #include <functional>
@@ -41,7 +41,7 @@ namespace seqan3::detail
  * \note The returned name is implementation defined and might change between different tool chains.
  */
 template <typename type>
-inline std::string const type_name_as_string = [] ()
+inline std::string const type_name_as_string = []()
 {
     std::string demangled_name{};
 #if defined(__GNUC__) || defined(__clang__) // clang and gcc only return a mangled name.
@@ -50,21 +50,25 @@ inline std::string const type_name_as_string = [] ()
     // https://gcc.gnu.org/onlinedocs/libstdc++/libstdc++-html-USERS-4.3/a01696.html
     int status{};
     safe_ptr_t demangled_name_ptr{abi::__cxa_demangle(typeid(type).name(), 0, 0, &status),
-                                  [] (char * name_ptr) { free(name_ptr); }};
+                                  [](char * name_ptr)
+                                  {
+                                      free(name_ptr);
+                                  }};
 
     // We exclude status != 0, because this code can't be reached normally, only if there is a defect in the compiler
     // itself, since the type is directly given by the compiler. See https://github.com/seqan/seqan3/pull/2311.
     // LCOV_EXCL_START
     if (status != 0)
-        return std::string{typeid(type).name()} +
-               " (abi::__cxa_demangle error status (" + std::to_string(status) + "): " +
-               (status == -1 ? "A memory allocation failure occurred." :
-               (status == -2 ? "mangled_name is not a valid name under the C++ ABI mangling rules." :
-               (status == -3 ? "One of the arguments is invalid." : "Unknown Error"))) + ")";
+        return std::string{typeid(type).name()} + " (abi::__cxa_demangle error status (" + std::to_string(status)
+             + "): "
+             + (status == -1 ? "A memory allocation failure occurred."
+                             : (status == -2 ? "mangled_name is not a valid name under the C++ ABI mangling rules."
+                                             : (status == -3 ? "One of the arguments is invalid." : "Unknown Error")))
+             + ")";
     // LCOV_EXCL_STOP
 
     demangled_name = std::string{std::addressof(*demangled_name_ptr)};
-#else // e.g. MSVC
+#else  // e.g. MSVC
     demangled_name = typeid(type).name();
 #endif // defined(__GNUC__) || defined(__clang__)
 
@@ -78,4 +82,4 @@ inline std::string const type_name_as_string = [] ()
     return demangled_name;
 }();
 
-}  // namespace seqan3::detail
+} // namespace seqan3::detail
