@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -24,11 +24,9 @@ namespace seqan3
 #define SEQAN_NOT_POD "If you are not going to insert a POD type, use std::tuple instead."
 //!\endcond
 
-//!cond
-template <typename ...types>
+template <typename... types>
 struct pod_tuple
 {};
-//!\endcond
 
 /*!\brief Behaves like std::tuple but is an aggregate [PODType](https://en.cppreference.com/w/cpp/named_req/PODType).
  * \ingroup utility_tuple
@@ -50,7 +48,7 @@ struct pod_tuple
  * \include test/snippet/utility/tuple/pod_tuple.cpp
  *
  */
-template <typename type0, typename ...types>
+template <typename type0, typename... types>
 struct pod_tuple<type0, types...>
 {
     static_assert(std::is_standard_layout_v<type0> && std::is_trivial_v<type0>, SEQAN_NOT_POD);
@@ -163,8 +161,8 @@ struct pod_tuple<type0>
 
 //!\brief User defined deduction guide enables easy use.
 //!\relates pod_tuple
-template <typename ...types>
-pod_tuple(types && ...) -> pod_tuple<types...>;
+template <typename... types>
+pod_tuple(types &&...) -> pod_tuple<types...>;
 
 /*!\name Access an element of a pod_tuple by index
  * \{
@@ -174,59 +172,51 @@ pod_tuple(types && ...) -> pod_tuple<types...>;
  */
 //!\brief The same as [std::get](https://en.cppreference.com/w/cpp/utility/tuple/get) on a std::tuple.
 //!\relates seqan3::pod_tuple
-template <std::size_t i, typename ...types>
+template <std::size_t i, typename... types>
 constexpr auto & get(seqan3::pod_tuple<types...> & t) noexcept
-//!\cond
     requires (i < sizeof...(types))
-//!\endcond
 {
     if constexpr (i == 0)
         return t._head;
     else
-        return seqan3::get<i-1>(t._tail);
+        return seqan3::get<i - 1>(t._tail);
 }
 
 //!\brief The same as [std::get](https://en.cppreference.com/w/cpp/utility/tuple/get) on a std::tuple.
 //!\relates seqan3::pod_tuple
-template <std::size_t i, typename ...types>
+template <std::size_t i, typename... types>
 constexpr auto const & get(seqan3::pod_tuple<types...> const & t) noexcept
-//!\cond
     requires (i < sizeof...(types))
-//!\endcond
 {
     if constexpr (i == 0)
         return t._head;
     else
-        return seqan3::get<i-1>(t._tail);
+        return seqan3::get<i - 1>(t._tail);
 }
 
 // extra overloads for temporaries required, because members of temporaries may only be returned as temporaries
 //!\brief The same as [std::get](https://en.cppreference.com/w/cpp/utility/tuple/get) on a std::tuple.
 //!\relates seqan3::pod_tuple
-template <std::size_t i, typename ...types>
+template <std::size_t i, typename... types>
 constexpr auto && get(seqan3::pod_tuple<types...> && t) noexcept
-//!\cond
     requires (i < sizeof...(types))
-//!\endcond
 {
     if constexpr (i == 0)
         return std::move(t._head);
     else
-        return seqan3::get<i-1>(std::move(t._tail));
+        return seqan3::get<i - 1>(std::move(t._tail));
 }
 
 //!\brief The same as [std::get](https://en.cppreference.com/w/cpp/utility/tuple/get) on a std::tuple.
 //!\relates seqan3::pod_tuple
-template <std::size_t i, typename ...types>
+template <std::size_t i, typename... types>
 constexpr auto const && get(seqan3::pod_tuple<types...> const && t) noexcept
-//!\cond
     requires (i < sizeof...(types))
-//!\endcond
 {
     if constexpr (i == 0)
         return std::move(t._head);
     else
-        return seqan3::get<i-1>(std::move(t._tail));
+        return seqan3::get<i - 1>(std::move(t._tail));
 }
 //!\}
 
@@ -240,44 +230,36 @@ constexpr auto const && get(seqan3::pod_tuple<types...> const && t) noexcept
  */
 //!\brief The same as [std::get](https://en.cppreference.com/w/cpp/utility/tuple/get) on a std::tuple.
 //!\relates seqan3::pod_tuple
-template <typename type, typename ...arg_types>
+template <typename type, typename... arg_types>
 constexpr auto & get(seqan3::pod_tuple<arg_types...> & t) noexcept
-//!\cond
     requires (seqan3::pack_traits::count<type, arg_types...> == 1)
-//!\endcond
 {
     return seqan3::get<seqan3::pack_traits::find<type, arg_types...>>(t);
 }
 
 //!\brief The same as [std::get](https://en.cppreference.com/w/cpp/utility/tuple/get) on a std::tuple.
 //!\relates seqan3::pod_tuple
-template <typename type, typename ...arg_types>
+template <typename type, typename... arg_types>
 constexpr auto const & get(seqan3::pod_tuple<arg_types...> const & t) noexcept
-//!\cond
     requires (seqan3::pack_traits::count<type, arg_types...> == 1)
-//!\endcond
 {
     return seqan3::get<seqan3::pack_traits::find<type, arg_types...>>(t);
 }
 
 //!\brief The same as [std::get](https://en.cppreference.com/w/cpp/utility/tuple/get) on a std::tuple.
 //!\relates seqan3::pod_tuple
-template <typename type, typename ...arg_types>
+template <typename type, typename... arg_types>
 constexpr auto && get(seqan3::pod_tuple<arg_types...> && t) noexcept
-//!\cond
     requires (seqan3::pack_traits::count<type, arg_types...> == 1)
-//!\endcond
 {
     return seqan3::get<seqan3::pack_traits::find<type, arg_types...>>(std::move(t));
 }
 
 //!\brief The same as [std::get](https://en.cppreference.com/w/cpp/utility/tuple/get) on a std::tuple.
 //!\relates seqan3::pod_tuple
-template <typename type, typename ...arg_types>
+template <typename type, typename... arg_types>
 constexpr auto const && get(seqan3::pod_tuple<arg_types...> const && t) noexcept
-//!\cond
     requires (seqan3::pack_traits::count<type, arg_types...> == 1)
-//!\endcond
 {
     return seqan3::get<seqan3::pack_traits::find<type, arg_types...>>(std::move(t));
 }
@@ -289,56 +271,56 @@ namespace std
 {
 
 //!\cond
-template <std::size_t i, typename ...types>
+template <std::size_t i, typename... types>
 constexpr auto & get(seqan3::pod_tuple<types...> & t) noexcept
     requires (i < sizeof...(types))
 {
     return seqan3::get<i>(t);
 }
 
-template <std::size_t i, typename ...types>
+template <std::size_t i, typename... types>
 constexpr auto const & get(seqan3::pod_tuple<types...> const & t) noexcept
     requires (i < sizeof...(types))
 {
     return seqan3::get<i>(t);
 }
 
-template <std::size_t i, typename ...types>
+template <std::size_t i, typename... types>
 constexpr auto && get(seqan3::pod_tuple<types...> && t) noexcept
     requires (i < sizeof...(types))
 {
     return seqan3::get<i>(std::move(t));
 }
 
-template <std::size_t i, typename ...types>
+template <std::size_t i, typename... types>
 constexpr auto const && get(seqan3::pod_tuple<types...> const && t) noexcept
     requires (i < sizeof...(types))
 {
     return seqan3::get<i>(std::move(t));
 }
 
-template <typename type, typename ...types>
+template <typename type, typename... types>
 constexpr auto & get(seqan3::pod_tuple<types...> & t) noexcept
     requires (seqan3::pack_traits::count<type, types...> == 1)
 {
     return seqan3::get<type>(t);
 }
 
-template <typename type, typename ...types>
+template <typename type, typename... types>
 constexpr auto const & get(seqan3::pod_tuple<types...> const & t) noexcept
     requires (seqan3::pack_traits::count<type, types...> == 1)
 {
     return seqan3::get<type>(t);
 }
 
-template <typename type, typename ...types>
+template <typename type, typename... types>
 constexpr auto && get(seqan3::pod_tuple<types...> && t) noexcept
     requires (seqan3::pack_traits::count<type, types...> == 1)
 {
     return seqan3::get<type>(std::move(t));
 }
 
-template <typename type, typename ...types>
+template <typename type, typename... types>
 constexpr auto const && get(seqan3::pod_tuple<types...> const && t) noexcept
     requires (seqan3::pack_traits::count<type, types...> == 1)
 {
@@ -351,11 +333,8 @@ constexpr auto const && get(seqan3::pod_tuple<types...> const && t) noexcept
  * \relates seqan3::pod_tuple
  * \see [std::tuple_element](https://en.cppreference.com/w/cpp/utility/tuple/tuple_element)
  */
-template <std::size_t i, template <typename ...> typename t, typename ...types>
-//!\cond
-    requires (i < sizeof...(types)) &&
-            std::is_base_of_v<seqan3::pod_tuple<types...>, t<types...>>
-//!\endcond
+template <std::size_t i, template <typename...> typename t, typename... types>
+    requires (i < sizeof...(types)) && std::is_base_of_v<seqan3::pod_tuple<types...>, t<types...>>
 struct tuple_element<i, t<types...>>
 {
     //!\brief Element type.
@@ -367,10 +346,9 @@ struct tuple_element<i, t<types...>>
  * \see std::tuple_size_v
  * \relates seqan3::pod_tuple
  */
-template <template <typename ...> typename t, typename ...types>
+template <template <typename...> typename t, typename... types>
     requires std::is_base_of_v<seqan3::pod_tuple<types...>, t<types...>>
-struct tuple_size<t<types...>> :
-    public std::integral_constant<std::size_t, sizeof...(types)>
+struct tuple_size<t<types...>> : public std::integral_constant<std::size_t, sizeof...(types)>
 {};
 
 } // namespace std
