@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -12,7 +12,7 @@
 
 #pragma once
 
-#include <seqan3/std/type_traits>
+#include <type_traits>
 
 #include <seqan3/utility/type_list/type_list.hpp>
 #include <seqan3/utility/type_pack/traits.hpp>
@@ -29,21 +29,21 @@ namespace seqan3::list_traits::detail
  * \tparam pack_t   Types in the type list.
  * \ingroup utility_type_list
  */
-template <ptrdiff_t idx, typename ...pack_t>
+template <ptrdiff_t idx, typename... pack_t>
 std::type_identity<seqan3::pack_traits::at<idx, pack_t...>> at(type_list<pack_t...>);
 
 /*!\brief Implementation for seqan3::list_traits::front.
  * \tparam pack_t   Types in the type list.
  * \ingroup utility_type_list
  */
-template <typename ...pack_t>
+template <typename... pack_t>
 std::type_identity<seqan3::pack_traits::front<pack_t...>> front(type_list<pack_t...>);
 
 /*!\brief Implementation for seqan3::list_traits::back.
  * \tparam pack_t   Types in the type list.
  * \ingroup utility_type_list
  */
-template <typename ...pack_t>
+template <typename... pack_t>
 std::type_identity<seqan3::pack_traits::back<pack_t...>> back(type_list<pack_t...>);
 
 /*!\brief Implementation for seqan3::list_traits::concat.
@@ -51,8 +51,7 @@ std::type_identity<seqan3::pack_traits::back<pack_t...>> back(type_list<pack_t..
  * \tparam pack2_t   Types in the second type list.
  * \ingroup utility_type_list
  */
-template <typename ...pack1_t,
-          typename ...pack2_t>
+template <typename... pack1_t, typename... pack2_t>
 type_list<pack1_t..., pack2_t...> concat(type_list<pack1_t...>, type_list<pack2_t...>);
 
 /*!\brief Implementation for seqan3::list_traits::concat [overload for more than two lists].
@@ -61,10 +60,8 @@ type_list<pack1_t..., pack2_t...> concat(type_list<pack1_t...>, type_list<pack2_
  * \tparam more_lists_t The remaining type lists.
  * \ingroup utility_type_list
  */
-template <typename ...pack1_t,
-          typename ...pack2_t,
-          typename ...more_lists_t>
-auto concat(type_list<pack1_t...>, type_list<pack2_t...>, more_lists_t ...)
+template <typename... pack1_t, typename... pack2_t, typename... more_lists_t>
+auto concat(type_list<pack1_t...>, type_list<pack2_t...>, more_lists_t...)
 {
     return concat(type_list<pack1_t..., pack2_t...>{}, more_lists_t{}...);
 }
@@ -73,7 +70,7 @@ auto concat(type_list<pack1_t...>, type_list<pack2_t...>, more_lists_t ...)
  * \tparam pack_t   Types in the type list.
  * \ingroup utility_type_list
  */
-template <typename ...pack_t>
+template <typename... pack_t>
 pack_traits::drop_front<pack_t...> drop_front(type_list<pack_t...>);
 
 /*!\brief Implementation for seqan3::list_traits::transform.
@@ -81,7 +78,7 @@ pack_traits::drop_front<pack_t...> drop_front(type_list<pack_t...>);
  * \tparam pack_t  Types in the type list.
  * \ingroup utility_type_list
  */
-template <template <typename> typename trait_t, typename ...pack_t>
+template <template <typename> typename trait_t, typename... pack_t>
 pack_traits::transform<trait_t, pack_t...> transform(type_list<pack_t...>);
 
 /*!\brief Implementation for seqan3::list_traits::split_after.
@@ -89,38 +86,65 @@ pack_traits::transform<trait_t, pack_t...> transform(type_list<pack_t...>);
  * \tparam pack_t Types in the type list to split
  * \ingroup utility_type_list
  */
-template <ptrdiff_t idx,
-          typename ...pack1_t>
+template <ptrdiff_t idx, typename... pack1_t>
 pack_traits::split_after<idx, pack1_t...> split_after(type_list<pack1_t...>);
 
+/*!\brief Implementation for seqan3::list_traits::repeat.
+ * \tparam count The number of repititions.
+ * \tparam t The type to repeat
+ * \ingroup utility_type_list
+ */
+template <size_t count, typename t>
+auto repeat()
+{
+    if constexpr (count == 0)
+        return type_list<>{};
+    else if constexpr (count == 1)
+        return type_list<t>{};
+    else if constexpr (count == 2)
+        return type_list<t, t>{};
+    else if constexpr (count == 3)
+        return type_list<t, t, t>{};
+    else if constexpr (count == 4)
+        return type_list<t, t, t, t>{};
+    else if constexpr (count == 5)
+        return type_list<t, t, t, t, t>{};
+    else
+        return concat(repeat<5, t>(), repeat<count - 5, t>());
+}
+
 /*!\brief Implementation for seqan3::list_traits::replace_at.
  * \tparam replace_t The type replacing the old one.
  * \tparam idx The index of the type to replace.
  * \tparam pack_t Types in the type list to be modified.
  * \ingroup utility_type_list
  */
-template <typename replace_t,
-          ptrdiff_t idx,
-          typename ...pack_t>
+template <typename replace_t, ptrdiff_t idx, typename... pack_t>
 pack_traits::replace_at<replace_t, idx, pack_t...> replace_at(type_list<pack_t...>);
 
 //!\brief A replacement for meta::reverse [recursion anchor]
-inline constexpr type_list<> reverse(type_list<>) { return {}; }
+inline constexpr type_list<> reverse(type_list<>)
+{
+    return {};
+}
 
 //!\brief A replacement for meta::reverse [recursion]
-template <typename head_t, typename ...pack_t>
+template <typename head_t, typename... pack_t>
 auto reverse(type_list<head_t, pack_t...>)
 {
     return concat(reverse(type_list<pack_t...>{}), type_list<head_t>{});
 }
 
 //!\brief Constructs the multiset difference `list1 \ list2` [recursion anchor]
-template <typename ...current_list_t>
-constexpr seqan3::type_list<current_list_t...> type_list_difference(seqan3::type_list<current_list_t...>, seqan3::type_list<>)
-{ return {}; }
+template <typename... current_list_t>
+constexpr seqan3::type_list<current_list_t...> type_list_difference(seqan3::type_list<current_list_t...>,
+                                                                    seqan3::type_list<>)
+{
+    return {};
+}
 
 //!\brief Constructs the multiset difference `list1 \ list2` [recursion]
-template <typename ...current_list_t, typename remove_t, typename ...remove_list_t>
+template <typename... current_list_t, typename remove_t, typename... remove_list_t>
 constexpr auto type_list_difference(seqan3::type_list<current_list_t...>, seqan3::type_list<remove_t, remove_list_t...>)
 {
     constexpr auto pos = seqan3::pack_traits::find<remove_t, current_list_t...>;
@@ -167,7 +191,7 @@ inline constexpr size_t size = 0;
  *
  * \include test/snippet/utility/type_list/list_traits_size.cpp
  */
-template <typename ...pack_t>
+template <typename... pack_t>
 inline constexpr size_t size<type_list<pack_t...>> = sizeof...(pack_t);
 
 //!\cond
@@ -182,9 +206,8 @@ inline constexpr ptrdiff_t count = -1;
  *
  * \include test/snippet/utility/type_list/list_traits_count.cpp
  */
-template <typename query_t, typename ...pack_t>
-inline constexpr ptrdiff_t count<query_t, type_list<pack_t...>> =
-    seqan3::pack_traits::count<query_t, pack_t...>;
+template <typename query_t, typename... pack_t>
+inline constexpr ptrdiff_t count<query_t, type_list<pack_t...>> = seqan3::pack_traits::count<query_t, pack_t...>;
 
 //!\cond
 template <typename query_t, typename list_t>
@@ -198,7 +221,7 @@ inline constexpr ptrdiff_t find = -1;
  *
  * \include test/snippet/utility/type_list/list_traits_find.cpp
  */
-template <typename query_t, typename ...pack_t>
+template <typename query_t, typename... pack_t>
 inline constexpr ptrdiff_t find<query_t, type_list<pack_t...>> =
     seqan3::pack_traits::detail::find<query_t, pack_t...>();
 
@@ -214,7 +237,7 @@ inline constexpr ptrdiff_t find_if = -1;
  *
  * \include test/snippet/utility/type_list/list_traits_find_if.cpp
  */
-template <template <typename> typename pred_t, typename ...pack_t>
+template <template <typename> typename pred_t, typename... pack_t>
 inline constexpr ptrdiff_t find_if<pred_t, type_list<pack_t...>> =
     seqan3::pack_traits::detail::find_if<pred_t, pack_t...>();
 
@@ -225,9 +248,7 @@ inline constexpr ptrdiff_t find_if<pred_t, type_list<pack_t...>> =
  * \include test/snippet/utility/type_list/list_traits_contains.cpp
  */
 template <typename query_t, typename list_t>
-//!\cond
     requires seqan3::detail::template_specialisation_of<list_t, seqan3::type_list>
-//!\endcond
 inline constexpr bool contains = (find<query_t, list_t> != -1);
 
 //!\}
@@ -253,10 +274,8 @@ inline constexpr bool contains = (find<query_t, list_t> != -1);
  * \include test/snippet/utility/type_list/list_traits_at.cpp
  */
 template <ptrdiff_t idx, typename list_t>
-//!\cond
-    requires (seqan3::detail::template_specialisation_of<list_t, seqan3::type_list>) &&
-             ((idx >= 0 && idx < size<list_t>) || (-idx <= size<list_t>))
-//!\endcond
+    requires (seqan3::detail::template_specialisation_of<list_t, seqan3::type_list>)
+              && ((idx >= 0 && idx < size<list_t>) || (-idx <= size<list_t>))
 using at = typename decltype(detail::at<idx>(list_t{}))::type;
 
 /*!\brief Return the first type from the type list.
@@ -273,9 +292,7 @@ using at = typename decltype(detail::at<idx>(list_t{}))::type;
  * \include test/snippet/utility/type_list/list_traits_front.cpp
  */
 template <typename list_t>
-//!\cond
     requires (seqan3::detail::template_specialisation_of<list_t, seqan3::type_list>) && (size<list_t> > 0)
-//!\endcond
 using front = typename decltype(detail::front(list_t{}))::type;
 
 /*!\brief Return the last type from the type list.
@@ -295,9 +312,7 @@ using front = typename decltype(detail::front(list_t{}))::type;
  * \include test/snippet/utility/type_list/list_traits_back.cpp
  */
 template <typename list_t>
-//!\cond
     requires (seqan3::detail::template_specialisation_of<list_t, seqan3::type_list>) && (size<list_t> > 0)
-//!\endcond
 using back = typename decltype(detail::back(list_t{}))::type;
 
 //!\}
@@ -322,10 +337,8 @@ using back = typename decltype(detail::back(list_t{}))::type;
  *
  * \include test/snippet/utility/type_list/list_traits_concat.cpp
  */
-template <typename ...lists_t>
-//!\cond
+template <typename... lists_t>
     requires (seqan3::detail::template_specialisation_of<lists_t, seqan3::type_list> && ...)
-//!\endcond
 using concat = decltype(detail::concat(lists_t{}...));
 
 /*!\brief Return a seqan3::type_list of all the types in the type list, except the first.
@@ -342,9 +355,7 @@ using concat = decltype(detail::concat(lists_t{}...));
  * \include test/snippet/utility/type_list/list_traits_drop_front.cpp
  */
 template <typename list_t>
-//!\cond
     requires (seqan3::detail::template_specialisation_of<list_t, seqan3::type_list>) && (size<list_t> > 0)
-//!\endcond
 using drop_front = decltype(detail::drop_front(list_t{}));
 
 /*!\brief Return a seqan3::type_list of the first `n` types in the input type list.
@@ -362,9 +373,7 @@ using drop_front = decltype(detail::drop_front(list_t{}));
  * \include test/snippet/utility/type_list/list_traits_take.cpp
  */
 template <ptrdiff_t i, typename list_t>
-//!\cond
     requires (seqan3::detail::template_specialisation_of<list_t, seqan3::type_list>) && (i >= 0 && i <= size<list_t>)
-//!\endcond
 using take = typename decltype(detail::split_after<i>(list_t{}))::first_type;
 
 /*!\brief Return a seqan3::type_list of the types in the input type list, except the first `n`.
@@ -382,9 +391,7 @@ using take = typename decltype(detail::split_after<i>(list_t{}))::first_type;
  * \include test/snippet/utility/type_list/list_traits_drop.cpp
  */
 template <ptrdiff_t i, typename list_t>
-//!\cond
     requires (seqan3::detail::template_specialisation_of<list_t, seqan3::type_list>) && (i >= 0 && i <= size<list_t>)
-//!\endcond
 using drop = typename decltype(detail::split_after<i>(list_t{}))::second_type;
 
 /*!\brief Return a seqan3::type_list of the last `n` types in the input type list.
@@ -402,9 +409,7 @@ using drop = typename decltype(detail::split_after<i>(list_t{}))::second_type;
  * \include test/snippet/utility/type_list/list_traits_take_last.cpp
  */
 template <ptrdiff_t i, typename list_t>
-//!\cond
     requires (seqan3::detail::template_specialisation_of<list_t, seqan3::type_list>) && (i >= 0 && i <= size<list_t>)
-//!\endcond
 using take_last = drop<size<list_t> - i, list_t>;
 
 /*!\brief Return a seqan3::type_list of the types the input type list, except the last `n`.
@@ -422,9 +427,7 @@ using take_last = drop<size<list_t> - i, list_t>;
  * \include test/snippet/utility/type_list/list_traits_drop_last.cpp
  */
 template <ptrdiff_t i, typename list_t>
-//!\cond
     requires (seqan3::detail::template_specialisation_of<list_t, seqan3::type_list>) && (i >= 0 && i <= size<list_t>)
-//!\endcond
 using drop_last = take<size<list_t> - i, list_t>;
 
 /*!\brief Split a seqan3::type_list into two parts returned as a pair of seqan3::type_list.
@@ -442,9 +445,7 @@ using drop_last = take<size<list_t> - i, list_t>;
  * \include test/snippet/utility/type_list/list_traits_drop_last.cpp
  */
 template <ptrdiff_t i, typename list_t>
-//!\cond
     requires (seqan3::detail::template_specialisation_of<list_t, seqan3::type_list>) && (i >= 0 && i <= size<list_t>)
-//!\endcond
 using split_after = decltype(detail::split_after<i>(list_t{}));
 
 /*!\brief Apply a transformation trait to every type in the list and return a seqan3::type_list of the results.
@@ -465,9 +466,7 @@ using split_after = decltype(detail::split_after<i>(list_t{}));
  * \include test/snippet/utility/type_list/list_traits_transform.cpp
  */
 template <template <typename> typename trait_t, typename list_t>
-//!\cond
     requires seqan3::detail::template_specialisation_of<list_t, seqan3::type_list>
-//!\endcond
 using transform = decltype(detail::transform<trait_t>(list_t{}));
 
 /*!\brief Replace the type at the given index with the given type.
@@ -486,11 +485,23 @@ using transform = decltype(detail::transform<trait_t>(list_t{}));
  * \include test/snippet/utility/type_list/list_traits_replace_at.cpp
  */
 template <typename replace_t, std::ptrdiff_t i, typename list_t>
-//!\cond
     requires (seqan3::detail::template_specialisation_of<list_t, seqan3::type_list>) && (i >= 0 && i < size<list_t>)
-//!\endcond
 using replace_at = decltype(detail::replace_at<replace_t, i>(list_t{}));
 
+/*!\brief Create a type list with the given type repeated `count` times..
+ * \tparam count The number of repititions.
+ * \tparam t The type to repeat
+ * \ingroup utility_type_list
+ *
+ * ### (Compile-time) Complexity
+ *
+ * * Number of template instantiations: O(n)
+ * * Other operations: O(n)
+ *
+ * However, with a constant of 0.2, e.g. repeat<10,int> results in 2-3 instantiations.
+ */
+template <size_t count, typename t>
+using repeat = decltype(detail::repeat<count, t>());
 //!\}
 
 } // namespace seqan3::list_traits
