@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -12,7 +12,7 @@
 
 #pragma once
 
-#include <seqan3/std/type_traits>
+#include <type_traits>
 
 #include <seqan3/utility/type_traits/concept.hpp>
 
@@ -39,9 +39,9 @@ namespace seqan3::detail
  *   seqan3::detail::transformation_trait_or_t as a shorthand for *seqan3::detail::transformation_trait_or::type*
  */
 template <typename type_t, typename default_t>
-using transformation_trait_or = std::conditional_t<transformation_trait<type_t>,    // check if type_t::type exists
-                                                   type_t,                          // if yes, return type_t
-                                                   std::type_identity<default_t>>;  // else return default_t as trait
+using transformation_trait_or = std::conditional_t<transformation_trait<type_t>,   // check if type_t::type exists
+                                                   type_t,                         // if yes, return type_t
+                                                   std::type_identity<default_t>>; // else return default_t as trait
 
 /*!\brief Helper type of seqan3::detail::transformation_trait_or (transformation_trait shortcut).
  * \see seqan3::detail::transformation_trait_or
