@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -12,7 +12,7 @@
 
 #pragma once
 
-#include <seqan3/std/ranges>
+#include <ranges>
 
 #include <seqan3/core/range/detail/adaptor_base.hpp>
 #include <seqan3/core/range/type_traits.hpp>
@@ -113,12 +113,12 @@ public:
     /*!\name Constructors, destructor and assignment
      * \{
      */
-    constexpr deep()                         noexcept = default; //!< Defaulted.
-    constexpr deep(deep const &)             noexcept = default; //!< Defaulted.
-    constexpr deep(deep &&)                  noexcept = default; //!< Defaulted.
+    constexpr deep() noexcept = default;                         //!< Defaulted.
+    constexpr deep(deep const &) noexcept = default;             //!< Defaulted.
+    constexpr deep(deep &&) noexcept = default;                  //!< Defaulted.
     constexpr deep & operator=(deep const &) noexcept = default; //!< Defaulted.
-    constexpr deep & operator=(deep &&)      noexcept = default; //!< Defaulted.
-    ~deep()                                  noexcept = default; //!< Defaulted.
+    constexpr deep & operator=(deep &&) noexcept = default;      //!< Defaulted.
+    ~deep() noexcept = default;                                  //!< Defaulted.
 
     using base_type::base_type;
     //!\}
@@ -175,9 +175,8 @@ public:
     {
         if constexpr (range_dimension > 1u)
         {
-            auto transform
-                = [adaptor = recursive_adaptor<range_dimension - 1u>(std::forward<underlying_adaptor_t>(deep_adaptor))]
-                  (auto && inner_range)
+            auto transform = [adaptor = recursive_adaptor<range_dimension - 1u>(
+                                  std::forward<underlying_adaptor_t>(deep_adaptor))](auto && inner_range)
             {
                 // We don't want to move a stateful adaptor here, as this adaptor will be called on any element of this
                 // std::views::transform range.
@@ -206,17 +205,15 @@ public:
      * \param[in] args             Further arguments (optional).
      * \returns A views::deep specialisation of a closure object, i.e. with stored arguments.
      */
-    template <typename first_arg_t, typename ...stored_arg_types>
-    //!\cond
+    template <typename first_arg_t, typename... stored_arg_types>
         requires (!std::ranges::input_range<first_arg_t>)
-    //!\endcond
-    constexpr auto operator()(first_arg_t && first, stored_arg_types && ...args) const
+    constexpr auto operator()(first_arg_t && first, stored_arg_types &&... args) const
     {
         // The adaptor currently wrapped is a proto-adaptor and this function has the arguments to "complete" it.
         // We extract the adaptor that is stored and invoke it with the given arguments.
         // This returns an adaptor closure object.
-        auto adaptor_closure = std::get<0>(this->arguments)(std::forward<first_arg_t>(first),
-                                                            std::forward<stored_arg_types>(args)...);
+        auto adaptor_closure =
+            std::get<0>(this->arguments)(std::forward<first_arg_t>(first), std::forward<stored_arg_types>(args)...);
         // Now we wrap this closure object back into a views::deep to get the deep behaviour.
         return deep<decltype(adaptor_closure)>{std::move(adaptor_closure)};
     }
@@ -244,11 +241,9 @@ public:
      *
      * Recurses and calls std::views::transform if the underlying range is a range-of-ranges.
      */
-    template <std::ranges::input_range urng_t, typename ...stored_arg_types>
-    //!\cond
+    template <std::ranges::input_range urng_t, typename... stored_arg_types>
         requires (sizeof...(stored_arg_types) > 0)
-    //!\endcond
-    constexpr auto operator()(urng_t && urange, stored_arg_types && ...args) const
+    constexpr auto operator()(urng_t && urange, stored_arg_types &&... args) const
     {
         auto adaptor_closure = std::get<0>(this->arguments)(std::forward<stored_arg_types>(args)...);
         deep<decltype(adaptor_closure)> deep_adaptor{std::move(adaptor_closure)};
