@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -13,7 +13,7 @@
 #pragma once
 
 #include <cmath>
-#include <seqan3/std/ranges>
+#include <ranges>
 
 #include <seqan3/core/detail/iterator_traits.hpp>
 #include <seqan3/core/range/detail/adaptor_for_view_without_args.hpp>
@@ -39,13 +39,10 @@ namespace seqan3::detail
  * \include test/snippet/utility/views/pairwise_combine.cpp
  */
 template <std::ranges::view underlying_range_type>
-//!\cond
-    requires  std::ranges::forward_range<underlying_range_type> && std::ranges::common_range<underlying_range_type>
-//!\endcond
+    requires std::ranges::forward_range<underlying_range_type> && std::ranges::common_range<underlying_range_type>
 class pairwise_combine_view : public std::ranges::view_interface<pairwise_combine_view<underlying_range_type>>
 {
 private:
-
     //!\brief The forward declared iterator type for pairwise_combine_view.
     template <typename range_type>
     class basic_iterator;
@@ -57,20 +54,20 @@ private:
     //!\brief The iterator type.
     using iterator = basic_iterator<underlying_range_type>;
     //!\brief The const iterator type. Evaluates to void if the underlying range is not const iterable.
-    using const_iterator = transformation_trait_or_t<std::type_identity<basic_iterator<underlying_range_type const>>,
-                                                     void>;
+    using const_iterator =
+        transformation_trait_or_t<std::type_identity<basic_iterator<underlying_range_type const>>, void>;
     //!\}
 
 public:
     /*!\name Constructors, destructor and assignment
      * \{
      */
-    pairwise_combine_view() = default; //!< Defaulted.
-    pairwise_combine_view(pairwise_combine_view const &) = default; //!< Defaulted.
-    pairwise_combine_view(pairwise_combine_view &&) = default; //!< Defaulted.
+    pairwise_combine_view() = default;                                          //!< Defaulted.
+    pairwise_combine_view(pairwise_combine_view const &) = default;             //!< Defaulted.
+    pairwise_combine_view(pairwise_combine_view &&) = default;                  //!< Defaulted.
     pairwise_combine_view & operator=(pairwise_combine_view const &) = default; //!< Defaulted.
-    pairwise_combine_view & operator=(pairwise_combine_view &&) = default; //!< Defaulted.
-    ~pairwise_combine_view() = default; //!< Defaulted.
+    pairwise_combine_view & operator=(pairwise_combine_view &&) = default;      //!< Defaulted.
+    ~pairwise_combine_view() = default;                                         //!< Defaulted.
 
     /*!\brief Constructs from a view.
      * \param[in] range The underlying range to be wrapped. Of type `underlying_range_type`.
@@ -114,7 +111,8 @@ public:
                     do
                     {
                         back_iterator = tmp_it;
-                    } while (++tmp_it != std::ranges::end(u_range));
+                    }
+                    while (++tmp_it != std::ranges::end(u_range));
                 }
             }
         }
@@ -140,15 +138,14 @@ public:
      * Constant if `other_range_t` models std::ranges::bidirectional_range, otherwise linear.
      */
     template <typename other_range_t>
-    //!\cond
-        requires (!std::same_as<std::remove_cvref_t<other_range_t>, pairwise_combine_view>) &&
-                 std::ranges::viewable_range<other_range_t> &&  // Must come after self type check to avoid conflicts with the move constructor.
+        requires (!std::same_as<std::remove_cvref_t<other_range_t>, pairwise_combine_view>)
+              && std::ranges::viewable_range<other_range_t>
+              && // Must come after self type check to avoid conflicts with the move constructor.
                  std::constructible_from<underlying_range_type,
                                          std::ranges::ref_view<std::remove_reference_t<other_range_t>>>
-            //TODO: Investigate: the following expression is equivalent to the one above but raises a weird assertion in
-            //      the ranges adaptor suggesting that the pairwise_combine_view is not a viewable_range.
-            //      std::constructible_from<underlying_range_type, decltype(std::views::all(std::declval<other_range_t &&>()))>
-    //!\endcond
+    //TODO: Investigate: the following expression is equivalent to the one above but raises a weird assertion in
+    //      the ranges adaptor suggesting that the pairwise_combine_view is not a viewable_range.
+    //      std::constructible_from<underlying_range_type, decltype(std::views::all(std::declval<other_range_t &&>()))>
     explicit constexpr pairwise_combine_view(other_range_t && range) :
         pairwise_combine_view{std::views::all(std::forward<other_range_t>(range))}
     {}
@@ -176,9 +173,7 @@ public:
 
     //!\copydoc begin()
     constexpr const_iterator begin() const noexcept
-    //!\cond
         requires const_iterable_range<underlying_range_type>
-    //!\endcond
     {
         return {std::ranges::cbegin(u_range), std::ranges::cbegin(u_range), std::ranges::cend(u_range)};
     }
@@ -203,9 +198,7 @@ public:
 
     //!\copydoc end()
     constexpr const_iterator end() const noexcept
-    //!\cond
         requires const_iterable_range<underlying_range_type>
-    //!\endcond
     {
         return {back_iterator, std::ranges::cbegin(u_range), std::ranges::cend(u_range)};
     }
@@ -215,13 +208,8 @@ public:
      * \{
      */
     //!\brief Computes the size based on the size of the underlying range.
-#if SEQAN3_WORKAROUND_GCC_NON_TEMPLATE_REQUIRES
-    template <typename = underlying_range_type>
-#endif // SEQAN3_WORKAROUND_GCC_NON_TEMPLATE_REQUIRES
     constexpr auto size() const noexcept
-    //!\cond
         requires std::ranges::sized_range<underlying_range_type>
-    //!\endcond
     {
         auto const size = std::ranges::size(u_range);
         return (size * (size - 1)) / 2;
@@ -229,7 +217,6 @@ public:
     //!\}
 
 private:
-
     //!\brief The underling range.
     underlying_range_type u_range{};
     //!\brief The cached iterator pointing to the last element of the underlying range.
@@ -242,8 +229,7 @@ private:
 
 //!\brief Deduces the correct template type from a non-view lvalue range by wrapping the range in std::views::all.
 template <std::ranges::viewable_range other_range_t>
-pairwise_combine_view(other_range_t && range) ->
-    pairwise_combine_view<std::views::all_t<other_range_t>>;
+pairwise_combine_view(other_range_t && range) -> pairwise_combine_view<std::views::all_t<other_range_t>>;
 //!\}
 
 /*!\brief The internal iterator type for pairwise_combine_view.
@@ -260,15 +246,12 @@ pairwise_combine_view(other_range_t && range) ->
  * the ranges algorithms.
  */
 template <std::ranges::view underlying_range_type>
-//!\cond
     requires std::ranges::forward_range<underlying_range_type> && std::ranges::common_range<underlying_range_type>
-//!\endcond
 template <typename range_type>
-class pairwise_combine_view<underlying_range_type>::basic_iterator
-    : public maybe_iterator_category<std::ranges::iterator_t<range_type>>
+class pairwise_combine_view<underlying_range_type>::basic_iterator :
+    public maybe_iterator_category<std::ranges::iterator_t<range_type>>
 {
 private:
-
     //!\brief Friend declaration for iterator with different range const-ness.
     template <typename other_range_type>
         requires std::same_as<std::remove_const_t<range_type>, std::remove_const_t<other_range_type>>
@@ -301,12 +284,12 @@ public:
     /*!\name Constructors, destructor and assignment
      * \{
      */
-    basic_iterator() = default; //!< Defaulted.
-    basic_iterator(basic_iterator const &) = default; //!< Defaulted.
-    basic_iterator(basic_iterator &&) = default; //!< Defaulted.
+    basic_iterator() = default;                                   //!< Defaulted.
+    basic_iterator(basic_iterator const &) = default;             //!< Defaulted.
+    basic_iterator(basic_iterator &&) = default;                  //!< Defaulted.
     basic_iterator & operator=(basic_iterator const &) = default; //!< Defaulted.
-    basic_iterator & operator=(basic_iterator &&) = default; //!< Defaulted.
-    ~basic_iterator() = default; //!< Defaulted.
+    basic_iterator & operator=(basic_iterator &&) = default;      //!< Defaulted.
+    ~basic_iterator() = default;                                  //!< Defaulted.
 
     /*!\brief Constructs the iterator from the current underlying iterator and the end iterator of the underlying
      *        range.
@@ -338,10 +321,8 @@ public:
      * This special constructor is needed as it is not covered by the standard copy and move constructors.
      */
     template <typename other_range_type>
-    //!\cond
-        requires std::convertible_to<other_range_type, range_type &> &&
-                 std::same_as<std::remove_const_t<other_range_type>, std::remove_const_t<range_type>>
-    //!\endcond
+        requires std::convertible_to<other_range_type, range_type &>
+              && std::same_as<std::remove_const_t<other_range_type>, std::remove_const_t<range_type>>
     constexpr basic_iterator(basic_iterator<other_range_type> other) noexcept :
         basic_iterator{std::move(other.first_it), std::move(other.begin_it), std::move(other.end_it)}
     {}
@@ -350,9 +331,8 @@ public:
     /*!\name Accessors
      * \{
      */
-     //!\brief Accesses the pointed-to element
-    constexpr reference operator*() const
-        noexcept(noexcept(*std::declval<underlying_iterator_type>()))
+    //!\brief Accesses the pointed-to element
+    constexpr reference operator*() const noexcept(noexcept(*std::declval<underlying_iterator_type>()))
     {
         return reference{*first_it, *second_it};
     }
@@ -362,9 +342,7 @@ public:
      */
     constexpr reference operator[](size_t const index) const
         noexcept(noexcept(std::declval<basic_iterator &>().from_index(1)))
-    //!\cond
         requires std::random_access_iterator<underlying_iterator_type>
-    //!\endcond
     {
         return *(*this + index);
     }
@@ -374,8 +352,8 @@ public:
      * \{
      */
     //!\brief Pre-increment operator.
-    constexpr basic_iterator & operator++(/*pre-increment*/)
-        noexcept(noexcept(++std::declval<underlying_iterator_type &>()))
+    constexpr basic_iterator &
+    operator++(/*pre-increment*/) noexcept(noexcept(++std::declval<underlying_iterator_type &>()))
     {
         if (++second_it == end_it)
         {
@@ -387,8 +365,8 @@ public:
     }
 
     //!\brief Post-increment operator.
-    constexpr basic_iterator operator++(int /*post-increment*/)
-        noexcept(noexcept(std::declval<underlying_iterator_type &>()++))
+    constexpr basic_iterator
+    operator++(int /*post-increment*/) noexcept(noexcept(std::declval<underlying_iterator_type &>()++))
     {
         basic_iterator tmp{*this};
         ++*this;
@@ -396,11 +374,9 @@ public:
     }
 
     //!\brief Pre-decrement operator; `underlying_iterator_type` must model std::bidirectional_iterator.
-    constexpr basic_iterator & operator--(/*pre-decrement*/)
-        noexcept(noexcept(--std::declval<underlying_iterator_type &>()))
-    //!\cond
+    constexpr basic_iterator &
+    operator--(/*pre-decrement*/) noexcept(noexcept(--std::declval<underlying_iterator_type &>()))
         requires std::bidirectional_iterator<underlying_iterator_type>
-    //!\endcond
     {
         if (--second_it == first_it)
         {
@@ -412,11 +388,9 @@ public:
     }
 
     //!\brief Post-decrement operator; `underlying_iterator_type` must model std::bidirectional_iterator.
-    constexpr basic_iterator operator--(int /*post-decrement*/)
-        noexcept(noexcept(std::declval<underlying_iterator_type &>()--))
-    //!\cond
+    constexpr basic_iterator
+    operator--(int /*post-decrement*/) noexcept(noexcept(std::declval<underlying_iterator_type &>()--))
         requires std::bidirectional_iterator<underlying_iterator_type>
-    //!\endcond
     {
         basic_iterator tmp{*this};
         --*this;
@@ -425,11 +399,9 @@ public:
 
     //!\brief Advances the iterator by the given offset; `underlying_iterator_type` must model
     //!\      std::random_access_iterator.
-    constexpr basic_iterator & operator+=(difference_type const offset)
-        noexcept(noexcept(std::declval<basic_iterator &>().from_index(1)))
-    //!\cond
+    constexpr basic_iterator &
+    operator+=(difference_type const offset) noexcept(noexcept(std::declval<basic_iterator &>().from_index(1)))
         requires std::random_access_iterator<underlying_iterator_type>
-    //!\endcond
     {
         from_index(to_index() + offset);
         return *this;
@@ -439,9 +411,7 @@ public:
     //!\      std::random_access_iterator.
     constexpr basic_iterator operator+(difference_type const offset) const
         noexcept(noexcept(std::declval<basic_iterator &>() += 1))
-    //!\cond
         requires std::random_access_iterator<underlying_iterator_type>
-    //!\endcond
     {
         basic_iterator tmp{*this};
         return (tmp += offset);
@@ -449,11 +419,10 @@ public:
 
     //!\brief Advances the iterator by the given offset; `underlying_iterator_type` must model
     //!\      std::random_access_iterator.
-    constexpr friend basic_iterator operator+(difference_type const offset, basic_iterator iter)
-        noexcept(noexcept(std::declval<basic_iterator<range_type> &>().from_index(1)))
-    //!\cond
+    constexpr friend basic_iterator
+    operator+(difference_type const offset,
+              basic_iterator iter) noexcept(noexcept(std::declval<basic_iterator<range_type> &>().from_index(1)))
         requires std::random_access_iterator<underlying_iterator_type>
-    //!\endcond
     {
         iter.from_index(iter.to_index() + offset);
         return iter;
@@ -461,11 +430,9 @@ public:
 
     //!\brief Decrements the iterator by the given offset; `underlying_iterator_type` must model
     //!\      std::random_access_iterator.
-    constexpr basic_iterator & operator-=(difference_type const offset)
-        noexcept(noexcept(std::declval<basic_iterator &>().from_index(1)))
-    //!\cond
+    constexpr basic_iterator &
+    operator-=(difference_type const offset) noexcept(noexcept(std::declval<basic_iterator &>().from_index(1)))
         requires std::random_access_iterator<underlying_iterator_type>
-    //!\endcond
     {
         from_index(to_index() - offset);
         return *this;
@@ -475,9 +442,7 @@ public:
     //!\      std::random_access_iterator.
     constexpr basic_iterator operator-(difference_type const offset) const
         noexcept(noexcept(std::declval<basic_iterator &>() -= 1))
-    //!\cond
         requires std::random_access_iterator<underlying_iterator_type>
-    //!\endcond
     {
         basic_iterator tmp{*this};
         return (tmp -= offset);
@@ -486,10 +451,8 @@ public:
     //!\brief Computes the distance between two iterators; `underlying_iterator_type` must model
     //!\      std::random_access_iterator.
     template <typename other_range_type>
-    //!\cond
-        requires std::random_access_iterator<underlying_iterator_type> &&
-                 std::same_as<std::remove_const_t<range_type>, std::remove_const_t<other_range_type>>
-    //!\endcond
+        requires std::random_access_iterator<underlying_iterator_type>
+              && std::same_as<std::remove_const_t<range_type>, std::remove_const_t<other_range_type>>
     constexpr difference_type operator-(basic_iterator<other_range_type> const & rhs) const
         noexcept(noexcept(std::declval<basic_iterator &>().to_index()))
     {
@@ -508,10 +471,8 @@ public:
 
     //!\brief Checks whether `*this` is equal to `rhs`.
     template <typename other_range_type>
-    //!\cond
-        requires std::equality_comparable_with<underlying_iterator_type, std::ranges::iterator_t<other_range_type>> &&
-                 std::same_as<std::remove_const_t<range_type>, std::remove_const_t<other_range_type>>
-    //!\endcond
+        requires std::equality_comparable_with<underlying_iterator_type, std::ranges::iterator_t<other_range_type>>
+              && std::same_as<std::remove_const_t<range_type>, std::remove_const_t<other_range_type>>
     constexpr bool operator==(basic_iterator<other_range_type> const & rhs) const
         noexcept(noexcept(std::declval<underlying_iterator_type &>() == std::declval<underlying_iterator_type &>()))
     {
@@ -520,10 +481,8 @@ public:
 
     //!\brief Checks whether `*this` is not equal to `rhs`.
     template <typename other_range_type>
-    //!\cond
-        requires std::equality_comparable_with<underlying_iterator_type, std::ranges::iterator_t<other_range_type>> &&
-                 std::same_as<std::remove_const_t<range_type>, std::remove_const_t<other_range_type>>
-    //!\endcond
+        requires std::equality_comparable_with<underlying_iterator_type, std::ranges::iterator_t<other_range_type>>
+              && std::same_as<std::remove_const_t<range_type>, std::remove_const_t<other_range_type>>
     constexpr bool operator!=(basic_iterator<other_range_type> const & rhs) const
         noexcept(noexcept(std::declval<underlying_iterator_type &>() != std::declval<underlying_iterator_type &>()))
     {
@@ -532,11 +491,8 @@ public:
 
     //!\brief Checks whether `*this` is less than `rhs`.
     template <typename other_range_type>
-    //!\cond
-        requires std::totally_ordered_with<underlying_iterator_type,
-                                               std::ranges::iterator_t<other_range_type>> &&
-                 std::same_as<std::remove_const_t<range_type>, std::remove_const_t<other_range_type>>
-    //!\endcond
+        requires std::totally_ordered_with<underlying_iterator_type, std::ranges::iterator_t<other_range_type>>
+              && std::same_as<std::remove_const_t<range_type>, std::remove_const_t<other_range_type>>
     constexpr bool operator<(basic_iterator<other_range_type> const & rhs) const
         noexcept(noexcept(std::declval<underlying_iterator_type &>() < std::declval<underlying_iterator_type &>()))
     {
@@ -545,11 +501,8 @@ public:
 
     //!\brief Checks whether `*this` is greater than `rhs`.
     template <typename other_range_type>
-    //!\cond
-        requires std::totally_ordered_with<underlying_iterator_type,
-                                               std::ranges::iterator_t<other_range_type>> &&
-                 std::same_as<std::remove_const_t<range_type>, std::remove_const_t<other_range_type>>
-    //!\endcond
+        requires std::totally_ordered_with<underlying_iterator_type, std::ranges::iterator_t<other_range_type>>
+              && std::same_as<std::remove_const_t<range_type>, std::remove_const_t<other_range_type>>
     constexpr bool operator>(basic_iterator<other_range_type> const & rhs) const
         noexcept(noexcept(std::declval<underlying_iterator_type &>() > std::declval<underlying_iterator_type &>()))
 
@@ -559,11 +512,8 @@ public:
 
     //!\brief Checks whether `*this` is less than or equal to `rhs`.
     template <typename other_range_type>
-    //!\cond
-        requires std::totally_ordered_with<underlying_iterator_type,
-                                               std::ranges::iterator_t<other_range_type>> &&
-                 std::same_as<std::remove_const_t<range_type>, std::remove_const_t<other_range_type>>
-    //!\endcond
+        requires std::totally_ordered_with<underlying_iterator_type, std::ranges::iterator_t<other_range_type>>
+              && std::same_as<std::remove_const_t<range_type>, std::remove_const_t<other_range_type>>
     constexpr bool operator<=(basic_iterator<other_range_type> const & rhs) const
         noexcept(noexcept(std::declval<underlying_iterator_type &>() <= std::declval<underlying_iterator_type &>()))
     {
@@ -572,11 +522,8 @@ public:
 
     //!\brief Checks whether `*this` is greater than or equal to `rhs`.
     template <typename other_range_type>
-    //!\cond
-        requires std::totally_ordered_with<underlying_iterator_type,
-                                               std::ranges::iterator_t<other_range_type>> &&
-                 std::same_as<std::remove_const_t<range_type>, std::remove_const_t<other_range_type>>
-    //!\endcond
+        requires std::totally_ordered_with<underlying_iterator_type, std::ranges::iterator_t<other_range_type>>
+              && std::same_as<std::remove_const_t<range_type>, std::remove_const_t<other_range_type>>
     constexpr bool operator>=(basic_iterator<other_range_type> const & rhs) const
         noexcept(noexcept(std::declval<underlying_iterator_type &>() >= std::declval<underlying_iterator_type &>()))
     {
@@ -585,7 +532,6 @@ public:
     //!\}
 
 private:
-
     /*!\brief Returns the index for the current iterator position.
      *
      * \details
@@ -600,33 +546,29 @@ private:
      */
     constexpr size_t to_index() const
         noexcept(noexcept(std::declval<underlying_iterator_type &>() - std::declval<underlying_iterator_type &>()))
-    //!\cond
         requires std::random_access_iterator<underlying_iterator_type>
-    //!\endcond
     {
         size_t src_size = end_it - begin_it;
         size_t index_i = first_it - begin_it;
         size_t index_j = second_it - begin_it;
-        return (src_size * (src_size - 1)/2) - (src_size - index_i) * ((src_size - index_i) - 1)/2 +
-               index_j - index_i - 1;
+        return (src_size * (src_size - 1) / 2) - (src_size - index_i) * ((src_size - index_i) - 1) / 2 + index_j
+             - index_i - 1;
     }
 
     /*!\brief Sets the iterator to the given index.
      * \param[in] index The index to set the iterator to.
      * \copydetails to_index()
      */
-    constexpr void from_index(size_t const index)
-        noexcept(noexcept(std::declval<underlying_iterator_type &>() - std::declval<underlying_iterator_type &>()) &&
-                 noexcept(std::declval<underlying_iterator_type &>() + 1))
-    //!\cond
+    constexpr void from_index(size_t const index) noexcept(noexcept(
+        std::declval<underlying_iterator_type &>()
+        - std::declval<underlying_iterator_type &>()) && noexcept(std::declval<underlying_iterator_type &>() + 1))
         requires std::random_access_iterator<underlying_iterator_type>
-    //!\endcond
     {
         size_t src_size = end_it - begin_it;
-        size_t index_i = src_size - 2 -
-                         std::floor(std::sqrt(-8 * index + 4 * src_size * (src_size - 1) - 7)/2.0 - 0.5);
-        size_t index_j = index + index_i + 1 - src_size * (src_size - 1)/2 + (src_size - index_i) *
-                         ((src_size - index_i) - 1)/2;
+        size_t index_i =
+            src_size - 2 - std::floor(std::sqrt(-8 * index + 4 * src_size * (src_size - 1) - 7) / 2.0 - 0.5);
+        size_t index_j =
+            index + index_i + 1 - src_size * (src_size - 1) / 2 + (src_size - index_i) * ((src_size - index_i) - 1) / 2;
         first_it = begin_it + index_i;
         second_it = begin_it + index_j;
     }
