@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -16,15 +16,15 @@
 
 // TODO(rrahn): At support for Windows platforms, when we support it.
 #if defined(__APPLE__)
-#include <unistd.h>
+#    include <unistd.h>
 #elif defined(_WIN32)
-#include <cstring>
-#include <io.h>
-#else  // other unix systems
-#include <stdlib.h>
+#    include <cstring>
+#    include <io.h>
+#else // other unix systems
+#    include <stdlib.h>
 #endif
 
-#include <seqan3/std/filesystem>
+#include <filesystem>
 
 #include <seqan3/core/platform.hpp>
 
@@ -73,7 +73,6 @@ inline char * mkdtemp(char * template_name)
 class tmp_filename
 {
 public:
-
     /* rule of six */
     /*!\name Constructors, destructor and assignment
      * \{
@@ -81,7 +80,8 @@ public:
     //!\brief Deleted default constructor.
     tmp_filename() = delete;
     //!\brief Copy constructor.
-    tmp_filename(tmp_filename const &) = delete;  // NOTE: We could store the path in a shared_ptr and by thus reactivating the .
+    tmp_filename(tmp_filename const &) =
+        delete; // NOTE: We could store the path in a shared_ptr and by thus reactivating the .
     //!\brief Move constructor.
     tmp_filename(tmp_filename &&) = default;
     //!\brief Copy assignment.
@@ -97,18 +97,19 @@ public:
      * ###Exceptions
      * Might throw std::filesystem::filesystem_error.
      */
-    explicit tmp_filename(const char * f_name)
+    explicit tmp_filename(char const * f_name)
     {
         if (f_name == nullptr)
-            throw std::filesystem::filesystem_error("Empty file name!", std::make_error_code(std::errc::invalid_argument));
+            throw std::filesystem::filesystem_error("Empty file name!",
+                                                    std::make_error_code(std::errc::invalid_argument));
 
         auto tmp_base_dir = std::filesystem::temp_directory_path();
         tmp_base_dir /= std::filesystem::path{"seqan_test_XXXXXXXX"};
         // We have to use mkdtemp, which is not deprecated. We place it into the dedicated tmp_dir
         // returned by temp_directory_path. Within this path we can safely create files, that would be
         // unique per test instance as the parent directory is.
-        auto path_str = tmp_base_dir.string();  // Copy the underlying path to get access to the raw char *.
-        if (char * f = mkdtemp(path_str.data()); f != nullptr)  // mkdtemp replaces XXXXXXXX in a safe and unique way.
+        auto path_str = tmp_base_dir.string(); // Copy the underlying path to get access to the raw char *.
+        if (char * f = mkdtemp(path_str.data()); f != nullptr) // mkdtemp replaces XXXXXXXX in a safe and unique way.
         {
             directory_path = f;
             file_path = directory_path / std::filesystem::path{f_name};
