@@ -1,19 +1,20 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
 
+#include <benchmark/benchmark.h>
+
 #include <algorithm>
 #include <vector>
 
-#include <benchmark/benchmark.h>
-
 #include <seqan3/test/performance/units.hpp>
 
 // This test allocates 1Gb data with a string and copies it to another memory location.
-static void memcpy_benchmark(benchmark::State & state) {
+static void memcpy_benchmark(benchmark::State & state)
+{
     size_t size = state.range(0);
     std::vector<char> src(size, '-');
     std::vector<char> dst(size);
