@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -11,7 +11,7 @@
 #include <iostream>
 #include <memory>
 #include <random>
-#include <seqan3/std/ranges>
+#include <ranges>
 #include <utility>
 #include <vector>
 
@@ -22,20 +22,19 @@
 #include <seqan3/test/performance/sequence_generator.hpp>
 #include <seqan3/test/performance/units.hpp>
 #include <seqan3/test/seqan2.hpp>
-#include <seqan3/utility/views/to.hpp>
+#include <seqan3/utility/range/to.hpp>
 #include <seqan3/utility/views/zip.hpp>
 
 #ifdef SEQAN3_HAS_SEQAN2
-    #include <seqan/align.h>
-    #include <seqan/align_parallel.h>
+#    include <seqan/align.h>
+#    include <seqan/align_parallel.h>
 #endif
 
-constexpr auto nt_score_scheme = seqan3::nucleotide_scoring_scheme{seqan3::match_score{4},
-                                                                   seqan3::mismatch_score{-5}};
-constexpr auto affine_cfg = seqan3::align_cfg::method_global{} |
-                            seqan3::align_cfg::gap_cost_affine{seqan3::align_cfg::open_score{-10},
-                                                               seqan3::align_cfg::extension_score{-1}} |
-                            seqan3::align_cfg::scoring_scheme{nt_score_scheme};
+constexpr auto nt_score_scheme = seqan3::nucleotide_scoring_scheme{seqan3::match_score{4}, seqan3::mismatch_score{-5}};
+constexpr auto affine_cfg =
+    seqan3::align_cfg::method_global{}
+    | seqan3::align_cfg::gap_cost_affine{seqan3::align_cfg::open_score{-10}, seqan3::align_cfg::extension_score{-1}}
+    | seqan3::align_cfg::scoring_scheme{nt_score_scheme};
 
 // Aliases to beautify the benchmark output
 using score = seqan3::align_cfg::output_score;
@@ -43,8 +42,8 @@ using trace = decltype(seqan3::align_cfg::output_score{} | seqan3::align_cfg::ou
 
 // Globally defined constants to ensure same test data.
 inline constexpr size_t sequence_length = 100;
-inline constexpr size_t set_size        = 500;
-inline constexpr size_t variance        = 10;
+inline constexpr size_t set_size = 500;
+inline constexpr size_t variance = 10;
 
 template <typename alphabet_t>
 auto generate_data_seqan3()
@@ -87,14 +86,14 @@ void seqan3_affine_dna4_parallel(benchmark::State & state)
 {
     auto [vec1, vec2] = generate_data_seqan3<seqan3::dna4>();
 
-    auto data = seqan3::views::zip(vec1, vec2) | seqan3::views::to<std::vector>;
+    auto data = seqan3::views::zip(vec1, vec2) | seqan3::ranges::to<std::vector>();
 
     int64_t total = 0;
     for (auto _ : state)
     {
-        for (auto && res : align_pairwise(data, affine_cfg |
-                                                result_t{} |
-                                                seqan3::align_cfg::parallel{std::thread::hardware_concurrency()}))
+        for (auto && res :
+             align_pairwise(data,
+                            affine_cfg | result_t{} | seqan3::align_cfg::parallel{std::thread::hardware_concurrency()}))
         {
             total += res.score();
         }
@@ -117,7 +116,7 @@ void seqan3_affine_dna4_omp_for(benchmark::State & state)
     int64_t total = 0;
     for (auto _ : state)
     {
-        #pragma omp parallel for num_threads(std::thread::hardware_concurrency()) schedule(guided)
+#    pragma omp parallel for num_threads(std::thread::hardware_concurrency()) schedule(guided)
         for (size_t i = 0; i < zip.size(); ++i)
         {
             auto rng = align_pairwise(zip[i], affine_cfg | result_t{});
@@ -185,7 +184,7 @@ void seqan2_affine_dna4_omp_for(benchmark::State & state)
     int64_t total = 0;
     for (auto _ : state)
     {
-        #pragma omp parallel for num_threads(std::thread::hardware_concurrency()) schedule(guided)
+#    pragma omp parallel for num_threads(std::thread::hardware_concurrency()) schedule(guided)
         for (size_t i = 0; i < seqan::length(vec1); ++i)
         {
             if constexpr (score_only)
