@@ -1,34 +1,34 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
 
+#include <benchmark/benchmark.h>
+
 #include <algorithm>
 #include <cstring>
 
-#include <benchmark/benchmark.h>
-
 #include <seqan3/alphabet/all.hpp>
 #include <seqan3/test/seqan2.hpp>
 
 #if SEQAN3_HAS_SEQAN2
-#include <seqan/align.h>
-#include <seqan/basic.h>
-#include <seqan/modifier.h>
+#    include <seqan/align.h>
+#    include <seqan/basic.h>
+#    include <seqan/modifier.h>
 #endif
 
 template <typename alphabet_t, bool is_seqan2>
 std::array<alphabet_t, 256> create_alphabet_array()
 {
-    std::array<alphabet_t, 256> alphabet_array{};
+    std::array<alphabet_t, 256> alphabet_array;
 
-    auto convert_to_alphabet = [] (auto const c, auto & a)
+    auto convert_to_alphabet = [](auto const c, auto & a)
     {
         if constexpr (is_seqan2)
         {
-             a = (char) c;
+            a = (char)c;
         }
         else
         {
@@ -72,8 +72,14 @@ BENCHMARK_TEMPLATE(to_char, char);
 BENCHMARK_TEMPLATE(to_char, char32_t);
 /* alphabet variant */
 BENCHMARK_TEMPLATE(to_char, seqan3::gapped<seqan3::dna4>);
-BENCHMARK_TEMPLATE(to_char, seqan3::alphabet_variant<seqan3::gap, seqan3::dna4, seqan3::dna5, seqan3::dna15,
-                                                     seqan3::rna15, seqan3::rna4, seqan3::rna5>);
+BENCHMARK_TEMPLATE(to_char,
+                   seqan3::alphabet_variant<seqan3::gap,
+                                            seqan3::dna4,
+                                            seqan3::dna5,
+                                            seqan3::dna15,
+                                            seqan3::rna15,
+                                            seqan3::rna4,
+                                            seqan3::rna5>);
 BENCHMARK_TEMPLATE(to_char, seqan3::alphabet_variant<seqan3::dna4, char>);
 /* alphabet tuple */
 BENCHMARK_TEMPLATE(to_char, seqan3::masked<seqan3::dna4>);
