@@ -1,15 +1,17 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
 
+#include <benchmark/benchmark.h>
+
 #include <deque>
 #include <list>
 #include <vector>
 
-#include <benchmark/benchmark.h>
+#include <sdsl/int_vector.hpp>
 
 #include <seqan3/alignment/decorator/gap_decorator.hpp>
 #include <seqan3/alphabet/all.hpp>
@@ -17,8 +19,6 @@
 #include <seqan3/test/performance/sequence_generator.hpp>
 #include <seqan3/utility/container/small_vector.hpp>
 
-#include <sdsl/int_vector.hpp>
-
 template <typename t>
 using sdsl_int_vec = sdsl::int_vector<sizeof(t) * 8>;
 
@@ -35,9 +35,8 @@ void sequential_read(benchmark::State & state)
     auto cont_rando = seqan3::test::generate_sequence<alphabet_t>(10'000, 0, 0);
     container_t<alphabet_t> source(cont_rando.begin(), cont_rando.end());
 
-    using source_ref_t = std::conditional_t<const_qualified,
-                                            container_t<alphabet_t> const &,
-                                            container_t<alphabet_t> &>;
+    using source_ref_t =
+        std::conditional_t<const_qualified, container_t<alphabet_t> const &, container_t<alphabet_t> &>;
 
     source_ref_t source_ref{source};
 
