@@ -4,7 +4,7 @@
 
 int main()
 {
-    using seqan3::operator""_rna4;
+    using namespace seqan3::literals;
 
     seqan3::alphabet_variant<seqan3::dna4, seqan3::gap> letter1{'C'_rna4};
     seqan3::alphabet_variant<seqan3::dna4, seqan3::gap> letter2 = 'C'_rna4;
