@@ -1,4 +1,4 @@
-#include <seqan3/std/ranges>
+#include <ranges>
 #include <vector>
 
 #include <seqan3/alphabet/nucleotide/dna4.hpp>
@@ -12,7 +12,7 @@ bool do_find(fwd_rng_type const &, uint8_t const, uint8_t const)
     return true;
 }
 
-}  // namespace detail
+} // namespace detail
 
 template <std::ranges::forward_range fwd_rng_type>
 bool search(fwd_rng_type const & rng, uint8_t const window_size, uint8_t const error)
