@@ -1,8 +1,6 @@
 #include <sstream>
-#include <utility>
 
 #include <seqan3/io/sam_file/input.hpp>
-#include <seqan3/utility/type_list/type_list.hpp>
 
 auto sam_file_raw = R"(@HD	VN:1.6	SO:coordinate	GO:none
 @SQ	SN:ref	LN:45
