@@ -9,17 +9,14 @@
 
 int main()
 {
-    using seqan3::operator""_rna5;
-    using seqan3::operator""_wuss51;
+    using namespace seqan3::literals;
 
     seqan3::structure_file_output fout{std::ostringstream{}, seqan3::format_vienna{}};
 
-    std::vector<std::tuple<seqan3::rna5_vector, std::string, std::vector<seqan3::wuss51>>> range
-    {
-        { "ACGT"_rna5, "First", "...."_wuss51 },
-        { "NATA"_rna5, "2nd",   "...."_wuss51 },
-        { "GATA"_rna5, "Third", "...."_wuss51 }
-    }; // a range of "records"
+    std::vector<std::tuple<seqan3::rna5_vector, std::string, std::vector<seqan3::wuss51>>> range{
+        {"ACGT"_rna5, "First", "...."_wuss51},
+        {"NATA"_rna5, "2nd", "...."_wuss51},
+        {"GATA"_rna5, "Third", "...."_wuss51}}; // a range of "records"
 
     fout = range; // will iterate over the records and write them
 }
