@@ -1,4 +1,4 @@
-#include <seqan3/std/algorithm>
+#include <algorithm>
 
 #include <seqan3/alphabet/nucleotide/dna4.hpp>
 #include <seqan3/alphabet/views/complement.hpp>
