@@ -1,6 +1,11 @@
-#include <forward_list>                                    // std::forward_list
-#include <seqan3/std/ranges>                               // std::ranges::input_range
-#include <vector>                                          // std::vector
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wunused-parameter"
+#pragma GCC diagnostic ignored "-Wunused-local-typedefs"
+
+//![complete]
+#include <forward_list> // std::forward_list
+#include <ranges>       // std::ranges::input_range
+#include <vector>       // std::vector
 
 #include <seqan3/core/range/type_traits.hpp>               // seqan3::size_type_t
 #include <seqan3/utility/type_traits/lazy_conditional.hpp> // seqan3::lazy_conditional_t
@@ -29,6 +34,9 @@ void foobar(rng_t && range)
 
 int main()
 {
-    foobar(std::vector<int>{});         // sized
-    foobar(std::forward_list<int>{});   // not sized
+    foobar(std::vector<int>{});       // sized
+    foobar(std::forward_list<int>{}); // not sized
 }
+//![complete]
+
+#pragma GCC diagnostic pop
