@@ -1,4 +1,4 @@
-#include <seqan3/std/ranges>
+#include <ranges>
 
 #include <seqan3/core/debug_stream.hpp>
 #include <seqan3/utility/views/repeat.hpp>
