@@ -1,13 +1,13 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
 
 #include <gtest/gtest.h>
 
-#include <seqan3/std/concepts>
+#include <concepts>
 #include <functional>
 
 #include <seqan3/alignment/configuration/align_config_on_result.hpp>
@@ -18,7 +18,10 @@
 
 TEST(align_cfg_on_result, with_captureless_lambda)
 {
-    seqan3::align_cfg::on_result on_result_cfg{[] (auto && result) { return result; }};
+    seqan3::align_cfg::on_result on_result_cfg{[](auto && result)
+                                               {
+                                                   return result;
+                                               }};
 
     EXPECT_TRUE((std::invocable<decltype(on_result_cfg.callback), int>));
     EXPECT_EQ((std::invoke(on_result_cfg.callback, 10)), 10);
@@ -26,7 +29,10 @@ TEST(align_cfg_on_result, with_captureless_lambda)
 TEST(align_cfg_on_result, with_capturing_lambda)
 {
     int global_result = 0;
-    seqan3::align_cfg::on_result on_result_cfg{[&] (auto && result) { global_result = result; }};
+    seqan3::align_cfg::on_result on_result_cfg{[&](auto && result)
+                                               {
+                                                   global_result = result;
+                                               }};
 
     EXPECT_TRUE((std::invocable<decltype(on_result_cfg.callback), int>));
     EXPECT_EQ(global_result, 0);
