@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -12,9 +12,9 @@
 
 #include <seqan3/alignment/matrix/detail/alignment_score_matrix_one_column.hpp>
 
+#include "../../../range/iterator_test_template.hpp"
 #include "alignment_matrix_base_test_template.hpp"
 #include "simulated_alignment_test_template.hpp"
-#include "../../../range/iterator_test_template.hpp"
 
 template <typename t>
 struct alignment_score_matrix_one_column_test
@@ -26,25 +26,18 @@ struct alignment_score_matrix_one_column_test
     alignment_score_matrix_one_column_test(std::string f, std::string s) : matrix{matrix_t{f, s, -100}}
     {}
 
-    std::vector<t> gold_matrix{  0, -1, -2, -3, -4,
-                                -1, -1, -1, -2, -3,
-                                -2, -1, -2, -1, -2,
-                                -3, -2, -2, -2, -2,
-                                -4, -3, -2, -3, -2};
+    std::vector<t> gold_matrix{0,  -1, -2, -3, -4, -1, -1, -1, -2, -3, -2, -1, -2,
+                               -1, -2, -3, -2, -2, -2, -2, -4, -3, -2, -3, -2};
 
     matrix_t matrix{};
     size_t last_init_column = 4;
 };
 
-INSTANTIATE_TYPED_TEST_SUITE_P(one_column,
-                               simulated_alignment_test,
-                               alignment_score_matrix_one_column_test<int32_t>, );
+INSTANTIATE_TYPED_TEST_SUITE_P(one_column, simulated_alignment_test, alignment_score_matrix_one_column_test<int32_t>, );
 
 using test_type = std::pair<seqan3::detail::alignment_score_matrix_one_column<int32_t>, std::false_type>;
 
-INSTANTIATE_TYPED_TEST_SUITE_P(one_column,
-                               alignment_matrix_base_test,
-                               test_type, );
+INSTANTIATE_TYPED_TEST_SUITE_P(one_column, alignment_matrix_base_test, test_type, );
 
 //-----------------------------------------------------------------------------
 // Test outer iterator
@@ -70,9 +63,7 @@ struct iterator_fixture<outer_iterator> : alignment_matrix_base_test<test_type>
     }
 };
 
-INSTANTIATE_TYPED_TEST_SUITE_P(score_matrix_outer_iterator,
-                               iterator_fixture,
-                               outer_iterator, );
+INSTANTIATE_TYPED_TEST_SUITE_P(score_matrix_outer_iterator, iterator_fixture, outer_iterator, );
 
 //-----------------------------------------------------------------------------
 // Test inner iterator
@@ -98,6 +89,4 @@ struct iterator_fixture<inner_iterator> : alignment_matrix_base_test<test_type>
     }
 };
 
-INSTANTIATE_TYPED_TEST_SUITE_P(score_matrix_inner_iterator,
-                               iterator_fixture,
-                               inner_iterator, );
+INSTANTIATE_TYPED_TEST_SUITE_P(score_matrix_inner_iterator, iterator_fixture, inner_iterator, );
