@@ -1,13 +1,13 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
 
 #include <gtest/gtest.h>
 
-#include <seqan3/std/ranges>
+#include <ranges>
 #include <stdexcept>
 #include <string_view>
 #include <type_traits>
@@ -27,16 +27,13 @@ template <typename t>
 struct align_pairwise_test : ::testing::Test
 {
     // two helper variables to check if the TypeParam contains vectorised.
-    using dummy_cfg_t = std::conditional_t<std::is_same_v<void, t>,
-                                           decltype(seqan3::align_cfg::min_score{-1}),
-                                           t>;
+    using dummy_cfg_t = std::conditional_t<std::is_same_v<void, t>, decltype(seqan3::align_cfg::min_score{-1}), t>;
     using config_t = decltype(seqan3::align_cfg::method_global{} | seqan3::align_cfg::edit_scheme | dummy_cfg_t{});
 
     static constexpr bool is_vectorised = config_t::template exists<seqan3::align_cfg::vectorised>();
 };
 
-using testing_types = ::testing::Types<void,
-                                       seqan3::align_cfg::parallel>;
+using testing_types = ::testing::Types<void, seqan3::align_cfg::parallel>;
 
 TYPED_TEST_SUITE(align_pairwise_test, testing_types, );
 
@@ -64,10 +61,9 @@ TYPED_TEST(align_pairwise_test, single_pair)
     // use std::tie
     auto p1 = std::tie(seq1, seq2);
 
-    {  // the score
-        seqan3::configuration cfg = seqan3::align_cfg::method_global{} |
-                                    seqan3::align_cfg::edit_scheme |
-                                    seqan3::align_cfg::output_score{};
+    { // the score
+        seqan3::configuration cfg =
+            seqan3::align_cfg::method_global{} | seqan3::align_cfg::edit_scheme | seqan3::align_cfg::output_score{};
 
         for (auto && res : call_alignment<TypeParam>(p1, cfg))
         {
@@ -75,9 +71,8 @@ TYPED_TEST(align_pairwise_test, single_pair)
         }
     }
 
-    {  // with everything (default if no output is specified)
-        seqan3::configuration cfg = seqan3::align_cfg::method_global{} |
-                                    seqan3::align_cfg::edit_scheme;
+    { // with everything (default if no output is specified)
+        seqan3::configuration cfg = seqan3::align_cfg::method_global{} | seqan3::align_cfg::edit_scheme;
         unsigned idx = 0;
         for (auto && res : call_alignment<TypeParam>(p1, cfg))
         {
@@ -93,12 +88,11 @@ TYPED_TEST(align_pairwise_test, single_pair)
     }
 
     // use std::pair
-    std::pair sequences{"ACGTGATG"_dna4,"AGTGATACT"_dna4};
+    std::pair sequences{"ACGTGATG"_dna4, "AGTGATACT"_dna4};
 
-    {  // the score
-        seqan3::configuration cfg = seqan3::align_cfg::method_global{} |
-                                    seqan3::align_cfg::edit_scheme |
-                                    seqan3::align_cfg::output_score{};
+    { // the score
+        seqan3::configuration cfg =
+            seqan3::align_cfg::method_global{} | seqan3::align_cfg::edit_scheme | seqan3::align_cfg::output_score{};
 
         for (auto && res : call_alignment<TypeParam>(sequences, cfg))
         {
@@ -106,9 +100,8 @@ TYPED_TEST(align_pairwise_test, single_pair)
         }
     }
 
-    {  // with everything (default if no output is specified)
-        seqan3::configuration cfg = seqan3::align_cfg::method_global{} |
-                                    seqan3::align_cfg::edit_scheme;
+    { // with everything (default if no output is specified)
+        seqan3::configuration cfg = seqan3::align_cfg::method_global{} | seqan3::align_cfg::edit_scheme;
         unsigned idx = 0;
         for (auto && res : call_alignment<TypeParam>(sequences, cfg))
         {
@@ -126,10 +119,9 @@ TYPED_TEST(align_pairwise_test, single_pair)
     // use make_pair
     auto p2 = std::make_pair(seq1, seq2);
 
-    {  // the score
-        seqan3::configuration cfg = seqan3::align_cfg::method_global{} |
-                                    seqan3::align_cfg::edit_scheme |
-                                    seqan3::align_cfg::output_score{};
+    { // the score
+        seqan3::configuration cfg =
+            seqan3::align_cfg::method_global{} | seqan3::align_cfg::edit_scheme | seqan3::align_cfg::output_score{};
 
         for (auto && res : call_alignment<TypeParam>(p2, cfg))
         {
@@ -137,9 +129,8 @@ TYPED_TEST(align_pairwise_test, single_pair)
         }
     }
 
-    {  // with everything (default if no output is specified)
-        seqan3::configuration cfg = seqan3::align_cfg::method_global{} |
-                                    seqan3::align_cfg::edit_scheme;
+    { // with everything (default if no output is specified)
+        seqan3::configuration cfg = seqan3::align_cfg::method_global{} | seqan3::align_cfg::edit_scheme;
         unsigned idx = 0;
         for (auto && res : call_alignment<TypeParam>(p2, cfg))
         {
@@ -166,11 +157,9 @@ TYPED_TEST(align_pairwise_test, single_pair_double_score)
 
         auto p = std::tie(seq1, seq2);
 
-        {  // the score
-            seqan3::configuration cfg = seqan3::align_cfg::method_global{} |
-                                        seqan3::align_cfg::edit_scheme |
-                                        seqan3::align_cfg::output_score{} |
-                                        seqan3::align_cfg::score_type<double>{};
+        { // the score
+            seqan3::configuration cfg = seqan3::align_cfg::method_global{} | seqan3::align_cfg::edit_scheme
+                                      | seqan3::align_cfg::output_score{} | seqan3::align_cfg::score_type<double>{};
 
             for (auto && res : call_alignment<TypeParam>(p, cfg))
             {
@@ -179,15 +168,12 @@ TYPED_TEST(align_pairwise_test, single_pair_double_score)
             }
         }
 
-        {  // with everything (default if no output is specified)
-            seqan3::configuration cfg = seqan3::align_cfg::method_global{} |
-                                        seqan3::align_cfg::edit_scheme |
-                                        seqan3::align_cfg::output_alignment{} |
-                                        seqan3::align_cfg::output_end_position{} |
-                                        seqan3::align_cfg::output_sequence1_id{} |
-                                        seqan3::align_cfg::output_sequence2_id{} |
-                                        seqan3::align_cfg::output_score{} |
-                                        seqan3::align_cfg::score_type<double>{};
+        { // with everything (default if no output is specified)
+            seqan3::configuration cfg = seqan3::align_cfg::method_global{} | seqan3::align_cfg::edit_scheme
+                                      | seqan3::align_cfg::output_alignment{} | seqan3::align_cfg::output_end_position{}
+                                      | seqan3::align_cfg::output_sequence1_id{}
+                                      | seqan3::align_cfg::output_sequence2_id{} | seqan3::align_cfg::output_score{}
+                                      | seqan3::align_cfg::score_type<double>{};
 
             for (auto && res : call_alignment<TypeParam>(p, cfg))
             {
@@ -211,19 +197,17 @@ TYPED_TEST(align_pairwise_test, single_view)
 
     auto v = std::views::single(std::tie(seq1, seq2)) | std::views::common;
 
-    {  // the score
-        seqan3::configuration cfg = seqan3::align_cfg::method_global{} |
-                                    seqan3::align_cfg::edit_scheme |
-                                    seqan3::align_cfg::output_score{};
+    { // the score
+        seqan3::configuration cfg =
+            seqan3::align_cfg::method_global{} | seqan3::align_cfg::edit_scheme | seqan3::align_cfg::output_score{};
         for (auto && res : call_alignment<TypeParam>(v, cfg))
         {
-             EXPECT_EQ(res.score(), -4);
+            EXPECT_EQ(res.score(), -4);
         }
     }
 
-    {  // with everything (default if no output is specified)
-        seqan3::configuration cfg = seqan3::align_cfg::method_global{} |
-                                    seqan3::align_cfg::edit_scheme;
+    { // with everything (default if no output is specified)
+        seqan3::configuration cfg = seqan3::align_cfg::method_global{} | seqan3::align_cfg::edit_scheme;
 
         for (auto && res : call_alignment<TypeParam>(v, cfg))
         {
@@ -245,10 +229,8 @@ TYPED_TEST(align_pairwise_test, collection)
     auto p = std::tie(seq1, seq2);
     std::vector<decltype(p)> vec{10, p};
 
-    seqan3::configuration cfg = seqan3::align_cfg::method_global{} |
-                                seqan3::align_cfg::edit_scheme |
-                                seqan3::align_cfg::output_score{} |
-                                seqan3::align_cfg::output_alignment{};
+    seqan3::configuration cfg = seqan3::align_cfg::method_global{} | seqan3::align_cfg::edit_scheme
+                              | seqan3::align_cfg::output_score{} | seqan3::align_cfg::output_alignment{};
     for (auto && res : call_alignment<TypeParam>(vec, cfg))
     {
         EXPECT_EQ(res.score(), -4);
@@ -270,11 +252,9 @@ TYPED_TEST(align_pairwise_test, collection_with_double_score_type)
         auto p = std::tie(seq1, seq2);
         std::vector<decltype(p)> vec{10, p};
 
-        seqan3::configuration cfg = seqan3::align_cfg::method_global{} |
-                                    seqan3::align_cfg::edit_scheme |
-                                    seqan3::align_cfg::output_alignment{} |
-                                    seqan3::align_cfg::output_score{} |
-                                    seqan3::align_cfg::score_type<double>{};
+        seqan3::configuration cfg = seqan3::align_cfg::method_global{} | seqan3::align_cfg::edit_scheme
+                                  | seqan3::align_cfg::output_alignment{} | seqan3::align_cfg::output_score{}
+                                  | seqan3::align_cfg::score_type<double>{};
 
         for (auto && res : call_alignment<TypeParam>(vec, cfg))
         {
@@ -291,13 +271,13 @@ TYPED_TEST(align_pairwise_test, bug_1598)
     // https://github.com/seqan/seqan3/issues/1598
     using seqan3::operator""_dna4;
     auto s1 = "TTACGTACGGACTAGCTACAACATTACGGACTAC"_dna4;
-    auto g  = "GGACGACATGACGTACGACTTTACGTACGACTAGC"_dna4;
+    auto g = "GGACGACATGACGTACGACTTTACGTACGACTAGC"_dna4;
     auto s2 = g | std::views::drop(2);
 
     // Configure the alignment kernel.
-    seqan3::configuration cfg = seqan3::align_cfg::method_global{} |
-                                seqan3::align_cfg::scoring_scheme{seqan3::nucleotide_scoring_scheme{}} |
-                                seqan3::align_cfg::output_alignment{};
+    seqan3::configuration cfg = seqan3::align_cfg::method_global{}
+                              | seqan3::align_cfg::scoring_scheme{seqan3::nucleotide_scoring_scheme{}}
+                              | seqan3::align_cfg::output_alignment{};
 
     // Invoke the pairwise alignment which returns a lazy range over alignment results.
     auto results = seqan3::align_pairwise(std::tie(s1, s2), cfg);
@@ -307,10 +287,8 @@ TEST(align_pairwise_test, parallel_without_parameter)
 {
     auto seq1 = "ACGTGATG"_dna4;
     auto seq2 = "AGTGATACT"_dna4;
-    seqan3::configuration cfg = seqan3::align_cfg::method_global{} |
-                                seqan3::align_cfg::edit_scheme |
-                                seqan3::align_cfg::output_score{} |
-                                seqan3::align_cfg::parallel{};
+    seqan3::configuration cfg = seqan3::align_cfg::method_global{} | seqan3::align_cfg::edit_scheme
+                              | seqan3::align_cfg::output_score{} | seqan3::align_cfg::parallel{};
 
     EXPECT_THROW(seqan3::align_pairwise(std::tie(seq1, seq2), cfg), std::runtime_error);
 }
