@@ -1,14 +1,14 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
 
-#include <vector>
-
 #include <gtest/gtest.h>
 
+#include <vector>
+
 #include <seqan3/alignment/pairwise/align_pairwise.hpp>
 
 #include "fixture/global_affine_unbanded.hpp"
@@ -31,11 +31,10 @@ static auto dna4_01 = []()
     return alignment_fixture_collection{base_fixture.config | seqan3::align_cfg::parallel{4}, data};
 }();
 
-} // namespace seqan3::test::alignment::fixture::collection::global::affine::unbanded
+} // namespace seqan3::test::alignment::collection::global::affine::unbanded
 
 using pairwise_global_affine_collection_unbanded_testing_types = ::testing::Types<
-        pairwise_alignment_fixture<&seqan3::test::alignment::collection::global::affine::unbanded::dna4_01>
-    >;
+    pairwise_alignment_fixture<&seqan3::test::alignment::collection::global::affine::unbanded::dna4_01>>;
 
 INSTANTIATE_TYPED_TEST_SUITE_P(pairwise_global_affine_collection_unbanded,
                                pairwise_alignment_collection_test,
