@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -13,11 +13,10 @@
 #include "pairwise_alignment_single_test_template.hpp"
 
 using pairwise_semiglobal_affine_unbanded_testing_types = ::testing::Types<
-        pairwise_alignment_fixture<&seqan3::test::alignment::fixture::semi_global::affine::unbanded::dna4_01_semi_first>,
-        pairwise_alignment_fixture<&seqan3::test::alignment::fixture::semi_global::affine::unbanded::dna4_02_semi_first>,
-        pairwise_alignment_fixture<&seqan3::test::alignment::fixture::semi_global::affine::unbanded::dna4_03_semi_second>,
-        pairwise_alignment_fixture<&seqan3::test::alignment::fixture::semi_global::affine::unbanded::dna4_04_semi_second>
-    >;
+    pairwise_alignment_fixture<&seqan3::test::alignment::fixture::semi_global::affine::unbanded::dna4_01_semi_first>,
+    pairwise_alignment_fixture<&seqan3::test::alignment::fixture::semi_global::affine::unbanded::dna4_02_semi_first>,
+    pairwise_alignment_fixture<&seqan3::test::alignment::fixture::semi_global::affine::unbanded::dna4_03_semi_second>,
+    pairwise_alignment_fixture<&seqan3::test::alignment::fixture::semi_global::affine::unbanded::dna4_04_semi_second>>;
 
 INSTANTIATE_TYPED_TEST_SUITE_P(pairwise_semiglobal_affine_unbanded,
                                pairwise_alignment_test,
