@@ -1,14 +1,14 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
 
-#include <iostream>
-
 #include <gtest/gtest.h>
 
+#include <iostream>
+
 #include <seqan3/alphabet/adaptation/char.hpp>
 
 #include "../alphabet_constexpr_test_template.hpp"
@@ -45,20 +45,17 @@ TYPED_TEST(char_adaptation, alphabet_char_t)
 TYPED_TEST(char_adaptation, to_char)
 {
     TypeParam l{'A'};
-    EXPECT_TRUE((std::is_same_v<decltype(seqan3::to_char(l)),
-                                seqan3::alphabet_char_t<TypeParam>>));
-    EXPECT_TRUE((std::is_same_v<decltype(seqan3::to_char(TypeParam{'A'})),
-                                seqan3::alphabet_char_t<TypeParam>>));
+    EXPECT_TRUE((std::is_same_v<decltype(seqan3::to_char(l)), seqan3::alphabet_char_t<TypeParam>>));
+    EXPECT_TRUE((std::is_same_v<decltype(seqan3::to_char(TypeParam{'A'})), seqan3::alphabet_char_t<TypeParam>>));
     EXPECT_EQ(seqan3::to_char(TypeParam{'A'}), l);
 }
 
 TYPED_TEST(char_adaptation, assign_char_to)
 {
     TypeParam l{'A'};
-    EXPECT_TRUE((std::is_same_v<decltype(seqan3::assign_char_to('A', l)),
-                                seqan3::alphabet_char_t<TypeParam> &>));
-    EXPECT_TRUE((std::is_same_v<decltype(seqan3::assign_char_to('A', TypeParam{'A'})),
-                                seqan3::alphabet_char_t<TypeParam>>));
+    EXPECT_TRUE((std::is_same_v<decltype(seqan3::assign_char_to('A', l)), seqan3::alphabet_char_t<TypeParam> &>));
+    EXPECT_TRUE(
+        (std::is_same_v<decltype(seqan3::assign_char_to('A', TypeParam{'A'})), seqan3::alphabet_char_t<TypeParam>>));
     EXPECT_EQ((seqan3::assign_char_to('A', TypeParam{'C'})), l);
     EXPECT_EQ((seqan3::assign_char_to('C', l)), TypeParam{'C'});
 }
@@ -66,8 +63,8 @@ TYPED_TEST(char_adaptation, assign_char_to)
 TYPED_TEST(char_adaptation, assign_char_strictly_to)
 {
     TypeParam l{'A'};
-    EXPECT_TRUE((std::is_same_v<decltype(seqan3::assign_char_strictly_to('A', l)),
-                                seqan3::alphabet_char_t<TypeParam> &>));
+    EXPECT_TRUE(
+        (std::is_same_v<decltype(seqan3::assign_char_strictly_to('A', l)), seqan3::alphabet_char_t<TypeParam> &>));
     EXPECT_TRUE((std::is_same_v<decltype(seqan3::assign_char_strictly_to('A', TypeParam{'A'})),
                                 seqan3::alphabet_char_t<TypeParam>>));
     EXPECT_EQ((seqan3::assign_char_strictly_to('A', TypeParam{'C'})), l);
@@ -84,10 +81,8 @@ TYPED_TEST(char_adaptation, alphabet_rank_t)
 TYPED_TEST(char_adaptation, to_rank)
 {
     TypeParam l{'A'};
-    EXPECT_TRUE((std::is_same_v<decltype(seqan3::to_rank(l)),
-                                seqan3::alphabet_rank_t<TypeParam>>));
-    EXPECT_TRUE((std::is_same_v<decltype(seqan3::to_rank(TypeParam{'A'})),
-                                seqan3::alphabet_rank_t<TypeParam>>));
+    EXPECT_TRUE((std::is_same_v<decltype(seqan3::to_rank(l)), seqan3::alphabet_rank_t<TypeParam>>));
+    EXPECT_TRUE((std::is_same_v<decltype(seqan3::to_rank(TypeParam{'A'})), seqan3::alphabet_rank_t<TypeParam>>));
 
     unsigned char cmp{'A'};
     EXPECT_EQ(seqan3::to_rank(TypeParam{65}), cmp);
@@ -96,10 +91,9 @@ TYPED_TEST(char_adaptation, to_rank)
 TYPED_TEST(char_adaptation, assign_rank_to)
 {
     TypeParam l{'A'};
-    EXPECT_TRUE((std::is_same_v<decltype(seqan3::assign_rank_to(65, l)),
-                                seqan3::alphabet_char_t<TypeParam> &>));
-    EXPECT_TRUE((std::is_same_v<decltype(seqan3::assign_rank_to(65, TypeParam{'A'})),
-                                seqan3::alphabet_char_t<TypeParam>>));
+    EXPECT_TRUE((std::is_same_v<decltype(seqan3::assign_rank_to(65, l)), seqan3::alphabet_char_t<TypeParam> &>));
+    EXPECT_TRUE(
+        (std::is_same_v<decltype(seqan3::assign_rank_to(65, TypeParam{'A'})), seqan3::alphabet_char_t<TypeParam>>));
     EXPECT_EQ((seqan3::assign_rank_to(65, TypeParam{'C'})), l);
     EXPECT_EQ((seqan3::assign_rank_to(67, l)), TypeParam{'C'});
 }
@@ -107,5 +101,6 @@ TYPED_TEST(char_adaptation, assign_rank_to)
 TYPED_TEST(char_adaptation, alphabet_size)
 {
     EXPECT_EQ(seqan3::alphabet_size<TypeParam>,
-        static_cast<size_t>(std::numeric_limits<TypeParam>::max()) + 1 - std::numeric_limits<TypeParam>::lowest());
+              static_cast<size_t>(std::numeric_limits<TypeParam>::max()) + 1
+                  - std::numeric_limits<TypeParam>::lowest());
 }
