@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -58,9 +58,12 @@ public:
     }
     auto values_to_cmp()
     {
-        return std::make_tuple(/*low */'A'_dna4, 'A'_dna5,
-                               /*mid */'C'_dna4, 'C'_dna5,
-                               /*high*/'T'_dna4, 'T'_dna5);
+        return std::make_tuple(/*low */ 'A'_dna4,
+                               'A'_dna5,
+                               /*mid */ 'C'_dna4,
+                               'C'_dna5,
+                               /*high*/ 'T'_dna4,
+                               'T'_dna5);
     }
 };
 
