@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -10,9 +10,10 @@
 // Tests the ADL-capabilities of the alphabet customisation point objects; type that isn't default constructible
 
 //![my_alph]
-#include <cstddef>                      // for size_t
-#include <seqan3/alphabet/concept.hpp>  // for seqan3::alphabet
-#include <seqan3/std/type_traits>       // for std::type_identity
+#include <cstddef>     // for size_t
+#include <type_traits> // for std::type_identity
+
+#include <seqan3/alphabet/concept.hpp> // for seqan3::alphabet
 
 namespace my_namespace
 {
@@ -26,17 +27,35 @@ public:
     constexpr my_alph(my_alph const &) = default;
     constexpr my_alph & operator=(my_alph const &) = default;
 
-    constexpr my_alph(bool rank) : rank{rank} {}
+    constexpr my_alph(bool rank) : rank{rank}
+    {}
 
-    constexpr friend bool operator==(my_alph lhs, my_alph rhs) { return lhs.rank == rhs.rank; }
-    constexpr friend bool operator!=(my_alph lhs, my_alph rhs) { return lhs.rank != rhs.rank; }
-    constexpr friend bool operator<=(my_alph lhs, my_alph rhs) { return lhs.rank <= rhs.rank; }
-    constexpr friend bool operator>=(my_alph lhs, my_alph rhs) { return lhs.rank >= rhs.rank; }
-    constexpr friend bool operator< (my_alph lhs, my_alph rhs) { return lhs.rank <  rhs.rank; }
-    constexpr friend bool operator> (my_alph lhs, my_alph rhs) { return lhs.rank >  rhs.rank; }
+    constexpr friend bool operator==(my_alph lhs, my_alph rhs)
+    {
+        return lhs.rank == rhs.rank;
+    }
+    constexpr friend bool operator!=(my_alph lhs, my_alph rhs)
+    {
+        return lhs.rank != rhs.rank;
+    }
+    constexpr friend bool operator<=(my_alph lhs, my_alph rhs)
+    {
+        return lhs.rank <= rhs.rank;
+    }
+    constexpr friend bool operator>=(my_alph lhs, my_alph rhs)
+    {
+        return lhs.rank >= rhs.rank;
+    }
+    constexpr friend bool operator<(my_alph lhs, my_alph rhs)
+    {
+        return lhs.rank < rhs.rank;
+    }
+    constexpr friend bool operator>(my_alph lhs, my_alph rhs)
+    {
+        return lhs.rank > rhs.rank;
+    }
 };
 
-
 constexpr size_t alphabet_size(std::type_identity<my_alph> const &) noexcept
 {
     return 2;
@@ -65,8 +84,14 @@ constexpr my_alph & assign_char_to(char const c, my_alph & a) noexcept
 {
     switch (c)
     {
-        case '0': case 'F': case 'f': a.rank = 0; return a;
-        default: a.rank = 1; return a;
+    case '0':
+    case 'F':
+    case 'f':
+        a.rank = 0;
+        return a;
+    default:
+        a.rank = 1;
+        return a;
     }
 }
 
@@ -74,8 +99,15 @@ constexpr bool char_is_valid_for(char const c, std::type_identity<my_alph> const
 {
     switch (c)
     {
-        case '0': case 'F': case 'f': case '1': case 'T': case 't': return true;
-        default: return false;
+    case '0':
+    case 'F':
+    case 'f':
+    case '1':
+    case 'T':
+    case 't':
+        return true;
+    default:
+        return false;
     }
 }
 
