@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -13,7 +13,6 @@
 #include "../semi_alphabet_constexpr_test_template.hpp"
 #include "../semi_alphabet_test_template.hpp"
 
-
 class alphabet_proxy_example : public seqan3::alphabet_proxy<alphabet_proxy_example, seqan3::dna4>
 {
 private:
@@ -32,8 +31,7 @@ public:
     constexpr alphabet_proxy_example & operator=(alphabet_proxy_example &&) = default;
     ~alphabet_proxy_example() = default;
 
-    constexpr alphabet_proxy_example(alphabet_type const a) noexcept : base_t{a}
-    {};
+    constexpr alphabet_proxy_example(alphabet_type const a) noexcept : base_t{a} {};
 
     using base_t::operator=;
 };
@@ -59,17 +57,35 @@ public:
     constexpr my_alph(my_alph const &) = default;
     constexpr my_alph & operator=(my_alph const &) = default;
 
-    constexpr my_alph(bool rank) : rank{rank} {}
+    constexpr my_alph(bool rank) : rank{rank}
+    {}
 
-    constexpr friend bool operator==(my_alph lhs, my_alph rhs) { return lhs.rank == rhs.rank; }
-    constexpr friend bool operator!=(my_alph lhs, my_alph rhs) { return lhs.rank != rhs.rank; }
-    constexpr friend bool operator<=(my_alph lhs, my_alph rhs) { return lhs.rank <= rhs.rank; }
-    constexpr friend bool operator>=(my_alph lhs, my_alph rhs) { return lhs.rank >= rhs.rank; }
-    constexpr friend bool operator< (my_alph lhs, my_alph rhs) { return lhs.rank <  rhs.rank; }
-    constexpr friend bool operator> (my_alph lhs, my_alph rhs) { return lhs.rank >  rhs.rank; }
+    constexpr friend bool operator==(my_alph lhs, my_alph rhs)
+    {
+        return lhs.rank == rhs.rank;
+    }
+    constexpr friend bool operator!=(my_alph lhs, my_alph rhs)
+    {
+        return lhs.rank != rhs.rank;
+    }
+    constexpr friend bool operator<=(my_alph lhs, my_alph rhs)
+    {
+        return lhs.rank <= rhs.rank;
+    }
+    constexpr friend bool operator>=(my_alph lhs, my_alph rhs)
+    {
+        return lhs.rank >= rhs.rank;
+    }
+    constexpr friend bool operator<(my_alph lhs, my_alph rhs)
+    {
+        return lhs.rank < rhs.rank;
+    }
+    constexpr friend bool operator>(my_alph lhs, my_alph rhs)
+    {
+        return lhs.rank > rhs.rank;
+    }
 };
 
-
 constexpr size_t alphabet_size(my_alph const &) noexcept
 {
     return 2;
@@ -98,8 +114,14 @@ constexpr my_alph & assign_char_to(char const c, my_alph & a) noexcept
 {
     switch (c)
     {
-        case '0': case 'F': case 'f': a.rank = 0; return a;
-        default: a.rank = 1; return a;
+    case '0':
+    case 'F':
+    case 'f':
+        a.rank = 0;
+        return a;
+    default:
+        a.rank = 1;
+        return a;
     }
 }
 
@@ -127,8 +149,7 @@ public:
     constexpr alphabet_proxy_example2 & operator=(alphabet_proxy_example2 &&) = default;
     ~alphabet_proxy_example2() = default;
 
-    constexpr alphabet_proxy_example2(alphabet_type const a) noexcept : base_t{a}
-    {};
+    constexpr alphabet_proxy_example2(alphabet_type const a) noexcept : base_t{a} {};
 };
 
 INSTANTIATE_TYPED_TEST_SUITE_P(alphabet_proxy2, alphabet, alphabet_proxy_example2, );
