@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -18,9 +18,8 @@ using seqan3::operator""_dna4;
 template <typename T>
 using debug_stream_test = ::testing::Test;
 
-using alphabet_types = ::testing::Types<seqan3::dna4,
-                                        seqan3::qualified<seqan3::dna4, seqan3::phred42>,
-                                        seqan3::gapped<seqan3::dna4>>;
+using alphabet_types =
+    ::testing::Types<seqan3::dna4, seqan3::qualified<seqan3::dna4, seqan3::phred42>, seqan3::gapped<seqan3::dna4>>;
 
 TYPED_TEST_SUITE(debug_stream_test, alphabet_types, );
 
