@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -34,23 +34,15 @@ INSTANTIATE_TYPED_TEST_SUITE_P(wuss67, semi_alphabet_constexpr, seqan3::wuss<67>
 // assign_char functions
 TEST(wuss, assign_char)
 {
-    std::vector<char> input
-    {
-        '.', '(', ')',
-        ':', ',', '-', '_', '~', ';',
-        '<', '>', '[', ']', '{', '}',
-        'H', 'B', 'E', 'G', 'I', 'T', 'S'
-    };
+    std::vector<char> input{'.', '(', ')', ':', ',', '-', '_', '~', ';', '<', '>',
+                            '[', ']', '{', '}', 'H', 'B', 'E', 'G', 'I', 'T', 'S'};
 
-    std::vector<seqan3::wuss51> cmp
-    {
-        '.'_wuss51, '('_wuss51, ')'_wuss51,
-        ':'_wuss51, ','_wuss51, '-'_wuss51, '_'_wuss51, '~'_wuss51, ';'_wuss51,
-        '<'_wuss51, '>'_wuss51, '['_wuss51, ']'_wuss51, '{'_wuss51, '}'_wuss51,
-        'H'_wuss51, 'B'_wuss51, 'E'_wuss51, 'G'_wuss51, 'I'_wuss51, 'T'_wuss51, 'S'_wuss51
-    };
+    std::vector<seqan3::wuss51> cmp{'.'_wuss51, '('_wuss51, ')'_wuss51, ':'_wuss51, ','_wuss51, '-'_wuss51,
+                                    '_'_wuss51, '~'_wuss51, ';'_wuss51, '<'_wuss51, '>'_wuss51, '['_wuss51,
+                                    ']'_wuss51, '{'_wuss51, '}'_wuss51, 'H'_wuss51, 'B'_wuss51, 'E'_wuss51,
+                                    'G'_wuss51, 'I'_wuss51, 'T'_wuss51, 'S'_wuss51};
 
-    for (auto [ ch, cm ] : seqan3::views::zip(input, cmp))
+    for (auto [ch, cm] : seqan3::views::zip(input, cmp))
         EXPECT_EQ((seqan3::assign_char_to(ch, seqan3::wuss51{})), cm);
 }
 
@@ -83,7 +75,7 @@ TEST(wuss, concept_check)
     EXPECT_TRUE(seqan3::rna_structure_alphabet<seqan3::wuss51 const &>);
     EXPECT_NE(seqan3::max_pseudoknot_depth<seqan3::wuss51>, 0);
 
-    EXPECT_TRUE(seqan3::rna_structure_alphabet<seqan3::wuss<>>);  // same as wuss51
+    EXPECT_TRUE(seqan3::rna_structure_alphabet<seqan3::wuss<>>); // same as wuss51
     EXPECT_TRUE(seqan3::rna_structure_alphabet<seqan3::wuss<> &>);
     EXPECT_TRUE(seqan3::rna_structure_alphabet<seqan3::wuss<> const>);
     EXPECT_TRUE(seqan3::rna_structure_alphabet<seqan3::wuss<> const &>);
@@ -94,7 +86,6 @@ TEST(wuss, concept_check)
     EXPECT_TRUE(seqan3::rna_structure_alphabet<seqan3::wuss<67> const>);
     EXPECT_TRUE(seqan3::rna_structure_alphabet<seqan3::wuss<67> const &>);
     EXPECT_NE(seqan3::max_pseudoknot_depth<seqan3::wuss<67>>, 0);
-
 }
 
 TEST(wuss, literals)
@@ -118,7 +109,7 @@ TEST(wuss, rna_structure_properties)
         EXPECT_FALSE(vec[idx].is_pair_close());
         EXPECT_FALSE(vec[idx].pseudoknot_id());
     }
-    for (unsigned idx = 7; idx <= 21; idx+=2)
+    for (unsigned idx = 7; idx <= 21; idx += 2)
     {
         EXPECT_TRUE(vec[idx].is_pair_open());
         EXPECT_FALSE(vec[idx].is_unpaired());
@@ -126,7 +117,7 @@ TEST(wuss, rna_structure_properties)
         EXPECT_TRUE(vec[idx].pseudoknot_id());
         EXPECT_EQ(vec[idx].pseudoknot_id(), std::optional<uint8_t>{(idx - 7) / 2});
     }
-    for (unsigned idx = 8; idx <= 22; idx+=2)
+    for (unsigned idx = 8; idx <= 22; idx += 2)
     {
         EXPECT_TRUE(vec[idx].is_pair_close());
         EXPECT_FALSE(vec[idx].is_unpaired());
