@@ -1,13 +1,13 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
 
 #include <gtest/gtest.h>
 
-#include <seqan3/std/iterator>
+#include <iterator>
 #include <sstream>
 
 #include <seqan3/io/sam_file/input.hpp>
@@ -19,26 +19,13 @@ using seqan3::operator""_dna5;
 
 using default_fields = seqan3::fields<seqan3::field::seq, seqan3::field::id, seqan3::field::qual>;
 
-std::vector<seqan3::dna5_vector> seqs
-{
-    "ACGT"_dna5,
-    "AGGCTGNAGGCTGNA"_dna5,
-    "GGAGTATAATATATATATATATAT"_dna5
-};
+std::vector<seqan3::dna5_vector> seqs{"ACGT"_dna5, "AGGCTGNAGGCTGNA"_dna5, "GGAGTATAATATATATATATATAT"_dna5};
 
-std::vector<std::string> ids
-{
-    "read1",
-    "read2",
-    "read3"
-};
+std::vector<std::string> ids{"read1", "read2", "read3"};
 
-std::string const output_comp
-{
-    "read1\t0\t*\t0\t0\t*\t*\t0\t0\tACGT\t*\n"
-    "read2\t0\t*\t0\t0\t*\t*\t0\t0\tAGGCTGNAGGCTGNA\t*\n"
-    "read3\t0\t*\t0\t0\t*\t*\t0\t0\tGGAGTATAATATATATATATATAT\t*\n"
-};
+std::string const output_comp{"read1\t0\t*\t0\t0\t*\t*\t0\t0\tACGT\t*\n"
+                              "read2\t0\t*\t0\t0\t*\t*\t0\t0\tAGGCTGNAGGCTGNA\t*\n"
+                              "read3\t0\t*\t0\t0\t*\t*\t0\t0\tGGAGTATAATATATATATATATAT\t*\n"};
 
 // ----------------------------------------------------------------------------
 // general
@@ -68,46 +55,43 @@ TEST(general, construct_by_filename)
     /* just the filename */
     {
         seqan3::test::tmp_filename filename{"sam_file_output_constructor.sam"};
-        EXPECT_NO_THROW( seqan3::sam_file_output<>{filename.get_path()} );
+        EXPECT_NO_THROW(seqan3::sam_file_output<>{filename.get_path()});
     }
 
     /* wrong extension */
     {
         seqan3::test::tmp_filename filename{"sam_file_output_constructor.xyz"};
         std::ofstream filecreator{filename.get_path(), std::ios::out | std::ios::binary};
-        EXPECT_THROW( seqan3::sam_file_output<>{filename.get_path()},
-                      seqan3::unhandled_extension_error );
+        EXPECT_THROW(seqan3::sam_file_output<>{filename.get_path()}, seqan3::unhandled_extension_error);
     }
 
     /* unknown file */
     {
         seqan3::test::tmp_filename filename{"I/do/not/exist.sam"};
-        EXPECT_THROW( seqan3::sam_file_output<>{filename.get_path()}, seqan3::file_open_error );
+        EXPECT_THROW(seqan3::sam_file_output<>{filename.get_path()}, seqan3::file_open_error);
     }
 
     /* filename + fields */
     using fields_seq = seqan3::fields<seqan3::field::seq>;
     {
         seqan3::test::tmp_filename filename{"sam_file_output_constructor.sam"};
-        EXPECT_NO_THROW(( seqan3::sam_file_output<fields_seq,
-                                                  seqan3::type_list<seqan3::format_sam>>{filename.get_path(),
-                                                                                         fields_seq{}} ));
+        EXPECT_NO_THROW((seqan3::sam_file_output<fields_seq, seqan3::type_list<seqan3::format_sam>>{filename.get_path(),
+                                                                                                    fields_seq{}}));
     }
 }
 
 TEST(general, construct_from_stream)
 {
     /* stream + format_tag */
-    EXPECT_NO_THROW(( seqan3::sam_file_output<default_fields,
-                                              seqan3::type_list<seqan3::format_sam>>{std::ostringstream{},
-                                                                                     seqan3::format_sam{}} ));
-
+    EXPECT_NO_THROW(
+        (seqan3::sam_file_output<default_fields, seqan3::type_list<seqan3::format_sam>>{std::ostringstream{},
+                                                                                        seqan3::format_sam{}}));
 
     /* stream + format_tag + fields */
-    EXPECT_NO_THROW(( seqan3::sam_file_output<default_fields,
-                                              seqan3::type_list<seqan3::format_sam>>{std::ostringstream{},
-                                                                                     seqan3::format_sam{},
-                                                                                     default_fields{}} ));
+    EXPECT_NO_THROW(
+        (seqan3::sam_file_output<default_fields, seqan3::type_list<seqan3::format_sam>>{std::ostringstream{},
+                                                                                        seqan3::format_sam{},
+                                                                                        default_fields{}}));
 }
 
 TEST(general, default_template_args_and_deduction_guides)
@@ -132,8 +116,8 @@ TEST(general, default_template_args_and_deduction_guides)
     {
         using t = seqan3::sam_file_output<>;
         EXPECT_TRUE((std::is_same_v<typename t::selected_field_ids, comp1>));
-        EXPECT_TRUE((std::is_same_v<typename t::valid_formats,      comp2>));
-        EXPECT_TRUE((std::is_same_v<typename t::stream_char_type,   comp3>));
+        EXPECT_TRUE((std::is_same_v<typename t::valid_formats, comp2>));
+        EXPECT_TRUE((std::is_same_v<typename t::stream_char_type, comp3>));
     }
 
     /* guided filename constructor */
@@ -144,8 +128,8 @@ TEST(general, default_template_args_and_deduction_guides)
 
         using t = decltype(fout);
         EXPECT_TRUE((std::is_same_v<typename t::selected_field_ids, comp1>));
-        EXPECT_TRUE((std::is_same_v<typename t::valid_formats,      comp2>));
-        EXPECT_TRUE((std::is_same_v<typename t::stream_char_type,   comp3>));
+        EXPECT_TRUE((std::is_same_v<typename t::valid_formats, comp2>));
+        EXPECT_TRUE((std::is_same_v<typename t::stream_char_type, comp3>));
     }
 
     /* guided filename constructor + custom fields */
@@ -155,9 +139,10 @@ TEST(general, default_template_args_and_deduction_guides)
         seqan3::sam_file_output fout{filename.get_path(), seqan3::fields<seqan3::field::alignment>{}};
 
         using t = decltype(fout);
-        EXPECT_TRUE((std::is_same_v<typename t::selected_field_ids, seqan3::fields<seqan3::field::alignment>>)); // changed
-        EXPECT_TRUE((std::is_same_v<typename t::valid_formats,      comp2>));
-        EXPECT_TRUE((std::is_same_v<typename t::stream_char_type,   comp3>));
+        EXPECT_TRUE(
+            (std::is_same_v<typename t::selected_field_ids, seqan3::fields<seqan3::field::alignment>>)); // changed
+        EXPECT_TRUE((std::is_same_v<typename t::valid_formats, comp2>));
+        EXPECT_TRUE((std::is_same_v<typename t::stream_char_type, comp3>));
     }
 
     /* guided stream constructor */
@@ -167,8 +152,8 @@ TEST(general, default_template_args_and_deduction_guides)
 
         using t = decltype(fout);
         EXPECT_TRUE((std::is_same_v<typename t::selected_field_ids, comp1>));
-        EXPECT_TRUE((std::is_same_v<typename t::valid_formats,      seqan3::type_list<seqan3::format_sam>>)); // changed
-        EXPECT_TRUE((std::is_same_v<typename t::stream_char_type,   comp3>));
+        EXPECT_TRUE((std::is_same_v<typename t::valid_formats, seqan3::type_list<seqan3::format_sam>>)); // changed
+        EXPECT_TRUE((std::is_same_v<typename t::stream_char_type, comp3>));
     }
 
     /* guided stream temporary constructor */
@@ -177,8 +162,8 @@ TEST(general, default_template_args_and_deduction_guides)
 
         using t = decltype(fout);
         EXPECT_TRUE((std::is_same_v<typename t::selected_field_ids, comp1>));
-        EXPECT_TRUE((std::is_same_v<typename t::valid_formats,      seqan3::type_list<seqan3::format_sam>>)); // changed
-        EXPECT_TRUE((std::is_same_v<typename t::stream_char_type,   comp3>));
+        EXPECT_TRUE((std::is_same_v<typename t::valid_formats, seqan3::type_list<seqan3::format_sam>>)); // changed
+        EXPECT_TRUE((std::is_same_v<typename t::stream_char_type, comp3>));
     }
 }
 
@@ -215,105 +200,118 @@ void assign_impl(source_t && source)
 
 TEST(row, assign_to_iterator)
 {
-    row_wise_impl([&] (auto & file, size_t i)
-    {
-        seqan3::record<seqan3::type_list<seqan3::dna5_vector, std::string>,
-                       seqan3::fields<seqan3::field::seq, seqan3::field::id>> r{seqs[i], ids[i]};
+    row_wise_impl(
+        [&](auto & file, size_t i)
+        {
+            seqan3::record<seqan3::type_list<seqan3::dna5_vector, std::string>,
+                           seqan3::fields<seqan3::field::seq, seqan3::field::id>>
+                r{seqs[i], ids[i]};
 
-        std::ranges::begin(file) = r;
-    });
+            std::ranges::begin(file) = r;
+        });
 }
 
 TEST(row, push_back_record)
 {
-    row_wise_impl([&] (auto & file, size_t i)
-    {
-        seqan3::record<seqan3::type_list<seqan3::dna5_vector, std::string>,
-                       seqan3::fields<seqan3::field::seq, seqan3::field::id>> r{seqs[i], ids[i]};
+    row_wise_impl(
+        [&](auto & file, size_t i)
+        {
+            seqan3::record<seqan3::type_list<seqan3::dna5_vector, std::string>,
+                           seqan3::fields<seqan3::field::seq, seqan3::field::id>>
+                r{seqs[i], ids[i]};
 
-        file.push_back(r);
-    });
+            file.push_back(r);
+        });
 }
 
 TEST(row, push_back_record_rvalue)
 {
-    row_wise_impl([&] (auto & file, size_t i)
-    {
-        seqan3::record<seqan3::type_list<seqan3::dna5_vector, std::string>,
-                       seqan3::fields<seqan3::field::seq, seqan3::field::id>> r{seqs[i], ids[i]};
+    row_wise_impl(
+        [&](auto & file, size_t i)
+        {
+            seqan3::record<seqan3::type_list<seqan3::dna5_vector, std::string>,
+                           seqan3::fields<seqan3::field::seq, seqan3::field::id>>
+                r{seqs[i], ids[i]};
 
-        file.push_back(std::move(r));
-    });
+            file.push_back(std::move(r));
+        });
 }
 
 TEST(row, push_back_record_const)
 {
-    row_wise_impl([&] (auto & file, size_t i)
-    {
-        seqan3::record<seqan3::type_list<seqan3::dna5_vector, std::string>,
-                       seqan3::fields<seqan3::field::seq, seqan3::field::id>> const r{seqs[i], ids[i]};
+    row_wise_impl(
+        [&](auto & file, size_t i)
+        {
+            seqan3::record<seqan3::type_list<seqan3::dna5_vector, std::string>,
+                           seqan3::fields<seqan3::field::seq, seqan3::field::id>> const r{seqs[i], ids[i]};
 
-        file.push_back(r);
-    });
+            file.push_back(r);
+        });
 }
 
 TEST(row, push_back_record_const_element)
 {
-    row_wise_impl([&] (auto & file, size_t i)
-    {
-        seqan3::record<seqan3::type_list<seqan3::dna5_vector const, std::string const>,
-                       seqan3::fields<seqan3::field::seq, seqan3::field::id>> const r{seqs[i], ids[i]};
+    row_wise_impl(
+        [&](auto & file, size_t i)
+        {
+            seqan3::record<seqan3::type_list<seqan3::dna5_vector const, std::string const>,
+                           seqan3::fields<seqan3::field::seq, seqan3::field::id>> const r{seqs[i], ids[i]};
 
-        file.push_back(r);
-    });
+            file.push_back(r);
+        });
 }
 
 TEST(row, push_back_tuple)
 {
-    row_wise_impl([&] (auto & file, size_t i)
-    {
-        std::tuple<seqan3::dna5_vector, std::string> t{seqs[i], ids[i]};
+    row_wise_impl(
+        [&](auto & file, size_t i)
+        {
+            std::tuple<seqan3::dna5_vector, std::string> t{seqs[i], ids[i]};
 
-        file.push_back(t);
-    });
+            file.push_back(t);
+        });
 }
 
 TEST(row, push_back_tuple_rvalue)
 {
-    row_wise_impl([&] (auto & file, size_t i)
-    {
-        std::tuple<seqan3::dna5_vector, std::string> t{seqs[i], ids[i]};
+    row_wise_impl(
+        [&](auto & file, size_t i)
+        {
+            std::tuple<seqan3::dna5_vector, std::string> t{seqs[i], ids[i]};
 
-        file.push_back(std::move(t));
-    });
+            file.push_back(std::move(t));
+        });
 }
 
 TEST(row, push_back_tuple_const)
 {
-    row_wise_impl([&] (auto & file, size_t i)
-    {
-        std::tuple<seqan3::dna5_vector, std::string> const t{seqs[i], ids[i]};
+    row_wise_impl(
+        [&](auto & file, size_t i)
+        {
+            std::tuple<seqan3::dna5_vector, std::string> const t{seqs[i], ids[i]};
 
-        file.push_back(t);
-    });
+            file.push_back(t);
+        });
 }
 
 TEST(row, push_back_tuple_const_element)
 {
-    row_wise_impl([&] (auto & file, size_t i)
-    {
-        std::tuple<seqan3::dna5_vector const, std::string const> t{seqs[i], ids[i]};
+    row_wise_impl(
+        [&](auto & file, size_t i)
+        {
+            std::tuple<seqan3::dna5_vector const, std::string const> t{seqs[i], ids[i]};
 
-        file.push_back(t);
-    });
+            file.push_back(t);
+        });
 }
 
 TEST(row, emplace_back)
 {
-    row_wise_impl([&] (auto & file, size_t i)
-    {
-        file.emplace_back(seqs[i], ids[i]);
-    });
+    row_wise_impl(
+        [&](auto & file, size_t i)
+        {
+            file.emplace_back(seqs[i], ids[i]);
+        });
 }
 
 /* Here the record contains a different field composite than the file. The record knows about the
@@ -325,12 +323,12 @@ TEST(row, different_fields_in_record_and_file)
     qual.resize(seqs[1].size());
 
     seqan3::record<seqan3::type_list<std::vector<seqan3::phred42>, std::string, seqan3::dna5_vector>,
-                   seqan3::fields<seqan3::field::qual, seqan3::field::id, seqan3::field::seq>> rec{qual,
-                                                                                                   ids[1],
-                                                                                                   seqs[1]};
+                   seqan3::fields<seqan3::field::qual, seqan3::field::id, seqan3::field::seq>>
+        rec{qual, ids[1], seqs[1]};
 
-    seqan3::sam_file_output fout{std::ostringstream{}, seqan3::format_sam{}, seqan3::fields<seqan3::field::seq,
-                                                                                            seqan3::field::id>{}};
+    seqan3::sam_file_output fout{std::ostringstream{},
+                                 seqan3::format_sam{},
+                                 seqan3::fields<seqan3::field::seq, seqan3::field::id>{}};
 
     fout.emplace_back("AGGCTGNAGGCTGNA"_dna5, std::string("read1"));
     // fout.emplace_back("AGGCTGNAGGCTGNA"_dna5, "read1"); // const char * is not allowed
@@ -338,11 +336,8 @@ TEST(row, different_fields_in_record_and_file)
 
     fout.get_stream().flush();
 
-    std::string const expected_out
-    {
-        "read1\t0\t*\t0\t0\t*\t*\t0\t0\tAGGCTGNAGGCTGNA\t*\n"
-        "read2\t0\t*\t0\t0\t*\t*\t0\t0\tAGGCTGNAGGCTGNA\t!!!!!!!!!!!!!!!\n"
-    };
+    std::string const expected_out{"read1\t0\t*\t0\t0\t*\t*\t0\t0\tAGGCTGNAGGCTGNA\t*\n"
+                                   "read2\t0\t*\t0\t0\t*\t*\t0\t0\tAGGCTGNAGGCTGNA\t!!!!!!!!!!!!!!!\n"};
 
     EXPECT_EQ(reinterpret_cast<std::ostringstream &>(fout.get_stream()).str(), expected_out);
 }
@@ -350,7 +345,7 @@ TEST(row, different_fields_in_record_and_file)
 TEST(row, print_header_in_file)
 {
     std::vector<std::string> ref_ids{"ref1", "ref2"};
-    std::vector<int32_t>     ref_len{234511, 243243};
+    std::vector<int32_t> ref_len{234511, 243243};
 
     seqan3::sam_file_output fout{std::ostringstream{},
                                  ref_ids,
@@ -362,8 +357,7 @@ TEST(row, print_header_in_file)
 
     fout.get_stream().flush();
 
-    std::string const expected_out
-    {
+    std::string const expected_out{
         "@HD\tVN:1.6\n"
         "@SQ\tSN:ref1\tLN:234511\n"
         "@SQ\tSN:ref2\tLN:243243\n"
@@ -376,7 +370,7 @@ TEST(row, print_header_in_file)
 TEST(row, print_header_in_record)
 {
     std::vector<std::string> const ref_ids{"ref1", "ref2"};
-    std::vector<int32_t>     const ref_len{234511, 243243};
+    std::vector<int32_t> const ref_len{234511, 243243};
 
     seqan3::sam_file_header header{ref_ids};
 
@@ -395,11 +389,10 @@ TEST(row, print_header_in_record)
 
         fout.get_stream().flush();
 
-        std::string const expected_out
-        {
-           "@HD\tVN:1.6\n"
-           "@SQ\tSN:ref1\tLN:234511\n"
-           "@SQ\tSN:ref2\tLN:243243\n"
+        std::string const expected_out{
+            "@HD\tVN:1.6\n"
+            "@SQ\tSN:ref1\tLN:234511\n"
+            "@SQ\tSN:ref2\tLN:243243\n"
             "*\t0\t*\t0\t0\t*\t*\t0\t0\t*\t*\n" // empty read
         };
 
@@ -418,11 +411,10 @@ TEST(row, print_header_in_record)
 
         fout.get_stream().flush();
 
-        std::string const expected_out
-        {
-           "@HD\tVN:1.6\n"
-           "@SQ\tSN:ref1\tLN:234511\n"
-           "@SQ\tSN:ref2\tLN:243243\n"
+        std::string const expected_out{
+            "@HD\tVN:1.6\n"
+            "@SQ\tSN:ref1\tLN:234511\n"
+            "@SQ\tSN:ref2\tLN:243243\n"
             "*\t0\t*\t0\t0\t*\t*\t0\t0\t*\t*\n" // empty read
         };
 
@@ -437,7 +429,8 @@ TEST(row, print_header_in_record)
 TEST(rows, assign_range_of_records)
 {
     std::vector<seqan3::record<seqan3::type_list<seqan3::dna5_vector, std::string>,
-                               seqan3::fields<seqan3::field::seq, seqan3::field::id>>> range;
+                               seqan3::fields<seqan3::field::seq, seqan3::field::id>>>
+        range;
 
     for (size_t i = 0; i < 3; ++i)
         range.emplace_back(seqs[i], ids[i]);
@@ -448,7 +441,8 @@ TEST(rows, assign_range_of_records)
 TEST(rows, assign_range_of_records_const)
 {
     std::vector<seqan3::record<seqan3::type_list<seqan3::dna5_vector, std::string>,
-                               seqan3::fields<seqan3::field::seq, seqan3::field::id>>> range;
+                               seqan3::fields<seqan3::field::seq, seqan3::field::id>>>
+        range;
 
     for (size_t i = 0; i < 3; ++i)
         range.emplace_back(seqs[i], ids[i]);
@@ -472,7 +466,7 @@ TEST(rows, assign_sam_file_input)
     std::vector<seqan3::dna4_vector> ref_seqs{"ACTAGCTAGGAGGACTAGCATCGATC"_dna4};
 
     std::string comp =
-R"(@HD	VN:1.6	SO:unknown	GO:none
+        R"(@HD	VN:1.6	SO:unknown	GO:none
 @SQ	SN:ref	LN:26
 @PG	ID:prog1	PN:cool_program
 @CO	This is a comment.
@@ -512,7 +506,7 @@ TEST(rows, assign_sam_file_pipes)
     std::vector<seqan3::dna4_vector> const ref_seqs{"ACTAGCTAGGAGGACTAGCATCGATC"_dna4};
 
     std::string comp =
-R"(@HD	VN:1.6	SO:unknown	GO:none
+        R"(@HD	VN:1.6	SO:unknown	GO:none
 @SQ	SN:ref	LN:26
 @PG	ID:prog1	PN:cool_program
 @CO	This is a comment.
@@ -540,7 +534,7 @@ TEST(rows, write_bam_file)
     std::vector<seqan3::dna4_vector> const ref_seqs{"ACTAGCTAGGAGGACTAGCATCGATC"_dna4};
 
     std::string comp =
-R"(@HD	VN:1.6	SO:unknown	GO:none
+        R"(@HD	VN:1.6	SO:unknown	GO:none
 @SQ	SN:ref	LN:26
 @PG	ID:prog1	PN:cool_program
 @CO	This is a comment.
@@ -581,16 +575,17 @@ std::string compression_by_filename_impl(seqan3::test::tmp_filename & filename)
         // explicitly only test compression on sam format
         seqan3::sam_file_output<typename seqan3::sam_file_output<>::selected_field_ids,
                                 seqan3::type_list<seqan3::format_sam>,
-                                seqan3::ref_info_not_given> fout{filename.get_path()};
+                                seqan3::ref_info_not_given>
+            fout{filename.get_path()};
 
         for (size_t i = 0; i < 3; ++i)
         {
             seqan3::record<seqan3::type_list<seqan3::dna5_vector, std::string>,
-                           seqan3::fields<seqan3::field::seq, seqan3::field::id>> r{seqs[i], ids[i]};
+                           seqan3::fields<seqan3::field::seq, seqan3::field::id>>
+                r{seqs[i], ids[i]};
 
             fout.push_back(r);
         }
-
     }
 
     std::string buffer{};
@@ -612,25 +607,23 @@ void compression_by_stream_impl(comp_stream_t & stream)
     for (size_t i = 0; i < 3; ++i)
     {
         seqan3::record<seqan3::type_list<seqan3::dna5_vector, std::string>,
-                       seqan3::fields<seqan3::field::seq, seqan3::field::id>> r{seqs[i], ids[i]};
+                       seqan3::fields<seqan3::field::seq, seqan3::field::id>>
+            r{seqs[i], ids[i]};
 
         fout.push_back(r);
     }
 }
 
 #if defined(SEQAN3_HAS_ZLIB)
-std::string expected_gz
-{
-    '\x1F', '\x8B', '\x08', '\x00', '\x00', '\x00', '\x00', '\x00', '\x00', '\x00', '\x2B', '\x4A', '\x4D',
-    '\x4C', '\x31', '\xE4', '\x34', '\xE0', '\xD4', '\x02', '\x62', '\x10', '\x09', '\xA1', '\x1D', '\x9D',
-    '\xDD', '\x43', '\x38', '\xB5', '\xB8', '\x8A', '\x80', '\x92', '\x46', '\x98', '\x92', '\xEE', '\xEE',
-    '\xCE', '\x21', '\xEE', '\x7E', '\x30', '\x0A', '\xAA', '\xCE', '\x18', '\x43', '\x9D', '\xBB', '\xBB',
-    '\xA3', '\x7B', '\x88', '\x63', '\x88', '\xA3', '\x63', '\x08', '\x2A', '\x04', '\x6A', '\x00', '\x00',
-    '\x7E', '\x6C', '\x6C', '\x0F', '\x76', '\x00', '\x00', '\x00'
-};
+std::string expected_gz{'\x1F', '\x8B', '\x08', '\x00', '\x00', '\x00', '\x00', '\x00', '\x00', '\x00', '\x2B',
+                        '\x4A', '\x4D', '\x4C', '\x31', '\xE4', '\x34', '\xE0', '\xD4', '\x02', '\x62', '\x10',
+                        '\x09', '\xA1', '\x1D', '\x9D', '\xDD', '\x43', '\x38', '\xB5', '\xB8', '\x8A', '\x80',
+                        '\x92', '\x46', '\x98', '\x92', '\xEE', '\xEE', '\xCE', '\x21', '\xEE', '\x7E', '\x30',
+                        '\x0A', '\xAA', '\xCE', '\x18', '\x43', '\x9D', '\xBB', '\xBB', '\xA3', '\x7B', '\x88',
+                        '\x63', '\x88', '\xA3', '\x63', '\x08', '\x2A', '\x04', '\x6A', '\x00', '\x00', '\x7E',
+                        '\x6C', '\x6C', '\x0F', '\x76', '\x00', '\x00', '\x00'};
 
-std::string expected_bgzf
-{
+std::string expected_bgzf{
     '\x1F', '\x8B', '\x08', '\x04', '\x00', '\x00', '\x00', '\x00', '\x00', '\x00', '\x06', '\x00', '\x42', '\x43',
     '\x02', '\x00', '\x50', '\x00', '\x2B', '\x4A', '\x4D', '\x4C', '\x31', '\xE4', '\x34', '\xE0', '\xD4', '\x02',
     '\x62', '\x10', '\x09', '\xA1', '\x1D', '\x9D', '\xDD', '\x43', '\x38', '\xB5', '\xB8', '\x8A', '\x80', '\x92',
@@ -638,8 +631,7 @@ std::string expected_bgzf
     '\x18', '\x43', '\x9D', '\xBB', '\xBB', '\xA3', '\x7B', '\x88', '\x63', '\x88', '\x23', '\x10', '\xA1', '\x40',
     '\xA0', '\x06', '\x00', '\x7E', '\x6C', '\x6C', '\x0F', '\x76', '\x00', '\x00', '\x00', '\x1F', '\x8B', '\x08',
     '\x04', '\x00', '\x00', '\x00', '\x00', '\x00', '\xFF', '\x06', '\x00', '\x42', '\x43', '\x02', '\x00', '\x1B',
-    '\x00', '\x03', '\x00', '\x00', '\x00', '\x00', '\x00', '\x00', '\x00', '\x00', '\x00'
-};
+    '\x00', '\x03', '\x00', '\x00', '\x00', '\x00', '\x00', '\x00', '\x00', '\x00', '\x00'};
 
 TEST(compression, by_filename_gz)
 {
@@ -687,16 +679,14 @@ TEST(compression, by_stream_bgzf)
 #endif
 
 #if defined(SEQAN3_HAS_BZIP2)
-std::string expected_bz2
-{
-    '\x42', '\x5A', '\x68', '\x39', '\x31', '\x41', '\x59', '\x26', '\x53', '\x59', '\xEA', '\x2B', '\x97',
-    '\x64', '\x00', '\x00', '\x39', '\xDF', '\x80', '\x00', '\x30', '\x00', '\x10', '\x78', '\x00', '\x28',
-    '\x81', '\x04', '\x00', '\x26', '\x00', '\x10', '\x00', '\x20', '\x00', '\x48', '\x45', '\x4D', '\xAA',
-    '\x31', '\x0C', '\x80', '\xC5', '\x19', '\x06', '\x86', '\x48', '\x31', '\xF0', '\xCC', '\x6F', '\x8C',
-    '\xDC', '\x78', '\x1B', '\x38', '\x51', '\xDB', '\xAE', '\xA5', '\x5B', '\x50', '\x0E', '\xCA', '\x49',
-    '\x44', '\x35', '\x4C', '\x12', '\x41', '\x20', '\x6C', '\x24', '\xC9', '\xA3', '\x47', '\xE2', '\xEE',
-    '\x48', '\xA7', '\x0A', '\x12', '\x1D', '\x45', '\x72', '\xEC', '\x80'
-};
+std::string expected_bz2{'\x42', '\x5A', '\x68', '\x39', '\x31', '\x41', '\x59', '\x26', '\x53', '\x59', '\xEA',
+                         '\x2B', '\x97', '\x64', '\x00', '\x00', '\x39', '\xDF', '\x80', '\x00', '\x30', '\x00',
+                         '\x10', '\x78', '\x00', '\x28', '\x81', '\x04', '\x00', '\x26', '\x00', '\x10', '\x00',
+                         '\x20', '\x00', '\x48', '\x45', '\x4D', '\xAA', '\x31', '\x0C', '\x80', '\xC5', '\x19',
+                         '\x06', '\x86', '\x48', '\x31', '\xF0', '\xCC', '\x6F', '\x8C', '\xDC', '\x78', '\x1B',
+                         '\x38', '\x51', '\xDB', '\xAE', '\xA5', '\x5B', '\x50', '\x0E', '\xCA', '\x49', '\x44',
+                         '\x35', '\x4C', '\x12', '\x41', '\x20', '\x6C', '\x24', '\xC9', '\xA3', '\x47', '\xE2',
+                         '\xEE', '\x48', '\xA7', '\x0A', '\x12', '\x1D', '\x45', '\x72', '\xEC', '\x80'};
 
 TEST(compression, by_filename_bz2)
 {
