@@ -1,20 +1,20 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
 
-#include <sstream>
-
 #include <gtest/gtest.h>
 
+#include <algorithm>
+#include <sstream>
+
+#include <seqan3/io/sequence_file/format_embl.hpp>
 #include <seqan3/io/sequence_file/input.hpp>
 #include <seqan3/io/sequence_file/input_format_concept.hpp>
 #include <seqan3/io/sequence_file/output.hpp>
 #include <seqan3/io/sequence_file/output_format_concept.hpp>
-#include <seqan3/io/sequence_file/format_embl.hpp>
-#include <seqan3/std/algorithm>
 #include <seqan3/test/pretty_printing.hpp>
 
 #include "sequence_file_format_test_template.hpp"
@@ -22,9 +22,8 @@
 template <>
 struct sequence_file_read<seqan3::format_embl> : public sequence_file_data
 {
-    std::string standard_input
-    {
-R"(ID ID1;	 stuff
+    std::string standard_input{
+        R"(ID ID1;	 stuff
 SQ Sequence 1859 BP; 609 A; 314 C; 355 G; 581 T; 0 other;
   ACGTTTTTTT TTTTTTTT        18
 //
@@ -36,20 +35,16 @@ TTTTTTTTTT TTTTTTTTTT TT        82
 ID ID3 lala;
 SQ Sequence 1859 BP; 609 A; 314 C; 355 G; 581 T; 0 other;
   ACGTTTA        7
-//)"
-    };
+//)"};
 
-    std::string illegal_alphabet_character_input
-    {
-R"(ID ID1;	 stuff
+    std::string illegal_alphabet_character_input{
+        R"(ID ID1;	 stuff
 SQ Sequence 1859 BP; 609 A; 314 C; 355 G; 581 T; 0 other;
   AXGTTTTTTT TTTTTTTT        18
-//)"
-    };
+//)"};
 
-    std::string standard_output
-    {
-R"(ID ID1; 18 BP.
+    std::string standard_output{
+        R"(ID ID1; 18 BP.
 SQ Sequence 18 BP;
 ACGTTTTTTT TTTTTTTT                                               18
 //
@@ -62,16 +57,13 @@ ID ID3 lala; 7 BP.
 SQ Sequence 7 BP;
 ACGTTTA                                                           7
 //
-)"
-    };
+)"};
 
-    std::string no_or_ill_formatted_id_input
-    {
-R"(IK ID1;   stuff
+    std::string no_or_ill_formatted_id_input{
+        R"(IK ID1;   stuff
 SQ Sequence 1859 BP; 609 A; 314 C; 355 G; 581 T; 0 other;
   ACGTTTTTTT TTTTTTTT        18
-//)"
-    };
+//)"};
 };
 
 // ---------------------------------------------------------------------------------------------------------------------
@@ -87,9 +79,8 @@ INSTANTIATE_TYPED_TEST_SUITE_P(embl, sequence_file_write, seqan3::format_embl, )
 
 struct read : public sequence_file_data
 {
-    std::string input
-    {
-R"(ID ID1;	stuff
+    std::string input{
+        R"(ID ID1;	stuff
 SQ Sequence 1859 BP; 609 A; 314 C; 355 G; 581 T; 0 other;
   ACGTTTTTTT TTTTTTTT        18
 //
@@ -101,8 +92,7 @@ TTTTTTTTTT TTTTTTTTTT TT        82
 ID ID3 lala;
 SQ Sequence 1859 BP; 609 A; 314 C; 355 G; 581 T; 0 other;
   ACGTTTA        7
-//)"
-    };
+//)"};
 
     seqan3::sequence_file_input_options<seqan3::dna15> options{};
 
@@ -110,8 +100,9 @@ SQ Sequence 1859 BP; 609 A; 314 C; 355 G; 581 T; 0 other;
     {
         std::stringstream istream{input};
 
-        seqan3::sequence_file_input fin{istream, seqan3::format_embl{}, seqan3::fields<seqan3::field::id,
-                                                                                       seqan3::field::seq>{}};
+        seqan3::sequence_file_input fin{istream,
+                                        seqan3::format_embl{},
+                                        seqan3::fields<seqan3::field::id, seqan3::field::seq>{}};
         fin.options = options;
 
         auto it = fin.begin();
@@ -125,9 +116,8 @@ SQ Sequence 1859 BP; 609 A; 314 C; 355 G; 581 T; 0 other;
 
 TEST_F(read, complete_header)
 {
-    std::string input
-    {
-R"(ID ID1;	Stuff
+    std::string input{
+        R"(ID ID1;	Stuff
 SQ Sequence 1859 BP; 609 A; 314 C; 355 G; 581 T; 0 other;
   ACGTTTTTTT TTTTTTTT        18
 //
@@ -142,8 +132,7 @@ AC   AB000263;
 XX
 SQ Sequence 1859 BP; 609 A; 314 C; 355 G; 581 T; 0 other;
   ACGTTTA        7
-//)"
-    };
+//)"};
 
     options.embl_genbank_complete_header = true;
     ids[0] = "ID ID1;\tStuff\n";
@@ -154,9 +143,8 @@ SQ Sequence 1859 BP; 609 A; 314 C; 355 G; 581 T; 0 other;
 
 TEST_F(read, multiple_lines_before_seq)
 {
-    std::string input
-    {
-R"(ID ID1;	Stuff
+    std::string input{
+        R"(ID ID1;	Stuff
 XX
 XX
 XX
@@ -171,8 +159,7 @@ TTTTTTTTTT TTTTTTTTTT TT        82
 ID ID3 lala;
 SQ Sequence 1859 BP; 609 A; 314 C; 355 G; 581 T; 0 other;
   ACGTTTA        7
-//)"
-    };
+//)"};
 
     do_read_test(input);
 }
@@ -183,23 +170,15 @@ SQ Sequence 1859 BP; 609 A; 314 C; 355 G; 581 T; 0 other;
 
 struct write : public ::testing::Test
 {
-    std::vector<seqan3::dna5_vector> seqs
-    {
+    std::vector<seqan3::dna5_vector> seqs{
         "ACGT"_dna5,
         "AGGCTGNAGGCTGNAGGCTGNAGGCTGNAGGCTGNAGGCTGNAGGCTGNAGGCTGNAGGCTGNAGGCTGNAGGCTGNAGGCTGNAGGCTGN"_dna5,
-        "GGAGTATAATATATATATATATAT"_dna5
-    };
+        "GGAGTATAATATATATATATATAT"_dna5};
 
-    std::vector<std::string> ids
-    {
-        "TEST 1",
-        "Test2",
-        "Test3"
-    };
+    std::vector<std::string> ids{"TEST 1", "Test2", "Test3"};
 
-	std::string comp
-    {
-R"(ID TEST 1; 4 BP.
+    std::string comp{
+        R"(ID TEST 1; 4 BP.
 SQ Sequence 4 BP;
 ACGT                                                              4
 //
@@ -212,8 +191,7 @@ ID Test3; 24 BP.
 SQ Sequence 24 BP;
 GGAGTATAAT ATATATATAT ATAT                                        24
 //
-)"
-    };
+)"};
 
     seqan3::sequence_file_output_options options{};
 
@@ -221,8 +199,9 @@ GGAGTATAAT ATATATATAT ATAT                                        24
 
     void do_write_test()
     {
-        seqan3::sequence_file_output fout{ostream, seqan3::format_embl{}, seqan3::fields<seqan3::field::seq,
-                                                                                         seqan3::field::id>{}};
+        seqan3::sequence_file_output fout{ostream,
+                                          seqan3::format_embl{},
+                                          seqan3::fields<seqan3::field::seq, seqan3::field::id>{}};
         fout.options = options;
 
         for (unsigned i = 0; i < 3; ++i)
@@ -234,9 +213,8 @@ GGAGTATAAT ATATATATAT ATAT                                        24
 
 TEST_F(write, complete_header)
 {
-    std::string comp
-    {
-R"(ID TEST 1; 4 BP.
+    std::string comp{
+        R"(ID TEST 1; 4 BP.
 XX
 SQ Sequence 4 BP;
 ACGT                                                              4
@@ -252,8 +230,7 @@ XX
 SQ Sequence 24 BP;
 GGAGTATAAT ATATATATAT ATAT                                        24
 //
-)"
-    };
+)"};
     options.embl_genbank_complete_header = true;
     ids[0] = std::string{"ID TEST 1; 4 BP.\nXX\n"};
     ids[1] = std::string{"ID Test2; 91 BP.\nXX\n"};
