@@ -1,14 +1,14 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
 
 #include <gtest/gtest.h>
 
-#include <seqan3/std/algorithm>
-#include <seqan3/std/iterator>
+#include <algorithm>
+#include <iterator>
 #include <set>
 #include <sstream>
 #include <tuple>
@@ -44,61 +44,46 @@ TEST(general, concepts)
 
 struct read : public ::testing::Test
 {
-    std::string input
-    {
-        "> S.cerevisiae_tRNA-PHE M10740/1-73\n"
-        "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
-        "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))). (-17.50)\n"
-        "> example 2\n"
-        "UUGGAGUACACAACCUGUACACUCUUUC\n"
-        "..(((((..(((...)))..)))))... (-3.71)\n"
-    };
+    std::string input{"> S.cerevisiae_tRNA-PHE M10740/1-73\n"
+                      "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
+                      "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))). (-17.50)\n"
+                      "> example 2\n"
+                      "UUGGAGUACACAACCUGUACACUCUUUC\n"
+                      "..(((((..(((...)))..)))))... (-3.71)\n"};
 
-    std::vector<std::string> expected_id
-    {
-        { "S.cerevisiae_tRNA-PHE M10740/1-73" },
-        { "example 2" }
-    };
+    std::vector<std::string> expected_id{{"S.cerevisiae_tRNA-PHE M10740/1-73"}, {"example 2"}};
 
-    std::vector<seqan3::rna5_vector> const expected_seq
-    {
-        { "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA"_rna5 },
-        { "UUGGAGUACACAACCUGUACACUCUUUC"_rna5 }
-    };
+    std::vector<seqan3::rna5_vector> const expected_seq{
+        {"GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA"_rna5},
+        {"UUGGAGUACACAACCUGUACACUCUUUC"_rna5}};
 
-    std::vector<std::vector<seqan3::wuss<51>>> const expected_structure
-    {
-        { "(((((((..((((........)))).((((.........)))).....(((((.......))))))))))))."_wuss51 },
-        { "..(((((..(((...)))..)))))..."_wuss51 }
-    };
+    std::vector<std::vector<seqan3::wuss<51>>> const expected_structure{
+        {"(((((((..((((........)))).((((.........)))).....(((((.......))))))))))))."_wuss51},
+        {"..(((((..(((...)))..)))))..."_wuss51}};
 
-    std::vector<double> const expected_energy
-    {
-        -17.5, -3.71
-    };
+    std::vector<double> const expected_energy{-17.5, -3.71};
 
-    std::vector<std::vector<uint8_t>> const expected_interactions
-    {
-        {
-            71, 70, 69, 68, 67, 66, 65, 24, 23, 22, 21, 12, 11, 10,  9, 42, 41, 40, 39, 29,
-            28, 27, 26, 64, 63, 62, 61, 60, 52, 51, 50, 49, 48,  6,  5,  4,  3,  2,  1,  0
-        },
-        {
-            24, 23, 22, 21, 20, 17, 16, 15, 11, 10,  9,  6,  5,  4,  3,  2
-        }
-    };
+    std::vector<std::vector<uint8_t>> const expected_interactions{
+        {71, 70, 69, 68, 67, 66, 65, 24, 23, 22, 21, 12, 11, 10, 9, 42, 41, 40, 39, 29,
+         28, 27, 26, 64, 63, 62, 61, 60, 52, 51, 50, 49, 48, 6,  5, 4,  3,  2,  1,  0},
+        {24, 23, 22, 21, 20, 17, 16, 15, 11, 10, 9, 6, 5, 4, 3, 2}};
 
     seqan3::structure_file_input_options<seqan3::rna15, false> options;
 
     bool check_seq = true;
     bool check_id = true;
     bool check_structure = true;
-    bool check_energy= true;
+    bool check_energy = true;
 
     void bpp_test(std::vector<std::set<std::pair<double, size_t>>> & bpp, std::vector<uint8_t> const & bpp_comp)
     {
         size_t cnt = 0ul;
-        auto interaction_sets = bpp | std::views::filter([] (auto & set) { return set.size() == 1; });
+        auto interaction_sets = bpp
+                              | std::views::filter(
+                                    [](auto & set)
+                                    {
+                                        return set.size() == 1;
+                                    });
         for (auto & iset : interaction_sets)
         {
             EXPECT_EQ(iset.size(), 1u);
@@ -155,93 +140,76 @@ TEST_F(read, standard)
 
 TEST_F(read, newline_before_eof)
 {
-    input =
-    {
-        "> S.cerevisiae_tRNA-PHE M10740/1-73\n"
-        "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
-        "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))). (-17.50)\n"
-        "> example 2\n"
-        "UUGGAGUACACAACCUGUACACUCUUUC\n"
-        "..(((((..(((...)))..)))))... (-3.71)"
-    };
+    input = {"> S.cerevisiae_tRNA-PHE M10740/1-73\n"
+             "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
+             "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))). (-17.50)\n"
+             "> example 2\n"
+             "UUGGAGUACACAACCUGUACACUCUUUC\n"
+             "..(((((..(((...)))..)))))... (-3.71)"};
     do_read_test(input);
 }
 
 TEST_F(read, whitespace_in_seq)
 {
-    input =
-    {
-        "> S.cerevisiae_tRNA-PHE M10740/1-73\n"
-        "GCGGAUUUAGCU CAGUUGGGAGAGCGCCAGACU GAAGAUUUGGAGGUC CUGUGUUCGAUCCACA   GAAUU CGCA\n"
-        "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))). (-17.50)\n"
-        "> example 2\n"
-        "UUGGAGUAC   ACAACCUGUACAC UCUUUC \n"
-        "..(((((..(((...)))..)))))... (-3.71)\n"
-    };
+    input = {"> S.cerevisiae_tRNA-PHE M10740/1-73\n"
+             "GCGGAUUUAGCU CAGUUGGGAGAGCGCCAGACU GAAGAUUUGGAGGUC CUGUGUUCGAUCCACA   GAAUU CGCA\n"
+             "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))). (-17.50)\n"
+             "> example 2\n"
+             "UUGGAGUAC   ACAACCUGUACAC UCUUUC \n"
+             "..(((((..(((...)))..)))))... (-3.71)\n"};
     do_read_test(input);
 }
 
 TEST_F(read, no_energies)
 {
     check_energy = false;
-    input =
-    {
-        "> S.cerevisiae_tRNA-PHE M10740/1-73\n"
-        "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
-        "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))).\n"
-        "> example 2\n"
-        "UUGGAGUACACAACCUGUACACUCUUUC\n"
-        "..(((((..(((...)))..)))))...\n"
-    };
+    input = {"> S.cerevisiae_tRNA-PHE M10740/1-73\n"
+             "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
+             "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))).\n"
+             "> example 2\n"
+             "UUGGAGUACACAACCUGUACACUCUUUC\n"
+             "..(((((..(((...)))..)))))...\n"};
     do_read_test(input);
 }
 
 TEST_F(read, no_ids)
 {
     check_id = false;
-    input =
-    {
-        "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
-        "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))). (-17.50)\n"
-        "UUGGAGUACACAACCUGUACACUCUUUC\n"
-        "..(((((..(((...)))..)))))... (-3.71)\n"
-    };
+    input = {"GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
+             "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))). (-17.50)\n"
+             "UUGGAGUACACAACCUGUACACUCUUUC\n"
+             "..(((((..(((...)))..)))))... (-3.71)\n"};
     do_read_test(input);
 }
 
 TEST_F(read, spaces_and_carriage_return)
 {
     check_id = false;
-    input =
-    {
-        "> S.cerevisiae_tRNA-PHE M10740/1-73\r\n"
-        "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\r\n"
-        "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))). (-17.5)\r\n"
-        ">example 2\r\n"
-        "UUGGAGUA CACAACCUGUACA  CUCU UUC \r\n"
-        "..(((((..(((...)))..)))))...     ( -3.71 )\r\n"
-    };
+    input = {"> S.cerevisiae_tRNA-PHE M10740/1-73\r\n"
+             "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\r\n"
+             "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))). (-17.5)\r\n"
+             ">example 2\r\n"
+             "UUGGAGUA CACAACCUGUACA  CUCU UUC \r\n"
+             "..(((((..(((...)))..)))))...     ( -3.71 )\r\n"};
     do_read_test(input);
 }
 
 TEST_F(read, options_truncate_ids)
 {
-    input =
-    {
-        "> S.cerevisiae_tRNA-PHE M10740/1-73\n"
-        "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
-        "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))). (-17.50)\n"
-        "> example 2\n"
-        "UUGGAGUACACAACCUGUACACUCUUUC\n"
-        "..(((((..(((...)))..)))))... (-3.71)\n"
-    };
+    input = {"> S.cerevisiae_tRNA-PHE M10740/1-73\n"
+             "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
+             "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))). (-17.50)\n"
+             "> example 2\n"
+             "UUGGAGUACACAACCUGUACACUCUUUC\n"
+             "..(((((..(((...)))..)))))... (-3.71)\n"};
 
     options.truncate_ids = true;
     expected_id = {"S.cerevisiae_tRNA-PHE", "example"};
     do_read_test(input);
 }
 
-struct read_fields : public read {};
+struct read_fields : public read
+{};
 
 TEST_F(read_fields, only_seq)
 {
@@ -299,7 +267,8 @@ TEST_F(read_fields, only_bpp)
     }
 }
 
-struct read_fail : public read {};
+struct read_fail : public read
+{};
 
 TEST_F(read_fail, wrong_id)
 {
@@ -311,11 +280,8 @@ TEST_F(read_fail, wrong_id)
 
 TEST_F(read_fail, missing_seq)
 {
-    input =
-    {
-        "> S.cerevisiae_tRNA-PHE M10740/1-73\n"
-        "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))). (-17.50)\n"
-    };
+    input = {"> S.cerevisiae_tRNA-PHE M10740/1-73\n"
+             "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))). (-17.50)\n"};
     std::stringstream istream{input};
     seqan3::structure_file_input fin{istream, seqan3::format_vienna{}};
     EXPECT_THROW(fin.begin(), seqan3::parse_error);
@@ -323,13 +289,10 @@ TEST_F(read_fail, missing_seq)
 
 TEST_F(read_fail, missing_structure)
 {
-    input =
-    {
-        "> S.cerevisiae_tRNA-PHE M10740/1-73\n"
-        "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
-        "> example 2\n"
-        "UUGGAGUACACAACCUGUACACUCUUUC\n"
-    };
+    input = {"> S.cerevisiae_tRNA-PHE M10740/1-73\n"
+             "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
+             "> example 2\n"
+             "UUGGAGUACACAACCUGUACACUCUUUC\n"};
     std::stringstream istream{input};
     seqan3::structure_file_input fin{istream, seqan3::format_vienna{}};
     EXPECT_THROW(fin.begin(), seqan3::parse_error);
@@ -337,11 +300,8 @@ TEST_F(read_fail, missing_structure)
 
 TEST_F(read_fail, missing_structure_and_id)
 {
-    input =
-    {
-        "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
-        "UUGGAGUACACAACCUGUACACUCUUUC\n"
-    };
+    input = {"GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
+             "UUGGAGUACACAACCUGUACACUCUUUC\n"};
     std::stringstream istream{input};
     seqan3::structure_file_input fin{istream, seqan3::format_vienna{}};
     EXPECT_THROW(fin.begin(), seqan3::parse_error);
@@ -349,12 +309,9 @@ TEST_F(read_fail, missing_structure_and_id)
 
 TEST_F(read_fail, structure_too_long)
 {
-    input =
-    {
-        "> S.cerevisiae_tRNA-PHE M10740/1-73\n"
-        "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
-        "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))).. (-17.50)\n"
-    };
+    input = {"> S.cerevisiae_tRNA-PHE M10740/1-73\n"
+             "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
+             "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))).. (-17.50)\n"};
     std::stringstream istream{input};
     seqan3::structure_file_input fin{istream, seqan3::format_vienna{}};
     EXPECT_THROW(fin.begin(), seqan3::parse_error);
@@ -362,12 +319,9 @@ TEST_F(read_fail, structure_too_long)
 
 TEST_F(read_fail, structure_too_short)
 {
-    input =
-    {
-        "> S.cerevisiae_tRNA-PHE M10740/1-73\n"
-        "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
-        "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))) (-17.50)\n"
-    };
+    input = {"> S.cerevisiae_tRNA-PHE M10740/1-73\n"
+             "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
+             "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))) (-17.50)\n"};
     std::stringstream istream{input};
     seqan3::structure_file_input fin{istream, seqan3::format_vienna{}};
     EXPECT_THROW(fin.begin(), seqan3::parse_error);
@@ -375,12 +329,9 @@ TEST_F(read_fail, structure_too_short)
 
 TEST_F(read_fail, structure_too_long_structured_seq)
 {
-    input =
-    {
-        "> S.cerevisiae_tRNA-PHE M10740/1-73\n"
-        "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
-        "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))).. (-17.50)\n"
-    };
+    input = {"> S.cerevisiae_tRNA-PHE M10740/1-73\n"
+             "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
+             "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))).. (-17.50)\n"};
     std::stringstream istream{input};
     seqan3::structure_file_input fin{istream, seqan3::format_vienna{}, seqan3::fields<seqan3::field::structured_seq>{}};
     EXPECT_THROW(fin.begin(), seqan3::parse_error);
@@ -388,12 +339,9 @@ TEST_F(read_fail, structure_too_long_structured_seq)
 
 TEST_F(read_fail, structure_too_short_structured_seq)
 {
-    input =
-    {
-        "> S.cerevisiae_tRNA-PHE M10740/1-73\n"
-        "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
-        "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))) (-17.50)\n"
-    };
+    input = {"> S.cerevisiae_tRNA-PHE M10740/1-73\n"
+             "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
+             "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))) (-17.50)\n"};
     std::stringstream istream{input};
     seqan3::structure_file_input fin{istream, seqan3::format_vienna{}, seqan3::fields<seqan3::field::structured_seq>{}};
     EXPECT_THROW(fin.begin(), seqan3::parse_error);
@@ -401,12 +349,9 @@ TEST_F(read_fail, structure_too_short_structured_seq)
 
 TEST_F(read_fail, wrong_char)
 {
-    input =
-    {
-        "> S.cerevisiae_tRNA-PHE M10740/1-73\n"
-        "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUICUGUGUUCGAUCCACAGAAUUCGCA\n"
-        "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))). (-17.50)\n"
-    };
+    input = {"> S.cerevisiae_tRNA-PHE M10740/1-73\n"
+             "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUICUGUGUUCGAUCCACAGAAUUCGCA\n"
+             "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))). (-17.50)\n"};
     std::stringstream istream{input};
     seqan3::structure_file_input fin{istream, seqan3::format_vienna{}};
     EXPECT_THROW(fin.begin(), seqan3::parse_error);
@@ -418,184 +363,164 @@ TEST_F(read_fail, wrong_char)
 
 struct write : public ::testing::Test
 {
-    std::vector<std::string> id
-    {
-        { "S.cerevisiae_tRNA-PHE M10740/1-73" },
-        { "example 2" }
-    };
+    std::vector<std::string> id{{"S.cerevisiae_tRNA-PHE M10740/1-73"}, {"example 2"}};
 
-    std::vector<seqan3::rna5_vector> const seq
-    {
-        { "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA"_rna5 },
-        { "UUGGAGUACACAACCUGUACACUCUUUC"_rna5 }
-    };
+    std::vector<seqan3::rna5_vector> const seq{
+        {"GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA"_rna5},
+        {"UUGGAGUACACAACCUGUACACUCUUUC"_rna5}};
 
-    std::vector<std::vector<seqan3::wuss<51>>> const structure
-    {
-        { "(((((((..((((........)))).((((.........)))).....(((((.......))))))))))))."_wuss51 },
-        { "..(((((..(((...)))..)))))..."_wuss51 }
-    };
+    std::vector<std::vector<seqan3::wuss<51>>> const structure{
+        {"(((((((..((((........)))).((((.........)))).....(((((.......))))))))))))."_wuss51},
+        {"..(((((..(((...)))..)))))..."_wuss51}};
 
-    std::vector<float> const energy
-    {
-        -17.5f, -3.71f
-    };
+    std::vector<float> const energy{-17.5f, -3.71f};
 
     std::ostringstream ostream;
 };
 
 TEST_F(write, standard)
 {
-    seqan3::structure_file_output fout{ostream, seqan3::format_vienna{}, seqan3::fields<seqan3::field::seq,
-                                                                                        seqan3::field::id,
-                                                                                        seqan3::field::structure,
-                                                                                        seqan3::field::energy>{}};
+    seqan3::structure_file_output fout{
+        ostream,
+        seqan3::format_vienna{},
+        seqan3::fields<seqan3::field::seq, seqan3::field::id, seqan3::field::structure, seqan3::field::energy>{}};
     for (size_t i = 0ul; i < seq.size(); ++i)
         fout.emplace_back(seq[i], id[i], structure[i], energy[i]);
-        //EXPECT_NO_THROW(format.write(ostream, options, seq[i], id[i], ig, structure[i], energy[i], ig, ig, ig, ig));
+    //EXPECT_NO_THROW(format.write(ostream, options, seq[i], id[i], ig, structure[i], energy[i], ig, ig, ig, ig));
 
-    std::string const expected_content
-    {
+    std::string const expected_content{
         "> S.cerevisiae_tRNA-PHE M10740/1-73\n"
         "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
         "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))). (-17.500000)\n"
         "> example 2\n"
         "UUGGAGUACACAACCUGUACACUCUUUC\n"
-        "..(((((..(((...)))..)))))... (-3.710000)\n"
-    };
+        "..(((((..(((...)))..)))))... (-3.710000)\n"};
     ostream.flush();
     EXPECT_EQ(ostream.str(), expected_content);
 }
 
 TEST_F(write, option_precision)
 {
-    seqan3::structure_file_output fout{ostream, seqan3::format_vienna{}, seqan3::fields<seqan3::field::seq,
-                                                                                        seqan3::field::id,
-                                                                                        seqan3::field::structure,
-                                                                                        seqan3::field::energy>{}};
+    seqan3::structure_file_output fout{
+        ostream,
+        seqan3::format_vienna{},
+        seqan3::fields<seqan3::field::seq, seqan3::field::id, seqan3::field::structure, seqan3::field::energy>{}};
     fout.options.precision = 2; // we want 2 digits for energy
     for (size_t i = 0ul; i < seq.size(); ++i)
         fout.emplace_back(seq[i], id[i], structure[i], energy[i]);
 
-    std::string const expected_content
-    {
+    std::string const expected_content{
         "> S.cerevisiae_tRNA-PHE M10740/1-73\n"
         "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
         "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))). (-17.50)\n"
         "> example 2\n"
         "UUGGAGUACACAACCUGUACACUCUUUC\n"
-        "..(((((..(((...)))..)))))... (-3.71)\n"
-    };
+        "..(((((..(((...)))..)))))... (-3.71)\n"};
     ostream.flush();
     EXPECT_EQ(ostream.str(), expected_content);
 }
 
 TEST_F(write, option_add_carriage_return)
 {
-    seqan3::structure_file_output fout{ostream, seqan3::format_vienna{}, seqan3::fields<seqan3::field::seq,
-                                                                                        seqan3::field::id,
-                                                                                        seqan3::field::structure,
-                                                                                        seqan3::field::energy>{}};
+    seqan3::structure_file_output fout{
+        ostream,
+        seqan3::format_vienna{},
+        seqan3::fields<seqan3::field::seq, seqan3::field::id, seqan3::field::structure, seqan3::field::energy>{}};
     fout.options.add_carriage_return = true;
     for (size_t i = 0ul; i < seq.size(); ++i)
         fout.emplace_back(seq[i], id[i], structure[i], energy[i]);
 
-    std::string const expected_content
-    {
+    std::string const expected_content{
         "> S.cerevisiae_tRNA-PHE M10740/1-73\r\n"
         "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\r\n"
         "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))). (-17.500000)\r\n"
         "> example 2\r\n"
         "UUGGAGUACACAACCUGUACACUCUUUC\r\n"
-        "..(((((..(((...)))..)))))... (-3.710000)\r\n"
-    };
+        "..(((((..(((...)))..)))))... (-3.710000)\r\n"};
     ostream.flush();
     EXPECT_EQ(ostream.str(), expected_content);
 }
 
-struct write_fields : public write {};
+struct write_fields : public write
+{};
 
 TEST_F(write_fields, id_missing)
 {
-    seqan3::structure_file_output fout{ostream, seqan3::format_vienna{}, seqan3::fields<seqan3::field::seq,
-                                                                                        seqan3::field::structure,
-                                                                                        seqan3::field::energy>{}};
+    seqan3::structure_file_output fout{
+        ostream,
+        seqan3::format_vienna{},
+        seqan3::fields<seqan3::field::seq, seqan3::field::structure, seqan3::field::energy>{}};
     fout.options.precision = 2; // we want 2 digits for energy
     for (size_t i = 0ul; i < seq.size(); ++i)
         fout.emplace_back(seq[i], structure[i], energy[i]);
 
-    std::string const expected_content
-    {
+    std::string const expected_content{
         "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
         "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))). (-17.50)\n"
         "UUGGAGUACACAACCUGUACACUCUUUC\n"
-        "..(((((..(((...)))..)))))... (-3.71)\n"
-    };
+        "..(((((..(((...)))..)))))... (-3.71)\n"};
     ostream.flush();
     EXPECT_EQ(ostream.str(), expected_content);
 }
 
 TEST_F(write_fields, energy_missing)
 {
-    seqan3::structure_file_output fout{ostream, seqan3::format_vienna{}, seqan3::fields<seqan3::field::seq,
-                                                                                        seqan3::field::id,
-                                                                                        seqan3::field::structure>{}};
+    seqan3::structure_file_output fout{
+        ostream,
+        seqan3::format_vienna{},
+        seqan3::fields<seqan3::field::seq, seqan3::field::id, seqan3::field::structure>{}};
     for (size_t i = 0ul; i < seq.size(); ++i)
         fout.emplace_back(seq[i], id[i], structure[i]);
 
-    std::string const expected_content
-    {
-        "> S.cerevisiae_tRNA-PHE M10740/1-73\n"
-        "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
-        "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))).\n"
-        "> example 2\n"
-        "UUGGAGUACACAACCUGUACACUCUUUC\n"
-        "..(((((..(((...)))..)))))...\n"
-    };
+    std::string const expected_content{"> S.cerevisiae_tRNA-PHE M10740/1-73\n"
+                                       "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
+                                       "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))).\n"
+                                       "> example 2\n"
+                                       "UUGGAGUACACAACCUGUACACUCUUUC\n"
+                                       "..(((((..(((...)))..)))))...\n"};
     ostream.flush();
     EXPECT_EQ(ostream.str(), expected_content);
 }
 
 TEST_F(write_fields, structure_missing)
 {
-    seqan3::structure_file_output fout{ostream, seqan3::format_vienna{}, seqan3::fields<seqan3::field::seq,
-                                                                                        seqan3::field::id,
-                                                                                        seqan3::field::energy>{}};
+    seqan3::structure_file_output fout{ostream,
+                                       seqan3::format_vienna{},
+                                       seqan3::fields<seqan3::field::seq, seqan3::field::id, seqan3::field::energy>{}};
     EXPECT_THROW(fout.emplace_back(seq[0], id[0], energy[0]), std::logic_error);
 }
 
 TEST_F(write_fields, structure_and_energy_missing)
 {
-    seqan3::structure_file_output fout{ostream, seqan3::format_vienna{}, seqan3::fields<seqan3::field::seq,
-                                                                                        seqan3::field::id>{}};
+    seqan3::structure_file_output fout{ostream,
+                                       seqan3::format_vienna{},
+                                       seqan3::fields<seqan3::field::seq, seqan3::field::id>{}};
     for (size_t i = 0ul; i < seq.size(); ++i)
         fout.emplace_back(seq[i], id[i]);
 
-    std::string const expected_content
-    {
-        "> S.cerevisiae_tRNA-PHE M10740/1-73\n"
-        "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
-        "> example 2\n"
-        "UUGGAGUACACAACCUGUACACUCUUUC\n"
-    };
+    std::string const expected_content{"> S.cerevisiae_tRNA-PHE M10740/1-73\n"
+                                       "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
+                                       "> example 2\n"
+                                       "UUGGAGUACACAACCUGUACACUCUUUC\n"};
     ostream.flush();
     EXPECT_EQ(ostream.str(), expected_content);
 }
 
 TEST_F(write_fields, seq_missing)
 {
-    seqan3::structure_file_output fout{ostream, seqan3::format_vienna{}, seqan3::fields<seqan3::field::id,
-                                                                                        seqan3::field::structure,
-                                                                                        seqan3::field::energy>{}};
+    seqan3::structure_file_output fout{
+        ostream,
+        seqan3::format_vienna{},
+        seqan3::fields<seqan3::field::id, seqan3::field::structure, seqan3::field::energy>{}};
     EXPECT_THROW(fout.emplace_back(id[0], structure[0], energy[0]), std::logic_error);
 }
 
 TEST_F(write_fields, seq_empty)
 {
-    seqan3::structure_file_output fout{ostream, seqan3::format_vienna{}, seqan3::fields<seqan3::field::seq,
-                                                                                        seqan3::field::id,
-                                                                                        seqan3::field::structure,
-                                                                                        seqan3::field::energy>{}};
+    seqan3::structure_file_output fout{
+        ostream,
+        seqan3::format_vienna{},
+        seqan3::fields<seqan3::field::seq, seqan3::field::id, seqan3::field::structure, seqan3::field::energy>{}};
     EXPECT_THROW(fout.emplace_back(""_rna5, id[0], structure[0], energy[0]), std::runtime_error);
 }
 
@@ -605,11 +530,8 @@ TEST_F(write_fields, only_seq)
     for (size_t i = 0ul; i < seq.size(); ++i)
         fout.emplace_back(seq[i]);
 
-    std::string const expected_content
-    {
-        "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
-        "UUGGAGUACACAACCUGUACACUCUUUC\n"
-    };
+    std::string const expected_content{"GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
+                                       "UUGGAGUACACAACCUGUACACUCUUUC\n"};
     ostream.flush();
     EXPECT_EQ(ostream.str(), expected_content);
 }
@@ -636,13 +558,10 @@ TEST_F(write_fields, structured_seq)
     for (size_t i = 0ul; i < seq.size(); ++i)
         fout.emplace_back(structured_seq[i]);
 
-    std::string const expected_content
-    {
-        "GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
-        "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))).\n"
-        "UUGGAGUACACAACCUGUACACUCUUUC\n"
-        "..(((((..(((...)))..)))))...\n"
-    };
+    std::string const expected_content{"GCGGAUUUAGCUCAGUUGGGAGAGCGCCAGACUGAAGAUUUGGAGGUCCUGUGUUCGAUCCACAGAAUUCGCA\n"
+                                       "(((((((..((((........)))).((((.........)))).....(((((.......)))))))))))).\n"
+                                       "UUGGAGUACACAACCUGUACACUCUUUC\n"
+                                       "..(((((..(((...)))..)))))...\n"};
     ostream.flush();
     EXPECT_EQ(ostream.str(), expected_content);
 }
