@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -8,8 +8,7 @@
 #include "fm_index_collection_test_template.hpp"
 #include "fm_index_test_template.hpp"
 
-using t1 = std::pair<seqan3::bi_fm_index<unsigned char, seqan3::text_layout::single>,
-                     std::vector<unsigned char>>;
+using t1 = std::pair<seqan3::bi_fm_index<unsigned char, seqan3::text_layout::single>, std::vector<unsigned char>>;
 INSTANTIATE_TYPED_TEST_SUITE_P(char, fm_index_test, t1, );
 using t2 = std::pair<seqan3::bi_fm_index<unsigned char, seqan3::text_layout::collection>,
                      std::vector<std::vector<unsigned char>>>;
