@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -10,9 +10,8 @@
 #include "fm_index_collection_test_template.hpp"
 #include "fm_index_test_template.hpp"
 
-using t1 = std::pair<seqan3::bi_fm_index<seqan3::dna4, seqan3::text_layout::single>,
-                     seqan3::dna4_vector>;
+using t1 = std::pair<seqan3::bi_fm_index<seqan3::dna4, seqan3::text_layout::single>, seqan3::dna4_vector>;
 INSTANTIATE_TYPED_TEST_SUITE_P(dna4, fm_index_test, t1, );
-using t2 = std::pair<seqan3::bi_fm_index<seqan3::dna4, seqan3::text_layout::collection>,
-                     std::vector<seqan3::dna4_vector>>;
+using t2 =
+    std::pair<seqan3::bi_fm_index<seqan3::dna4, seqan3::text_layout::collection>, std::vector<seqan3::dna4_vector>>;
 INSTANTIATE_TYPED_TEST_SUITE_P(dna4_collection, fm_index_collection_test, t2, );
