@@ -1,13 +1,13 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
 
 #include <gtest/gtest.h>
 
-#include <seqan3/std/ranges>
+#include <ranges>
 
 #include <seqan3/test/expect_same_type.hpp>
 #include <seqan3/test/seqan2.hpp>
@@ -15,7 +15,7 @@
 // Note: this file will only test regressions encountered with seqan2 compatibility and has no claim to be complete
 
 #ifdef SEQAN3_HAS_SEQAN2
-#include <seqan/sequence.h>
+#    include <seqan/sequence.h>
 
 template <typename T>
 class seqan2_container : public ::testing::Test
@@ -89,11 +89,14 @@ TYPED_TEST(seqan2_container, std_iterator)
 }
 
 template <typename range_t>
-SEQAN3_CONCEPT SeqAn2Range = requires(range_t range)
-{
-    SEQAN3_RETURN_TYPE_CONSTRAINT(seqan::begin(range), std::same_as, std::ranges::iterator_t<range_t>);
-    SEQAN3_RETURN_TYPE_CONSTRAINT(seqan::end(range), std::same_as, std::ranges::iterator_t<range_t>);
-};
+concept SeqAn2Range = requires (range_t range) {
+                          {
+                              seqan::begin(range)
+                              } -> std::same_as<std::ranges::iterator_t<range_t>>;
+                          {
+                              seqan::end(range)
+                              } -> std::same_as<std::ranges::iterator_t<range_t>>;
+                      };
 
 TYPED_TEST(seqan2_container, seqan_range_concept)
 {
