@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -71,11 +71,11 @@ TEST(tmp_filename_dtr, dtr)
 class read_only_directory
 {
 public:
-    read_only_directory() = delete; //< Deleted.
-    read_only_directory(read_only_directory const &) = delete; //< Deleted.
-    read_only_directory(read_only_directory &&) = default; //< Defaulted.
-    read_only_directory & operator=(read_only_directory const &) = delete; //< Deleted.
-    read_only_directory & operator=(read_only_directory &&) = default; //< Defaulted.
+    read_only_directory() = delete;                                        //!< Deleted.
+    read_only_directory(read_only_directory const &) = delete;             //!< Deleted.
+    read_only_directory(read_only_directory &&) = default;                 //!< Defaulted.
+    read_only_directory & operator=(read_only_directory const &) = delete; //!< Deleted.
+    read_only_directory & operator=(read_only_directory &&) = default;     //!< Defaulted.
 
     /*!\brief Construct a directory from a given path.
      * \throws if std::filesystem::create_directory throws.
