@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -21,11 +21,16 @@ using namespace std::literals;
 template <char char_v>
 struct foo : seqan3::detail::char_predicate_base<foo<char_v>>
 {
-    inline static const std::string msg{std::string{"foo_"} + std::string{char_v}};
+    static inline const std::string msg{std::string{"foo_"} + std::string{char_v}};
 
     using base_t = seqan3::detail::char_predicate_base<foo<char_v>>;
 
-    static auto constexpr data = [] () { typename base_t::data_t d{}; d[char_v] = true; return d; }();
+    static constexpr auto data = []()
+    {
+        typename base_t::data_t d{};
+        d[char_v] = true;
+        return d;
+    }();
 };
 
 template <char char_v>
@@ -57,7 +62,7 @@ TEST(char_predicate, concept)
     using seqan3::operator""_aa27;
 
     EXPECT_TRUE(seqan3::detail::char_predicate<decltype(seqan3::is_char<seqan3::to_char('A'_aa27)>)>);
-    EXPECT_TRUE((seqan3::detail::char_predicate<decltype(seqan3::is_in_interval<'a','z'>)>));
+    EXPECT_TRUE((seqan3::detail::char_predicate<decltype(seqan3::is_in_interval<'a', 'z'>)>));
     EXPECT_TRUE(seqan3::detail::char_predicate<decltype(seqan3::is_space)>);
     EXPECT_TRUE(seqan3::detail::char_predicate<decltype(seqan3::is_blank)>);
     EXPECT_TRUE(seqan3::detail::char_predicate<decltype(seqan3::is_graph)>);
@@ -82,7 +87,7 @@ TEST(char_predicate, char_predicate_disjunction)
     EXPECT_FALSE(cond_t{}('!'));
     EXPECT_FALSE(cond_t{}('1'));
 
-    auto constexpr p = foo_v<'a'> || foo_v<'A'> || foo_v<'0'>;
+    constexpr auto p = foo_v<'a'> || foo_v<'A'> || foo_v<'0'>;
     EXPECT_TRUE(p('a'));
     EXPECT_TRUE(p('A'));
     EXPECT_TRUE(p('0'));
@@ -94,7 +99,7 @@ TEST(char_predicate, char_predicate_disjunction)
 TEST(char_predicate, char_predicate_disjunction_msg)
 {
     using or_t = seqan3::detail::char_predicate_disjunction<foo<'a'>, foo<'A'>, foo<'0'>>;
-    EXPECT_EQ(or_t::msg,   "(foo_a || foo_A || foo_0)"s);
+    EXPECT_EQ(or_t::msg, "(foo_a || foo_A || foo_0)"s);
 }
 
 TEST(char_predicate, is_not)
@@ -104,7 +109,7 @@ TEST(char_predicate, is_not)
     EXPECT_TRUE(cond_t{}('A'));
     EXPECT_TRUE(cond_t{}('0'));
 
-    auto constexpr p = !foo_v<'a'>;
+    constexpr auto p = !foo_v<'a'>;
     EXPECT_FALSE(p('a'));
     EXPECT_TRUE(p('A'));
     EXPECT_TRUE(p('0'));
@@ -118,7 +123,7 @@ TEST(char_predicate, is_not_msg)
 
 TEST(char_predicate, is_in_interval)
 {
-    auto constexpr cond = seqan3::is_in_interval<'a', 'z'>;
+    constexpr auto cond = seqan3::is_in_interval<'a', 'z'>;
     EXPECT_TRUE(cond('a'));
     EXPECT_TRUE(cond('k'));
     EXPECT_TRUE(cond('z'));
@@ -136,13 +141,13 @@ TEST(char_predicate, is_char)
 {
     using seqan3::operator""_aa27;
     {
-        auto constexpr cond = seqan3::is_char<'A'>;
+        constexpr auto cond = seqan3::is_char<'A'>;
         EXPECT_TRUE(cond('A'));
         EXPECT_FALSE(cond('x'));
     }
 
     {
-        auto constexpr cond = seqan3::is_char<seqan3::to_char('A'_aa27)>;
+        constexpr auto cond = seqan3::is_char<seqan3::to_char('A'_aa27)>;
         EXPECT_TRUE(cond('A'));
         EXPECT_FALSE(cond('z'));
     }
@@ -179,7 +184,6 @@ TEST(char_predicate, is_print_msg)
     EXPECT_EQ((seqan3::is_print.message()), "is_in_interval<' ', '~'>"s);
 }
 
-
 TEST(char_predicate, is_blank)
 {
     EXPECT_TRUE(seqan3::is_blank(' '));
@@ -207,8 +211,7 @@ TEST(char_predicate, is_space)
 
 TEST(char_predicate, is_space_msg)
 {
-    EXPECT_EQ((seqan3::is_space.message()),
-              "(is_in_interval<'\t', '\r'> || is_char<' '>)"s);
+    EXPECT_EQ((seqan3::is_space.message()), "(is_in_interval<'\t', '\r'> || is_char<' '>)"s);
 }
 
 TEST(char_predicate, is_punct)
@@ -230,8 +233,9 @@ TEST(char_predicate, is_punct)
 
 TEST(char_predicate, is_punct_msg)
 {
-    EXPECT_EQ((seqan3::is_punct.message()),
-              "(((is_in_interval<'!', '/'> || is_in_interval<':', '@'>) || is_in_interval<'[', '`'>) || is_in_interval<'{', '~'>)"s);
+    EXPECT_EQ(
+        (seqan3::is_punct.message()),
+        "(((is_in_interval<'!', '/'> || is_in_interval<':', '@'>) || is_in_interval<'[', '`'>) || is_in_interval<'{', '~'>)"s);
 }
 
 TEST(char_predicate, is_alpha)
@@ -248,8 +252,7 @@ TEST(char_predicate, is_alpha)
 
 TEST(char_predicate, is_alpha_msg)
 {
-    EXPECT_EQ((seqan3::is_alpha.message()),
-              "(is_in_interval<'A', 'Z'> || is_in_interval<'a', 'z'>)"s);
+    EXPECT_EQ((seqan3::is_alpha.message()), "(is_in_interval<'A', 'Z'> || is_in_interval<'a', 'z'>)"s);
 }
 
 TEST(char_predicate, is_upper)
@@ -326,7 +329,8 @@ TEST(char_predicate, is_xdigit)
 
 TEST(char_predicate, is_xdigit_msg)
 {
-    EXPECT_EQ((seqan3::is_xdigit.message()), "((is_in_interval<'0', '9'> || is_in_interval<'A', 'F'>) || is_in_interval<'a', 'f'>)"s);
+    EXPECT_EQ((seqan3::is_xdigit.message()),
+              "((is_in_interval<'0', '9'> || is_in_interval<'A', 'F'>) || is_in_interval<'a', 'f'>)"s);
 }
 
 TEST(char_predicate, is_alnum)
@@ -344,7 +348,8 @@ TEST(char_predicate, is_alnum)
 
 TEST(char_predicate, is_alnum_msg)
 {
-    EXPECT_EQ((seqan3::is_alnum.message()), "((is_in_interval<'0', '9'> || is_in_interval<'A', 'Z'>) || is_in_interval<'a', 'z'>)"s);
+    EXPECT_EQ((seqan3::is_alnum.message()),
+              "((is_in_interval<'0', '9'> || is_in_interval<'A', 'Z'>) || is_in_interval<'a', 'z'>)"s);
 }
 
 TEST(char_predicate, is_graph)
@@ -368,7 +373,7 @@ TEST(char_predicate, is_graph_msg)
 
 TEST(char_predicate, char_types)
 {
-    {  // is_char
+    { // is_char
         char c1 = '\t';
         EXPECT_TRUE(seqan3::is_char<'\t'>(c1));
         char16_t c2 = '\t';
@@ -377,11 +382,11 @@ TEST(char_predicate, char_types)
         EXPECT_TRUE(seqan3::is_char<'\t'>(c3));
     }
 
-    {  // check value out of range.
+    { // check value out of range.
         EXPECT_FALSE(seqan3::is_char<'\t'>(char16_t{256}));
     }
 
-    {  // is_in_interval
+    { // is_in_interval
         char c1 = 'n';
         EXPECT_TRUE((seqan3::is_in_interval<'a', 'z'>(c1)));
         char16_t c2 = 'n';
@@ -390,7 +395,7 @@ TEST(char_predicate, char_types)
         EXPECT_TRUE((seqan3::is_in_interval<'a', 'z'>(c3)));
     }
 
-    {  // check value out of range.
+    { // check value out of range.
         EXPECT_FALSE((seqan3::is_in_interval<'a', 'z'>(char16_t{256})));
     }
 }
@@ -398,8 +403,8 @@ TEST(char_predicate, char_types)
 // see issue https://github.com/seqan/seqan3/issues/1972
 TEST(char_predicate, issue1972)
 {
-    EXPECT_TRUE(seqan3::char_is_valid_for<seqan3::gapped<seqan3::rna5>>('A')); // valid seqan3::rna5 char
-    EXPECT_TRUE(seqan3::char_is_valid_for<seqan3::gapped<seqan3::rna5>>('a')); // valid seqan3::rna5 char
-    EXPECT_TRUE(seqan3::char_is_valid_for<seqan3::gapped<seqan3::rna5>>('-')); // valid seqan3::gap char
+    EXPECT_TRUE(seqan3::char_is_valid_for<seqan3::gapped<seqan3::rna5>>('A'));  // valid seqan3::rna5 char
+    EXPECT_TRUE(seqan3::char_is_valid_for<seqan3::gapped<seqan3::rna5>>('a'));  // valid seqan3::rna5 char
+    EXPECT_TRUE(seqan3::char_is_valid_for<seqan3::gapped<seqan3::rna5>>('-'));  // valid seqan3::gap char
     EXPECT_FALSE(seqan3::char_is_valid_for<seqan3::gapped<seqan3::rna5>>('S')); // neither seqan3::rna5 nor seqan3::gap
 }
