@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -14,9 +14,8 @@
 #include <seqan3/utility/simd/detail/builtin_simd.hpp>
 #include <seqan3/utility/simd/detail/default_simd_backend.hpp>
 
-
 TEST(default_simd_backend, test)
 {
-    EXPECT_TRUE((std::is_same_v<seqan3::detail::default_simd_backend<int16_t, 8>,
-                                seqan3::detail::builtin_simd<int16_t, 8>>));
+    EXPECT_TRUE(
+        (std::is_same_v<seqan3::detail::default_simd_backend<int16_t, 8>, seqan3::detail::builtin_simd<int16_t, 8>>));
 }
